<?php
// Register a blog posts block for Gutenberg.
add_filter( 'rwmb_meta_boxes', function( $meta_boxes ) {

	// get petition categories
	$category_options = array();
	$categories =  get_terms( array(
		'taxonomy' => 'category',
		'hide_empty' => false,
	) );

	foreach ($categories as $category) {
		$category_options[$category->term_id] = $category->name;
	}

	// get petition tags
	$tags_options = array();
	$tags =  get_terms( array(
		'taxonomy' => 'post_tag',
		'hide_empty' => false,
	) );

	foreach ($tags as $tag) {
		$tags_options[$tag->term_id] = $tag->name;
	}

	$meta_boxes[] = [
		'title' => esc_html__('Blog Posts', 'campoal-tapo'),
		'id'    => 'blog-posts',
		'type'  => 'block', // Important.
		'mode' 	=> 'edit',
		// 'icon'  => 'awards', // Or you can set a custom SVG if you don't like Dashicons
		'icon'  => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><!-- Font Awesome Pro 5.15.4 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) --><defs><style>.fa-secondary{opacity:.4}</style></defs><path d="M511.9 303C503.4 139.82 372.2 8.62 209 0a16.1 16.1 0 0 0-17 16v31.6a15.84 15.84 0 0 0 15 15.9c129.4 7 233.4 112 240.9 241.5a16 16 0 0 0 15.9 15h32.1a16.1 16.1 0 0 0 16-17zM209.3 96a16.13 16.13 0 0 0-17.3 16.1v32.1a15.94 15.94 0 0 0 14.8 15.9c76.8 6.3 138 68.2 144.9 145.2a16.07 16.07 0 0 0 15.9 14.7h32.2a16.19 16.19 0 0 0 16.1-17.3C407.5 192.62 319.4 104.52 209.3 96z" class="fa-secondary"/><path d="M172.2 226.82c75.5 15 129.9 89.3 112.5 172.2-11.4 54.3-55.3 98.3-109.7 109.7C82.1 528.22 0 457.52 0 368V120a23.94 23.94 0 0 1 24-24h48a23.94 23.94 0 0 1 24 24v248a48 48 0 1 0 64.7-45c-9.6-3.6-16.7-11.8-16.7-22v-50.4c0-14.9 13.6-26.7 28.2-23.8z" class="fa-primary"/></svg>',
		'category' => 'campoal',
		'context' => 'side', // The block settings will be available on the right sidebar.
		'supports' => [
			'align' => ['wide', 'full'],
		],
		// 'render_callback' => 'conikal_featured_posts_shortcode',
		'render_template' => plugin_dir_path( __FILE__ ) . 'template.php', // The PHP template that renders the block.
		// 'enqueue_style'   => plugin_dir_path( __FILE__ ) . 'style.css', // CSS file for the block.

		// Now register the block fields.
		'fields' => [
			[
				'type' 			=> 'text',
				'id'   			=> 'title',
				'name' 			=> esc_html__('Section Title', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter a title', 'campoal-tapo'),
			],
			[
				'type' 			=> 'button_group',
				'id'   			=> 'title_alignment',
				'name' 			=> esc_html__('Title Alignment', 'campoal-tapo'),
				'options' => array(
					'left' 			=> '<span class="dashicons dashicons-editor-alignleft"></span>',
					'center' 		=> '<span class="dashicons dashicons-editor-aligncenter"></span>',
					'right' 		=> '<span class="dashicons dashicons-editor-alignright"></span>',
				),
				'inline'   => true,
			],
			[
				'type' => 'select',
				'id'   => 'type',
				'name' => esc_html__('Type', 'campoal-tapo'),
				'options' => array(
					'recent' 			=> esc_html__('Recent', 'campoal-tapo'),
					'featured' 			=> esc_html__('Featured', 'campoal-tapo'),
					'by_id' 			=> esc_html__('Post by IDs', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 			=> 'number',
				'id'   			=> 'show',
				'name' 			=> esc_html__('Show', 'campoal-tapo'),
				'placeholder'	=> esc_html__('Number of posts display', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'column',
				'name' => esc_html__('Column', 'campoal-tapo'),
				'options' => array(
					'two' 	=> '2',
					'three' => '3',
					'four' 	=> '4',
				),
				'placeholder'     => esc_html__('Select an number', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'orderby',
				'name' => 'Order by',
				'options' => array(
					'none' 			=> esc_html__('None', 'campoal-tapo'),
					'ID' 			=> esc_html__('ID', 'campoal-tapo'),
					'author' 		=> esc_html__('Author', 'campoal-tapo'),
					'title' 		=> esc_html__('Title', 'campoal-tapo'),
					'name' 			=> esc_html__('Name', 'campoal-tapo'),
					'date' 			=> esc_html__('Date', 'campoal-tapo'),
					'modified' 		=> esc_html__('Modified', 'campoal-tapo'),
					'rand' 			=> esc_html__('Random', 'campoal-tapo'),
					'comment_count'	=> esc_html__('Comment count', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'order',
				'name' => esc_html__('Order', 'campoal-tapo'),
				'options' => array(
					'ASC' 	=> esc_html__('Ascending', 'campoal-tapo'),
					'DESC' 	=> esc_html__('Descending', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'categories',
				'name' 		=> esc_html__('Categories', 'campoal-tapo'),
				'options' 	=> $category_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'tags',
				'name' 		=> esc_html__('Tags', 'campoal-tapo'),
				'options' 	=> $tags_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'carousel',
				'name' => esc_html__('Carousel', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'hover',
				'name' => esc_html__('Shadow', 'campoal-tapo'),
			],
			[
				'type' 			=> 'text',
				'id'   			=> 'post_ids',
				'name' 			=> esc_html__('Post IDs', 'campoal-tapo'),
				'placeholder'   => esc_html__('Optional (separated by commas)', 'campoal-tapo'),
			],
		],
	];
	return $meta_boxes;
} );
