<?php
/**
 * The template file to display the block.
 *
 * Available parameters:
 * @param array $attributes The block attributes.
 * @param bool  $is_preview Whether in the preview mode.
 */

// Fields data.
if ( empty( $attributes['data'] ) ) {
	return;
}
// Unique HTML ID if available.
$block_id = 'campoal-blog-posts-' . ( $attributes['id'] ?? '' );
if ( ! empty( $attributes['anchor'] ) ) {
	$block_id = $attributes['anchor'];
}

// Custom CSS class name.
$class = 'campoal-blog-posts ' . ( $attributes['className'] ?? '' );
if ( ! empty( $attributes['align'] ) ) {
	$class .= " align{$attributes['align']}";
}

extract(shortcode_atts(array(
	'title' 		=> '',
	'type'			=> 'recent',
	'show' 			=> '4',
	'categories' 	=> '',
	'tags'			=> '',
	'carousel'		=> 'no',
	'column' 		=> 'four',
	'orderby' 		=> 'date',
	'order' 		=> 'DESC',
	'hover' 		=> false,
	'post_ids' 		=> '',
), $attributes['data']));

$show = conikal_show_number_block_preview($is_preview, $carousel, $column, $show);
$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

$args = array(
	'posts_per_page'    => $show,
    'paged'             => $paged,
	'post_type'     	=> 'post',
	'orderby'       	=> $orderby,
	'order'         	=> $order,
	'post_status'   	=> 'publish');

if ( $type == 'by_id' && !empty($post_ids) ) {
	$post_ids = array_map('intval', explode(',', $post_ids));
	$args['post__in'] = $post_ids;
}

$args['tax_query'] = array('relation' => 'OR');
if (!empty($categories)) {
	array_push($args['tax_query'], array(
		'taxonomy' => 'category',
		'terms'    => $categories,
	));
}

if (!empty($tags)) {
	array_push($args['tax_query'], array(
		'taxonomy' => 'post_tag',
		'terms'    => $tags,
	));
}

if ($type == 'featured') {
	$args['meta_query'] = array('relation' => 'AND');
	array_push($args['meta_query'], array(
		'key'     => 'post_featured',
		'value'   => '1',
		'compare' => '=='
	));
}
$posts = new WP_Query($args);

$return_string = conikal_shortcode_loop_post($posts, $attributes['data'], null);

wp_reset_postdata();
wp_reset_query();
?>
<div id="<?= $block_id ?>" class="<?= $class ?>">
	<?php echo $return_string; ?>
</div>
