<?php
// Register a category block block for Gutenberg.
add_filter( 'rwmb_meta_boxes', function( $meta_boxes ) {

	// get petition category
	$category_options = array();
	$categories =  get_terms( array(
		'taxonomy' => 'petition_category',
		'hide_empty' => false,
	) );

	foreach ($categories as $category) {
		$category_options[$category->term_id] = $category->name;
	}

	// get petition topcis
	$topics_options = array();
	$topics =  get_terms( array(
		'taxonomy' => 'petition_topics',
		'hide_empty' => false,
	) );

	foreach ($topics as $topic) {
		$topics_options[$topic->term_id] = $topic->name;
	}

	$meta_boxes[] = [
		'title' => esc_html__('Category Grid', 'campoal-tapo'),
		'id'    => 'category-grid',
		'type'  => 'block', // Important.
		'mode' 	=> 'edit',
		// 'icon'  => 'awards', // Or you can set a custom SVG if you don't like Dashicons
		'icon'  => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><!-- Font Awesome Pro 5.15.4 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) --><defs><style>.fa-secondary{opacity:.4}</style></defs><path d="M306.67 352H205.33a24 24 0 0 0-24 24v80a24 24 0 0 0 24 24h101.34a24 24 0 0 0 24-24v-80a24 24 0 0 0-24-24zM488 192H386.67a24 24 0 0 0-24 24v80a24 24 0 0 0 24 24H488a24 24 0 0 0 24-24v-80a24 24 0 0 0-24-24zM306.67 32H205.33a24 24 0 0 0-24 24v80a24 24 0 0 0 24 24h101.34a24 24 0 0 0 24-24V56a24 24 0 0 0-24-24zM125.33 192H24a24 24 0 0 0-24 24v80a24 24 0 0 0 24 24h101.33a24 24 0 0 0 24-24v-80a24 24 0 0 0-24-24z" class="fa-secondary"/><path d="M488 352H386.67a24 24 0 0 0-24 24v80a24 24 0 0 0 24 24H488a24 24 0 0 0 24-24v-80a24 24 0 0 0-24-24zM306.67 192H205.33a24 24 0 0 0-24 24v80a24 24 0 0 0 24 24h101.34a24 24 0 0 0 24-24v-80a24 24 0 0 0-24-24zM488 32H386.67a24 24 0 0 0-24 24v80a24 24 0 0 0 24 24H488a24 24 0 0 0 24-24V56a24 24 0 0 0-24-24zm-362.67 0H24A24 24 0 0 0 0 56v80a24 24 0 0 0 24 24h101.33a24 24 0 0 0 24-24V56a24 24 0 0 0-24-24zm0 320H24a24 24 0 0 0-24 24v80a24 24 0 0 0 24 24h101.33a24 24 0 0 0 24-24v-80a24 24 0 0 0-24-24z" class="fa-primary"/></svg>',
		'category' => 'campoal',
		'context' => 'side', // The block settings will be available on the right sidebar.
		'supports' => [
			'align' => ['wide', 'full'],
		],
		// 'render_callback' => 'conikal_featured_posts_shortcode',
		'render_template' => plugin_dir_path( __FILE__ ) . 'template.php', // The PHP template that renders the block.
		// 'enqueue_style'   => plugin_dir_path( __FILE__ ) . 'style.css', // CSS file for the block.

		// Now register the block fields.
		'fields' => [
			[
				'type' 			=> 'text',
				'id'   			=> 'title',
				'name' 			=> esc_html__('Section Title', 'campoal-tapo'),
				'placeholder'   => esc_html__('Enter a title', 'campoal-tapo'),
			],
			[
				'type' 			=> 'button_group',
				'id'   			=> 'title_alignment',
				'name' 			=> esc_html__('Title Alignment', 'campoal-tapo'),
				'options' => array(
					'left' 			=> '<span class="dashicons dashicons-editor-alignleft"></span>',
					'center' 		=> '<span class="dashicons dashicons-editor-aligncenter"></span>',
					'right' 		=> '<span class="dashicons dashicons-editor-alignright"></span>',
				),
				'inline'   => true,
			],
			[
				'type' => 'select',
				'id'   => 'type',
				'name' => esc_html__('Type', 'campoal-tapo'),
				'options' => array(
					'category'	=> esc_html__('Category', 'campoal-tapo'),
					'topics' 	=> esc_html__('Topics', 'campoal-tapo'),
					'by_id' 			=> esc_html__('By ID or Slug', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 			=> 'number',
				'id'   			=> 'show',
				'name' 			=> esc_html__('Show', 'campoal-tapo'),
				'placeholder'	=> esc_html__('Number of posts display', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'orderby',
				'name' => 'Order by',
				'options' => array(
					'name' 			=> esc_html__('Name', 'campoal-tapo'),
					'id' 			=> esc_html__('ID', 'campoal-tapo'),
					'slug' 			=> esc_html__('Slug', 'campoal-tapo'),
					'term_group' 	=> esc_html__('Term Group', 'campoal-tapo'),
					'term_id' 		=> esc_html__('Term ID', 'campoal-tapo'),
					'description' 	=> esc_html__('Description', 'campoal-tapo'),
					'parent' 		=> esc_html__('Parent', 'campoal-tapo'),
					'term_order' 	=> esc_html__('Term order', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'order',
				'name' => esc_html__('Order', 'campoal-tapo'),
				'options' => array(
					'ASC' 	=> esc_html__('Ascending', 'campoal-tapo'),
					'DESC' 	=> esc_html__('Descending', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'categories',
				'name' 		=> esc_html__('Categories', 'campoal-tapo'),
				'options' 	=> $category_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'topics',
				'name' 		=> esc_html__('Topics', 'campoal-tapo'),
				'options' 	=> $topics_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'exclude_selected',
				'name' => esc_html__('Exclude Selected', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'hide_empty',
				'name' => esc_html__('Hide Empty', 'campoal-tapo'),
			],
			[
				'type' 			=> 'text',
				'id'   			=> 'slugs',
				'name' 			=> esc_html__('Category IDs or slugs', 'campoal-tapo'),
				'placeholder'   => esc_html__('Optional (separated by commas)', 'campoal-tapo'),
			],
		],
	];
	return $meta_boxes;
} );
