<?php
// Register a topic cards block for Gutenberg.

add_filter( 'rwmb_meta_boxes', function( $meta_boxes ) {
	// get petition category
	$category_options = array();
	$categories =  get_terms( array(
		'taxonomy' => 'petition_category',
		'hide_empty' => false,
	) );

	foreach ($categories as $category) {
		$category_options[$category->term_id] = $category->name;
	}

	// get petition topcis
	$topics_options = array();
	$topics =  get_terms( array(
		'taxonomy' => 'petition_topics',
		'hide_empty' => false,
	) );

	foreach ($topics as $topic) {
		$topics_options[$topic->term_id] = $topic->name;
	}

	$meta_boxes[] = [
		'title' => esc_html__('Topic Cards', 'campoal-tapo'),
		'id'    => 'topic-cards',
		'type'  => 'block', // Important.
		'mode' 	=> 'edit',
		// 'icon'  => 'awards', // Or you can set a custom SVG if you don't like Dashicons
		'icon'  => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 576 512"><!-- Font Awesome Pro 5.15.4 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) --><defs><style>.fa-secondary{opacity:.4}</style></defs><path d="M340 352H204a12 12 0 0 0-12 12v40a12 12 0 0 0 12 12h136a12 12 0 0 0 12-12v-40a12 12 0 0 0-12-12zm-192 0H76a12 12 0 0 0-12 12v40a12 12 0 0 0 12 12h72a12 12 0 0 0 12-12v-40a12 12 0 0 0-12-12z" class="fa-secondary"/><path d="M528 32H48A48 48 0 0 0 0 80v352a48 48 0 0 0 48 48h480a48 48 0 0 0 48-48V80a48 48 0 0 0-48-48zM160 404a12 12 0 0 1-12 12H76a12 12 0 0 1-12-12v-40a12 12 0 0 1 12-12h72a12 12 0 0 1 12 12zm192 0a12 12 0 0 1-12 12H204a12 12 0 0 1-12-12v-40a12 12 0 0 1 12-12h136a12 12 0 0 1 12 12z" class="fa-primary"/></svg>',
		'category' => 'campoal',
		'context' => 'side', // The block settings will be available on the right sidebar.
		'supports' => [
			'align' => ['wide', 'full'],
		],
		// 'render_callback' => 'conikal_featured_posts_shortcode',
		'render_template' => plugin_dir_path( __FILE__ ) . 'template.php', // The PHP template that renders the block.
		// 'enqueue_style'   => plugin_dir_path( __FILE__ ) . 'style.css', // CSS file for the block.

		// Now register the block fields.
		'fields' => [
			[
				'type' => 'select',
				'id'   => 'type',
				'name' => esc_html__('Type', 'campoal-tapo'),
				'options' => array(
					'petition_topics' 	=> esc_html__('Topics', 'campoal-tapo'),
					'petition_category' => esc_html__('Category', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 			=> 'number',
				'id'   			=> 'show',
				'name' 			=> esc_html__('Show', 'campoal-tapo'),
				'placeholder'	=> esc_html__('Number of posts display', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'orderby',
				'name' => 'Order by',
				'options' => array(
					'id' 		=> esc_html__('ID', 'campoal-tapo'), 
					'count' 	=> esc_html__('Count', 'campoal-tapo'), 
					'name' 		=> esc_html__('Name', 'campoal-tapo'),
					// 'rand' 		=> esc_html__('Random', 'campoal-tapo')
				),
				'placeholder'     	=> esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' => 'select',
				'id'   => 'order',
				'name' => esc_html__('Order', 'campoal-tapo'),
				'options' => array(
					'ASC' 		=> esc_html__('Ascending', 'campoal-tapo'),
					'DESC' 		=> esc_html__('Descending', 'campoal-tapo'),
				),
				'placeholder'     => esc_html__('Default', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'categories',
				'name' 		=> esc_html__('Categories', 'campoal-tapo'),
				'options' 	=> $category_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' 		=> 'select',
				'id'   		=> 'topics',
				'name' 		=> esc_html__('Topics', 'campoal-tapo'),
				'options' 	=> $topics_options,
				'multiple'        => true,
				'select_all_none' => true,
				'placeholder'     => esc_html__('All', 'campoal-tapo'),
			],
			[
				'type' 			=> 'text',
				'id'   			=> 'slugs',
				'name' 			=> esc_html__('Topics IDs or Slugs', 'campoal-tapo'),
				'placeholder'   => esc_html__('Optional (separated by commas)', 'campoal-tapo'),
			],
			[
				'type' => 'checkbox',
				'id'   => 'show_empty',
				'name' => esc_html__('Show empty', 'campoal-tapo'),
			],
		],
	];
	return $meta_boxes;
} );
