<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Basic variable for email template
 */
if (!function_exists('conikal_basic_variables_email')) : 
    function conikal_basic_variables_email() {
        global $campoal_options;

        $email_logo                       = isset($campoal_options['conikal_email_logo_field']['url']) ? $campoal_options['conikal_email_logo_field']['url'] : '';
        $main_color                 = isset($campoal_options['conikal_main_color_field']) ? $campoal_options['conikal_main_color_field'] : '#0065FF';
        $segment_bg_color           = isset($campoal_options['conikal_segment_bg_color_field']) ? $campoal_options['conikal_segment_bg_color_field'] : '#F4F5F8';
        $heading_color              = isset($campoal_options['conikal_heading_color_field']) ? $campoal_options['conikal_heading_color_field'] : '#172B4D';
        $subheading_color           = isset($campoal_options['conikal_subheading_color_field']) ? $campoal_options['conikal_subheading_color_field'] : '#9e9e9e';

        // find custom variables in email template
        $vars_find     = array(
            '%home_url%', 
            '%logo_url%', 
            '%blog_name%',
            '%main_color%',
            '%segment_color%',
            '%heading_color%',
            '%subheading_color%',
            '%template_uri%',
        );

        // replace variables with value in email template
        $vars_replace  = array(
            home_url('/'), 
            esc_url($email_logo), 
            get_bloginfo('name'), 
            esc_html($main_color),
            esc_html($segment_bg_color),
            esc_html($heading_color),
            esc_html($subheading_color),
            get_template_directory_uri(),
        );

        $email_vars = array();
        $email_vars['find'] = $vars_find;
        $email_vars['replace'] = $vars_replace;
    
        return $email_vars;
    }
endif;

/**
 * Replacing custom email template with general email template
 */
if( !function_exists('conikal_apply_general_template') ): 
    function conikal_apply_general_template($email_subject, $email_content) {
        global $campoal_options;
        $enable_general_email_template = isset($campoal_options['conikal_enable_general_email_template_field']) ? $campoal_options['conikal_enable_general_email_template_field'] : '';
        $general_email_template = isset($campoal_options['conikal_general_email_template_field']) ? $campoal_options['conikal_general_email_template_field'] : conikal_general_email_template();

        if (empty($email_subject) || empty($email_content)) {
            return;
        }

        if ($enable_general_email_template) {
            // custom variables
            $vars_find     = array(
                '%email_subject%',
                '%email_content%' 
            );
            $vars_replace  = array(
                $email_subject,
                $email_content
            );

            $email_vars = conikal_basic_variables_email();
            $vars_find = array_merge($email_vars['find'], $vars_find);
            $vars_replace = array_merge($email_vars['replace'], $vars_replace);

            // replace custom email with genetal template
            $email_template = str_replace($vars_find, $vars_replace, $general_email_template);
        } else {
            $email_template = $email_content;
        }

        return $email_template;
    }
endif;


/**
 * Admin notification when new comment submitted
 */
if( !function_exists('conikal_admin_new_comment_notification') ): 
    function conikal_admin_new_comment_notification($post_id, $comment_id) {
        global $campoal_options;
        $admin_new_comment_subject = isset($campoal_options['conikal_admin_new_comment_subject_field']) ? $campoal_options['conikal_admin_new_comment_subject_field'] : esc_html__('A New Commment Submitted', 'campoal-tapo');
        $admin_new_comment_template = isset($campoal_options['conikal_admin_new_comment_template_field']) ? $campoal_options['conikal_admin_new_comment_template_field'] : '';
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;
        
        $title = get_the_title($post_id);
        $link = get_permalink($post_id);
        $comment = get_comment($comment_id);

        // custom comment variables
        $vars_find     = array(
            '%post_title%', 
            '%comment_author%', 
            '%comment_author_email%', 
            '%comment_author_IP%',
            '%comment_agent%',
            '%comment_author_url%', 
            '%comment_content%',
            '%comment_link%',
        );
        $vars_replace  = array(
            esc_html($title),
            esc_html($comment->comment_author),
            esc_html($comment->comment_author_email),
            esc_html($comment->comment_author_IP),
            esc_html($comment->comment_agent),
            esc_url($comment->comment_author_url),
            esc_html($comment->comment_content),
            esc_url($link),
        );

        // add commment variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        // replace variables in template with values
        $subject = $admin_new_comment_subject;
        $subject = str_replace($vars_find, $vars_replace, $subject);
        $message = str_replace($vars_find, $vars_replace, $admin_new_comment_template);
        $message = conikal_apply_general_template($subject, $message);

        // header for email, it's not required you can remove that
        $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();

        $sent = wp_mail(
            get_option('admin_email'),
            sprintf(esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject)),
            $message,
            ($email_header ? $headers : '')
        );

        return $sent;
    }
endif;


/**
 * Admin notification when new contribute submitted
 */
if( !function_exists('conikal_admin_contribute_notification') ): 
    function conikal_admin_contribute_notification($form_id, $petition_id, $user_id, $edit) {
        global $campoal_options;
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $admin_contribute_submit_subject = isset($campoal_options['conikal_admin_contribute_submit_subject_field']) ? $campoal_options['conikal_admin_contribute_submit_subject_field'] : esc_html__('A Contribute Submitted', 'campoal-tapo');
        $admin_contribute_update_subject = isset($campoal_options['conikal_admin_contribute_update_subject_field']) ? $campoal_options['conikal_admin_contribute_update_subject_field'] : esc_html__('A Contribute Changed', 'campoal-tapo');
        $admin_contribute_submit_template = isset($campoal_options['conikal_admin_contribute_submit_template_field']) ? $campoal_options['conikal_admin_contribute_submit_template_field'] : '';
        $admin_contribute_update_template = isset($campoal_options['conikal_admin_contribute_update_template_field']) ? $campoal_options['conikal_admin_contribute_update_template_field'] : '';
        $email_new_contribute = isset($campoal_options['conikal_new_contribute_field']) ? $campoal_options['conikal_new_contribute_field'] : 0;
        $email_edit_contribute = isset($campoal_options['conikal_edit_contribute_field']) ? $campoal_options['conikal_edit_contribute_field'] : 0;
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        if (empty($petition_id) || $petition_id == $form_id) {
            $admin_contribute_submit_subject = isset($campoal_options['conikal_admin_crowdfunding_submit_subject_field']) ? $campoal_options['conikal_admin_crowdfunding_submit_subject_field'] : esc_html__('A Crowdfunding Submitted', 'campoal-tapo');
            $admin_contribute_update_subject = isset($campoal_options['conikal_admin_crowdfunding_update_subject_field']) ? $campoal_options['conikal_admin_crowdfunding_update_subject_field'] : esc_html__('A Contribute Changed', 'campoal-tapo');
            $admin_contribute_submit_template = isset($campoal_options['conikal_admin_crowdfunding_submit_template_field']) ? $campoal_options['conikal_admin_crowdfunding_submit_template_field'] : conikal_admin_crowdfunding_submit_template();
            $admin_contribute_update_template = isset($campoal_options['conikal_admin_crowdfunding_update_template_field']) ? $campoal_options['conikal_admin_crowdfunding_update_template_field'] : conikal_admin_crowdfunding_update_template();
            $new_crowdfunding_confirm_subject = isset($campoal_options['conikal_email_new_crowdfunding_confirm_subject_field']) ? $campoal_options['conikal_email_new_crowdfunding_confirm_subject_field'] : esc_html__('Your crowdfunding submited successfully %crowdfunding_title%', 'campoal-tapo');
            $new_crowdfunding_confirm_template = isset($campoal_options['conikal_email_new_crowdfunding_confirm_template_field']) ? $campoal_options['conikal_email_new_crowdfunding_confirm_template_field'] : conikal_email_new_crowdfunding_confirm_template();
            $email_new_contribute = isset($campoal_options['conikal_new_crowdfunding_field']) ? $campoal_options['conikal_new_crowdfunding_field'] : 1;
            $email_edit_contribute = isset($campoal_options['conikal_edit_crowdfunding_field']) ? $campoal_options['conikal_edit_crowdfunding_field'] : 0;
            $email_crowdfunding_confirm = isset($campoal_options['conikal_new_crowdfunding_confirm_field']) ? $campoal_options['conikal_new_crowdfunding_confirm_field'] : 1;
        }

        $user_info          = get_userdata($user_id);
        $petition_title     = get_the_title($petition_id);
        $petition_link      = get_permalink($petition_id);
        $contribute_title   = get_the_title($form_id);
        $contribute_link    = get_permalink($form_id);
        $thumbnail          = conikal_get_petition_thumbnail($form_id, 'large', 'thumbnail');

        // set current user is admin
        wp_set_current_user(1);
        $post_edit_link     = get_edit_post_link($form_id);

        // custom comment variables
        $vars_find     = array(
            '%petition_title%', 
            '%petition_link%',
            '%crowdfunding_title%', 
            '%crowdfunding_link%',
            '%crowdfunding_thumbnail%',
            '%contribute_title%', 
            '%contribute_link%',
            '%author_name%', 
            '%author_email%',
            '%author_url%',
            '%post_edit_link%', 
        );
        $vars_replace  = array(
            esc_html($petition_title),
            esc_html($petition_link),
            esc_html($contribute_title),
            esc_html($contribute_link),
            esc_url($thumbnail),
            esc_html($contribute_title),
            esc_html($contribute_link),
            esc_html($user_info->display_name),
            esc_html($user_info->user_email),
            esc_url(get_author_posts_url($user_info->ID, $user_info->user_nicename)),
            esc_url($post_edit_link),
        );

        // add commment variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();

        // Send confirm crowdfunding confirm
        if ($edit == '' && empty($petition_id) && $email_crowdfunding_confirm == 1) {
            // replace variables in template with values
            $subject_confirm = $new_crowdfunding_confirm_subject;
            $subject_confirm = str_replace($vars_find, $vars_replace, $subject_confirm);
            $message_confirm = str_replace($vars_find, $vars_replace, $new_crowdfunding_confirm_template);
            $message_confirm = conikal_apply_general_template($subject_confirm, $message_confirm);
            
            $sent_confirm = wp_mail(
                $user_info->user_email,
                sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject_confirm) ),
                $message_confirm,
                ($email_header ? $headers : '')
            );
        }

        if($edit == '' && $email_new_contribute == 1) {
            // replace variables in template with values
            $message = str_replace($vars_find, $vars_replace, $admin_contribute_submit_template);
            $subject = $admin_contribute_submit_subject;
        } else if ($email_edit_contribute == 1) { 
            // replace variables in template with values
            $message = str_replace($vars_find, $vars_replace, $admin_contribute_update_template);
            $subject = $admin_contribute_update_subject;
        } else {
            return false;
        }

        // apply general emai template for email
        $subject = str_replace($vars_find, $vars_replace, $subject);
        $message = conikal_apply_general_template($subject, $message);

        $sent = wp_mail(
            get_option('admin_email'),
            sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
            $message,
            ($email_header ? $headers : '')
        );

        return $sent;
    }
endif;

/**
 * Petition owner notification when new petition submitted successfully
 */
if( !function_exists('conikal_petition_confirm_notification') ): 
    function conikal_petition_confirm_notification($petition_id, $user_id, $edit) {
        global $campoal_options;
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $email_new_petition_confirm = isset($campoal_options['conikal_new_petition_confirm_field']) ? $campoal_options['conikal_new_petition_confirm_field'] : 0;
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        // check send email sending is enable or not
        if (empty($edit) && $email_new_petition_confirm == 1) {
            $email_new_petition_confirm_subject = isset($campoal_options['conikal_email_new_petition_confirm_subject_field']) ? $campoal_options['conikal_email_new_petition_confirm_subject_field'] : esc_html__('Your petition submited successfully: %petition_title%', 'campoal-tapo');
            $email_new_petition_confirm_template = isset($campoal_options['conikal_email_new_petition_confirm_template_field']) ? $campoal_options['conikal_email_new_petition_confirm_template_field'] : 0;

            // petition dashboard link
            $page_dashboard_petition = isset($campoal_options['conikal_page_dashboard_petition_field']) ? $campoal_options['conikal_page_dashboard_petition_field'] : 0;
            $page_dashboard_petition = get_permalink($page_dashboard_petition);
            $page_dashboard = $page_dashboard_petition ? add_query_arg(array('section' => 'dashboard', 'id' => $petition_id), $page_dashboard_petition) : '';

            // get supporter user info
            $user_info          = get_userdata($user_id);

            // get author email
            $author_id          = get_post_field('post_author', $petition_id);
            $author_email       = get_the_author_meta('user_email', $author_id);

            // get petition info
            $petition_title     = get_the_title($petition_id);
            $petition_link      = get_permalink($petition_id);
            $remove_signature   = add_query_arg(array('action' => 'remove_signature'), $petition_link);
            $thumbnail          = conikal_get_petition_thumbnail($petition_id, 'large', 'thumbnail');

            // custom comment variables
            $vars_find     = array(
                '%author_name%', 
                '%author_email%',
                '%petition_title%', 
                '%petition_link%',
                '%petition_thumbnail%',
                '%petition_dashboard_link%',
            );
            $vars_replace  = array(
                esc_html($user_info->display_name), 
                esc_html($user_info->user_email), 
                esc_html($petition_title), 
                esc_url($petition_link),
                esc_url($thumbnail),
                esc_url($page_dashboard),
            );

            // add commment variable into basic variables
            $email_vars = conikal_basic_variables_email();
            $vars_find = array_merge($email_vars['find'], $vars_find);
            $vars_replace = array_merge($email_vars['replace'], $vars_replace);
        }

        $result = false;

        // notification for author
        if (empty($edit) && $email_new_petition_confirm == 1 && $author_id == $user_id) {
            $subject = $email_new_petition_confirm_subject;
            $subject = str_replace($vars_find, $vars_replace, $subject);
            $message = str_replace($vars_find, $vars_replace, $email_new_petition_confirm_template);
            $message = conikal_apply_general_template($subject, $message);

            $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
            $sent = wp_mail(
                $author_email,
                sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
                $message,
                ($email_header ? $headers : '')
            );

            $result = $sent;
        }

        return $result;
    }
endif;


/**
 * Admin notification when new petition submitted
 */
if( !function_exists('conikal_admin_petition_notification') ): 
    function conikal_admin_petition_notification($petition_id, $user_id, $edit) {
        global $campoal_options;
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $admin_new_petition_subject = isset($campoal_options['conikal_admin_new_petition_subject_field']) ? $campoal_options['conikal_admin_new_petition_subject_field'] : esc_html__('An Petition Submitted', 'campoal-tapo');
        $admin_update_petition_subject = isset($campoal_options['conikal_admin_update_petition_subject_field']) ? $campoal_options['conikal_admin_update_petition_subject_field'] : esc_html__('An Petition Updated', 'campoal-tapo');
        $admin_new_petition_template = isset($campoal_options['conikal_admin_new_petition_template_field']) ? $campoal_options['conikal_admin_new_petition_template_field'] : 0;
        $admin_update_petition_template = isset($campoal_options['conikal_admin_update_petition_template_field']) ? $campoal_options['conikal_admin_update_petition_template_field'] : 0;
        $email_new_petition = isset($campoal_options['conikal_new_petition_field']) ? $campoal_options['conikal_new_petition_field'] : 0;
        $email_edit_petition = isset($campoal_options['conikal_edit_petition_field']) ? $campoal_options['conikal_edit_petition_field'] : 0;
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        $user_info = get_userdata($user_id);
        $petition_title = get_the_title($petition_id);
        $petition_link = get_permalink($petition_id);
        
        // set current user is admin
        wp_set_current_user(1);
        $post_edit_link = get_edit_post_link($petition_id);

        // custom comment variables
        $vars_find     = array(
            '%petition_title%', 
            '%petition_link%',
            '%author_name%', 
            '%author_email%',
            '%author_url%',
            '%post_edit_link%', 
        );
        $vars_replace  = array(
            esc_html($petition_title),
            esc_html($petition_link),
            esc_html($user_info->display_name),
            esc_html($user_info->user_email),
            esc_url(get_author_posts_url($user_info->ID, $user_info->user_nicename)),
            esc_url($post_edit_link),
        );

        // add commment variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        if($edit == '' && $email_new_petition == 1) {
            // replace variables in template with values
            $message = str_replace($vars_find, $vars_replace, $admin_new_petition_template);
            $subject = $admin_new_petition_subject;
        } elseif ($edit != '' && $email_edit_petition == 1) { 
            // replace variables in template with values
            $message = str_replace($vars_find, $vars_replace, $admin_update_petition_template);
            $subject = $admin_update_petition_subject;
        } else {
            return false;
        }

        // apply general template
        $subject = str_replace($vars_find, $vars_replace, $subject);
        $message = conikal_apply_general_template($subject, $message);

        $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
        $sent = wp_mail(
            get_option('admin_email'),
            sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
            $message,
            ($email_header ? $headers : '')
        );

        return $sent;
    }
endif;

/**
 * Petition Update notification when new post update for petition
 */
if( !function_exists('conikal_admin_citation_notification') ): 
    function conikal_admin_citation_notification($petition_id, $citaton_id, $user_id, $edit) {
        global $campoal_options;
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $admin_new_citation_subject = isset($campoal_options['conikal_admin_new_citation_subject_field']) ? $campoal_options['conikal_admin_new_citation_subject_field'] : esc_html__('A New Citation Submited', 'campoal-tapo');
        $admin_update_citation_subject = isset($campoal_options['conikal_admin_update_citation_subject_field']) ? $campoal_options['conikal_admin_update_citation_subject_field'] : esc_html__('An Citation Changed', 'campoal-tapo');
        $admin_new_citation_template = isset($campoal_options['conikal_admin_new_citation_template_field']) ? $campoal_options['conikal_admin_new_citation_template_field'] : 0;
        $admin_update_citation_template = isset($campoal_options['conikal_admin_update_citation_template_field']) ? $campoal_options['conikal_admin_update_citation_template_field'] : 0;
        $email_new_petition = isset($campoal_options['conikal_new_citation_field']) ? $campoal_options['conikal_new_citation_field'] : 0;
        $edit_citation = isset($campoal_options['conikal_edit_citation_field']) ? $campoal_options['conikal_edit_citation_field'] : 0;
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        $user_info = get_userdata($user_id);
        $petition_title = get_the_title($petition_id);
        $petition_link = get_permalink($petition_id);
        $citation_title = get_the_title($citaton_id);
        $citation_link = get_permalink($citaton_id);

        // set current user is admin
        wp_set_current_user(1);
        $post_edit_link = get_edit_post_link($citaton_id);

        // custom comment variables
        $vars_find     = array(
            '%petition_title%', 
            '%petition_link%',
            '%citation_title%', 
            '%citation_link%',
            '%author_name%', 
            '%author_email%',
            '%author_url%',
            '%post_edit_link%', 
        );
        $vars_replace  = array(
            esc_html($petition_title),
            esc_html($petition_link),
            esc_html($citation_title),
            esc_html($citation_link),
            esc_html($user_info->display_name),
            esc_html($user_info->user_email),
            esc_url(get_author_posts_url($user_info->ID, $user_info->user_nicename)),
            esc_url($post_edit_link),
        );

        // add commment variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        if ($edit == '' && $email_new_petition == 1) {
            // replace variables in template with values
            $message = str_replace($vars_find, $vars_replace, $admin_new_citation_template);
            $subject = $admin_new_citation_subject;
        } elseif ($edit != '' && $edit_citation == 1) {
            // replace variables in template with values
            $message = str_replace($vars_find, $vars_replace, $admin_update_citation_template);
            $subject = $admin_update_citation_subject;
        } else {
            return false;
        }

        // apply general template for email
        $subject = str_replace($vars_find, $vars_replace, $subject);
        $message = conikal_apply_general_template($subject, $message);

        // send email notification for admin
        $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();

        $sent = wp_mail(
            get_option('admin_email'),
            sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
            $message,
            ($email_header ? $headers : '')
        );

        return $sent;
    }
endif;


/**
 * Petition Update notification when new post update for petition
 */
if( !function_exists('conikal_new_update_notification') ): 
    function conikal_new_update_notification($petition_id, $update_id, $user_id, $edit, $send_supporter = 1) {
        global $campoal_options;
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $admin_new_update_campaign_subject = isset($campoal_options['conikal_admin_new_update_campaign_subject_field']) ? $campoal_options['conikal_admin_new_update_campaign_subject_field'] : esc_html__('New Update on Petition', 'campoal-tapo');
        $admin_edit_update_campaign_subject = isset($campoal_options['conikal_admin_edit_update_campaign_subject_field']) ? $campoal_options['conikal_admin_edit_update_campaign_subject_field'] : esc_html__('Petition Update Changed', 'campoal-tapo');

        $admin_new_update_campaign_template = isset($campoal_options['conikal_admin_new_update_campaign_template_field']) ? $campoal_options['conikal_admin_new_update_campaign_template_field'] : 0;
        $admin_edit_update_campaign_template = isset($campoal_options['conikal_admin_edit_update_campaign_template_field']) ? $campoal_options['conikal_admin_edit_update_campaign_template_field'] : 0;
        $email_new_update = isset($campoal_options['conikal_new_update_field']) ? $campoal_options['conikal_new_update_field'] : 0;
        $email_edit_update = isset($campoal_options['conikal_edit_update_field']) ? $campoal_options['conikal_edit_update_field'] : 0;
        $email_update_supporter = isset($campoal_options['conikal_update_supporter_field']) ? $campoal_options['conikal_update_supporter_field'] : 0;
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        $user_info = get_userdata($user_id);
        $sign_users = get_post_meta($petition_id, 'petition_users', true);
        $supporters = array();

        if (!empty($sign_users)) {
            foreach ($sign_users as $user) {
                if (isset($user['notice']) && $user['notice'] == 1) {
                    $user_data = get_userdata($user['user_id']);
                    $user_email = isset($user_data->user_email) ? $user_data->user_email : false;
                    if (!empty($user_email)) {
                        array_push($supporters, $user_email);
                    }
                }
            }
        }
        $petition_title = get_the_title($petition_id);
        $petition_link = get_permalink($petition_id);
        $update_title = get_the_title($update_id);
        $update_link = get_permalink($update_id);

        // set current user is admin
        wp_set_current_user(1);
        $post_edit_link = get_edit_post_link($update_id);

        // custom comment variables
        $vars_find     = array(
            '%petition_title%', 
            '%petition_link%',
            '%update_title%', 
            '%update_link%',
            '%author_name%', 
            '%author_email%',
            '%author_url%',
            '%post_edit_link%', 
        );
        $vars_replace  = array(
            esc_html($petition_title),
            esc_html($petition_link),
            esc_html($update_title),
            esc_html($update_link),
            esc_html($user_info->display_name),
            esc_html($user_info->user_email),
            esc_url(get_author_posts_url($user_info->ID, $user_info->user_nicename)),
            esc_url($post_edit_link),
        );

        // add commment variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();

        if ($edit == '' && $email_new_update == 1) {
            // replace variables in template with values
            $message = str_replace($vars_find, $vars_replace, $admin_new_update_campaign_template);
            $subject = $admin_new_update_campaign_subject;
        } elseif ($edit != '' && $email_edit_update == 1) {
            // replace variables in template with values
            $message = str_replace($vars_find, $vars_replace, $admin_edit_update_campaign_template);
            $subject = $admin_edit_update_campaign_subject;
        } else {
            return false;
        }

        // apply general template for email
        if (!empty($message)) {
            $subject = str_replace($vars_find, $vars_replace, $subject);
            $message = conikal_apply_general_template($subject, $message);
        }

        // send email notification for admin
        $sent = wp_mail(
            get_option('admin_email'),
            sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
            $message,
            ($email_header ? $headers : '')
        );

        // send email notification for supporters
        if ($email_update_supporter == 1 && $send_supporter == 1) {
            $sent = wp_mail(
                $supporters,
                sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
                $message,
                ($email_header ? $headers : '')
            );
        }

        return $sent;
    }
endif;


/**
 * Sign Petition Notifications
 */
if( !function_exists('conikal_signature_notifications') ): 
    function conikal_signature_notifications($petition_id, $user_id, $reason) {
        global $campoal_options;
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        // get email setting is enable or not
        $email_new_signature        = isset($campoal_options['conikal_new_signature_field']) ? $campoal_options['conikal_new_signature_field'] : 0;
        $email_signature_supporter  = isset($campoal_options['conikal_signature_supporter_field']) ? $campoal_options['conikal_signature_supporter_field'] : 0;
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        // check send email sending is enable or not
        if ($email_new_signature == 1 || $email_signature_supporter == 1) {
            $email_signature_confirm_subject  = isset($campoal_options['conikal_email_signature_confirm_subject_field']) ? $campoal_options['conikal_email_signature_confirm_subject_field'] : esc_html__('You signed successfully', 'campoal-tapo');
            $email_signature_confirm_template  = isset($campoal_options['conikal_email_signature_confirm_template_field']) ? $campoal_options['conikal_email_signature_confirm_template_field'] : 0;

            $admin_new_signature_subject  = isset($campoal_options['conikal_admin_new_signature_subject_field']) ? $campoal_options['conikal_admin_new_signature_subject_field'] : esc_html__('New Signature', 'campoal-tapo');
            $admin_new_signature_template  = isset($campoal_options['conikal_admin_new_signature_template_field']) ? $campoal_options['conikal_admin_new_signature_template_field'] : 0;

            $office_address  = isset($campoal_options['conikal_office_address_field']) ? $campoal_options['conikal_office_address_field'] : '';

            // get supporter user info
            $user_info          = get_userdata($user_id);

            // get author email
            $author_id          = get_post_field('post_author', $petition_id);
            $author_email       = get_the_author_meta('user_email', $author_id);

            // get petition info
            $petition_title     = get_the_title($petition_id);
            $petition_link      = get_permalink($petition_id);
            $remove_signature   = add_query_arg(array('action' => 'remove_signature'), $petition_link);
            $gallery            = get_post_meta($petition_id, 'petition_gallery', true);
            $images             = conikal_get_gallery_images($gallery);
            $thumb              = get_post_meta($petition_id, 'petition_thumb_small', true);

            if(has_post_thumbnail($petition_id)) {
                $thumb_id = get_post_thumbnail_id($petition_id);
                $thumbnail = wp_get_attachment_image_src($thumb_id, 'large', true);
                $thumbnail = $thumbnail[0];
            } elseif ($gallery) {
                $thumbnail = $images[1];
            } elseif ($thumb) {
                $thumbnail = $thumb;
            } else {
                $thumbnail = get_template_directory_uri() . '/images/thumbnail.svg';
            }

            // custom comment variables
            $vars_find     = array(
                '%supporter_name%', 
                '%supporter_email%', 
                '%petition_title%', 
                '%petition_link%',
                '%petition_thumbnail%',
                '%join_date%', 
                '%reason%',
                '%remove_signature%',
                '%current_year%',
                '%office_address%',
            );
            $vars_replace  = array(
                esc_html($user_info->display_name), 
                esc_html($user_info->user_email), 
                esc_html($petition_title), 
                esc_url($petition_link),
                esc_url($thumbnail),
                date_i18n(get_option('date_format'), strtotime($user_info->user_registered)), 
                esc_html($reason),
                esc_url($remove_signature),
                esc_html(date('Y')),
                esc_html($office_address),
            );

            // add commment variable into basic variables
            $email_vars = conikal_basic_variables_email();
            $vars_find = array_merge($email_vars['find'], $vars_find);
            $vars_replace = array_merge($email_vars['replace'], $vars_replace);
        }

        $result = false;

        // notification for author
        if ($email_new_signature == 1 && $author_id != $user_id) {
            $subject = $admin_new_signature_subject;
            $subject = str_replace($vars_find, $vars_replace, $subject);
            $message = str_replace($vars_find, $vars_replace, $admin_new_signature_template);
            $message = conikal_apply_general_template($subject, $message);
            
            $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
            $sent = wp_mail(
                $author_email,
                sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
                $message,
                ($email_header ? $headers : '')
            );

            $result = $sent;
        }

        // notification for supporter
        if ($email_signature_supporter == 1 && $author_id != $user_id) {
            $subject = $email_signature_confirm_subject;
            $subject = str_replace($vars_find, $vars_replace, $subject);
            $message = str_replace($vars_find, $vars_replace, $email_signature_confirm_template);
            // $message = conikal_apply_general_template($message);

            $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
            $sent = wp_mail(
                $user_info->user_email,
                sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
                $message,
                ($email_header ? $headers : '')
            );

            $result = $sent;
        }

        return $result;
    }
endif;


/**
 * Sign Up Notifications
 */
if( !function_exists('conikal_signup_notifications') ): 
    function conikal_signup_notifications($user, $user_pass = '') {
        global $campoal_options;
        $sender_name                    = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email                   = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $email_new_user_signup          = isset($campoal_options['conikal_new_user_signup_field']) ? $campoal_options['conikal_new_user_signup_field'] : 0;
        $new_account_confirm            = isset($campoal_options['conikal_new_account_confirm_field']) ? $campoal_options['conikal_new_account_confirm_field'] : 1;
        $signup_notifications_subject   = isset($campoal_options['conikal_signup_notifications_subject_field']) ? $campoal_options['conikal_signup_notifications_subject_field'] : esc_html__('New User Sign Up', 'campoal-tapo');
        $signup_notifications_template  = isset($campoal_options['conikal_signup_notifications_template_field']) ? $campoal_options['conikal_signup_notifications_template_field'] : 0;
        $signup_confirm_subject         = isset($campoal_options['conikal_signup_confirm_subject_field']) ? $campoal_options['conikal_signup_confirm_subject_field'] : esc_html__('Your username and password', 'campoal-tapo');
        $signup_confirm_template        = isset($campoal_options['conikal_signup_confirm_template_field']) ? $campoal_options['conikal_signup_confirm_template_field'] : 0;
        $email_header                   = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        $new_user = new WP_User($user);

        $user_login         = stripslashes($new_user->user_login);
        $user_email         = stripslashes($new_user->user_email);
        $user_first_name    = stripslashes($new_user->first_name);

        if(empty($user_pass)) return;

        // custom comment variables
        $vars_find     = array(
            '%user_login%', 
            '%user_email%', 
            '%user_first_name%', 
            '%user_last_name%',
            '%user_pass%',
        );
        $vars_replace  = array(
            esc_html($new_user->user_login), 
            esc_html($new_user->user_email), 
            esc_html($new_user->first_name), 
            esc_html($new_user->last_name),
            esc_html($user_pass), 
        );

        // add commment variable into basic variables
        $email_vars     = conikal_basic_variables_email();
        $vars_find      = array_merge($email_vars['find'], $vars_find);
        $vars_replace   = array_merge($email_vars['replace'], $vars_replace);

        $headers    = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
        $sent       = false;

        if ($email_new_user_signup == 1) {
            $subject = $signup_notifications_subject;
            $subject = str_replace($vars_find, $vars_replace, $subject);
            $message = str_replace($vars_find, $vars_replace, $signup_notifications_template);
            $message = conikal_apply_general_template($subject, $message);
            
            wp_mail(
                get_option('admin_email'),
                sprintf(esc_html__('[%1$s] %2$s','campoal-tapo'), get_option('blogname'), esc_html($subject) ),
                $message,
                ($email_header ? $headers : '')
            );
        }

        // send email confirm account for new user
        if ($new_account_confirm == 1) { 
            $confirm_subject = $signup_confirm_subject;
            $confirm_message = str_replace($vars_find, $vars_replace, $signup_confirm_template);
            $confirm_message = conikal_apply_general_template(str_replace($vars_find, '', $confirm_subject), $confirm_message);
            $confirm_subject = str_replace($vars_find, $vars_replace, $confirm_subject);
            
            $sent = wp_mail(
                $user_email,
                sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_option('blogname'), esc_html($confirm_subject) ),
                $confirm_message,
                ($email_header ? $headers : '')
            );
        }

        return $sent;
    }
endif;


/**
 * Send security when request reset password
 */
if( !function_exists('conikal_forgot_pass_email') ): 
    function conikal_forgot_pass_email($user_login, $user_email, $key) {
        global $campoal_options;
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $forgot_pass_email_subject = isset($campoal_options['conikal_forgot_pass_email_subject_field']) ? $campoal_options['conikal_forgot_pass_email_subject_field'] : esc_html__('Request Password Reset', 'campoal-tapo');
        $forgot_pass_email_template = isset($campoal_options['conikal_forgot_pass_email_template_field']) ? $campoal_options['conikal_forgot_pass_email_template_field'] : 0;
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        // custom comment variables
        $vars_find     = array(
            '%user_login%', 
            '%user_email%', 
            '%security_code%', 
            '%reset_pass_link%',
        );
        $vars_replace  = array(
            esc_html($user_login), 
            esc_html($user_email), 
            esc_html($key), 
            esc_url(network_site_url("?action=rp&key=$key&login=" . rawurlencode($user_login), 'login')),
        );

        // add commment variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        $subject = $forgot_pass_email_subject;
        $subject = str_replace($vars_find, $vars_replace, $subject);
        $message = str_replace($vars_find, $vars_replace, $forgot_pass_email_template);
        $message = conikal_apply_general_template($subject, $message);

        $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();

        $blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);
        $title = sprintf( esc_html__('[%1$s] %2$s', 'campoal-tapo'), esc_html($blogname), esc_html($subject) );

        $send = wp_mail(
            $user_email,
            wp_specialchars_decode( $title ),
            $message,
            ($email_header ? $headers : '')
        );

        return $send;
    }
endif;


/**
 * Invite notification email for co author
 */
if( !function_exists('conikal_co_author_invite_notification') ): 
    function conikal_co_author_invite_notification($petition_id, $user_id, $co_author_id) {
        global $campoal_options;
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $co_author_invite_emai = isset($campoal_options['conikal_co_author_invite_email_field']) ? $campoal_options['conikal_co_author_invite_email_field'] : 1;
        $invite_co_author_email_subject = isset($campoal_options['conikal_invite_co_author_email_subject_field']) ? $campoal_options['conikal_invite_co_author_email_subject_field'] : esc_html__('You are invited to be a co-author', 'campoal-tapo');
        $invite_co_author_email_template = isset($campoal_options['conikal_invite_co_author_email_template_field']) ? $campoal_options['conikal_invite_co_author_email_template_field'] : '';
        $page_dashboard_petition = isset($campoal_options['conikal_page_dashboard_petition_field']) ? $campoal_options['conikal_page_dashboard_petition_field'] : 0;
        $page_dashboard_petition = $page_dashboard_petition ? get_permalink($page_dashboard_petition) : '';
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        $user_info = get_userdata($user_id);
        $petition_title = get_the_title($petition_id);
        $petition_link = get_permalink($petition_id);
        $co_author = get_userdata($co_author_id);

        $petition_dashboard_link = add_query_arg(array('section' => 'dashboard', 'id' => $petition_id), $page_dashboard_petition);

        // custom comment variables
        $vars_find     = array(
            '%petition_title%', 
            '%petition_link%',
            '%author_name%', 
            '%author_url%',
            '%co_author_name%',
            '%petition_dashboard_link%',
        );

        $vars_replace  = array(
            esc_html($petition_title),
            esc_url($petition_link),
            esc_html($user_info->display_name),
            esc_url( get_author_posts_url( $user_info->ID, $user_info->user_nicename ) ),
            esc_html($co_author->display_name),
            esc_url($petition_dashboard_link),
        );

        // add adventage variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        // replace variables in template with values
        $subject = $invite_co_author_email_subject;
        $subject = str_replace($vars_find, $vars_replace, $subject);
        $message = str_replace($vars_find, $vars_replace, $invite_co_author_email_template);
        $message = conikal_apply_general_template($subject, $message);
        
        $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
        $sent = wp_mail(
            $co_author->user_email,
            sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
            $message,
            ($email_header ? $headers : '')
        );

        return $sent;
    }
endif;


/**
 * Decision maker notification when new petition submitted
 */
if( !function_exists('conikal_decision_maker_petition_notification') ): 
    function conikal_decision_maker_petition_notification($type, $petition_id, $user_id, $decisionmakers, $update_id = false) {
        global $campoal_options;
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];
        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        if (empty($type)) {
            $type = 'new';
        }

        switch ($type) {
            case 'new':
                $decision_maker_petition_subject    = isset($campoal_options['conikal_decision_maker_new_petition_subject_field']) ? $campoal_options['conikal_decision_maker_new_petition_subject_field'] : esc_html__('A new petition to you %petition_title%', 'campoal-tapo');
                $decision_maker_petition_template   = isset($campoal_options['conikal_decision_maker_new_petition_template_field']) ? $campoal_options['conikal_decision_maker_new_petition_template_field'] : 0;
                break;

            case 'update':
                $decision_maker_petition_subject    = isset($campoal_options['conikal_decision_maker_new_update_subject_field']) ? $campoal_options['conikal_decision_maker_new_update_subject_field'] : esc_html__('Petition to you has a new update %update_title%', 'campoal-tapo');
                $decision_maker_petition_template   = isset($campoal_options['conikal_decision_maker_new_update_template_field']) ? $campoal_options['conikal_decision_maker_new_update_template_field'] : 0;
                break;

            case 'victory':
                $decision_maker_petition_subject    = isset($campoal_options['conikal_decision_maker_victory_subject_field']) ? $campoal_options['conikal_decision_maker_victory_subject_field'] : esc_html__('A petition to you declared victory %petition_title%', 'campoal-tapo');
                $decision_maker_petition_template   = isset($campoal_options['conikal_decision_maker_victory_template_field']) ? $campoal_options['conikal_decision_maker_victory_template_field'] : 0;
                break;

            case 'signature':
                $decision_maker_petition_subject    = isset($campoal_options['conikal_decision_maker_new_signature_subject_field']) ? $campoal_options['conikal_decision_maker_new_signature_subject_field'] : esc_html__('New signature on %petition_title%', 'campoal-tapo');
                $decision_maker_petition_template   = isset($campoal_options['conikal_decision_maker_new_signature_template_field']) ? $campoal_options['conikal_decision_maker_new_signature_template_field'] : 0;
                break;

            case 'milestone':
                $decision_maker_petition_subject    = isset($campoal_options['conikal_decision_maker_signature_reached_subject_field']) ? $campoal_options['conikal_decision_maker_signature_reached_subject_field'] : esc_html__('A petition to you just hit the new signature milestone %petition_title%', 'campoal-tapo');
                $decision_maker_petition_template   = isset($campoal_options['conikal_decision_maker_signature_reached_template_field']) ? $campoal_options['conikal_decision_maker_signature_reached_template_field'] : 0;
                break;
            
            default:
                $decision_maker_petition_subject    = isset($campoal_options['conikal_decision_maker_new_petition_subject_field']) ? $campoal_options['conikal_decision_maker_new_petition_subject_field'] : esc_html__('A new petition to you %petition_title%', 'campoal-tapo');
                $decision_maker_petition_template   = isset($campoal_options['conikal_decision_maker_new_petition_template_field']) ? $campoal_options['conikal_decision_maker_new_petition_template_field'] : 0;
                break;
        }

        $decision_name      = $decisionmakers->name;
        $decision_position  = $decisionmakers->position;
        $decision_email     = $decisionmakers->email;

        $user_info          = get_userdata($user_id);
        $petition_title     = get_the_title($petition_id);
        $petition_link      = get_permalink($petition_id);
        $update_title       = get_the_title($update_id);
        $update_link        = get_permalink($update_id);

        $supporter_number   = conikal_get_supporter_donors_number($petition_id);

        $page_dashboard_petition = isset($campoal_options['conikal_page_dashboard_petition_field']) ? $campoal_options['conikal_page_dashboard_petition_field'] : 0;
        $page_dashboard_petition = $page_dashboard_petition ? get_permalink($page_dashboard_petition) : '';
        $params_link = array('section' => 'add_update', 'type' => 'responsive', 'id' => $petition_id);
        $response_link = add_query_arg($params_link, $page_dashboard_petition);

        // custom comment variables
        $vars_find     = array(
            '%decision_name%', 
            '%decision_position%', 
            '%decision_email%', 
            '%petition_title%', 
            '%petition_link%',
            '%update_title%', 
            '%update_link%',
            '%supporters_number%',
            '%supporters_label%',
            '%author_name%', 
            '%author_email%',
            '%author_url%',
            '%response_link%', 
        );
        $vars_replace  = array(
            esc_html($decision_name),
            esc_html($decision_position),
            esc_html($decision_email),
            esc_html($petition_title),
            esc_html($petition_link),
            esc_html($update_title ? $update_title : 0),
            esc_html($update_link ? $update_link : 0),
            esc_html($supporter_number->sign_format),
            esc_html($supporter_number->label),
            esc_html($user_info->display_name),
            esc_html($user_info->user_email),
            esc_url(get_author_posts_url($user_info->ID, $user_info->user_nicename)),
            esc_url($response_link),
        );

        // add custom variable into basic variables
        $email_vars     = conikal_basic_variables_email();
        $vars_find      = array_merge($email_vars['find'], $vars_find);
        $vars_replace   = array_merge($email_vars['replace'], $vars_replace);

        // replace variables in template with values
        $message = str_replace($vars_find, $vars_replace, $decision_maker_petition_template);
        $subject = $decision_maker_petition_subject;

        // apply general template
        $subject = str_replace($vars_find, $vars_replace, $subject);
        $message = conikal_apply_general_template($subject, $message);

        $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
        $sent = wp_mail(
            $decision_email,
            sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
            $message,
            ($email_header ? $headers : '')
        );

        return $sent;
    }
endif;


/**
 * Remind validate license to administrator
 */
if( !function_exists('conikal_decision_maker_notification') ): 
    function conikal_decision_maker_notification($type, $petition_id, $user_id, $update_id = false) {
        global $campoal_options;
        $decision_maker_new_petition        = isset($campoal_options['conikal_decision_maker_new_petition_field']) ? $campoal_options['conikal_decision_maker_new_petition_field'] : 0;
        $decision_maker_new_update          = isset($campoal_options['conikal_decision_maker_new_update_field']) ? $campoal_options['conikal_decision_maker_new_update_field'] : 0;
        $decision_maker_petition_victory    = isset($campoal_options['conikal_decision_maker_petition_victory_field']) ? $campoal_options['conikal_decision_maker_petition_victory_field'] : 0;
        $decision_maker_new_signature       = isset($campoal_options['conikal_decision_maker_new_signature_field']) ? $campoal_options['conikal_decision_maker_new_signature_field'] : 0;
        $decision_maker_new_milestone       = isset($campoal_options['conikal_decision_maker_new_milestone_field']) ? $campoal_options['conikal_decision_maker_new_milestone_field'] : 0;

        if (empty($type)) {
            $type = 'new';
        }

        $all_decisionmakers = conikal_get_decistion_makers($petition_id);
        $sent = false;
        foreach ($all_decisionmakers as $decisionmaker) {
            $decisionmaker = (object) $decisionmaker;
            
            if ( !empty($decisionmaker->email) ) :
                if ( $type == 'new' && $decision_maker_new_petition == 1 ) {
                    $sent = conikal_decision_maker_petition_notification($type, $petition_id, $user_id, $decisionmaker);
                } elseif ( $type == 'update' && $decision_maker_new_update == 1 ) {
                    $sent = conikal_decision_maker_petition_notification($type, $petition_id, $user_id, $decisionmaker, $update_id);
                } elseif ( $type == 'victory' && $decision_maker_petition_victory == 1 ) {
                    $sent = conikal_decision_maker_petition_notification($type, $petition_id, $user_id, $decisionmaker, $update_id);
                } elseif ( $type == 'signature' && $decision_maker_new_signature == 1 ) {
                    $sent = conikal_decision_maker_petition_notification($type, $petition_id, $user_id, $decisionmaker);
                } elseif ( $type == 'milestone' && $decision_maker_new_milestone == 1 ) {
                    $sent = conikal_decision_maker_petition_notification($type, $petition_id, $user_id, $decisionmaker);
                }
            endif;
        }
    
        return $sent;
    }
endif;

/**
 * Remind validate license to administrator
 */
if( !function_exists('conikal_remind_license_notification') ): 
    function conikal_remind_license_notification($vaidate_object) {
        global $campoal_options;
                
        $remind_license_email_subject = ($vaidate_object['revoked'] == 1) ? esc_html__('The theme has been revoked due to lack of license', 'campoal-tapo') : esc_html__('Passed 3 times failed license validation attempts', 'campoal-tapo');
        $remind_license_email_template = conikal_remind_license_email_template($vaidate_object['revoked']);

        $email_header = isset($campoal_options['conikal_email_header_field']) ? $campoal_options['conikal_email_header_field'] : 1;

        $conikal_license_link = admin_url('options-general.php?page=conikal-license');

        // custom comment variables
        $vars_find     = array(
            '%failed_times%',
            '%conikal_license_link%',
        );

        $vars_replace  = array(
            esc_html($vaidate_object['failed_times']),
            esc_url($conikal_license_link),
        );

        // add adventage variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        // replace variables in template with values
        $subject = $remind_license_email_subject;
        $subject = str_replace($vars_find, $vars_replace, $subject);
        $message = str_replace($vars_find, $vars_replace, $remind_license_email_template);
        $message = conikal_apply_general_template($subject, $message);
        
        $headers = 'From: ' . get_option('admin_email') . '  <' .get_option('admin_email') . '>' . "\r\n" .
                    'Reply-To: ' . get_option('admin_email') . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();

        $sent = wp_mail(
            get_option('admin_email'),
            sprintf( esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
            $message,
            ($email_header ? $headers : '')
        );

        return $sent;
    }
endif;

/**
 * Remind validate license to administrator
 */
if( !function_exists('conikal_user_email_sharing') ): 
    function conikal_user_email_sharing($id, $type = 'subject', $custom_share_link = false) {
        global $current_user;
        global $campoal_options;

        $post_type = get_post_type($id);
        if ($post_type == 'petition') {
            $prefix = 'petition_';
        } else if ($post_type == 'give_forms') {
            $prefix = '_give_';
        } else {
            $prefix = 'post_';
        }
        
        // get mail setting
        $mail_sharing_subject   = isset($campoal_options['conikal_mail_sharing_subject_field']) ? $campoal_options['conikal_mail_sharing_subject_field'] : '';
        $mail_sharing_content   = isset($campoal_options['conikal_mail_sharing_content_field']) ? $campoal_options['conikal_mail_sharing_content_field'] : '';
        $mail_sharing_custom    = isset($campoal_options['conikal_mail_sharing_custom_field']) ? $campoal_options['conikal_mail_sharing_custom_field'] : '';
        $post_sharing_subject   = isset($campoal_options['conikal_post_sharing_subject_field']) ? $campoal_options['conikal_post_sharing_subject_field'] : '';
        $post_sharing_custom    = isset($campoal_options['conikal_post_sharing_custom_field']) ? $campoal_options['conikal_post_sharing_custom_field'] : '';

        // get custom mail for petition
        $custom_mail_subject         = get_post_meta($id, $prefix . 'mail_subject', true);
        $custom_mail_message         = get_post_meta($id, $prefix . 'mail', true);

        // change campaign template when post_type is post
        if ($post_type == 'post') {
            $mail_sharing_subject = $post_sharing_subject;
            $mail_sharing_content = $post_sharing_custom;
        }

        // get custom mail subject if exist
        if (!empty($custom_mail_subject)) {
            $mail_sharing_subject = $custom_mail_subject;
        }

        // get custom mail content if exist
        if (!empty($custom_mail_message)) {
            $mail_sharing_content = $custom_mail_message;
            $mail_sharing_custom = $custom_mail_message;
        }

        // get custom share link if exist
        if (!empty($custom_share_link)) {
            $post_title = get_the_title($custom_share_link);
            $post_url = get_permalink($custom_share_link);
        } else {
            $post_title = get_the_title($id);
            $post_url = get_permalink($id);
        }
        
        // special chars need remove
        $special_chars  = array(">", "<", "\"", "&", "gt;", "lt;", "&quot;", "&amp;", "#62;", "#60;", "#8221;", "#038;");
        $replace_charts = array("", "", "", "", "", "", "", "", "", "", "", "");

        // custom heading variable
        $vars_find = array(
            '{title}',
            '{link}',
            '{supporter_name}',
            '{supporters_number}',
            '{decision_maker}',
            '{author_name}',
            '{blog_name}'
        );

        $supporter_name = is_user_logged_in() ? $current_user->display_name : esc_html__('Your friend', 'campoal-tapo');
        $supporter_number = conikal_get_supporter_donors_number($id, (get_post_type($id) == 'petition' ? 'supporter' : 'donor'), true);
        $author_id = get_post_field ('post_author', $id);
        $author_name = get_the_author_meta('display_name', $author_id);
        $decision_maker = conikal_get_decistion_makers($id, true, 1);

        $vars_replace = array(
            esc_html($post_title),
            esc_url($post_url),
            esc_html($supporter_name),
            esc_html(conikal_format_number('%!,0i', $supporter_number->sign)),
            esc_html($decision_maker),
            esc_html($author_name),
            get_bloginfo('name')
        );

        // replace variables in template with values
        $subject    = str_replace($vars_find, $vars_replace, $mail_sharing_subject);
        $message    = str_replace($vars_find, $vars_replace, $mail_sharing_content);
        $custom     = str_replace($vars_find, $vars_replace, $mail_sharing_custom);

        $subject    = str_replace($special_chars, $replace_charts, $subject);
        $message    = str_replace($special_chars, $replace_charts, $message);
        $custom     = str_replace($special_chars, $replace_charts, $custom);

        if ($type == 'subject') {
            $result = $subject;
        } else if ($type == 'message') {
            $result = $message;
        } else {
            $result = $custom;
        }

        return $result;
    }
endif;

?>