<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Send verification email after register
 */
add_action( 'user_register', 'conikal_verification_registration', 10, 2 );
if (!function_exists('conikal_verification_registration')) :
    function conikal_verification_registration($user_id, $type = 'new') {
        global $campoal_options;

        $verification_email = isset($campoal_options['conikal_verification_email_field']) ? $campoal_options['conikal_verification_email_field'] : 1;
        $verification_email_subject = isset($campoal_options['conikal_verification_email_subject_field']) ? $campoal_options['conikal_verification_email_subject_field'] : esc_html__('Confirm your email', 'campoal-');
        $verification_email_template = isset($campoal_options['conikal_verification_email_template_field']) ? $campoal_options['conikal_verification_email_template_field'] : '';
        $change_email_subject = isset($campoal_options['conikal_change_email_subject_field']) ? $campoal_options['conikal_change_email_subject_field'] : '';
        $change_email_template = isset($campoal_options['conikal_change_email_template_field']) ? $campoal_options['conikal_change_email_template_field'] : '';
        $sender_name = isset($campoal_options['conikal_sender_name_field']) ? $campoal_options['conikal_sender_name_field'] : 'noreply';
        $sender_email = isset($campoal_options['conikal_sender_email_field']) ? $campoal_options['conikal_sender_email_field'] : 'noreply@'.$_SERVER['HTTP_HOST'];

        // verify success page
        $page_verificattion_success         = isset($campoal_options['conikal_page_verificattion_success_field']) ? $campoal_options['conikal_page_verificattion_success_field'] : 0;
        $page_verificattion_success         = ($page_verificattion_success ? get_permalink($page_verificattion_success) : home_url('/'));

        // stop when verification is disabled
        if ($verification_email != 0) :

            // get user data
            $user_info = get_userdata($user_id);
            // create md5 code to verify later
            $code = md5(time());
            // make it into a code to send it to user via email
            $string = array('verify' => 1, 'id' => $user_id, 'code' => $code);
            // create the activation code and activation status
            // update_user_meta($user_id, 'is_activated', 0);
            update_user_meta($user_id, 'activation_code', $code);
            // create the url
            $active_url = add_query_arg($string, $page_verificattion_success);

            // custom verification email variables
            $vars_find     = array(
                '%user_login%', 
                '%user_email%', 
                '%user_first_name%', 
                '%user_last_name%',
                '%active_account_link%',
            );
            $vars_replace  = array(
                esc_html($user_info->user_login), 
                esc_html($user_info->user_email), 
                esc_html($user_info->first_name), 
                esc_html($user_info->last_name),
                esc_url($active_url),
            );

            // add commment variable into basic variables
            $email_vars = conikal_basic_variables_email();
            $vars_find = array_merge($email_vars['find'], $vars_find);
            $vars_replace = array_merge($email_vars['replace'], $vars_replace);

            // replace variables in template with values
            if (!empty($type) && $type == 'change') {
                $message = str_replace($vars_find, $vars_replace, $change_email_template);
                $subject = $change_email_subject;
            } else {
                $message = str_replace($vars_find, $vars_replace, $verification_email_template);
                $subject = $verification_email_subject;
            }
            $subject = str_replace($vars_find, $vars_replace, $subject);
            $message = conikal_apply_general_template($subject, $message);

            // header for email, it's not required you can remove that
            $headers = 'From: ' . $sender_name . '  <' . $sender_email . '>' . "\r\n" .
                    'Reply-To: ' . $sender_email . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();

            $send = wp_mail(
                $user_info->user_email,
                sprintf(esc_html__('[%1$s] %2$s','campoal-tapo'), get_bloginfo('name'), esc_html($subject) ),
                $message,
                $headers
            );

            return $send;
        endif;
    }
endif;


/**
 * Resend verification email for user
 */
if (!function_exists('conikal_resend_verification_email')) :
    function conikal_resend_verification_email() {
        check_ajax_referer('resend_ajax_nonce', 'security');

        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : 'new';
        $resend = conikal_verification_registration($user_id, $type);

        if ($resend && $user_id != '') {
            if ($type == 'change') {
                update_user_meta($user_id, 'is_activated', 0);
            }
            echo json_encode(array('status'=>true, 'message' => 'New verification email has sent.'));
            exit();
        } else {
            echo json_encode(array('status'=>false, 'message' => 'Sent verification email failed.'));
            exit();
        }

        die();
    }
endif;
add_action('wp_ajax_nopriv_conikal_resend_verification_email', 'conikal_resend_verification_email');
add_action('wp_ajax_conikal_resend_verification_email', 'conikal_resend_verification_email');


/**
 * Verify code when user click the link from email
 */
add_action( 'init', 'conikal_verify_user_code' );
if (!function_exists('conikal_verify_user_code')) :
    function conikal_verify_user_code(){
        if( isset($_GET['verify']) && isset($_GET['id']) && isset($_GET['code']) ){
            $user_id    = sanitize_text_field($_GET['id']);
            $user_code  = sanitize_text_field($_GET['code']);

            $code = get_user_meta($user_id, 'activation_code', true);
            // verify whether the code given is the same as ours
            if($code == $user_code){
                // update the user meta
                update_user_meta($user_id, 'is_activated', 1);
            }
        }
    }
endif;


?>