<?php 

if (!function_exists('conikal_embed_petition')) :
    function conikal_embed_petition($id, $embed_style, $format = 'html') {
        global $campoal_options;
        $decisionmakers_display = isset($campoal_options['conikal_decisionmakers_display_field']) ? $campoal_options['conikal_decisionmakers_display_field'] : 1;
        if (!empty($id) && !empty($embed_style) && $embed_style == 'card') :
            // get embed settings
            $embed_code = isset($campoal_options['conikal_embed_code_field']) ? $campoal_options['conikal_embed_code_field'] : 0;
            $embed_css_template = isset($campoal_options['conikal_embed_css_template_field']) ? $campoal_options['conikal_embed_css_template_field'] : '';
            $embed_html_template= isset($campoal_options['conikal_embed_html_template_field']) ? $campoal_options['conikal_embed_html_template_field'] : '';
            
            // get colors settings
            $main_color     = isset($campoal_options['conikal_main_color_field']) ? $campoal_options['conikal_main_color_field'] : '#6059C9';
            $heading_color  = isset($campoal_options['conikal_heading_color_field']) ? $campoal_options['conikal_heading_color_field'] : '#2B2B39';
            $caption_color  = isset($campoal_options['conikal_subheading_color_field']) ? $campoal_options['conikal_subheading_color_field'] : '#5F5F75';
            $link_color     = isset($campoal_options['conikal_text_link_color_field']) ? $campoal_options['conikal_text_link_color_field'] : '#2B2B39';
            $border_radius  = isset($campoal_options['conikal_card_border_radius_field']) ? $campoal_options['conikal_card_border_radius_field'] : '10px';
            $button_radius  = isset($campoal_options['conikal_button_border_radius_field']) ? $campoal_options['conikal_button_border_radius_field'] : '10px';
            $label_radius   = isset($campoal_options['conikal_label_border_radius_field']) ? $campoal_options['conikal_label_border_radius_field'] : '6px';
            $label_bg_color = isset($campoal_options['conikal_label_bg_color_field']) ? $campoal_options['conikal_label_bg_color_field'] : '#F5EFE0';

            $petition_title             = get_the_title($id);
            $status                     = get_post_meta($id, 'petition_status', true);
            $petition_status            = ((int)$status == 1) ? 'block' : 'none';
            $petition_thumbnail         = conikal_get_petition_thumbnail($id, 'conikal-petition-thumbnail', false);
            $petition_link              = get_permalink($id);
            $city                       = get_post_meta($id, 'petition_city', true);
            $state                      = get_post_meta($id, 'petition_state', true);
            $country                    = get_post_meta($id, 'petition_country', true);
            $petition_location          = ($city ? $city . ', ' : '') . ($state ? $state . ', ' : '') . ($country ? $country : '');
            $receiver                   = conikal_get_decistion_makers($id, true, $decisionmakers_display);
            $petition_receiver          = sprintf(esc_html__('Petition to %s', 'campoal-tapo'), $receiver);
            $petition_description       = conikal_get_excerpt_by_id($id, 12);
            $author_id                  = get_post_field ('post_author', $id);;
            $author_link                = get_author_posts_url($author_id);
            $author_name                = get_the_author_meta('display_name', $author_id);
            $author_avatar              = conikal_get_avatar_url($author_id, array('size' => 64));
            $supporter_number           = conikal_get_supporter_donors_number($id);
            $supporter_label            = $supporter_number->label;
            $goal                       = $supporter_number->goal;
            $sign                       = $supporter_number->sign;
            $sign_percent               = ((int)$sign < (int)$goal) && (int)$status != 1 ? ((int)$sign / (int)$goal) * 100 : 100;
            $counter_supporter          = sprintf($supporter_label, esc_html(conikal_format_number('%!,0i', $sign)));
            $comments                   = wp_count_comments($id);
            $counter_comment            = conikal_format_number('%!,0i', $comments->approved, true);
            $counter_view               = conikal_format_number('%!,0i', (int) conikal_get_post_views($id), true);

            // get custom sign button label
            $sign_button_text           = conikal_custom_sign_label_button($id);

            // find and replce custom variable embed template
            if (!empty($embed_code) && !empty($embed_html_template) && !empty($embed_css_template)) :
                // find and replace custom variable in html template
                $embed_html_find     = array(
                    '%petition_title%',
                    '%petition_thumbnail%',
                    '%petition_link%',
                    '%petition_location%',
                    '%petition_receiver%',
                    '%petition_description%',
                    '%author_link%',
                    '%author_name%',
                    '%author_avatar%',
                    '%counter_view%',
                    '%counter_supporter%',
                    '%counter_comment%',
                    '%sign_text%',
                    '%sign_percent%',
                    '%petition_status%',
                    '%supporter_label%'
                );
                $embed_html_replace  = array(
                    esc_html($petition_title),
                    esc_url($petition_thumbnail),
                    esc_url($petition_link),
                    esc_html($petition_location),
                    esc_html($petition_receiver),
                    esc_html($petition_description),
                    esc_url($author_link),
                    esc_html($author_name),
                    esc_html($author_avatar),
                    esc_html($counter_view),
                    esc_html($counter_supporter),
                    esc_html($counter_comment),
                    esc_html($sign_button_text),
                    esc_html($sign_percent),
                    esc_html($petition_status),
                    esc_html($supporter_label),
                );
                    
                $embed_html = str_replace($embed_html_find, $embed_html_replace, $embed_html_template);

                // find and replace custom variable in css template
                $embed_css_find     = array(
                    '%main_color%',
                    '%heading_color%',
                    '%caption_color%',
                    '%link_color%',
                    '%border_radius%',
                    '%button_radius%',
                    '%label_radius%',
                    '%label_bg_color%',
                );
                $embed_css_replace  = array(
                    esc_attr($main_color),
                    esc_attr($heading_color),
                    esc_attr($caption_color),
                    esc_attr($link_color),
                    esc_attr($border_radius),
                    esc_attr($button_radius),
                    esc_attr($label_radius),
                    esc_attr($label_bg_color),
                );
                    
                $embed_css = str_replace($embed_css_find, $embed_css_replace, $embed_css_template);

                if ($format == 'style') {
                    $html = '<style>' . $embed_css . '</style>';
                } else if ($format == 'html') {
                    $html = '<body>' . $embed_html . '</body>';
                } else {
                    $html = '<style>' . $embed_css . '</style><body>' . $embed_html . '</body>';
                }

                return $html;
            endif;
        endif;
    }
endif;


if (!function_exists('conikal_embed_fundraising')) :
    function conikal_embed_fundraising($id, $embed_style, $format = 'style') {
        global $campoal_options;

        if (!empty($id) && !empty($embed_style) && $embed_style == 'card') :
            $give_prefix        = '_give_';
            $goal_option        = get_post_meta($id, $give_prefix . 'goal_option', true);

            // get embed settings
            $embed_code = isset($campoal_options['conikal_embed_code_field']) ? $campoal_options['conikal_embed_code_field'] : 0;
            $embed_css_template = isset($campoal_options['conikal_embed_css_template_field']) ? $campoal_options['conikal_embed_css_template_field'] : '';
            $embed_html_template= isset($campoal_options['conikal_give_embed_html_template_field']) ? $campoal_options['conikal_give_embed_html_template_field'] : '';
            
            // get colors settings
            $main_color     = isset($campoal_options['conikal_main_color_field']) ? $campoal_options['conikal_main_color_field'] : '#6059C9';
            $heading_color  = isset($campoal_options['conikal_heading_color_field']) ? $campoal_options['conikal_heading_color_field'] : '#2B2B39';
            $caption_color  = isset($campoal_options['conikal_subheading_color_field']) ? $campoal_options['conikal_subheading_color_field'] : '#5F5F75';
            $link_color     = isset($campoal_options['conikal_text_link_color_field']) ? $campoal_options['conikal_text_link_color_field'] : '#2B2B39';
            $border_radius  = isset($campoal_options['conikal_card_border_radius_field']) ? $campoal_options['conikal_card_border_radius_field'] : '10px';
            $button_radius  = isset($campoal_options['conikal_button_border_radius_field']) ? $campoal_options['conikal_button_border_radius_field'] : '10px';
            $label_radius   = isset($campoal_options['conikal_label_border_radius_field']) ? $campoal_options['conikal_label_border_radius_field'] : '6px';
            $label_bg_color = isset($campoal_options['conikal_label_bg_color_field']) ? $campoal_options['conikal_label_bg_color_field'] : '#F5EFE0';

            $petition_id        = get_post_meta($id, $give_prefix . 'petition_id', true);
            $backers            = give_get_form_sales_stats( $id );
            $backers_label      = (empty($backers)) ? esc_html_e('No Backer', 'campoal') : conikal_custom_icon('supporter') . sprintf(_n('%s backer', '%s backers', $backers, 'campoal'), conikal_format_number('%!,0i', $backers, true));
            $link               = get_permalink($id);
            $title              = get_the_title($id);
            $comments           = wp_count_comments($id);
            $counter_comment    = conikal_format_number('%!,0i', $comments->approved, true);
            $category           = wp_get_post_terms($id, 'give_forms_category', true);
            $content            = get_post_meta($id, $give_prefix . 'form_content', true);
            $excerpt            = conikal_get_excerpt_by_id($id, 12, $content);
            $city               = get_post_meta($id, $give_prefix . 'city', true);
            $state              = get_post_meta($id, $give_prefix . 'state', true);
            $country            = get_post_meta($id, $give_prefix . 'country', true);
            $location           = ($city ? $city . ', ' : '') . ($state ? $state . ', ' : '') . ($country ? $country : '');

            $donation_num       = give_get_form_sales_stats( $id );
            $goal               = get_post_meta($petition_id, 'petition_goal', true);
            $donation_needed    = intval($goal) - intval($donation_num);

            if (give_is_setting_enabled( $goal_option )) {
                $goal_stats             = give_goal_progress_stats( $id );
                $goal_stats             = ($goal_stats['raw_goal'] != 0 ? $goal_stats['raw_goal'] : $goal);
                $goal_stats_label       = give_currency_filter( give_format_amount( $goal_stats, array( 'sanitize' => false ) ) );
            
                $total_incom            = give_get_form_earnings_stats( $id );
                $total_raised           = give_currency_filter( give_format_amount( $total_incom, array( 'sanitize' => false ) ) );
                $total_raised_label     = sprintf(esc_html__('%s Raised', 'campoal-tapo'), $total_raised);
            
                $amount_needed          = intval($goal_stats) - intval($total_incom);
                $amount_needed_label    = give_currency_filter( give_format_amount( $amount_needed, array( 'sanitize' => false ) ) );
            } else {
                $goal_stats             = $goal;
                $goal_stats_label       = conikal_format_number('%!,0i', esc_html($goal_stats));
            
                $total_incom            = give_get_form_earnings_stats( $id );
                $total_raised           = give_currency_filter( give_format_amount( $total_incom, array( 'sanitize' => false ) ) );
                $total_raised_label     = sprintf(esc_html__('%s Raised', 'campoal-tapo'), $total_raised);
                
                $amount_needed          = $donation_needed;
                $amount_needed_label    = conikal_format_number('%!,0i', esc_html($amount_needed));
            }

            $fund_percent               = ((int)$total_incom < (int)$goal_stats) ? ((int)$total_incom / (int)$goal_stats) * 100 : 100;
            $fund_progress_label        = sprintf(esc_html__('%1$s of %2$s raised', 'campoal-tapo'), $total_raised, $goal_stats);

            $author_id = get_post_field ('post_author', $id);;
            $author_link = get_author_posts_url($author_id);
            $author_name = get_the_author_meta('display_name', $author_id);
            $author_avatar = conikal_get_avatar_url($author_id, array('size' => 64));

            // lazy placeholder
            $thumbnail          = conikal_get_petition_thumbnail($id, 'conikal-petition-thumbnail', false);

            $counter_view         = conikal_format_number('%!,0i', (int) conikal_get_post_views($id), true);

            $goal_option        = get_post_meta($id, $give_prefix . 'goal_option', true);

            // use petition thumbnail if donation form doesn't exist thumbnail
            if (!$thumbnail && !empty($petition_id)) {
                $thumbnail          = conikal_get_petition_thumbnail($petition_id, 'conikal-petition-thumbnail', false);
                    
                if(!is_array($category) || !isset($category[0])) {
                    $category       = wp_get_post_terms($petition_id, 'petition_category', true);
                }

                $city               = get_post_meta($petition_id, 'petition_city', true);
                $state              = get_post_meta($petition_id, 'petition_state', true);
                $country            = get_post_meta($petition_id, 'petition_country', true);
            }

            $reveal_label       = get_post_meta($id, $give_prefix . 'reveal_label', true);

            // find and replce custom variable embed template
            if (!empty($embed_code) && !empty($embed_html_template) && !empty($embed_css_template)) :
                // find and replace custom variable in html template
                $embed_html_find     = array(
                    '%campaign_title%',
                    '%campaign_thumbnail%',
                    '%campaign_link%',
                    '%campaign_location%',
                    '%campaign_description%',
                    '%author_link%',
                    '%author_name%',
                    '%author_avatar%',
                    '%counter_view%',
                    '%counter_backer%',
                    '%counter_backer_label%',
                    '%counter_comment%',
                    '%button_label%',
                    '%fund_goal%',
                    '%fund_raised%',
                    '%fund_needed%,',
                    '%fund_goal_label%',
                    '%fund_raised_label%',
                    '%fund_needed_label%,',
                    '%fund_percent%',
                    '%fund_progress_label%'
                );
                $embed_html_replace  = array(
                    esc_html($title),
                    esc_url($thumbnail),
                    esc_url($link),
                    esc_html($location),
                    esc_html($excerpt),
                    esc_url($author_link),
                    esc_html($author_name),
                    esc_html($author_avatar),
                    esc_html($counter_view),
                    esc_html($backers),
                    esc_html($backers_label),
                    esc_html($counter_comment),
                    esc_html($reveal_label),
                    esc_html($goal_stats),
                    esc_html($total_incom),
                    esc_html($amount_needed),
                    esc_html($goal_stats_label),
                    esc_html($total_raised_label),
                    esc_html($amount_needed_label),
                    esc_html($fund_percent),
                    esc_html($fund_progress_label),
                );
                    
                $embed_html = str_replace($embed_html_find, $embed_html_replace, $embed_html_template);

                // find and replace custom variable in css template
                $embed_css_find     = array(
                    '%main_color%',
                    '%heading_color%',
                    '%caption_color%',
                    '%link_color%',
                    '%border_radius%',
                    '%button_radius%',
                    '%label_radius%',
                    '%label_bg_color%',
                );
                $embed_css_replace  = array(
                    esc_attr($main_color),
                    esc_attr($heading_color),
                    esc_attr($caption_color),
                    esc_attr($link_color),
                    esc_attr($border_radius),
                    esc_attr($button_radius),
                    esc_attr($label_radius),
                    esc_attr($label_bg_color),
                );
                    
                $embed_css = str_replace($embed_css_find, $embed_css_replace, $embed_css_template);

                if ($format == 'style') {
                    $html = '<style>' . $embed_css . '</style>';
                } else if ($format == 'html') {
                    $html = '<body>' . $embed_html . '</body>';
                } else {
                    $html = '<style>' . $embed_css . '</style><body>' . $embed_html . '</body>';
                }

                return $html;
            endif;
        endif;
    }
endif;

if (!function_exists('conikal_share_embed_petition')) :
    function conikal_share_embed_petition($id, $format = 'html', $custom_share_link = false) {
        global $campoal_options;
        $decisionmakers_display = isset($campoal_options['conikal_decisionmakers_display_field']) ? $campoal_options['conikal_decisionmakers_display_field'] : 1;
        if (!empty($id)) :
            // facebook app id
            $fb_app_id      = isset($campoal_options['conikal_fb_id_field']) ? $campoal_options['conikal_fb_id_field'] : '';
            $fb_login       = isset($campoal_options['conikal_fb_login_field']) ? $campoal_options['conikal_fb_login_field'] : 0;
            $primary_share_button = isset($campoal_options['conikal_primary_share_button_field']) ? $campoal_options['conikal_primary_share_button_field'] : 'facebook';

            // get embed settings
            $embed_code             = isset($campoal_options['conikal_embed_code_field']) ? $campoal_options['conikal_embed_code_field'] : 0;
            $embed_css_template     = isset($campoal_options['conikal_share_embed_css_template_field']) ? $campoal_options['conikal_share_embed_css_template_field'] : '';
            $embed_html_template    = isset($campoal_options['conikal_share_embed_html_template_field']) ? $campoal_options['conikal_share_embed_html_template_field'] : '';
            $embed_button_icon      = isset($campoal_options['conikal_share_embed_button_icon_field']['url']) ? $campoal_options['conikal_share_embed_button_icon_field']['url'] : 0;

            // get colors settings
            $main_color     = isset($campoal_options['conikal_main_color_field']) ? $campoal_options['conikal_main_color_field'] : '#6059C9';
            $heading_color  = isset($campoal_options['conikal_heading_color_field']) ? $campoal_options['conikal_heading_color_field'] : '#2B2B39';
            $caption_color  = isset($campoal_options['conikal_subheading_color_field']) ? $campoal_options['conikal_subheading_color_field'] : '#5F5F75';
            $link_color     = isset($campoal_options['conikal_text_link_color_field']) ? $campoal_options['conikal_text_link_color_field'] : '#2B2B39';
            $border_radius  = isset($campoal_options['conikal_card_border_radius_field']) ? $campoal_options['conikal_card_border_radius_field'] : '10px';
            $button_radius  = isset($campoal_options['conikal_button_border_radius_field']) ? $campoal_options['conikal_button_border_radius_field'] : '10px';
            $label_radius   = isset($campoal_options['conikal_label_border_radius_field']) ? $campoal_options['conikal_label_border_radius_field'] : '6px';
            $label_bg_color = isset($campoal_options['conikal_label_bg_color_field']) ? $campoal_options['conikal_label_bg_color_field'] : '#F5EFE0';

            $petition_title     = get_the_title($id);
            $status             = get_post_meta($id, 'petition_status', true);
            $petition_status    = ((int)$status == 1) ? 'block' : 'none';
            $petition_thumbnail = conikal_get_petition_thumbnail($id, 'conikal-petition-thumbnail', false);
            $petition_link      = get_permalink($id);
            $city               = get_post_meta($id, 'petition_city', true);
            $state              = get_post_meta($id, 'petition_state', true);
            $country            = get_post_meta($id, 'petition_country', true);
            $petition_location  = ($city ? $city . ', ' : '') . ($state ? $state . ', ' : '') . ($country ? $country : '');
            $receiver           = conikal_get_decistion_makers($id, true, $decisionmakers_display);
            $petition_receiver  = sprintf(esc_html__('Petition to %s', 'campoal-tapo'), $receiver);
            $petition_description = conikal_get_excerpt_by_id($id, 12);
            $author_id          = get_post_field ('post_author', $id);;
            $author_link        = get_author_posts_url($author_id);
            $author_name        = get_the_author_meta('display_name', $author_id);
            $author_avatar      = conikal_get_avatar_url($author_id, array('size' => 64));
            $supporter_number   = conikal_get_supporter_donors_number($id);
            $supporter_label    = $supporter_number->label;
            $goal               = $supporter_number->goal;
            $sign               = $supporter_number->sign;
            $sign_percent       = ((int)$sign < (int)$goal) && (int)$status != 1 ? ((int)$sign / (int)$goal) * 100 : 100;
            $counter_supporter  = sprintf($supporter_label, esc_html(conikal_format_number('%!,0i', $sign)));
            $comments           = wp_count_comments($id);
            $counter_comment    = conikal_format_number('%!,0i', $comments->approved, true);
            $counter_view       = conikal_format_number('%!,0i', (int) conikal_get_post_views($id), true);
            $shorten_link       = conikal_get_shorten_link($id);

            // get custom sign button label
            $sign_button_text   = conikal_custom_sign_label_button($id);

            // place data if custom share link available
            if (!empty($custom_share_link)) {
                $petition_title     = get_the_title($custom_share_link);
                $petition_link      = get_permalink($custom_share_link);
                $shorten_link       = conikal_get_shorten_link($custom_share_link);
                $petition_thumbnail = conikal_get_petition_thumbnail($custom_share_link, 'conikal-petition-thumbnail', false);
            }

            // Get social meta
            $social_meta        = conikal_social_meta(!empty($custom_share_link) ? $custom_share_link : $id);

            // Get social button data
            $social_buttons     = conikal_social_buttons_data($social_meta, false, '0', $id, $custom_share_link);

            // Get primary button data
            $primary_button     = $social_buttons[$primary_share_button];

            // get icon link
            $primary_button_icon    = !empty($embed_button_icon) ? $embed_button_icon : get_template_directory_uri() . '/images/social/share-primary-facebook.png';
            $shorten_link_icon      = get_template_directory_uri() . '/images/social/share-link.png';

            // find and replce custom variable embed template
            if (!empty($embed_code) && !empty($embed_html_template) && !empty($embed_css_template)) :
                // create variable for share link
                $social_url_var       = array();
                $social_url_value     = array();
                $social_label_var     = array();
                $social_label_value   = array();
                $social_icon_var      = array();
                $social_icon_value    = array();

                foreach ($social_buttons as $key => $value) {
                    $social_url_var[]       = '%' . $key . '_url%';
                    $social_url_value[]     = $value['link'];
                    $social_label_var[]     = '%' . $key . '_label%';
                    $social_label_value[]   = $value['label'];
                    $social_icon_var[]      = '%' . $key . '_icon%';
                    $social_icon_value[]    = get_template_directory_uri() . '/images/social/share-' . $key . '.png';
                }

                // marge two array label and url
                $social_variables    = array_merge($social_url_var, $social_label_var, $social_icon_var);
                $social_values       = array_merge($social_url_value, $social_label_value, $social_icon_value);

                // find and replace custom variable in html template
                $embed_html_find     = array(
                    '%petition_title%',
                    '%petition_thumbnail%',
                    '%petition_link%',
                    '%petition_location%',
                    '%petition_receiver%',
                    '%petition_description%',
                    '%author_link%',
                    '%author_name%',
                    '%author_avatar%',
                    '%counter_view%',
                    '%counter_supporter%',
                    '%counter_comment%',
                    '%sign_text%',
                    '%sign_percent%',
                    '%petition_status%',
                    '%supporter_label%',
                    '%shorten_link%',
                    '%primary_share_url%',
                    '%primary_share_label%',
                    '%primary_button_icon%',
                    '%shorten_link_icon%'
                );
                $embed_html_replace  = array(
                    esc_html($petition_title),
                    esc_url($petition_thumbnail),
                    esc_url($petition_link),
                    esc_html($petition_location),
                    esc_html($petition_receiver),
                    esc_html($petition_description),
                    esc_url($author_link),
                    esc_html($author_name),
                    esc_html($author_avatar),
                    esc_html($counter_view),
                    esc_html($counter_supporter),
                    esc_html($counter_comment),
                    esc_html($sign_button_text),
                    esc_html($sign_percent),
                    esc_html($petition_status),
                    esc_html($supporter_label),
                    esc_attr($shorten_link),
                    esc_attr($primary_button['link']),
                    esc_html($primary_button['label']),
                    esc_attr($primary_button_icon),
                    esc_url($shorten_link_icon)
                );
                    
                $embed_html = str_replace(array_merge($embed_html_find, $social_variables), array_merge($embed_html_replace, $social_values), $embed_html_template);

                // find and replace custom variable in css template
                $embed_css_find     = array(
                    '%main_color%',
                    '%heading_color%',
                    '%caption_color%',
                    '%link_color%',
                    '%border_radius%',
                    '%button_radius%',
                    '%label_radius%',
                    '%label_bg_color%',
                );
                $embed_css_replace  = array(
                    esc_attr($main_color),
                    esc_attr($heading_color),
                    esc_attr($caption_color),
                    esc_attr($link_color),
                    esc_attr($border_radius),
                    esc_attr($button_radius),
                    esc_attr($label_radius),
                    esc_attr($label_bg_color),
                );
                    
                $embed_css = str_replace($embed_css_find, $embed_css_replace, $embed_css_template);

                if ($format == 'style') {
                    $html = '<style>' . $embed_css . '</style>';
                } else if ($format == 'html') {
                    $html = '<body>' . $embed_html . '</body>';
                } else {
                    $html = '<style>' . $embed_css . '</style><body>' . $embed_html . '</body>';
                }

                return $html;
            endif;
        endif;
    }
endif;
?>