<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */

/**
 * Accessing of Open Graph Protocol data
 *
 * @since Campoal Tapo 1.5.0
 */
if( !function_exists('conikal_open_graph_data') ): 
    function conikal_open_graph_data() {
        check_ajax_referer('opengraph_ajax_nonce', 'security');
        global $campoal_options;

        $url = isset($_POST['url']) ? sanitize_text_field($_POST['url']) : '';

        $graph_data = array();
        if ($url != '') {
            $graph = OpenGraph::fetch($url);
            if ($graph) {
                foreach ($graph as $key => $value) {
                    $graph_data[$key] = $value;
                }
            }
        } else {
            $graph = false;
        }

        if($graph) {
            // change sitename to domain name if site name not exist 
            if (!array_key_exists('site_name', $graph_data)) {
                $graph_data['site_name'] = wp_parse_url($url, 1);
                if (array_key_exists('image', $graph_data) && !wp_http_validate_url($graph_data['image'])) {
                    unset($graph_data['image']);
                }
            }

            echo json_encode(array('status'=>true, 'graph' => $graph_data, 'message'=>esc_html__('Access open graph data successfully.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Access open graph data failed.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_open_graph_data', 'conikal_open_graph_data' );
add_action( 'wp_ajax_conikal_open_graph_data', 'conikal_open_graph_data' );

?>