<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */

/**
 * Processing petitions query and get meta post
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_process_petition_query') ): 
    function conikal_process_petition_query($query, $days_trending = false) {
        global $campoal_options;
        $decisionmakers_display = isset($campoal_options['conikal_decisionmakers_display_field']) ? $campoal_options['conikal_decisionmakers_display_field'] : 1;
        $excerpt_words_grid 	= isset($campoal_options['conikal_excerpt_words_grid_field']) ? $campoal_options['conikal_excerpt_words_grid_field'] : 1;
        $excerpt_words_list 	= isset($campoal_options['conikal_excerpt_words_list_field']) ? $campoal_options['conikal_excerpt_words_list_field'] : 1;

        $arrayPetitions = array();
        if($query->have_posts() || $query->post_count) {
            foreach ( $query->posts as $post ) {
                $id                 = $post->ID;
                $approved           = get_post_status($id);
                $link               = get_permalink($id);
                $title              = get_the_title($id);
                $post_date          = get_the_date('Y-m-d', $id);
                $category           =  wp_get_post_terms($id, 'petition_category', true);
                $excerpt            = conikal_get_excerpt_by_id($id, $excerpt_words_list);
                $excerpt_short      = conikal_get_excerpt_by_id($id, $excerpt_words_grid);
                $comments           = wp_count_comments($id);
                $comments_fomated   = conikal_format_number('%!,0i', $comments->approved, true);
                $address            = get_post_meta($id, 'petition_address', true);
                $city               = get_post_meta($id, 'petition_city', true);
                $state              = get_post_meta($id, 'petition_state', true);
                $neighborhood       = get_post_meta($id, 'petition_neighborhood', true);
                $zip                = get_post_meta($id, 'petition_zip', true);
                $country            = get_post_meta($id, 'petition_country', true);
                $lat                = get_post_meta($id, 'petition_lat', true);
                $lng                = get_post_meta($id, 'petition_lng', true);
                $receiver           = conikal_get_decistion_makers($id, true, $decisionmakers_display);
                $updates            = get_post_meta($id, 'petition_update', true);

                $supporter_number           = conikal_get_supporter_donors_number( $id, 'supporter', false );
                $supporter_number_compact   = conikal_get_supporter_donors_number( $id, 'supporter', true );
                
                $goal           = $supporter_number->goal;
                $sign           = $supporter_number->sign;
                $sign_fomated   = $supporter_number->sign_format;
                $sign_compact   = $supporter_number_compact->sign_format;
                $status         = get_post_meta($id, 'petition_status', true);

                $author_id      = $post->post_author;
                $author_name    = conikal_get_author_name($author_id);
                $author_link    = get_author_posts_url($author_id);
                $avatar         = conikal_get_avatar_url($author_id, array('size' => 64));
                $avatar_retina  = conikal_get_avatar_url($author_id, array('size' => 128));

                $author_city          = get_user_meta( $author_id, 'user_city', true);
                $author_state         = get_user_meta( $author_id, 'user_state', true);
                $author_country       = get_user_meta( $author_id, 'user_country', true);

                $thumbnail                  = conikal_get_petition_thumbnail($id, 'conikal-petition-thumbnail', false);
                $thumbnail_retina           = conikal_get_petition_thumbnail($id, 'conikal-petition-thumbnail-retina', false);

                $thumbnail_medium           = conikal_get_petition_thumbnail($id, 'conikal-petition-medium', false);
                $thumbnail_medium_retina    = conikal_get_petition_thumbnail($id, 'conikal-petition-medium-retina', false);
                
                $thumbnail_small            = conikal_get_petition_thumbnail($id, 'conikal-petition-small', false);
                $thumbnail_small_retina     = conikal_get_petition_thumbnail($id, 'conikal-petition-small-retina', false);

                $lazy_placeholder           = conikal_lazy_load_placeholder('thumbnail');
                $lazy_placeholder_medium    = conikal_lazy_load_placeholder('thumbnail-medium');
                $lazy_placeholder_small     = conikal_lazy_load_placeholder('thumbnail-small');
                $lazy_placeholder_avatar    = conikal_lazy_load_placeholder('avatar');

                $arrayPetition = array(
                    'id'                        => $id,
                    'approved'                  => $approved,
                    'link'                      => $link,
                    'title'                     => $title,
                    'date'                      => $post_date,
                    'category_name'             => (isset($category[0]) ? $category[0]->name : ''),
                    'category_link'             => (isset($category[0]) ? get_term_link($category[0]->term_id) : ''),
                    'excerpt'                   => $excerpt,
                    'excerpt_short'             => $excerpt_short,
                    'comments'                  => $comments->approved,
                    'comments_fomated'          => $comments_fomated,
                    'comments_label'            => sprintf( _n('%s comment', '%s comments', $comments->approved, 'campoal-tapo'), $comments_fomated ),
                    'view'                      => (function_exists('conikal_get_post_views') ? conikal_format_number('%!,0i', (int) conikal_get_post_views($id), true) : ''),
                    'address'                   => $address,
                    'city'                      => $city,
                    'state'                     => $state,
                    'neighborhood'              => $neighborhood,
                    'zip'                       => $zip,
                    'country'                   => $country,
                    'lat'                       => $lat,
                    'lng'                       => $lng,
                    'receiver'                  => $receiver,
                    'updates'                   => $updates,
                    'thumbnail'                 => (wp_is_mobile() ? $thumbnail_medium : $thumbnail),
                    'thumbnail_medium'          => $thumbnail_medium,
                    'thumbnail_small'           => $thumbnail_small,
                    'thumbnail_retina'          => (wp_is_mobile() ? $thumbnail_medium_retina : $thumbnail_retina),
                    'thumbnail_medium_retina'   => $thumbnail_medium_retina,
                    'thumbnail_small_retina'    => $thumbnail_small_retina,
                    'lazy_placeholder'          => (wp_is_mobile() ? $lazy_placeholder_medium : $lazy_placeholder_small),
                    'lazy_placeholder_medium'   => $lazy_placeholder_medium,
                    'lazy_placeholder_small'    => $lazy_placeholder_small,
                    'lazy_placeholder_avatar'   => $lazy_placeholder_avatar,
                    'status'                    => $status,
                    'author_avatar'             => $avatar,
                    'author_avatar_retina'      => $avatar_retina,
                    'author_name'               => $author_name,
                    'author_link'               => $author_link,
                    'author_city'               => $author_city,
                    'author_state'              => $author_state,
                    'author_country'            => $author_country,
                    'goal'                      => $goal,
                    'sign'                      => $sign,
                    'sign_fomated'              => $sign_fomated,
                    'sign_compact'              => $sign_compact,
                    'supporter_label'           => $supporter_number->label,
                    'supporter_label_compact'   => $supporter_number_compact->label,
                    'supporter_text'            => $supporter_number->text,
                );

                // calculating trending index of petition
                if ($days_trending) {
                    $date = current_time('mysql');
                    $date = strtotime($date);
                    $arrDate = array();
                    for ($i=0; $i <= $days_trending; $i++) { 
                        $date = strtotime('-'.$i.' day', $date);
                        array_push($arrDate, date('m/d', $date));
                        $date = current_time('mysql');
                        $date = strtotime($date);
                    }

                    $sign_users = get_post_meta($id, 'petition_users', true);
                    $usrDate = array();
                    if (!empty($sign_users)) {
                        foreach ($sign_users as $user) {
                            $user_date = $date = strtotime($user['date']);
                            $user_date = date('m/d', $user_date);
                            array_push($usrDate, $user_date);
                        }
                    }
                    
                    $usrDate = array_count_values($usrDate);
                    $totalData = array();
                    foreach ($usrDate as $sign_date => $sign_count) {
                        if ( in_array($sign_date, $arrDate) ) {
                            $totalData[$sign_date] = $sign_count;
                        }
                    }
                    foreach ($arrDate as $date) {
                        if ( array_key_exists($date, $totalData) ) {
                            
                        } else {
                            $totalData[$date] = 0;
                        }
                    }
                    ksort($totalData);
                    $trending = 0;
                    foreach ($totalData as $date => $signs) {
                        $trending = $trending + $signs;
                    }

                    $arrayPetition['trending'] = $trending;
                }

                // add single petition to array of petition
                $arrayPetition = (object) $arrayPetition;
                array_push($arrayPetitions, $arrayPetition);
            }
        } else {
            $arrayPetitions = false;
        }

        return $arrayPetitions;
    }
endif;


/**
 * Load more victory petition
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_load_victory_petitions') ): 
    function conikal_load_victory_petitions() {
        check_ajax_referer('load_victory_petitions_ajax_nonce', 'security');
        global $campoal_options;
        $sortby_default = isset($campoal_options['conikal_sortby_default_field']) ? $campoal_options['conikal_sortby_default_field'] : 'date';
        $order_default = isset($campoal_options['conikal_order_default_field']) ? $campoal_options['conikal_order_default_field'] : 'DESC';
        $minimum_signature = isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;
        
        $order              = isset($_GET['order']) && !empty($_GET['order']) ? sanitize_text_field($_GET['order']) : $order_default;
        $orderby            = isset($_GET['orderby']) && !empty($_GET['orderby']) ? sanitize_text_field($_GET['orderby']) : $sortby_default;
        $posts_per_page     = isset($_GET['posts_per_page']) && !empty($_GET['posts_per_page']) ? sanitize_text_field($_GET['posts_per_page']) : 7;

        $args = array(
        'posts_per_page'   => $posts_per_page,
        'post_type'        => 'petition',
        'orderby'          => $orderby,
        'order'            => $order,
        'meta_key'         => 'petition_victory',
        'meta_value'       => '1',
        'post_status'      => 'publish' );

        $args['meta_query'] = array('relation' => 'AND');

        if ($minimum_signature != 0) {
            array_push($args['meta_query'], array(
                'key'     => 'petition_sign',
                'value'   => $minimum_signature,
                'type'    => 'NUMERIC',
                'compare' => '>='
            ));
        }
        array_push($args['meta_query'], array(
            'key'     => 'petition_status',
            'value'   => 2,
            'compare' => '!=',
            'type'    => 'NUMERIC'
        ));

        $petitions = new WP_Query($args);
        
        wp_reset_query();
        wp_reset_postdata();

        // processing query and get meta post.
        $arrayPetitions = conikal_process_petition_query($petitions);

        if ($arrayPetitions) {
            echo json_encode(array('status' => true, 'petitions' => $arrayPetitions, 'message' => esc_html__('Petitions was loaded successfully.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status' => false, 'message' => esc_html__('Something went wrong. Not found petitions.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;

add_action( 'wp_ajax_nopriv_conikal_load_victory_petitions', 'conikal_load_victory_petitions' );
add_action( 'wp_ajax_conikal_load_victory_petitions', 'conikal_load_victory_petitions' );


/**
 * Check user has purchased donation
 *
 * @since Campoal Tapo 1.6.5
 */
if( !function_exists('conikal_user_purchased_donation') ):
    function conikal_user_purchased_donation($form_id) {
        global $current_user;

        if (class_exists('Give') && is_user_logged_in()) {
            $donor = new Give_Donors_Query( array('user' => $current_user->ID) );
            $donor = $donor->get_donors();

            if ($donor) {
                $donor = current( $donor );
                
                $args = array(
                    'give_forms'    => array($form_id),
                    'donor'         => $donor->id,
                    'order'         => 'DESC'
                );
                $contributes = give_get_payments( $args );

                $user_purchased = false;
                foreach($contributes as $contribute) {
                    $customer_id = give_get_payment_donor_id( $contribute->ID );

                    if ($customer_id) {
                        $customer    = new Give_Customer( $customer_id );
                        $user = get_user_by('ID', $customer->user_id);
                        if ($user && $user->ID == $current_user->ID) {
                            $user_purchased = true; 
                        }
                    }
                }
            } else {
                $user_purchased = false;
            }
        } else {
            $user_purchased = false;
        }    

        return $user_purchased;   
    }
endif;


/**
* Reset post per page on custom post type
*
* @since Campoal Tapo 1.0.0
*/
add_filter('option_posts_per_page', 'conikal_tax_filter_posts_per_page');
if (!function_exists('conikal_tax_filter_posts_per_page')) :
	function conikal_tax_filter_posts_per_page( $value ) {
		if (is_tax('petition_category') || is_tax('petition_topics')) {
			$value = 1;
		}
		
		return $value;
	}
endif;
?>