<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Get signature nummber
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_get_signatures_number') ): 
    function conikal_get_signatures_number() {
        check_ajax_referer('sign_ajax_nonce', 'security');
        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';

        $sign_key = 'petition_sign';
        $status = get_post_meta($post_id, 'petition_status', true);
        $sign_no = get_post_meta($post_id, $sign_key, true);
        $goal_no = get_post_meta($post_id, 'petition_goal', true);
        $need_no = ($goal_no - $sign_no);

        if ($status == '0') {
            echo json_encode(array('status'=>true, 'number' => $sign_no, 'signature' => esc_html( conikal_format_number('%!,0i', $sign_no) ), 'need' => esc_html( conikal_format_number('%!,0i', $need_no) ) ));
        } else {
            echo json_encode(array('status'=>false, 'number' => $sign_no, 'signature' => esc_html( conikal_format_number('%!,0i', $sign_no) ), 'need' => esc_html( conikal_format_number('%!,0i', $need_no) ) ));
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_get_signatures_number', 'conikal_get_signatures_number' );
add_action( 'wp_ajax_conikal_get_signatures_number', 'conikal_get_signatures_number' );


/**
 * Add signature to user and petition
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_add_to_signatures') ): 
    function conikal_add_to_signatures() {
        check_ajax_referer('sign_ajax_nonce', 'security');

        global $campoal_options;
        $recaptcha_sign         = isset($campoal_options['conikal_google_recaptcha_sign_field']) ? $campoal_options['conikal_google_recaptcha_sign_field'] : 1;
        $receive_update         = isset($campoal_options['conikal_receive_update_field']) ? $campoal_options['conikal_receive_update_field'] : 'checked';
        $sign_anonymous         = isset($campoal_options['conikal_sign_anonymous_field']) ? $campoal_options['conikal_sign_anonymous_field'] : 'checked';

        $post_id    = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id    = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $comment    =  isset($_POST['comment']) ? sanitize_text_field($_POST['comment']) : '';
        $anonymous  = isset($_POST['anonymous']) && $sign_anonymous != 'none' ? $_POST['anonymous'] : 0;
        $notice     = isset($_POST['notice']) && $receive_update != 'none' ? $_POST['notice'] : 1;
        $ip_address = conikal_get_client_ip();
        $sendinblue_list = get_post_meta($post_id, 'petition_sendinblue_list', true);

        $sign_key = 'petition_sign';
        $sign_users_key = 'petition_users';
        $sign = get_user_meta($user_id, $sign_key, true);
        $sign_number = get_post_meta($post_id, $sign_key, true);
        $sign_users = get_post_meta($post_id, $sign_users_key, true);

        // add comment for signature
        if ($comment != '') {
            $comment_id = conikal_add_comment_sign($user_id, $post_id, $comment, $anonymous);
        } else {
            $comment_id = false;
        }

        // add post id to user signed
        if($sign == '') {
            $sign = array();
            delete_user_meta($user_id, $sign_key);
            add_user_meta($user_id, $sign_key, $sign);
        }

        if(is_array($sign) && in_array($post_id, $sign) === false) {
            array_push($sign, $post_id);
            update_user_meta($user_id, $sign_key, $sign);
        }

        // add user to post
        if ($sign_users == '') {
            $sign_users = array();
            delete_post_meta($post_id, $sign_users_key);
            add_post_meta($post_id, $sign_users_key, $sign_users);
        }

        if(is_array($sign_users) && array_key_exists($user_id, $sign_users) === false) {
            $sign_number = intval($sign_number) + 1;
            $sign_users[$user_id] = array('user_id' => $user_id, 'date' => current_time('mysql'), 'comment_id' => $comment_id, 'anonymous' => $anonymous, 'notice' => $notice, 'ip_address' => $ip_address);
            update_post_meta($post_id, $sign_key, $sign_number);
            update_post_meta($post_id, $sign_users_key, $sign_users);
        }

        $sign_no = get_post_meta($post_id, $sign_key, true);
        $goal_no = get_post_meta($post_id, 'petition_goal', true);
        $need_no = ($goal_no - $sign_no);

        // auto increase goal
        if ($need_no <= 0) {
            conikal_auto_increase_goal($post_id);
        }

        // save user email into sendinblue
        $sendinblue = conikal_sendinblue_users_list($sendinblue_list, $user_id, 'add', $notice);

        echo json_encode(array('status'=>true, 'number' => $sign_no, 'signature' => esc_html( conikal_format_number('%!,0i', $sign_no) ), 'need' => esc_html( conikal_format_number('%!,0i', $need_no) ), 'sendinblue' => $sendinblue) );

        // send an email notification
        conikal_signature_notifications($post_id, $user_id, $comment);

        // send milestone email notification
        conikal_decision_maker_new_milestone_notification($post_id);

        // send new signature notification to decision maker
        conikal_decision_maker_notification('signature', $post_id, $user_id);

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_add_to_signatures', 'conikal_add_to_signatures' );
add_action( 'wp_ajax_conikal_add_to_signatures', 'conikal_add_to_signatures' );


/**
 * Remove signature from user and petiton
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_remove_from_signatures') ): 
    function conikal_remove_from_signatures() {
        check_ajax_referer('sign_ajax_nonce', 'security');
        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $sendinblue_list = get_post_meta($post_id, 'petition_sendinblue_list', true);

        $sign_key = 'petition_sign';
        $sign_users_key = 'petition_users';
        $sign = get_user_meta($user_id, $sign_key, true);
        $sign_number = get_post_meta($post_id, $sign_key, true);
        $sign_users = get_post_meta($post_id, $sign_users_key, true);

        if(in_array($post_id, $sign)) {
            $sign = array_diff($sign, array($post_id));
            $sign_number = intval($sign_number) - 1;
            unset($sign_users[$user_id]);
            update_user_meta($user_id, $sign_key, $sign);
            update_post_meta($post_id, $sign_key, $sign_number);
            update_post_meta($post_id, $sign_users_key, $sign_users);
        }
        $sign_no = get_post_meta($post_id, $sign_key, true);
        $goal_no = get_post_meta($post_id, 'petition_goal', true);
        $need_no = ($goal_no - $sign_no);

        // remove user email from sendinblue list
        $sendinblue = conikal_sendinblue_users_list($sendinblue_list, $user_id, 'remove');

        echo json_encode(array('status'=>true, 'number' => $sign_no, 'signature' => esc_html( conikal_format_number('%!,0i', $sign_no) ), 'need' => esc_html( conikal_format_number('%!,0i', $need_no) ), 'sendinblue' => array($sendinblue)));

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_remove_from_signatures', 'conikal_remove_from_signatures' );
add_action( 'wp_ajax_conikal_remove_from_signatures', 'conikal_remove_from_signatures' );


/**
 * Add signature in libs for guest signing
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_add_to_signatures_plus') ): 
    function conikal_add_to_signatures_plus($user_id, $post_id, $comment = '', $notice = 1, $anonymous = 0) {

        // add comment for signature
        if ($comment != '') {
            $comment_id = conikal_add_comment_sign($user_id, $post_id, $comment, $anonymous);
        } else {
            $comment_id = false;
        }
        
        $ip_address = conikal_get_client_ip();
        $sign_key = 'petition_sign';
        $sign_users_key = 'petition_users';
        $sign = get_user_meta($user_id, $sign_key, true);
        $sign_number = get_post_meta($post_id, $sign_key, true);
        $sign_users = get_post_meta($post_id, $sign_users_key, true);
        $arrUser = array('user_id' => $user_id, 'date' => current_time('mysql'), 'comment_id' => $comment_id, 'anonymous' => $anonymous, 'notice' => $notice, 'ip_address' => $ip_address);
        $sendinblue_list = get_post_meta($post_id, 'petition_sendinblue_list', true);
    
        if($sign == '') {
            $sign = array();
            delete_user_meta($user_id, $sign_key);
            add_user_meta($user_id, $sign_key, $sign);
        }

        if ($sign_users == '') {
            $sign_users = array();
            update_post_meta($post_id, $sign_users_key, $sign_users);
        }

        if(in_array($post_id, $sign) === false) {
            array_push($sign, $post_id);
            $sign_number = intval($sign_number) + 1;
            $sign_users[$user_id] = $arrUser;
            update_user_meta($user_id, $sign_key, $sign);
            update_post_meta($post_id, $sign_key, $sign_number);
            update_post_meta($post_id, $sign_users_key, $sign_users);

            // auto increase goal
            conikal_auto_increase_goal($post_id);

            // send an email notification
            conikal_signature_notifications($post_id, $user_id, $comment);

            // send milestone email notification
            conikal_decision_maker_new_milestone_notification($post_id);

            // send new signature notification to decision maker
            conikal_decision_maker_notification('signature', $post_id, $user_id);

            // save user email into sendinblue
            conikal_sendinblue_users_list($sendinblue_list, $user_id, 'add', $notice);

            // update subsribers to supporter number
            conikal_sendinblue_subscribers_to_supporters($sendinblue_list, $post_id);
            
            $result = $sign_users[$user_id];
        } else {
            $result = false;
        }

        return $result;
    }
endif;


/**
 * Remove signature in libs from user and petiton
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_remove_signatures_link') ): 
    function conikal_remove_signatures_link($user_id = '', $post_id = '') {
        $sendinblue_list = get_post_meta($post_id, 'petition_sendinblue_list', true);

        $sign_key = 'petition_sign';
        $sign_users_key = 'petition_users';
        $sign = get_user_meta($user_id, $sign_key, true);
        $sign_number = get_post_meta($post_id, $sign_key, true);
        $sign_users = get_post_meta($post_id, $sign_users_key, true);

        if(in_array($post_id, $sign)) {
            $sign = array_diff($sign, array($post_id));
            $sign_number = intval($sign_number) - 1;
            unset($sign_users[$user_id]);
            update_user_meta($user_id, $sign_key, $sign);
            update_post_meta($post_id, $sign_key, $sign_number);
            update_post_meta($post_id, $sign_users_key, $sign_users);

            // remove user email from sendinblue list
            conikal_sendinblue_users_list($sendinblue_list, $user_id, 'remove');

            $result = true;
        } else {
            $result = false;
        }
        return $result;     
    }
endif;


/**
 * Auto increase goal when signature achive goal
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_auto_increase_goal') ): 
    function conikal_auto_increase_goal($post_id) {
        global $campoal_options;
        
        $auto_increase_goal = isset($campoal_options['conikal_auto_increase_goal_field']) ? $campoal_options['conikal_auto_increase_goal_field'] : 0;
        $auto_increase_goal_default = isset($campoal_options['conikal_auto_increase_goal_d_field']) ? $campoal_options['conikal_auto_increase_goal_d_field'] : 0;
        $auto_increase_percent = get_post_meta($post_id, 'petition_increase', true);
        $auto_increase_percent = $auto_increase_percent ? $auto_increase_percent : $auto_increase_goal_default;

        if ($auto_increase_goal == 1 && $auto_increase_percent != 0) {
            $sign_no = get_post_meta($post_id, 'petition_sign', true);
            $goal_no = get_post_meta($post_id, 'petition_goal', true);
            if ($sign_no && $goal_no) {
                $need_no = ($goal_no - $sign_no);
                if ($need_no <= 0) {
                    $add_goal = $goal_no * ((int)$auto_increase_percent / 100);
                    $new_goal = $goal_no + round($add_goal);
                    $new_goal_rounded = round( $new_goal, -(strlen($new_goal) - 1) );
                    update_post_meta($post_id, 'petition_goal', $new_goal_rounded);

                    return true;
                } else {
                    return false;
                }
            } else {
                return false;
            }
        } else {
            return false;
        }
    }
endif;


/**
 * Add temporary signature when not verify email
 *
 * @since Campoal Tapo 1.6.7
 */
if (!function_exists('conikal_add_temporary_signature')) :
    function conikal_add_temporary_signature($user_id, $post_id, $comment = '', $notice = 1, $anonymous = 0) {
        if (empty($user_id) || empty($post_id)) {
            return false;
        }

        $ip_address = conikal_get_client_ip();
        $temporary_sign_key = 'petition_sign_temporary';
        $sign_temporary = get_user_meta($user_id, $temporary_sign_key, true);

        $arrUser = array(
            'post_id' => $post_id,
            'date' => current_time('mysql'), 
            'comment' => $comment,
            'anonymous' => $anonymous, 
            'notice' => $notice, 
            'ip_address' => $ip_address,
        );

        if($sign_temporary == '') {
            $sign_temporary = array();
            delete_user_meta($user_id, $temporary_sign_key);
            add_user_meta($user_id, $temporary_sign_key, $sign_temporary);
        }

        if(!array_key_exists($post_id, $sign_temporary)) {
            $sign_users[$post_id] = $arrUser;
            update_user_meta($user_id, $temporary_sign_key, $sign_users);

            $result = $sign_users;
        } else {
            $result = false;
        }

        return $result;
    }
endif;


/**
 * Move temporary signature to really signature when email verified
 *
 * @since Campoal Tapo 1.6.7
 */
if (!function_exists('conikal_temporary_to_really_signature')) :
    function conikal_temporary_to_really_signature($user_id) {
        $sign_temporary = get_user_meta($user_id, 'petition_sign_temporary', true);

        $signature_added = array();
        if (!empty($sign_temporary)) {
            foreach ($sign_temporary as $id => $signature) {
                // add to petition signature
                $addsign = conikal_add_to_signatures_plus($user_id, $id, $signature['comment'], $signature['notice'], $signature['anonymous']);

                if ($addsign) {
                    // push signature added list
                    $signature_added[$id] = $sign_temporary[$id];
                    
                    //remove temporary signature
                    unset($sign_temporary[$id]);
                }   
            }
        }

        // delete temporary signature
        if (empty($sign_temporary)) {
            delete_user_meta($user_id, 'petition_sign_temporary');
        }

        // return signatures added
        if (!empty($signature_added)) {
            return $signature_added;
        } else {
            return false;
        }
    }
endif;



?>