<?php 


/**
 * Registers and sets up the Withdraw custom post type
 *
 * @since Campoal Tapo 1.0.0
 */

add_action( 'init', 'conikal_register_withdraw_type', 10 );
if( !function_exists('conikal_register_withdraw_type') ):
    function conikal_register_withdraw_type() {
        register_post_type('withdraw', array(
            'labels' => array(
                'name'                  => esc_html__('Withdraw', 'campoal-tapo'),
                'singular_name'         => esc_html__('Withdraw', 'campoal-tapo'),
                'add_new'               => esc_html__('Add New Withdraw', 'campoal-tapo'),
                'add_new_item'          => esc_html__('Add Withdraw', 'campoal-tapo'),
                'edit'                  => esc_html__('Edit', 'campoal-tapo'),
                'edit_item'             => esc_html__('Edit Withdraw', 'campoal-tapo'),
                'new_item'              => esc_html__('New Withdraw', 'campoal-tapo'),
                'view'                  => esc_html__('View', 'campoal-tapo'),
                'view_item'             => esc_html__('View Withdraw', 'campoal-tapo'),
                'search_items'          => esc_html__('Search Withdraw', 'campoal-tapo'),
                'not_found'             => esc_html__('No Withdraws found', 'campoal-tapo'),
                'not_found_in_trash'    => esc_html__('No Withdraws found in Trash', 'campoal-tapo'),
                'parent'                => esc_html__('Parent Withdraw', 'campoal-tapo'),
            ),
            'public'                => true,
            'exclude_from_search '  => true,
            'has_archive'           => true,
            'rewrite'               => array('slug' => 'withdraw'),
            'supports'              => array('author'),
            'can_export'            => true,
            'menu_icon'             => 'dashicons-money-alt',
        ));
    }
endif;

// Add custom column for Withdraw post type in admin
if( !function_exists('conikal_withdraw_custom_column') ):
    function conikal_withdraw_custom_column($defaults) {
        unset($defaults['title']);
        $defaults['type'] = esc_html__('Type','campoal-tapo');
        $defaults['amount'] = esc_html__('Amount','campoal-tapo');
        $defaults['metmod'] = esc_html__('Method','campoal-tapo');
        $defaults['status'] = esc_html__('Status','campoal-tapo');
        $defaults['detail'] = esc_html__('Details','campoal-tapo');
        return $defaults;
    }
endif;
add_filter('manage_withdraw_posts_columns', 'conikal_withdraw_custom_column');

if( !function_exists('conikal_withdraw_custom_column_views') ):
    function conikal_withdraw_custom_column_views($column_name, $id) {
        if ($column_name === 'type') {
            $withdraw_type = conikal_withdraw_label(get_the_ID());
            if ($withdraw_type) {
                echo '<div class="row-title">' . esc_html($withdraw_type->type) . '</div>';
            }
        }
        if ($column_name === 'amount') {
            $amount = get_post_meta(get_the_ID(), 'withdraw_amount', true);

            if ($amount) {
                $amount = give_currency_filter( give_format_amount( $amount, array( 'sanitize' => false ) ) );
            } else {
                $amount = '-';
            }
            if ($amount) {
                echo '<div class="row-title">' . esc_html($amount) . '</div>';
            }
        }
        if ($column_name === 'metmod') {
            $withdraw_metmod = conikal_withdraw_label(get_the_ID());
            if ($withdraw_metmod) {
                echo '<div class="row-title">' . esc_html($withdraw_metmod->method) . '</div>';
            }
        }
        if ($column_name === 'status') {
            $status = conikal_get_withdraw_status(get_the_ID());
            if ($status) {
                echo '<div>' . esc_html($status->label) . '</div>';
            }
        }
        if ($column_name === 'detail') {
            echo '<a href="' . get_edit_post_link(get_the_ID()) . '" class="give-payment-details-link button button-small"><span class="dashicons dashicons-visibility"></span></a>';
        }
    }
endif;
add_action('manage_withdraw_posts_custom_column', 'conikal_withdraw_custom_column_views', 5, 2);

if( !function_exists('conikal_withdraw_detail_render') ):
    function conikal_withdraw_detail_render() {
        global $post;

        wp_nonce_field(plugin_basename(__FILE__), 'withdraw_noncename');

        $post_id = $_GET['post'];
        $author_id = get_post_field ('post_author', $post_id);
        $user = get_userdata($author_id);
        $balance = conikal_give_balance($author_id);
        $type = get_post_meta($post_id, 'withdraw_type', true);
        $method = get_post_meta($post_id, 'withdraw_method', true);
        $type_method = conikal_withdraw_label($post_id);
        $status = get_post_status($post_id);
        $status_label = conikal_get_withdraw_status($post_id);

        // update amount when not complete
        if ($status == 'pending' && $type == 'all') {
            update_post_meta($post_id, 'withdraw_amount', $balance);
        }

        // get withdraw amount
        $amount = get_post_meta($post_id, 'withdraw_amount', true);
        if ($amount) {
            $amount = give_currency_filter( give_format_amount( $amount, array( 'sanitize' => false ) ) );
        } else {
            $amount = '-';
        }

        // get financial infomation
        $paypal     = get_user_meta($author_id, 'financial_paypal', true);
        $payoneer   = get_user_meta($author_id, 'financial_payoneer', true);
        $bank       = get_user_meta($author_id, 'financial_bank', true);
        $bitcoin 	= get_user_meta($author_id, 'financial_bitcoin', true);


        // convert financial infomation to object
        $paypal_details = $paypal ? (object) $paypal : '';
        $payoneer_details = $payoneer ? (object) $payoneer : '';
        $bank_details = $bank ? (object) $bank : '';
        $bitcion_details 	= $bitcoin ? (object) $bitcoin : '';
        ?>
        <table width="100%" border="0" cellspacing="0" cellpadding="0">
            <tr>
                <td width="50%" valign="top" align="left">
                    <h1><?php esc_html_e("User's Balance", 'campoal-tapo') ?>: <?php echo give_currency_filter( give_format_amount( $balance, array( 'sanitize' => false ) ) ) ?></h1>
                </td>
                <td width="50%" valign="top" align="right">
                    <h1><?php echo esc_html__('#', 'campoal-tapo') . esc_html($post_id) ?></h1>
                </td>
            </tr>
        </table>
        <hr>
        <table width="100%" border="0" cellspacing="0" cellpadding="0">
            <tr>
                <td width="25%" valign="top" align="left">
                    <h3><?php echo esc_html__('Type', 'campoal-tapo') . ': ' . esc_html($type_method->type) ?></h3>
                </td>
                <td width="25%" valign="top" align="left">
                    <h3><?php echo esc_html__('Amount', 'campoal-tapo') . ': ' . esc_html($amount) ?></h3>
                </td>
                <td width="25%" valign="top" align="left">
                    <h3><?php echo esc_html__('Method', 'campoal-tapo') . ': ' . esc_html($type_method->method) ?></h3>
                </td>
                <td width="25%" valign="top" align="right">
                    <h3><?php echo esc_html__('Status', 'campoal-tapo') . ': ' . esc_html($status_label->label) ?></h3>
                </td>
            </tr>
        </table>
        <hr>
        <table width="100%" border="0" cellspacing="0" cellpadding="0">
            <tr>
                <td width="50%" valign="top" align="left">
                    <h3><?php echo esc_html__('User infomation', 'campoal-tapo') ?></h3>
                    <p>
                        <?php
                            echo esc_html__('Display name', 'campoal-tapo') . ': <strong>' . esc_html($user->display_name) . '</strong><br>';
                            echo esc_html__('User ID', 'campoal-tapo') . ': <strong>' . esc_html($user->ID) . '</strong><br>';
                            echo esc_html__('Username', 'campoal-tapo') . ': <strong>' . esc_html($user->user_login) . '</strong><br>';
                            echo esc_html__('Email', 'campoal-tapo') . ': <strong>' . esc_html($user->user_email) . '</strong><br>';
                            echo esc_html__('Registered', 'campoal-tapo') . ': <strong>' . esc_html($user->user_registered) . '</strong><br>';
                            echo esc_html__('First name', 'campoal-tapo') . ': <strong>' . esc_html($user->first_name) . '</strong><br>';
                            echo esc_html__('Last name', 'campoal-tapo') . ': <strong>' . esc_html($user->last_name) . '</strong><br>';
                        ?>
                    </p>
                </td>
                <td width="50%" valign="top" align="left">
                    <h3><?php esc_html_e('Payment infomation', 'campoal-tapo') ?></h3>
                    <p>
                    <?php if ($method == 'paypal' && $paypal_details) { ?>
                        <?php esc_html_e('PayPal Email', 'campoal-tapo') ?>: <strong><?php echo esc_html($paypal_details->email) ?></strong>
                    <?php } elseif ($method == 'payoneer' && $payoneer_details) { ?>
                        <?php esc_html_e('Payoneer Email', 'campoal-tapo') ?>: <strong><?php echo esc_html($payoneer_details->email) ?></strong><br>
                        <?php esc_html_e('Payoneer Card', 'campoal-tapo') ?>: <strong><?php echo esc_html($payoneer_details->card) ?></strong>
                    <?php } elseif ($method == 'bitcoin' && $bitcion_details) { ?>
                    <?php esc_html_e('Network', 'campoal-tapo') ?>: <strong><?php echo esc_html($bitcion_details->network) ?></strong><br>
                    <?php esc_html_e('Address', 'campoal-tapo') ?>: <strong><?php echo esc_html($bitcion_details->address) ?></strong>
                    <?php } else if ($bank_details) { ?>
                        <h4><?php echo esc_html__('Account holder', 'campoal-tapo') ?></h4>
                        <?php
                        echo esc_html__('Name of the account holder', 'campoal-tapo') . ': <strong>' . esc_html($bank_details->fullname) . '</strong><br>';
                        echo esc_html__('User Address', 'campoal-tapo') . ': <strong>' . esc_html($bank_details->user_address) . '</strong><br>';
                        echo '<h4>' . esc_html__('Bank infomation', 'campoal-tapo') . '</h4>';
                        echo esc_html__('Bank Name', 'campoal-tapo') . ': <strong>' . esc_html($bank_details->name) . '</strong><br>';
                        echo esc_html__("Bank's Address", 'campoal-tapo') . ': <strong>' . esc_html($bank_details->address) . '</strong><br>';
                        echo esc_html__('SWIFT code', 'campoal-tapo') . ': <strong>' . esc_html($bank_details->swift_code) . '</strong><br>';
                        echo esc_html__('Account number', 'campoal-tapo') . ': <strong>' . esc_html($bank_details->account_number) . '</strong><br>';
                    } ?>
                    </p>
                </td>
            </tr>
        </table>
<?php }
endif;

?>