<?php 
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Create new Sendinblue mail list and update mail list
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_sendinblue_list') ): 
    function conikal_sendinblue_list($petition_id, $list_id, $list_name, $type = 'petition') {
    	global $campoal_options;
    	
    	$api_url 				= isset($campoal_options['conikal_sendinblue_api_url_field']) ? $campoal_options['conikal_sendinblue_api_url_field'] : '';
    	$sendinblue_list_status = isset($campoal_options['conikal_sendinblue_list_field']) ? $campoal_options['conikal_sendinblue_list_field'] : 0;
    	$sendinblue_key 		= isset($campoal_options['conikal_sendinblue_key_field']) ? $campoal_options['conikal_sendinblue_key_field'] : '';
    	$sendinblue_folder 		= isset($campoal_options['conikal_sendinblue_folder_id_field']) ? $campoal_options['conikal_sendinblue_folder_id_field'] : '';

		if ($type == 'petition') {
			$prefix = 'petition_';
		} else {
			$prefix = '_give_';
		}

    	if ($sendinblue_list_status == 1 && $sendinblue_key != '' && class_exists('SendinBlueMailin')) {
	    	$mailin = new SendinBlueMailin($api_url, $sendinblue_key);
		    $data = array(
		    	'list_name' => $list_name,
		      	'list_parent' => $sendinblue_folder
		    );

		    if ($list_id != '') {
		    	// update sendinblue list
	    		$data['id'] = $list_id;
	    		$list = $mailin->update_list($data);
	    	} else {
	    		// create new list
	    		$list = $mailin->create_list($data);

	    		// update sendinblue list id to petition
	    		if ($list['code'] == 'success') {
	    			update_post_meta($petition_id, $prefix . 'sendinblue_list', $list['data']['id']);
	    		}
	    	}
	    } else {
	    	$list = false;
	    }

    	return $list;
    }
endif;

/**
 * Create new Sendinblue user and add exist user to mail list
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_sendinblue_users_list') ): 
    function conikal_sendinblue_users_list($list_id, $user_id, $opt_in = 1, $action = 'add') {
    	global $campoal_options;
    	
    	$api_url 				= isset($campoal_options['conikal_sendinblue_api_url_field']) ? $campoal_options['conikal_sendinblue_api_url_field'] : '';
    	$sendinblue_list_status = isset($campoal_options['conikal_sendinblue_list_field']) ? $campoal_options['conikal_sendinblue_list_field'] : 0;
    	$sendinblue_key 		= isset($campoal_options['conikal_sendinblue_key_field']) ? $campoal_options['conikal_sendinblue_key_field'] : '';
    	$sendinblue_folder 		= isset($campoal_options['conikal_sendinblue_folder_id_field']) ? $campoal_options['conikal_sendinblue_folder_id_field'] : '';
    	$sendinblue_name 		= isset($campoal_options['conikal_sendinblue_name_field']) ? $campoal_options['conikal_sendinblue_name_field'] : 'NAME';
    	$sendinblue_firstname 	= isset($campoal_options['conikal_sendinblue_firstname_field']) ? $campoal_options['conikal_sendinblue_firstname_field'] : 'FIRSTNAME';
    	$sendinblue_opt_in 		= isset($campoal_options['conikal_sendinblue_opt_in_field']) ? $campoal_options['conikal_sendinblue_opt_in_field'] : 'DOUBLE_OPT-IN';
    	$sendinblue_force_add   = isset($campoal_options['conikal_sendinblue_force_add_field']) ? $campoal_options['conikal_sendinblue_force_add_field'] : 1;
    	$user 					= get_user_by('ID', $user_id);

    	if (($sendinblue_force_add == 1 || $opt_in == 1) && $sendinblue_list_status == 1 && $sendinblue_key != '' && class_exists('SendinBlueMailin')) {
	    	$mailin = new SendinBlueMailin($api_url, $sendinblue_key);
		    $data = array(
		    	'id' => $list_id,
		      	'users' => array($user->user_email),
		    );
	 
	 		if ($action == 'add') {
	 			// add exist user
	 			$list = array();

	 			// check user not exist
 				$new_contact = array(
 					"email" => $user->user_email,
			        "attributes" => array(
			        	$sendinblue_name => $user->last_name, 
			        	$sendinblue_firstname => $user->first_name,
			        	$sendinblue_opt_in => ($opt_in == 1 ? 1 : 2),
			        ),
			        "listid" => array($list_id),
			    );

 				// create new user
			    $contact = $mailin->create_update_user($new_contact);
			    array_push($list, array('new_user' => $contact));
	 		} else {
	 			// add exist user
	 			$list = array();

	 			// check user and unlink list
 				$new_contact = array(
 					"email" => $user->user_email,
			        "attributes" => array(
			        	$sendinblue_name => $user->last_name, 
			        	$sendinblue_firstname => $user->first_name,
			        	$sendinblue_opt_in => ($opt_in == 1 ? 1 : 2),
			        ),
			        "listid_unlink" => array($list_id),
			    );

 				// create new user a
			    $contact = $mailin->create_update_user($new_contact);
			    array_push($list, array('new_user' => $contact));
	 		}
	 	} else {
	 		$list = false;
	 	}

    	return $list;
    }
endif;


/**
 * Create and Update SendibBlue Campaign
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_sendinblue_campaigns') ): 
    function conikal_sendinblue_campaigns($update_id, $user_id, $content, $notification = 'now', $scheduled = '', $action = 'create') {
    	global $campoal_options;

    	// get SendinBlue settings
    	$api_url 				= isset($campoal_options['conikal_sendinblue_api_url_field']) ? $campoal_options['conikal_sendinblue_api_url_field'] : '';
    	$sendinblue_list_status = isset($campoal_options['conikal_sendinblue_list_field']) ? $campoal_options['conikal_sendinblue_list_field'] : 0;
    	$sendinblue_key 		= isset($campoal_options['conikal_sendinblue_key_field']) ? $campoal_options['conikal_sendinblue_key_field'] : '';
    	$sendinblue_folder 		= isset($campoal_options['conikal_sendinblue_folder_id_field']) ? $campoal_options['conikal_sendinblue_folder_id_field'] : '';
    	$sendinblue_sender 		= isset($campoal_options['conikal_sendinblue_sender_email_field']) ? $campoal_options['conikal_sendinblue_sender_email_field'] : '';
    	$sendinblue_name 		= isset($campoal_options['conikal_sendinblue_name_field']) ? $campoal_options['conikal_sendinblue_name_field'] : 'NAME';
    	$sendinblue_firstname 	= isset($campoal_options['conikal_sendinblue_firstname_field']) ? $campoal_options['conikal_sendinblue_firstname_field'] : 'FIRSTNAME';
    	$sendinblue_opt_in 		= isset($campoal_options['conikal_sendinblue_opt_in_field']) ? $campoal_options['conikal_sendinblue_opt_in_field'] : 'DOUBLE_OPT-IN';

    	// get petition update email template
    	$enable_custom_template_petition_update 	= isset($campoal_options['conikal_enable_custom_template_petition_update_field']) ? $campoal_options['conikal_enable_custom_template_petition_update_field'] : 0;
    	$supporter_petition_update_subject 			= isset($campoal_options['conikal_supporter_petition_update_subject_field']) ? $campoal_options['conikal_supporter_petition_update_subject_field'] : esc_html__('New update on %petition_title%', 'campoal-tapo');
        $supporter_petition_update_template 		= isset($campoal_options['conikal_supporter_petition_update_template_field']) ? $campoal_options['conikal_supporter_petition_update_template_field'] : 0;

        // get user infomation
    	$user_info 				= get_user_by('ID', $user_id);
    	
    	// get update details
    	$update_title			= get_the_title($update_id);
    	$update_link			= get_permalink($update_id);
    	$campaign_id 			= get_post_meta($update_id, 'update_campaign_id', true);
    	$gallery 				= get_post_meta($update_id, 'update_gallery', true);
        $images 				= conikal_get_gallery_images($gallery);
        $thumb_video 			= get_post_meta($update_id, 'update_thumb', true);

    	if(has_post_thumbnail($update_id)) {
            $thumb_id = get_post_thumbnail_id($update_id);
            $thumbnail = wp_get_attachment_image_src($thumb_id, 'large', true);
            $thumbnail = $thumbnail[0];
        } elseif ($thumb_video) {
            $thumbnail = $thumb_video;
        } elseif ($gallery) {
            $thumbnail = $images[1];
        } else {
            $thumbnail = '';
        }

    	// get petition details
    	$petition_id 			= get_post_meta($update_id, 'update_post_id', true);
    	$petition_title 		= get_the_title($petition_id);
    	$petition_link			= get_permalink($petition_id);
    	$sendinblue_list 		= get_post_meta($petition_id, 'petition_sendinblue_list', true);

    	// Class used to render markdown content into HTML
    	$Parsedown = new Parsedown();

    	// custom comment variables
        $vars_find     = array(
            '%petition_title%',
            '%petition_link%',
            '%update_title%',
            '%update_link%',
            '%update_content%',
            '%update_thumbnail%',
            '%author_name%',
            '%author_email%',
            '%author_url%',
        );
        $vars_replace  = array(
            esc_html($petition_title),
            esc_html($petition_link),
            esc_html($update_title),
            esc_html($update_link),
            wp_kses_post($Parsedown->text($content)),
            esc_url($thumbnail),
            esc_html($user_info->display_name),
            esc_html($user_info->user_email),
            esc_url(get_author_posts_url($user_info->ID, $user_info->user_nicename)),
        );

        // add commment variable into basic variables
        $email_vars = conikal_basic_variables_email();
        $vars_find = array_merge($email_vars['find'], $vars_find);
        $vars_replace = array_merge($email_vars['replace'], $vars_replace);

        $message = str_replace($vars_find, $vars_replace, $supporter_petition_update_template);
        $subject = str_replace($vars_find, $vars_replace, $supporter_petition_update_subject);

        // apply general template for email
        if (!empty($message) && $enable_custom_template_petition_update == 0) {
            $message = conikal_apply_general_template($update_title, $message);
        }

    	if ($sendinblue_list_status == 1 && $sendinblue_key != '' && class_exists('SendinBlueMailin') && $sendinblue_list != '') {
	    	$mailin = new SendinBlueMailin($api_url, $sendinblue_key);

		    $data = array(
		        'category'		=> $petition_title,
		        'from_email'	=> $sendinblue_sender,
		        'name'			=> $update_title,
		        'bat'			=> '',
		        'html_content'	=> $message,
		        'html_url'		=> '',
		        'listid'		=> array($sendinblue_list),
		        'subject'		=> $subject,
		        'reply_to'		=> $user_info->user_email,
		        'to_field'		=> '[' . $sendinblue_firstname . '] [' . $sendinblue_name . ']',
		        'exclude_list'	=> array(),
		        'attachment_url'=> '',
		        'inline_image'	=> 1,
		        'mirror_active'	=> 0,
		        'utm_campaign'	=> ''
		      );

		    // check if scheduled empty campaign will be send now
	    	if (empty($scheduled) || $notification == 'now') {
	    		$data['send_now'] = 1;
	    	} else {
	    		$data['send_now'] 		= 0;
	    		$data['scheduled_date']	= date_i18n('Y-m-d h:i:s', strtotime($scheduled)); 
	    	}

		    // check if campaign id exist campaign will be update not will be create
		    if ($action == 'update') {
		    	// update the campaign
	    		$data['id'] = $campaign_id;
	    		$campaign 	= $mailin->update_campaign($data);
	    	} elseif ($action == 'create') {
	    		// create new campaign
	    		$campaign	= $mailin->create_campaign($data);

	    		// add campaign id to update petition
	    		if ($campaign['code'] == 'success') {
	    			update_post_meta($update_id, 'update_campaign_id', $campaign['data']['id']);
	    		}
	    	} else {
	    		$campaign = false;
	    	}
	 	} else {
	 		$campaign = false;
	 	}

    	return $campaign;
    }
endif;


/**
 * Get detail SendibBlue Campaign
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_sendinblue_get_campaign') ): 
    function conikal_sendinblue_get_campaign($campaign_id) {
    	global $campoal_options;

    	$api_url 				= isset($campoal_options['conikal_sendinblue_api_url_field']) ? $campoal_options['conikal_sendinblue_api_url_field'] : '';
    	$sendinblue_list_status = isset($campoal_options['conikal_sendinblue_list_field']) ? $campoal_options['conikal_sendinblue_list_field'] : 0;
    	$sendinblue_key 		= isset($campoal_options['conikal_sendinblue_key_field']) ? $campoal_options['conikal_sendinblue_key_field'] : '';

    	// get campaign id
    	if ($sendinblue_list_status == 1 && $sendinblue_key != '' && class_exists('SendinBlueMailin') && $campaign_id != '') {
	    	$mailin = new SendinBlueMailin($api_url, $sendinblue_key);

	    	$campaign = $mailin->get_campaign_v2(array('id' => $campaign_id));
	    	if (array_key_exists('code', $campaign)) {
		    	if ($campaign['code'] == 'success') {
		    		$campaign['data'][0]['status'] = strtolower($campaign['data'][0]['status']);
		    	}
		    } else {
		    	$campaign = false;
		    }
	 	} else {
	 		$campaign = false;
	 	}

    	return $campaign;
    }
endif;


/**
 * Update status SendibBlue Campaign
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_sendinblue_campaign_status') ): 
    function conikal_sendinblue_campaign_status($campaign_id, $status) {
    	global $campoal_options;

    	$api_url 				= isset($campoal_options['conikal_sendinblue_api_url_field']) ? $campoal_options['conikal_sendinblue_api_url_field'] : '';
    	$sendinblue_list_status = isset($campoal_options['conikal_sendinblue_list_field']) ? $campoal_options['conikal_sendinblue_list_field'] : 0;
    	$sendinblue_key 		= isset($campoal_options['conikal_sendinblue_key_field']) ? $campoal_options['conikal_sendinblue_key_field'] : '';

    	// get campaign id
    	if ($sendinblue_list_status == 1 && $sendinblue_key != '' && class_exists('SendinBlueMailin') && $campaign_id != '') {
	    	$mailin = new SendinBlueMailin($api_url, $sendinblue_key);

	    	$status_data = array(
	    		'id' => $campaign_id,
		        'status' => $status,
		    );
		    $results = $mailin->update_campaign_status($status_data);
	 	} else {
	 		$results = false;
	 	}

    	return $results;
    }
endif;


/**
 * Delete SendibBlue Campaign
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_sendinblue_campaign_delete') ): 
    function conikal_sendinblue_campaign_delete($campaign_id) {
    	global $campoal_options;

    	$api_url 				= isset($campoal_options['conikal_sendinblue_api_url_field']) ? $campoal_options['conikal_sendinblue_api_url_field'] : '';
    	$sendinblue_list_status = isset($campoal_options['conikal_sendinblue_list_field']) ? $campoal_options['conikal_sendinblue_list_field'] : 0;
    	$sendinblue_key 		= isset($campoal_options['conikal_sendinblue_key_field']) ? $campoal_options['conikal_sendinblue_key_field'] : '';

    	// get campaign id
    	if ($sendinblue_list_status == 1 && $sendinblue_key != '' && class_exists('SendinBlueMailin') && $campaign_id != '') {
	    	$mailin = new SendinBlueMailin($api_url, $sendinblue_key);

	    	// change campaign to sent status before delete
		    $campaign_status = conikal_sendinblue_campaign_status($campaign_id, 'sent');

		    if ($campaign_status['code'] == 'success') {
		    	$data = array(
	    			'id'	=> $campaign_id,
		    	);

		    	// delete campaign
		    	$campaign = $mailin->delete_campaign($data);
		    } else {
		    	$campaign = false;
		    }
	 	} else {
	 		$campaign = false;
	 	}

    	return $campaign;
    }
endif;

?>