<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
* Increase share counter number
*
* @since Campoal Tapo 2.3.5
*/
if (!function_exists('conikal_increase_share_counter')) :    
	function conikal_increase_share_counter($post_id, $social = 'facebook') {
        $share_counter_key      = 'petition_share_counter';
        $share_counter_number   = get_post_meta($post_id, $share_counter_key, true);

        if (empty($share_counter_number)) {
            $share_counter_number = array(
                'mail'          => 0,
                'gmail'         => 0,
                'facebook'      => 0,
                'twitter'       => 0,
                'telegram'      => 0,
                'embed-widget'  => 0,
                'messenger'     => 0,
                'whatsapp'      => 0,
                'line'          => 0,
                'linkedin'      => 0,
                'tumblr'        => 0,
                'pinterest'     => 0,
                'reddit'        => 0,
                'vk'            => 0,
                'sms'           => 0,
                'total'         => 0,
            );
            delete_post_meta($post_id, $share_counter_key);
            add_post_meta($post_id, $share_counter_key, $share_counter_number);
        }

        if (is_array($share_counter_number)) {
            $share_counter_number[$social] = intval($share_counter_number[$social]) + 1;
            $share_counter_number['total'] = intval($share_counter_number['total']) + 1;
            update_post_meta($post_id, $share_counter_key, $share_counter_number);
        }

        $share_counter   = get_post_meta($post_id, $share_counter_key, true);

        return $share_counter;
    }
endif;


/**
* Get share counter number as array or number of each social
*
* @since Campoal Tapo 2.3.5
*/
if (!function_exists('conikal_get_share_counter')) :    
	function conikal_get_share_counter($post_id, $social = false) {
        $share_counter_key      = 'petition_share_counter';
        $share_counter          = get_post_meta($post_id, $share_counter_key, true);

        if (!empty($share_counter) && $social == false) {
            $results = $share_counter;
        } else if (!empty($social)) {
            if (is_array($share_counter) && array_key_exists($social, $share_counter)) {
                $results = $share_counter[$social];
            } else {
                $results = 0;
            }
        } else {
            $share_counter = array(
                'mail'          => 0,
                'gmail'         => 0,
                'facebook'      => 0,
                'twitter'       => 0,
                'telegram'      => 0,
                'embed-widget'  => 0,
                'messenger'     => 0,
                'whatsapp'      => 0,
                'line'          => 0,
                'linkedin'      => 0,
                'tumblr'        => 0,
                'pinterest'     => 0,
                'reddit'        => 0,
                'vk'            => 0,
                'sms'           => 0,
                'total'         => 0
            );
            $results = $share_counter;
        }
        
        return $results;
    }
endif;


/**
* Process share counting when click on social button
*
* @since Campoal Tapo 2.3.5
*/
if (!function_exists('conikal_share_counter')) :    
	function conikal_share_counter() {
        check_ajax_referer('share_ajax_nonce', 'security');

        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $social = isset($_POST['social']) ? sanitize_text_field($_POST['social']) : '';

        // increase share counter on each social button click
        $share_counter = conikal_increase_share_counter($post_id, $social);

        if (!empty($share_counter)) {
            echo json_encode(
                array(
                    'status'    => true, 
                    'message'   => esc_html__('Share counter are recorded!', 'campoal-tapo'), 
                    'total'     => esc_html( conikal_format_number('%!,0i', $share_counter['total'], true) ), 
                    'counter'   => $share_counter
                ) 
            );
            exit();
        } else {
            echo json_encode(
                array(
                    'status'    => false, 
                    'message'   => esc_html__('Share counter not record', 'campoal-tapo'), 
                ) 
            );
            exit();
        }
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_share_counter', 'conikal_share_counter' );
add_action( 'wp_ajax_conikal_share_counter', 'conikal_share_counter' );