<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Sign petition without login
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_sign_without_login') ): 
    function conikal_sign_without_login($email, $petition_id, $comment, $notice = 1, $anonymous = 0) {
        $user = get_user_by('email', $email);
        if ($user) {
            $addsign = conikal_add_to_signatures_plus($user->ID, $petition_id, $comment, $notice, $anonymous);
            if ($addsign) {
                $addsign = 'nologin';
            } else {
                $addsign = 'nologin';
            }
        } else {
            $addsign = false;
        }
        return $addsign;
    }
endif;


/**
 * User Sign Up Function
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_user_signup_form') ): 
    function conikal_user_signup_form() {
        check_ajax_referer('signup_ajax_nonce', 'security');
        global $campoal_options;
        
        $format_separate        = isset($campoal_options['conikal_format_separate_fullname_field']) ? $campoal_options['conikal_format_separate_fullname_field'] : 'first_s_middle_last';
        $sign_without_login     = isset($campoal_options['conikal_sign_petition_without_login_field']) ? $campoal_options['conikal_sign_petition_without_login_field'] : 0;
        $repeat_password        = isset($campoal_options['conikal_repeat_password_field']) ? $campoal_options['conikal_repeat_password_field'] : 0;
        $password_strength      = isset($campoal_options['conikal_password_strength_field']) ? $campoal_options['conikal_password_strength_field'] : 0;
        $acceptable_strength    = isset($campoal_options['conikal_acceptable_strength_field']) ? $campoal_options['conikal_acceptable_strength_field'] : 0;
        $choose_username        = isset($campoal_options['conikal_choose_username_field']) ? $campoal_options['conikal_choose_username_field'] : 0;
        $recaptcha_login        = isset($campoal_options['conikal_google_recaptcha_login_field']) ? $campoal_options['conikal_google_recaptcha_login_field'] : 1;
        $recaptcha_sign         = isset($campoal_options['conikal_google_recaptcha_sign_field']) ? $campoal_options['conikal_google_recaptcha_sign_field'] : 1;
        $two_input_name         = isset($campoal_options['conikal_two_input_name_field']) ? $campoal_options['conikal_two_input_name_field'] : 0;
        $receive_update         = isset($campoal_options['conikal_receive_update_field']) ? $campoal_options['conikal_receive_update_field'] : 'checked';
        $sign_anonymous         = isset($campoal_options['conikal_sign_anonymous_field']) ? $campoal_options['conikal_sign_anonymous_field'] : 'checked';
        $newsletters            = isset($campoal_options['conikal_signup_newsletters_field']) ? $campoal_options['conikal_signup_newsletters_field'] : 'checked';
        $newsletter_list_id     = isset($campoal_options['conikal_sendinblue_newsletter_list_id_field']) ? $campoal_options['conikal_sendinblue_newsletter_list_id_field'] : 0;
        $short_display_name     = isset($campoal_options['conikal_short_display_name_field']) ? $campoal_options['conikal_short_display_name_field'] : 'fullname';
        
        $signup_user            = isset($_POST['signup_user']) ? sanitize_user( $_POST['signup_user'] ) : '';
        $signup_name            = isset($_POST['signup_name']) ? sanitize_text_field( $_POST['signup_name'] ) : '';
        $signup_email           = isset($_POST['signup_email']) ? sanitize_email( $_POST['signup_email'] ) : '';
        $signup_pass            = isset($_POST['signup_pass']) ? sanitize_text_field($_POST['signup_pass']) : '';
        $signup_repass          = isset($_POST['signup_repass']) ? sanitize_text_field($_POST['signup_repass']) : '';
        $signup_strength        = isset($_POST['signup_strength']) ? sanitize_text_field($_POST['signup_strength']) : 0;
        $signup_gender          = isset($_POST['signup_gender']) ? sanitize_text_field($_POST['signup_gender']) : '';
        $signup_birthday        = isset($_POST['signup_birthday']) ? sanitize_text_field($_POST['signup_birthday']) : '';
        $signup_address         = isset($_POST['signup_address']) ? sanitize_text_field( $_POST['signup_address'] ) : '';
        $signup_city            = isset($_POST['signup_city']) ? sanitize_text_field( $_POST['signup_city'] ) : '';
        $signup_state           = isset($_POST['signup_state']) ? sanitize_text_field( $_POST['signup_state'] ) : '';
        $signup_neighborhood    = isset($_POST['signup_neighborhood']) ? sanitize_text_field( $_POST['signup_neighborhood'] ) : '';
        $signup_country         = isset($_POST['signup_country']) ? sanitize_text_field( $_POST['signup_country'] ) : '';
        $signup_lat             = isset($_POST['signup_lat']) ? sanitize_text_field( $_POST['signup_lat'] ) : '';
        $signup_lng             = isset($_POST['signup_lng']) ? sanitize_text_field( $_POST['signup_lng'] ) : '';
        $signup_zip             = isset($_POST['signup_zip']) ? sanitize_text_field( $_POST['signup_zip'] ) : '';
        $signup_newsletter      = isset($_POST['signup_newsletter']) ? rest_sanitize_boolean($_POST['signup_newsletter']) : 0;
        $signup_phone_code      = isset($_POST['signup_phone_code']) ? sanitize_text_field($_POST['signup_phone_code']) : '';
        $signup_phone_code      = conikal_format_phone_number($signup_phone_code);
        $signup_phone           = isset($_POST['signup_phone']) ? sanitize_text_field($_POST['signup_phone']) : '';
        $signup_phone           = conikal_format_phone_number($signup_phone);

        $petition_id            = isset($_POST['petition_id']) ? sanitize_text_field($_POST['petition_id']) : '';
        $comment                = isset($_POST['comment']) ? sanitize_text_field($_POST['comment']) : '';
        $anonymous              = isset($_POST['anonymous']) && $sign_anonymous != 'none' ? rest_sanitize_boolean($_POST['anonymous']) : 0;
        $notice                 = isset($_POST['notice']) && $receive_update != 'none' ? rest_sanitize_boolean($_POST['notice']) : 1;

        $form_referrent         = isset($_POST['form_referrent']) ? sanitize_text_field( $_POST['form_referrent'] ) : '';

        $parse_name = explode(' ', $signup_name);
        $signup_firstname = '';
        $signup_middle = '';
        $signup_lastname = '';

        // separate fullname
        foreach ($parse_name as $key => $value) {
            if (count($parse_name) <= 2) {
                if ($key == 0) {
                    $signup_firstname .= $value;
                } else {
                    $signup_lastname .= $value;
                }
            } else {
                if ($key == 0) {
                    $signup_firstname .= $value;
                } elseif ($key == 1) {
                    $signup_middle .= $value;
                } elseif ($key >= 2) {
                    $signup_lastname .= $value . ' ';
                }
            }
        }

        // Short display name
        switch ($short_display_name) {
            case 'firstname':
                $short_firstname    = !empty($signup_firstname) ? substr($signup_firstname, 0, 1) : '';;
                $signup_name        = $short_firstname . ($signup_middle != '' ? ' ' . $signup_middle : '') . ' ' . $signup_lastname;
                break;

            case 'lastname':
                $short_lastname     = !empty($signup_lastname) ? substr($signup_lastname, 0, 1) : '';
                $signup_name        = $signup_firstname . ($signup_middle != '' ? ' ' . $signup_middle : '') . ' ' . $short_lastname;
                break;
            
            default:
                $signup_name = $signup_name;
                break;
        }

        // reformat fullname
        switch ($format_separate) {
            case 'first_s_middle_last':
                $signup_lastname = ($signup_middle != '' ? $signup_middle . ' ' : '') . $signup_lastname;
                break;

            case 'first_middle_s_last':
                $signup_firstname = $signup_firstname . ($signup_middle != '' ? ' ' . $signup_middle : '');
                break;

            case 'last_s_middle_first':
                $signup_lastname_format = ($signup_middle != '' ? $signup_middle . ' ' : '') . $signup_firstname;
                $signup_firstname = $signup_lastname;
                $signup_lastname = $signup_lastname_format;
                break;

            case 'last_middle_s_first':
                $signup_firstname_format = $signup_lastname . ($signup_middle != '' ? ' ' . $signup_middle : '');
                $signup_lastname = $signup_firstname;
                $signup_firstname = $signup_firstname_format;
                break;
            
            default:
                $signup_lastname = ($signup_middle != '' ? $signup_middle . ' ' : '') . $signup_lastname;
                break;
        }

        if ($two_input_name == 1) {
            if (empty($signup_firstname)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('First name fields is mandatory.', 'campoal-tapo')));
                exit();
            } elseif (empty($signup_lastname)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Last name fields is mandatory.', 'campoal-tapo')));
                exit();
            }
        }

        if(empty($signup_user) && empty($signup_name) && empty($signup_email) && empty($signup_pass)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Required form fields are empty!', 'campoal-tapo')));
            exit();
        }

        if (empty($signup_user)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Username fields is mandatory.', 'campoal-tapo')));
            exit();
        } elseif (empty($signup_name)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Full name fields is mandatory.', 'campoal-tapo')));
            exit();
        } elseif (empty($signup_email)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Email fields is mandatory.', 'campoal-tapo')));
            exit();
        } elseif (empty($signup_pass)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Password fields is mandatory.', 'campoal-tapo')));
            exit();
        }

        if(strlen($signup_user) < 3) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Username too short. Please enter at least 4 characters!', 'campoal-tapo')));
            exit();
        }
        if(username_exists($signup_user)) {
            if ($choose_username == 1) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Username already exists!', 'campoal-tapo')));
                exit();
            } else {
                $random_number   = wp_rand(1000, 9999);
                $signup_user = $signup_user . $random_number;
            }
        }
        if(!validate_username($signup_user)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Invalid Username!', 'campoal-tapo')));
            exit();
        }
        if(!is_email($signup_email)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Invalid Email!', 'campoal-tapo')));
            exit();
        }

        if(email_exists($signup_email)) {
            if ($sign_without_login == 1 && $petition_id != '') {
                $add_sign = conikal_sign_without_login($signup_email, $petition_id, $comment, $notice, $anonymous);
                echo json_encode(array('status'=>false, 'add_sign' => $add_sign, 'message'=> esc_html__('You are signed by email without login.', 'campoal-tapo') ));
            } else {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Email already exists!', 'campoal-tapo')));
            }
            exit();
        }

        if(strlen($signup_pass) < 6) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Password too short. Please enter at least 6 characters!', 'campoal-tapo')));
            exit();
        }

        if($repeat_password == 1 && $signup_pass != $signup_repass) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Repeat password is not match!', 'campoal-tapo')));
            exit();
        }

        if($password_strength == 1 && !empty($signup_strength) && $signup_strength < $acceptable_strength) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Password is not strong enough!', 'campoal-tapo')));
            exit();
        }

        // check madatory when sign petition
        if (!empty($petition_id)) {
            $guest_location     = isset($campoal_options['conikal_guest_location_field']) ? $campoal_options['conikal_guest_location_field'] : 1;
            $guest_phone        = isset($campoal_options['conikal_guest_phone_field']) ? $campoal_options['conikal_guest_phone_field'] : 0;
            $guest_phone_r      = isset($campoal_options['conikal_guest_phone_r_field']) ? $campoal_options['conikal_guest_phone_r_field'] : 0;
            $guest_zip          = isset($campoal_options['conikal_guest_zip_field']) ? $campoal_options['conikal_guest_zip_field'] : 0;
            $guest_zip_r        = isset($campoal_options['conikal_guest_zip_r_field']) ? $campoal_options['conikal_guest_zip_r_field'] : 0;
            $guest_country      = isset($campoal_options['conikal_guest_country_field']) ? $campoal_options['conikal_guest_country_field'] : 0;
            $guest_country_r    = isset($campoal_options['conikal_guest_country_r_field']) ? $campoal_options['conikal_guest_country_r_field'] : 0;
            $guest_location_r   = isset($campoal_options['conikal_guest_location_r_field']) ? $campoal_options['conikal_guest_location_r_field'] : 0;

            if ($guest_location == 1 && $guest_location_r == 1 && empty($signup_address)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Location fields is mandatory.', 'campoal-tapo')));
                exit();
            }
            if ($guest_zip == 1 && $guest_zip_r == 1 && empty($signup_zip)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Zip code fields is mandatory.', 'campoal-tapo')));
                exit();
            }
            if ($guest_country == 1 && $guest_country_r == 1 && empty($signup_country)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Country fields is mandatory.', 'campoal-tapo')));
                exit();
            }
            if ($guest_phone == 1 && $guest_phone_r == 1 && (empty($signup_phone_code) || empty($signup_phone) ) ) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Phone number fields is mandatory.', 'campoal-tapo')));
                exit();
            }
        }

        // check mandatory when sign up from page
        if ($form_referrent == 'page') {
            $registration_gender    = isset($campoal_options['conikal_registration_gender_field']) ? $campoal_options['conikal_registration_gender_field'] : 0;
            $registration_location  = isset($campoal_options['conikal_registration_location_field']) ? $campoal_options['conikal_registration_location_field'] : 0;
            $registration_country   = isset($campoal_options['conikal_registration_country_field']) ? $campoal_options['conikal_registration_country_field'] : 0;
            $registration_phone     = isset($campoal_options['conikal_registration_phone_field']) ? $campoal_options['conikal_registration_phone_field'] : 0;
            $registration_birthday  = isset($campoal_options['conikal_registration_birthday_field']) ? $campoal_options['conikal_registration_birthday_field'] : 0;

            $user_gender_r          = isset($campoal_options['conikal_user_gender_r_field']) ? $campoal_options['conikal_user_gender_r_field'] : 0;
            $user_birthday_r        = isset($campoal_options['conikal_user_birthday_r_field']) ? $campoal_options['conikal_user_birthday_r_field'] : 0;
            $user_location_r        = isset($campoal_options['conikal_user_location_r_field']) ? $campoal_options['conikal_user_location_r_field'] : 0;
            $user_country_r         = isset($campoal_options['conikal_user_country_r_field']) ? $campoal_options['conikal_user_country_r_field'] : 0;
            $user_country_r         = isset($campoal_options['conikal_user_country_r_field']) ? $campoal_options['conikal_user_country_r_field'] : 0;
            $user_phone_r           = isset($campoal_options['conikal_user_phone_r_field']) ? $campoal_options['conikal_user_phone_r_field'] : 0;

            if ($registration_phone == 1 && $user_phone_r == 1 && (empty($signup_phone_code) || empty($signup_phone) ) ) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Phone number fields is mandatory.', 'campoal-tapo')));
                exit();
            }
            
            if ($registration_gender == 1 && $user_gender_r == 1 && empty($signup_gender)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Gender fields is mandatory.', 'campoal-tapo')));
                exit();
            }

            if ($registration_birthday == 1 && $user_birthday_r == 1 && empty($signup_birthday)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Birthday fields is mandatory.', 'campoal-tapo')));
                exit();
            }

            if ($registration_location == 1 && $user_location_r == 1 && empty($signup_address)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Location fields is mandatory.', 'campoal-tapo')));
                exit();
            }
            if ($registration_country == 1 && $user_country_r == 1 && empty($signup_country)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Country fields is mandatory.', 'campoal-tapo')));
                exit();
            }
            
        }

        // Vertify Google reCAPTCHA
        if (conikal_show_google_reCaptcha() && ($recaptcha_login == 1 || $recaptcha_sign == 1) ) {
            conikal_google_recaptcha_callback();
        }

        $user_data = array(
            'user_login' => sanitize_user($signup_user),
            'user_email' => sanitize_email($signup_email),
            'user_pass'  => sanitize_text_field($signup_pass),
            'first_name' => sanitize_text_field($signup_firstname),
            'last_name'  => sanitize_text_field($signup_lastname),
            'display_name' => sanitize_text_field($signup_name)
        );

        $new_user = wp_insert_user($user_data);

        update_user_meta($new_user, 'user_type', 'petitioner');
        update_user_meta($new_user, 'user_gender', $signup_gender);
        update_user_meta($new_user, 'user_birthday', $signup_birthday);
        update_user_meta($new_user, 'user_address', $signup_address);
        update_user_meta($new_user, 'user_city', $signup_city);
        update_user_meta($new_user, 'user_state', $signup_state);
        update_user_meta($new_user, 'user_neighborhood', $signup_neighborhood);
        update_user_meta($new_user, 'user_country', $signup_country);
        update_user_meta($new_user, 'user_lat', $signup_lat);
        update_user_meta($new_user, 'user_lng', $signup_lng);
        update_user_meta($new_user, 'user_zip', $signup_zip);
        update_user_meta($new_user, 'user_phone_code', $signup_phone_code);
        update_user_meta($new_user, 'user_phone', $signup_phone);

        // set password is temporary to remind change later
        if ($petition_id != '') {
            update_user_meta($new_user, 'user_temporary_pass', true);
        }

        // set profile complete progress
        $profile_progress = conikal_profile_complete_progress($new_user);

        // save user email into sendinblue
        if ($newsletters != 'none' && $newsletter_list_id) {
            $sendinblue = conikal_sendinblue_users_list($newsletter_list_id, $new_user, 'add', $signup_newsletter);
        }

        if(is_wp_error($new_user)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Something went wrong!', 'campoal-tapo')));
            exit();
        } else {
            $account_activation = get_user_meta($new_user, 'is_activated', true);
            $verification_email = isset($campoal_options['conikal_verification_email_field']) ? $campoal_options['conikal_verification_email_field'] : 1;
            $force_verify = isset($campoal_options['conikal_force_verify_field']) ? $campoal_options['conikal_force_verify_field'] : 0;
            if ( $verification_email != 0 && $account_activation != 1 && $force_verify != 0) {
                echo json_encode(array('status'=>false, 'verification' => true, 'username' => $signup_user, 'message'=>esc_html__('Verify your email to continue signing.', 'campoal-tapo')));
            } else {
                echo json_encode(array('status'=>true, 'ID' => $new_user, 'username' => $signup_user, 'message'=>esc_html__('Signed up successfully! Logging in...', 'campoal-tapo')));
            }
            conikal_signup_notifications($new_user, $signup_pass);
            exit();
        }

        die();
    }
endif;
add_action('wp_ajax_nopriv_conikal_user_signup_form', 'conikal_user_signup_form');
add_action('wp_ajax_conikal_user_signup_form', 'conikal_user_signup_form');


/**
 * Redirect after sign petiiton
 *
 * @since Campoal Tapo 1.6.7
 */
if (!function_exists('conikal_redirect_after_sign')) :
    function conikal_redirect_after_sign($post_id) {
        global $campoal_options;
        $action_after_sign = isset($campoal_options['conikal_action_after_sign_field']) ? $campoal_options['conikal_action_after_sign_field'] : '';

        if ($action_after_sign == 'redirect') {
            // Get custom confirmation page for this petition
            $confirmation_page = get_post_meta($post_id, 'petition_confirmation_page', true);

            // Check custom confirmation page for petition are available, if not so will use default confirm page in settings.
            if (!empty($confirmation_page)) {
                $sign_success_page = $confirmation_page;
            } else {
                $sign_success_page = isset($campoal_options['conikal_page_sign_successful_field']) ? $campoal_options['conikal_page_sign_successful_field'] : 0;
            }

            $sign_success_page = get_permalink($sign_success_page);
            $sign_success_page = add_query_arg(array('petition_id' => $post_id), $sign_success_page);
            if ($sign_success_page) {
                $referent = $sign_success_page;
            } else {
                $referent = get_permalink($post_id);
            }
        } elseif ($action_after_sign == 'modal') {
            $referent = get_permalink($post_id);
            $referent = add_query_arg(array('success' => $post_id), $referent);
        } else {
            $referent = '';
        }

        return $referent;
    }
endif;


/**
 * User Sign In Function
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_user_signin_form') ): 
    function conikal_user_signin_form() {
        // return success if user logged in
        if(is_user_logged_in()) { 
            echo json_encode(array('signedin'=>true, 'message'=>esc_html__('You are already signed in, redirecting...', 'campoal-tapo')));
            exit();
        }
        check_ajax_referer('signin_ajax_nonce', 'security');

        global $campoal_options;
        $recaptcha_login = isset($campoal_options['conikal_google_recaptcha_login_field']) ? $campoal_options['conikal_google_recaptcha_login_field'] : 1;
        $receive_update = isset($campoal_options['conikal_receive_update_field']) ? $campoal_options['conikal_receive_update_field'] : 'checked';
        $sign_anonymous = isset($campoal_options['conikal_sign_anonymous_field']) ? $campoal_options['conikal_sign_anonymous_field'] : 'checked';
        
        $signin_user = isset($_POST['signin_user']) ? sanitize_text_field($_POST['signin_user']) : '';
        $signin_pass = isset($_POST['signin_pass']) ? sanitize_text_field($_POST['signin_pass']) : '';
        $remember = isset($_POST['remember']) ? rest_sanitize_boolean($_POST['remember']) : true;
        $referent = isset($_POST['referent']) ? sanitize_text_field($_POST['referent']) : '';
        $referer_id = isset($_POST['referer_id']) ? sanitize_text_field($_POST['referer_id']) : '';
        $signature = isset($_POST['signature']) ? sanitize_text_field($_POST['signature']) : 0;
        $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
        $comment = isset($_POST['comment']) ? sanitize_text_field($_POST['comment']) : '';
        $anonymous = isset($_POST['anonymous']) && $sign_anonymous != 'none' ? rest_sanitize_boolean($_POST['anonymous']) : 0;
        $notice = isset($_POST['notice']) && $receive_update != 'none' ? rest_sanitize_boolean($_POST['notice']) : 1;
        $recaptcha_form = isset($_POST['recaptcha']) ? sanitize_text_field($_POST['recaptcha']) : 1;

        // get user data
        $user_field = is_email($signin_user) ? 'email' : 'login';
        $user_exist = get_user_by( $user_field, $signin_user );

        // Check login field is empty
        if ($signin_user == '' || $signin_pass == '') {
            echo json_encode(array('status' => false, 'provider' => false, 'message' => esc_html__('Username or password is empty!', 'campoal-tapo')));
            exit();
        }

        // Check user is registed
        if (empty($user_exist)) {
            echo json_encode(array('status' => false, 'provider' => false, 'message' => esc_html__('The user is not exist!', 'campoal-tapo')));
            exit();
        }

        // Authentication a user without login
        $authentication_user = wp_authenticate_username_password(null, $user_exist->user_login, $signin_pass);
        if (is_wp_error( $authentication_user )) {
            echo json_encode(array('status' => false, 'provider' => false, 'message' => esc_html__('Invalid username or password!', 'campoal-tapo')));
            exit();
        }

        // Vertify Google reCAPTCHA
        if (conikal_show_google_reCaptcha() && $recaptcha_login == 1) {
            if ($recaptcha_form == 0) {
                // if want disable recaptcha need checked user register is one hour ago
                $one_hour_ago = conikal_user_register_time_diff($signin_user);
                if (!$one_hour_ago) {
                    conikal_google_recaptcha_callback();
                }
            } else {
                conikal_google_recaptcha_callback();
            }
        }
        
        $vsessionid = session_id();
        if (empty($vsessionid)) {
            session_name('PHPSESSID');
            session_start();
        }

        wp_clear_auth_cookie();
        $data = array();
        $data['user_login'] = $signin_user;
        $data['user_password'] = $signin_pass;
        $data['remember'] = $remember;

        // Redirect to two factor authentication page
        if (!empty($user_exist)) {
            $provider = get_user_meta( $user_exist->ID, 'wp_2fa_enabled_methods', true );
            $provider = !empty($provider) ? $provider : false;

            if (!empty($provider)) {
                // login 2 factor validate page
                $login_page = isset($campoal_options['conikal_page_login_field']) ? $campoal_options['conikal_page_login_field'] : 0;
                $login_page = get_permalink($login_page);
                $two_factor_page = !empty($login_page) ? add_query_arg(array('action' => 'two_factor', 'user_id' => $user_exist->ID, 'provider' => $provider, 'referer_id' => $referer_id), $login_page) : '';

                echo json_encode(array('status' => false, 'message' => esc_html__('Redirect to 2 Factor Authentication', 'campoal-tapo'), 'user_id' => $user_exist->ID, 'provider' => $provider, 'redirect' => $two_factor_page));
                exit();
            }
        }

        $user_signon = wp_signon($data, true);

        if(is_wp_error($user_signon)) {
            echo json_encode(array('status' => false, 'provider' => false, 'message' => esc_html__('Login failed. Please contact to admin!', 'campoal-tapo')));
            exit();
        } else {
            wp_set_current_user($user_signon->ID);
            do_action('set_current_user');
            global $current_user;
            $current_user = wp_get_current_user();

            if ($signature == 1) {
                $addsign    = conikal_add_to_signatures_plus($user_signon->ID, $post_id, $comment, $notice, $anonymous);
                $referent   = conikal_redirect_after_sign($post_id);
            } else if ($signature == 2) {
                $addsign    = conikal_add_temporary_signature($user_signon->ID, $post_id, $comment, $notice, $anonymous);
                $referent   = conikal_redirect_after_sign($post_id);
            } else {
                $addsign    = false;
                $referent   = !empty($referer_id) ? get_permalink($referer_id) : '';
            }

            echo json_encode(array('status' => true, 'provider' => false, 'newuser' => $user_signon->ID, 'referent' => $referent, 'addsign' => $addsign, 'message' => esc_html__('Signed in successfully!, redirecting...', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action('wp_ajax_nopriv_conikal_user_signin_form', 'conikal_user_signin_form');
add_action('wp_ajax_conikal_user_signin_form', 'conikal_user_signin_form');

/**
 * Forgot Password Function
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_forgot_pass_form') ): 
    function conikal_forgot_pass_form() {
        check_ajax_referer('forgot_ajax_nonce', 'security');

        global $wpdb, $wp_hasher;
        global $campoal_options;
        $recaptcha_forgot_password = isset($campoal_options['conikal_google_recaptcha_forgot_password_field']) ? $campoal_options['conikal_google_recaptcha_forgot_password_field'] : 1;

        $forgot_email = isset($_POST['forgot_email']) ? sanitize_text_field($_POST['forgot_email']) : '';

        if($forgot_email == '') {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Email field is empty!', 'campoal-tapo')));
            exit();
        }

        $user_input = trim($forgot_email);

        if(is_email($user_input)) {
            $user_data = get_user_by('email', $user_input);
            if(empty($user_data)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Invalid email address!', 'campoal-tapo')));
                exit();
            }
        } else {
            $user_data = get_user_by('login', $user_input);
            if(empty($user_data)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Invalid username!', 'campoal-tapo')));
                exit();
            }
        }

        // Vertify Google reCAPTCHA
        if (conikal_show_google_reCaptcha() && $recaptcha_forgot_password == 1) {
            conikal_google_recaptcha_callback();
        }

        $user_login = $user_data->user_login;
        $user_email = $user_data->user_email;

        $key = wp_generate_password( 20, false );
        do_action( 'retrieve_password_key', $user_login, $key );

        if ( empty( $wp_hasher ) ) {
            require_once ABSPATH . WPINC . '/class-phpass.php';
            $wp_hasher = new PasswordHash( 8, true );
        }
        $hashed = time() . ':' . $wp_hasher->HashPassword( $key );
        $wpdb->update( $wpdb->users, array( 'user_activation_key' => $hashed ), array( 'user_login' => $user_login ) );

        $send_email = conikal_forgot_pass_email($user_login, $user_email, $key);

        if(!$send_email) {
            echo json_encode(array('status'=>false, 'login' => $user_login, 'message'=>esc_html__('Email failed to send for some unknown reason.', 'campoal-tapo')));
            exit();
        } else {
            echo json_encode(array('status'=>true, 'login' => $user_login, 'message'=>esc_html__('An email with password reset instructions was sent to you.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action('wp_ajax_nopriv_conikal_forgot_pass_form', 'conikal_forgot_pass_form');
add_action('wp_ajax_conikal_forgot_pass_form', 'conikal_forgot_pass_form');


/**
 * Reset Password Function
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_reset_pass_form') ): 
    function conikal_reset_pass_form() {
        check_ajax_referer('resetpass_ajax_nonce', 'security');

        global $campoal_options;
        $recaptcha_forgot_password = isset($campoal_options['conikal_google_recaptcha_forgot_password_field']) ? $campoal_options['conikal_google_recaptcha_forgot_password_field'] : 1;

        $allowed_html = array();
        $pass_1 = isset($_POST['pass_1']) ? wp_kses($_POST['pass_1'], $allowed_html) : '';
        $pass_2 = isset($_POST['pass_2']) ? wp_kses($_POST['pass_2'], $allowed_html) : '';
        $key = isset($_POST['key']) ? wp_kses($_POST['key'], $allowed_html) : '';
        $login = isset($_POST['login']) ? wp_kses($_POST['login'], $allowed_html) : '';

        if($pass_1 == '' || $pass_2 == '') {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Password field empty!', 'campoal-tapo')));
            exit();
        }

        // Vertify Google reCAPTCHA
        if (conikal_show_google_reCaptcha() && $recaptcha_forgot_password == 1) {
            conikal_google_recaptcha_callback();
        }

        if (!is_user_logged_in()) {
            $user = check_password_reset_key($key, $login);
            if(is_wp_error($user)) {
                if($user->get_error_code() === 'expired_key') {
                    echo json_encode(array('status'=>false, 'error' => $user->get_error_code(), 'message'=>esc_html__('Sorry, the link does not appear to be valid or is expired!', 'campoal-tapo')));
                    exit();
                } else {
                    echo json_encode(array('status'=>false, 'error' => $user->get_error_code(), 'message'=>esc_html__('Sorry, the link does not appear to be valid or is expired!', 'campoal-tapo')));
                    exit();
                }
            }
        }

        if(isset($pass_1) && $pass_1 != $pass_2 ) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('The passwords do not match!', 'campoal-tapo')));
            exit();
        } else {
            if (!is_user_logged_in()) {
                reset_password($user, $pass_1);
                delete_user_meta($user, 'user_temporary_pass');
                echo json_encode(array('status'=>true, 'reset' => true, 'message'=>esc_html__('Your password has been reset successfully!', 'campoal-tapo')));
            } else {
                global $current_user;
                wp_update_user(array( 'ID' => $current_user->ID, 'user_pass' => $pass_1 ));
                delete_user_meta($current_user->ID, 'user_temporary_pass');
                echo json_encode(array('status'=>true, 'reset' => false, 'message'=>esc_html__('Your new password has been set successfully!', 'campoal-tapo')));
            }
            exit();
        }

        die();
    }
endif;
add_action('wp_ajax_nopriv_conikal_reset_pass_form', 'conikal_reset_pass_form');
add_action('wp_ajax_conikal_reset_pass_form', 'conikal_reset_pass_form');


/**
 * Check user is connected with social
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_user_social_connection')) :
    function conikal_user_social_connection($email, $signup_data, $connection_meta = 'facebook_connection') {
        // Add connection type to sign up data
        $signup_data['connection'] = $connection_meta;

        // Automatic login //
        $user_signon = get_user_by('email', $email);

        // check this email login is connected with exist account or not
        $users_social_connection = get_users(array(
            'meta_key' => $connection_meta,
            'meta_value' => $email,
            'number' => 1,
            'count_total' => false
        ));  

        $user_data = false;
        if ($users_social_connection) {
            foreach ($users_social_connection as $user) {
                $user_data = $user;
            }
        }

        // user is connected with social do login
        if ($user_data) {
            conikal_cookie_auth_login($user_data, $signup_data, $connection_meta);
        } else {
            if($user_signon) {
                conikal_cookie_auth_login($user_signon, $signup_data, $connection_meta);
                exit();
            } else {
                $signup = conikal_social_signup($signup_data);
                $user_signup = get_userdata($signup);
                if ($user_signup) {
                    conikal_cookie_auth_login($user_signup, $signup_data, $connection_meta);
                    exit();
                } else {
                    echo json_encode(array('status'=>false, 'message'=>esc_html__('Something went wrong!', 'campoal-tapo')));
                    exit();
                }
            }
        }
    }
endif;

/**
 * Login without password via cookie auth
 *
 * @since Campoal Tapo 1.0.0
 */
if (!function_exists('conikal_cookie_auth_login')) :
    function conikal_cookie_auth_login($user_signon, $signup_data, $connection_meta = 'facebook_connection') {
        extract($signup_data);
        $vsessionid = session_id();
        if (empty($vsessionid)) {
            session_name('PHPSESSID');
            session_start();
        }

        update_user_meta($user_signon->ID, 'avatar', $avatar);
        update_user_meta($user_signon->ID, 'avatar_orginal', $avatar);
        update_user_meta($user_signon->ID, $connection_meta, $email);
        wp_clear_auth_cookie();
        wp_set_current_user($user_signon->ID);
        wp_set_auth_cookie($user_signon->ID);
        do_action('set_current_user');
        
        global $current_user;
        $current_user = wp_get_current_user($user_signon->ID);
        echo json_encode(array('status'=>true, 'message'=>esc_html__('Sign in successful, redirecting...', 'campoal-tapo')));
        exit();
    }
endif;

/**
 * Facebook Login Function
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_facebook_login') ): 
    function conikal_facebook_login() {
        if(is_user_logged_in()) { 
            echo json_encode(array('status'=>true, 'message'=>esc_html__('You are already signed in, redirecting...', 'campoal-tapo')));
            exit();
        }
        check_ajax_referer('signin_ajax_nonce', 'security');
        global $campoal_options;
        
        $fb_app_id = isset($campoal_options['conikal_fb_id_field']) ? $campoal_options['conikal_fb_id_field'] : '';
        $fb_app_secret = isset($campoal_options['conikal_fb_secret_field']) ? $campoal_options['conikal_fb_secret_field'] : '';

        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $signin_user = isset($_POST['signin_user']) ? sanitize_text_field($_POST['signin_user']) : '';
        $profile_id = isset($_POST['profile_id']) ? sanitize_text_field($_POST['profile_id']) : '';
        $full_name = isset($_POST['full_name']) ? sanitize_text_field($_POST['full_name']) : '';
        $first_name = isset($_POST['first_name']) ? sanitize_text_field($_POST['first_name']) : '';
        $last_name = isset($_POST['last_name']) ? sanitize_text_field($_POST['last_name']) : '';
        $email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
        $birthday = isset($_POST['birthday']) ? sanitize_text_field($_POST['birthday']) : '';
        $gender = isset($_POST['gender']) ? sanitize_text_field($_POST['gender']) : '';
        $url = isset($_POST['url']) ? sanitize_text_field($_POST['url']) : '';
        $cover = isset($_POST['cover']) ? sanitize_text_field($_POST['cover']) : '';
        $avatar = isset($_POST['avatar']) ? sanitize_text_field($_POST['avatar']) : '';
        $signin_pass = $fb_app_secret.$user_id;

        $signup_data = array(
            'profile_id' => $user_id,
            'email' => $email,
            'signin_user' => $signin_user,
            'full_name' => $full_name,
            'first_name' => $first_name,
            'last_name' => $last_name,
            'birthday' => $birthday,
            'gender' => $gender,
            'cover' => $cover,
            'avatar' => $avatar,
            'avatar_orginal' => $avatar,
            'pass' => $signin_pass,
        );

        conikal_user_social_connection($email, $signup_data, 'facebook_connection');
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_facebook_login', 'conikal_facebook_login' );
add_action( 'wp_ajax_conikal_facebook_login', 'conikal_facebook_login' );

/**
 * Google Signin Function
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_google_signin') ): 
    function conikal_google_signin() {
        if(is_user_logged_in()) { 
            echo json_encode(array('status'=>true, 'message'=>esc_html__('You are already signed in, redirecting...', 'campoal-tapo')));
            exit();
        }
        check_ajax_referer('signin_ajax_nonce', 'security');
        global $campoal_options;
        
        $google_client_id = isset($campoal_options['conikal_google_id_field']) ? $campoal_options['conikal_google_id_field'] : '';
        $google_client_secret = isset($campoal_options['conikal_google_secret_field']) ? $campoal_options['conikal_google_secret_field'] : '';

        $user_id = isset($_POST['userid']) ? sanitize_text_field($_POST['userid']) : '';
        $signin_user = isset($_POST['signin_user']) ? sanitize_text_field($_POST['signin_user']) : '';
        $full_name = isset($_POST['full_name']) ? sanitize_text_field($_POST['full_name']) : '';
        $first_name = isset($_POST['first_name']) ? sanitize_text_field($_POST['first_name']) : '';
        $last_name = isset($_POST['last_name']) ? sanitize_text_field($_POST['last_name']) : '';
        $email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
        $birthday = isset($_POST['birthday']) ? sanitize_text_field($_POST['birthday']) : '';
        $birthday = $birthday != '' ? explode('-', $birthday) : '';
        $birthday = $birthday ? $birthday[1] . '/' . $birthday[2] . '/' . $birthday[0] : '';
        $gender = isset($_POST['gender']) ? sanitize_text_field($_POST['gender']) : '';
        $url = isset($_POST['url']) ? sanitize_text_field($_POST['url']) : '';
        $cover = isset($_POST['cover']) ? sanitize_text_field($_POST['cover']) : '';
        $avatar = isset($_POST['avatar']) ? sanitize_text_field($_POST['avatar']) : '';
        $signin_pass = $google_client_secret.$user_id;

        $signup_data = array(
            'profile_id' => $user_id,
            'email' => $email,
            'signin_user' => $signin_user,
            'full_name' => $full_name,
            'first_name' => $first_name,
            'last_name' => $last_name,
            'birthday' => $birthday,
            'gender' => $gender,
            'cover' => $cover,
            'avatar' => $avatar,
            'avatar_orginal' => $avatar,
            'pass' => $signin_pass,
        );

        conikal_user_social_connection($email, $signup_data, 'google_connection');
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_google_signin', 'conikal_google_signin' );
add_action( 'wp_ajax_conikal_google_signin', 'conikal_google_signin' );

/**
 * Social Sign Up Function
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_social_signup') ): 
    function conikal_social_signup($signup_data) {
        extract($signup_data);
        $user_data = array(
            'profile_id'    => $profile_id,
            'user_login'    => $signin_user,
            'user_email'    => $email,
            'user_pass'     => $pass,
            'first_name'    => $first_name,
            'last_name'     => $last_name,
            'display_name'  => $full_name,
            'connection'    => $connection,
        );

        if(email_exists($email)) {
            if(username_exists($signin_user)) {
                return false;
            } else {
                $user_data['user_email'] = ' ';
                $user_id  = wp_insert_user($user_data);
                conikal_social_signup_update_meta($user_id, $signup_data);

                if(is_wp_error($user_id)) {
                    return false;
                } else {
                    conikal_signup_notifications($user_id, $pass);
                    return $user_id;
                }
            }
        } else {
            if(username_exists($signin_user)) {
                return false;
            } else {
                $user_id = wp_insert_user($user_data);
                conikal_social_signup_update_meta($user_id, $signup_data);

                if(is_wp_error($user_id)) {
                    return false;
                } else {
                    conikal_signup_notifications($user_id, $pass);
                    return $user_id;
                }
            }
        }
    }
endif;


/**
 * Update user meta then sign up via social network
 *
 * @since Campoal Tapo 1.4.3
 */
if (!function_exists('conikal_social_signup_update_meta')) :
    function conikal_social_signup_update_meta($user_id, $signup_data) {
        if (empty($user_id) || empty($signup_data)) {
            return false;
        }

        // get location of user by GeoIp
        $geoip_info = conikal_client_geoip_info();

        update_user_meta($user_id, 'is_activated', 1);
        update_user_meta($user_id, 'user_' . $signup_data['connection'] . '_profile_id', $signup_data['profile_id']);
        update_user_meta($user_id, 'user_birthday', $signup_data['birthday']);
        update_user_meta($user_id, 'user_gender', $signup_data['gender']);
        update_user_meta($user_id, 'user_cover', $signup_data['cover']);
        update_user_meta($user_id, 'user_temporary_pass', true);

        if ($geoip_info) {
            update_user_meta($user_id, 'user_state', $geoip_info ? $geoip_info->mostSpecificSubdivision->name : '');
            update_user_meta($user_id, 'user_city', $geoip_info ? $geoip_info->city->name : '');
            update_user_meta($user_id, 'user_country', $geoip_info ? $geoip_info->country->isoCode : '');
            update_user_meta($user_id, 'user_lat', $geoip_info ? $geoip_info->location->latitude : '');
            update_user_meta($user_id, 'user_lng', $geoip_info ? $geoip_info->location->longitude : '');
            update_user_meta($user_id, 'user_zip', $geoip_info ? $geoip_info->continent->geonameId : '');
        }

        // set profile complete progress
        $profile_progress = conikal_profile_complete_progress($user_id);

        return true;
    }
endif;


/**
 * Connect exist account with social account
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_social_connection') ): 
    function conikal_social_connection() {
        check_ajax_referer('signin_ajax_nonce', 'security');
        
        $user_id    = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $social     = isset($_POST['social']) ? sanitize_text_field($_POST['social']) : '';
        $email      = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';

        $connection_status = get_user_meta($user_id, $social, true);
        if ($connection_status) {
            delete_user_meta($user_id, $social);
        } else {
            // check this email login is connected with exist account or not
            $users_social_connection = get_users(array(
                'meta_key' => $social,
                'meta_value' => $email,
                'number' => 1,
                'count_total' => false
            ));  

            $user_data = false;
            if ($users_social_connection) {
                foreach ($users_social_connection as $user) {
                    $user_data = $user;
                }
            }

            if ($user_data) {
                // delete user connected and update new user connect
                delete_user_meta($user_data->ID, $social);
                update_user_meta($user_id, $social, $email);
            } else {
                update_user_meta($user_id, $social, $email);
            }
        }
        
        echo json_encode(array('status' => true, 'message' => esc_html__('Connected to social account successfully!', 'campoal-tapo')));
        exit();
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_social_connection', 'conikal_social_connection' );
add_action( 'wp_ajax_conikal_social_connection', 'conikal_social_connection' );



/**
 * Update user profile
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_update_user_profile') ): 
    function conikal_update_user_profile() {
        check_ajax_referer('user_profile_ajax_nonce', 'security');

        global $campoal_options;
        $user_gender_r = isset($campoal_options['conikal_user_gender_r_field']) ? $campoal_options['conikal_user_gender_r_field'] : 0;
        $user_birthday_r = isset($campoal_options['conikal_user_birthday_r_field']) ? $campoal_options['conikal_user_birthday_r_field'] : 0;
        $user_location_r = isset($campoal_options['conikal_user_location_r_field']) ? $campoal_options['conikal_user_location_r_field'] : 0;
        $user_phone_r = isset($campoal_options['conikal_user_phone_r_field']) ? $campoal_options['conikal_user_phone_r_field'] : 0;
        $user_zip = isset($campoal_options['conikal_user_zip_field']) ? $campoal_options['conikal_user_zip_field'] : 0;
        $user_zip_r = isset($campoal_options['conikal_user_zip_r_field']) ? $campoal_options['conikal_user_zip_r_field'] : 0;
        $user_country = isset($campoal_options['conikal_user_country_field']) ? $campoal_options['conikal_user_country_field'] : 1;
        $user_country_r = isset($campoal_options['conikal_user_country_r_field']) ? $campoal_options['conikal_user_country_r_field'] : 0;

        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $user_type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : '';
        $full_name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
        $first_name = isset($_POST['firstname']) ? sanitize_text_field($_POST['firstname']) : '';
        $last_name = isset($_POST['lastname']) ? sanitize_text_field($_POST['lastname']) : '';
        $gender = isset($_POST['gender']) ? sanitize_text_field($_POST['gender']) : '';
        $nickname = isset($_POST['nickname']) ? sanitize_text_field($_POST['nickname']) : '';
        $email = isset($_POST['email']) ? sanitize_text_field($_POST['email']) : '';
        $birthday = isset($_POST['birthday']) ? sanitize_text_field($_POST['birthday']) : '';
        $address = isset($_POST['address']) ? sanitize_text_field($_POST['address']) : '';
        $neighborhood = isset($_POST['neighborhood']) ? sanitize_text_field($_POST['neighborhood']) : '';
        $state = isset($_POST['state']) ? sanitize_text_field($_POST['state']) : '';
        $city = isset($_POST['city']) ? sanitize_text_field($_POST['city']) : '';
        $country = isset($_POST['country']) ? sanitize_text_field($_POST['country']) : '';
        $lat = isset($_POST['lat']) ? sanitize_text_field($_POST['lat']) : '';
        $lng = isset($_POST['lng']) ? sanitize_text_field($_POST['lng']) : '';
        $zip = isset($_POST['zip']) ? sanitize_text_field($_POST['zip']) : '';
        $phone_code = isset($_POST['phone_code']) ? sanitize_text_field($_POST['phone_code']) : '';
        $phone_code = conikal_format_phone_number($phone_code);
        $phone = isset($_POST['phone']) ? sanitize_text_field($_POST['phone']) : '';
        $phone = conikal_format_phone_number($phone);
        $organization_name = isset($_POST['organization_name']) ? sanitize_text_field($_POST['organization_name']) : '';
        $website = isset($_POST['website']) ? sanitize_text_field($_POST['website']) : '';
        $bio = isset($_POST['bio']) ? sanitize_textarea_field($_POST['bio']) : '';
        $old_password = isset($_POST['old_password']) ? sanitize_text_field($_POST['old_password']) : '';
        $new_password = isset($_POST['new_password']) ? sanitize_text_field($_POST['new_password']) : '';
        $re_password = isset($_POST['re_password']) ? sanitize_text_field($_POST['re_password']) : '';
        $avatar = isset($_POST['avatar']) ? sanitize_text_field($_POST['avatar']) : '';
        $avatar_id = isset($_POST['avatar_id']) ? sanitize_text_field($_POST['avatar_id']) : '';
        $user_data = get_userdata($user_id);
        $current_email = $user_data->user_email;

        $decision_maker = isset($_POST['decision_id']) ? sanitize_text_field($_POST['decision_id']) : '';
        $decision_title = isset($_POST['decision_title']) ? sanitize_text_field($_POST['decision_title']) : '';
        $decision_organization = isset($_POST['decision_organization']) ? sanitize_text_field($_POST['decision_organization']) : '';
        $temporary_pass = get_user_meta($user_id, 'user_temporary_pass', true);

        // check requirement fields
        if (empty($first_name) || empty($last_name) || empty($email)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Required form fields is mandatory.', 'campoal-tapo')));
            exit();
        }

        // check gender field requirement
        if ($user_gender_r == 1 && empty($gender)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('User gender fields is mandatory.', 'campoal-tapo')));
            exit();
        }

        // check user birthday requirement
        if ($user_birthday_r == 1 && empty($birthday)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('User birthday fields is mandatory.', 'campoal-tapo')));
            exit();
        }

        // check location requirement
        if ($user_location_r == 1 && empty($address)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('User location fields is mandatory.', 'campoal-tapo')));
            exit();
        }

        // check country requirement
        if ($user_zip == 1 && $user_zip_r == 1 && empty($zip)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('User zip code fields is mandatory.', 'campoal-tapo')));
            exit();
        }

        // check country requirement
        if ($user_country == 1 && $user_country_r == 1 && empty($country)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('User country fields is mandatory.', 'campoal-tapo')));
            exit();
        }

        // check phone number requiremnt
        if ($user_phone_r == 1 && empty($phone)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('User phone number fields is mandatory.', 'campoal-tapo')));
            exit();
        }

        // check user account type
        if ($user_type == 'decisioner') {
          if(empty($decision_title) || empty($decision_organization)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Required form fields are empty!', 'campoal-tapo')));
            exit();
          } 
        }

        // check valid email
        if (!is_email($email)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Invalid Email!', 'campoal-tapo')));
            exit();
        }

        if ($current_email != $email) {
            if (email_exists($email)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Email already exists!', 'campoal-tapo')));
                exit();
            }
        }


        // check password
        if ($new_password != '' && !$temporary_pass) {
            if ($old_password === '' || !wp_check_password($old_password, $user_data->user_pass, $user_id)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('The old password do not match!', 'campoal-tapo')));
                exit();
            }
        }

        if ($new_password != '' && 6 > strlen($new_password)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Password too short. Please enter at least 6 characters!', 'campoal-tapo')));
            exit();
        }

        if ($new_password != '' && $new_password != $re_password) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('The new passwords do not match!', 'campoal-tapo')));
            exit();
        }


        // user avatar
        $images = array('', '');
        if ($avatar != '') {
            $images = explode("~~~", $avatar);
            if ($avatar_id != '') {
                $avatar_url = wp_get_attachment_metadata($avatar_id, 'conikal-petition-avatar', true);
                $avatar_url = isset($avatar_url['file']) ? $avatar_url['file'] : '';
            } else {
                $avatar_url = isset($images[1]) ? $images[1] : '';
            }
        } else {
            $avatar_url = '';
        }

        if (empty($full_name)) {
            $full_name = $first_name . ' ' . $last_name;
        }


        // INSER DECISION MAKER
        global $campoal_options;
        
        $review = isset($campoal_options['conikal_review_decision_field']) ? $campoal_options['conikal_review_decision_field'] : 0;
        if($review == 0 || user_can($user_id, 'administrator') || user_can($user_id, 'editor')) {
            $prop_status = 'publish';
        } else {
            $prop_status = 'pending';
        }

        if ($user_type == 'decisioner') {
            $prop = array(
                'post_title' => $full_name,
                'post_content' => $bio,
                'post_type' => 'decisionmakers',
                'post_author' => $user_id
            );

            if($decision_maker != '') {
                $prop['ID'] = $decision_maker;
            } else {
                $prop['post_status'] = $prop_status;
            }

            if ($decision_maker != '') {
                $decision_id = wp_update_post($prop);
            } else {
                $decision_id = wp_insert_post($prop);
            }

            // set title and organization for decision maker
            wp_set_object_terms($decision_id, $decision_title, 'decisionmakers_title');
            wp_set_object_terms($decision_id, $decision_organization, 'decisionmakers_organization');
        } else {
            $indentify_attachments = array(
                'decisionmaker_indentify_frontside_photo',
                'decisionmaker_indentify_backside_photo',
                'decisionmaker_indentify_other_photo',
            );

            // delete indentify document attachments
            foreach ($indentify_attachments as $attachment_meta) {
                $attachment_id   = get_post_meta($decision_maker, $attachment_meta, true);
                wp_delete_attachment($attachment_id);
            }

            // delete decision maker post
            wp_delete_post($decision_maker);
            $decision_id = '';
        }

        // update user info
        $user_data = array(
            'ID' => $user_id,
            'user_email' => $email,
            'first_name' => $first_name,
            'last_name'  => $last_name,
            'display_name' => $full_name,
            'user_url' => $website,
            'description' => $bio,
        );

        update_user_meta($user_id, 'user_type', $user_type);
        update_user_meta($user_id, 'user_decision', $decision_id);
        update_user_meta($user_id, 'user_birthday', $birthday);
        update_user_meta($user_id, 'user_gender', $gender);
        update_user_meta($user_id, 'avatar', $avatar_url);
        update_user_meta($user_id, 'avatar_id', $avatar_id);
        update_user_meta($user_id, 'avatar_orginal', $images[1]);
        update_user_meta($user_id, 'user_address', $address);
        update_user_meta($user_id, 'user_neighborhood', $neighborhood);
        update_user_meta($user_id, 'user_state', $state);
        update_user_meta($user_id, 'user_city', $city);
        update_user_meta($user_id, 'user_country', $country);
        update_user_meta($user_id, 'user_lat', $lat);
        update_user_meta($user_id, 'user_lng', $lng);
        update_user_meta($user_id, 'user_zip', $zip);
        update_user_meta($user_id, 'user_phone_code', intval($phone_code));
        update_user_meta($user_id, 'user_phone', intval($phone));
        update_user_meta($user_id, 'user_organization_name', $organization_name);

        wp_update_user($user_data);

        $author_url = get_author_posts_url( $user_id );

        // set profile complete progress
        $profile_progress = conikal_profile_complete_progress($user_id);

        // update attribute contact to sendinblue
        $sendinblue = conikal_sendinblue_users_list(false, $user_id, 'update');

        if ($new_password != '' && $temporary_pass) {
            wp_update_user(array( 'ID' => $user_id, 'user_email' => $email, 'user_pass' => $new_password ));
            delete_user_meta($user_id, 'user_temporary_pass');
            echo json_encode(array('status'=>true, 'author_url' => $author_url, 'decision_id' => $decision_id, 'message'=>esc_html__('Your password was changed successfully!.', 'campoal-tapo')));
        } else if ($new_password != '' && $old_password != '') {
            wp_update_user(array( 'ID' => $user_id, 'user_email' => $email, 'user_pass' => $new_password ));
            echo json_encode(array('status'=>true, 'author_url' => $author_url, 'decision_id' => $decision_id, 'message'=>esc_html__('Your password was changed successfully!.', 'campoal-tapo')));
        } else {
            echo json_encode(array('status'=>true, 'author_url' => $author_url, 'decision_id' => $decision_id, 'message'=>esc_html__('Your profile was successfully updated!', 'campoal-tapo')));
        }
        exit();

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_update_user_profile', 'conikal_update_user_profile' );
add_action( 'wp_ajax_conikal_update_user_profile', 'conikal_update_user_profile' );


/**
 * Update indentify documents
 *
 * @since Campoal Tapo 1.7.4
 */
if (!function_exists('conikal_update_indentify_document')) :
    function conikal_update_indentify_document() {
        $user_id                    = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $field_required             = isset($_POST['field_required']) ? sanitize_text_field($_POST['field_required']) : 1;
        $indentify_type             = isset($_POST['indentify_type']) ? sanitize_text_field($_POST['indentify_type']) : '';
        $indentify_name             = isset($_POST['indentify_name']) ? sanitize_text_field($_POST['indentify_name']) : '';
        $indentify_id               = isset($_POST['indentify_id']) ? sanitize_text_field($_POST['indentify_id']) : '';
        $indentify_country_issue    = isset($_POST['indentify_country_issue']) ? sanitize_text_field($_POST['indentify_country_issue']) : '';
        $document_side              = isset($_POST['document_side']) ? sanitize_text_field($_POST['document_side']) : '';
        $document_url               = isset($_POST['document_url']) ? sanitize_text_field($_POST['document_url']) : '';
        $document_attch_id          = isset($_POST['document_attch_id']) ? sanitize_text_field($_POST['document_attch_id']) : '';

        // check mandory fields
        if ($field_required == 1) {
            if ( empty($indentify_name) || empty($indentify_id) || empty($indentify_country_issue) ) {
                echo json_encode(array('status' => false, 'message' => esc_html__('Required form fields is mandatory.', 'campoal-tapo')));
                exit();
            }
        }

        // get decisio makers id
        $decisionmaker_id = get_user_meta($user_id, 'user_decision', true);

        if (!empty($decisionmaker_id)) {
            $prefix = 'decisionmaker_';
            update_post_meta($decisionmaker_id, $prefix . 'indentify_type', $indentify_type);
            update_post_meta($decisionmaker_id, $prefix . 'indentify_name', $indentify_name);
            update_post_meta($decisionmaker_id, $prefix . 'indentify_id', $indentify_id);
            update_post_meta($decisionmaker_id, $prefix . 'indentify_country_issue', $indentify_country_issue);

            $message = esc_html__('Your indentify infomation was submited!', 'campoal-tapo');

            // update indentify document
            switch ($document_side) {
                case 'front':
                    update_post_meta($decisionmaker_id, $prefix . 'indentify_frontside_photo', $document_attch_id);
                    $message = esc_html__('Your front-side of indentify document was saved!', 'campoal-tapo');
                    break;

                case 'back':
                    update_post_meta($decisionmaker_id, $prefix . 'indentify_backside_photo', $document_attch_id);
                    $message = esc_html__('Your back-side of indentify document was saved!', 'campoal-tapo');
                    break;

                case 'other':
                    update_post_meta($decisionmaker_id, $prefix . 'indentify_other_photo', $document_attch_id);
                    $message = esc_html__('Your other indentify document was saved!', 'campoal-tapo');
                    break;
                
                default:
                    update_post_meta($decisionmaker_id, $prefix . 'indentify_frontside_photo', $document_attch_id);
                    $message = esc_html__('Your front-side of indentify document was saved!', 'campoal-tapo');
                    break;
            }

            echo json_encode(array('status'=>true, 'decision_id' => $decisionmaker_id, 'message'=>$message));
            exit();
        } else {
            echo json_encode(array('status' => false, 'message' => esc_html__('Can\'t save your indentify infomation.', 'campoal-tapo')));
            exit();
        }

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_update_indentify_document', 'conikal_update_indentify_document' );
add_action( 'wp_ajax_conikal_update_indentify_document', 'conikal_update_indentify_document' );


/**
 * Set profile complete progress
 *
 * @since Campoal Tapo 1.5.0
 */
if (!function_exists('conikal_profile_complete_progress')) :
    function conikal_profile_complete_progress($user_id) {
        global $campoal_options;
        $user_data = get_userdata($user_id);

        if ($user_data) {
            $user_gender_r = isset($campoal_options['conikal_user_gender_r_field']) ? $campoal_options['conikal_user_gender_r_field'] : 0;
            $user_birthday_r = isset($campoal_options['conikal_user_birthday_r_field']) ? $campoal_options['conikal_user_birthday_r_field'] : 0;
            $user_location_r = isset($campoal_options['conikal_user_location_r_field']) ? $campoal_options['conikal_user_location_r_field'] : 0;
            $user_phone_r = isset($campoal_options['conikal_user_phone_r_field']) ? $campoal_options['conikal_user_phone_r_field'] : 0;
            $user_avatar_r = isset($campoal_options['conikal_user_avatar_r_field']) ? $campoal_options['conikal_user_avatar_r_field'] : 0;

            $profile_fields = array(
                'user_email' => array(
                    'value' => $user_data->user_email,
                    'required' => true,
                ),
                'first_name' => array(
                    'value' => $user_data->first_name,
                    'required' => true,
                ),
                'last_name' => array(
                    'value' => $user_data->last_name,
                    'required' => true,
                ),
                'display_name' => array(
                    'value' => $user_data->display_name,
                    'required' => true,
                ),
                'user_type' => array(
                    'value' => get_user_meta($user_id, 'user_type', true),
                    'required' => true,
                ),
                'user_birthday' => array(
                    'value' => get_user_meta($user_id, 'user_birthday', true),
                    'required' => $user_birthday_r,
                ),
                'user_gender' => array(
                    'value' => get_user_meta($user_id, 'user_gender', true),
                    'required' => $user_gender_r,
                ),
                'avatar' => array(
                    'value' => get_user_meta($user_id, 'avatar', true),
                    'required' => $user_avatar_r,
                ),
                'user_address' => array(
                    'value' => get_user_meta($user_id, 'user_address', true),
                    'required' => $user_location_r,
                ),
                'user_phone' => array(
                    'value' => get_user_meta($user_id, 'user_phone', true),
                    'required' => $user_phone_r,
                )
            );

            $field_goal = 0;
            $field_completed = 0;
            foreach ($profile_fields as $name => $field) {
                if (!empty($field['value']) && $field['value'] != '') {
                    $field_completed++;
                }

                if ($field['required'] == true) {
                    $field_goal++;
                }
            }

            if ($field_completed >= $field_goal) {
                $profile_progress = true;
            } else {
                $profile_progress = array(
                    'goal' => $field_goal,
                    'completed' => $field_completed
                );
            }
            // save result to user meta
            update_user_meta($user_id, 'user_profile_progress', $profile_progress);
            $results = get_user_meta($user_id, 'user_profile_progress', true);
        } else {
            $results = false;
        }

        return $results;
    }
endif;

/**
 * Welcome notification seen
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_notification_seen') ): 
    function conikal_notification_seen() {
        check_ajax_referer('notificaiton_seen_ajax_nonce', 'security');

        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $notification = isset($_POST['notification']) ? sanitize_text_field($_POST['notification']) : 0;
        update_user_meta($user_id, $notification, true);

        echo json_encode(array('status'=>true, 'message'=>esc_html__('Notification has been set is seen.', 'campoal-tapo')));
        exit();
        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_notification_seen', 'conikal_notification_seen' );
add_action( 'wp_ajax_conikal_notification_seen', 'conikal_notification_seen' );

/**
 * Set sign user option
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_set_sign_user_option') ): 
    function conikal_set_sign_user_option() {
        check_ajax_referer('general_ajax_nonce', 'security');

        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $option = isset($_POST['option']) ? sanitize_text_field($_POST['option']) : false;
        if (isset($_POST['value'])) {
            $value = is_int($_POST['value']) ? rest_sanitize_boolean($_POST['value']) : sanitize_text_field($_POST['value']);
        }

        update_user_meta($user_id, $option, $value);

        echo json_encode(array('status'=>true, 'message'=>esc_html__('The option has changed successfully.', 'campoal-tapo')));
        exit();

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_set_sign_user_option', 'conikal_set_sign_user_option' );
add_action( 'wp_ajax_conikal_set_sign_user_option', 'conikal_set_sign_user_option' );


/**
 * Update financial infomation
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_financial_infomation') ): 
    function conikal_financial_infomation() {
        check_ajax_referer('financial_ajax_nonce', 'security');

        $user_id                = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $paypal_email           = isset($_POST['paypal_email']) ? sanitize_text_field($_POST['paypal_email']) : '';
        $payoneer_email         = isset($_POST['payoneer_email']) ? sanitize_text_field($_POST['payoneer_email']) : '';
        $payoneer_card          = isset($_POST['payoneer_card']) ? sanitize_text_field($_POST['payoneer_card']) : '';
        $bitcoin_network        = isset($_POST['bitcoin_network']) ? sanitize_text_field($_POST['bitcoin_network']) : '';
        $bitcoin_address        = isset($_POST['bitcoin_address']) ? sanitize_text_field($_POST['bitcoin_address']) : '';
        $bank_fullname          = isset($_POST['bank_fullname']) ? sanitize_text_field($_POST['bank_fullname']) : '';
        $bank_user_address      = isset($_POST['bank_user_address']) ? sanitize_text_field($_POST['bank_user_address']) : '';
        $bank_name              = isset($_POST['bank_name']) ? sanitize_text_field($_POST['bank_name']) : '';
        $bank_address           = isset($_POST['bank_address']) ? sanitize_text_field($_POST['bank_address']) : '';
        $bank_swift_code        = isset($_POST['bank_swift_code']) ? sanitize_text_field($_POST['bank_swift_code']) : '';
        $bank_account_number    = isset($_POST['bank_account_number']) ? sanitize_text_field($_POST['bank_account_number']) : '';
        $confirm_password       = isset($_POST['confirm_password']) ? sanitize_text_field($_POST['confirm_password']) : '';
        $user_data              = get_userdata($user_id);

        if ($confirm_password === '' || !wp_check_password($confirm_password, $user_data->user_pass, $user_id)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('The password do not match!', 'campoal-tapo')));
            exit();
        }

        if(!empty($paypal_email) && !is_email($paypal_email)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Paypal email are incorrect!', 'campoal-tapo')));
            exit();
        }

        if(!empty($payoneer_email) && !is_email($payoneer_email)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Payoneer email are incorrect!', 'campoal-tapo')));
            exit();
        }

        // paypal details
        $paypal = array(
            'email' => $paypal_email
        );

        if (!$paypal_email) {
            $paypal = '';
        }
        
        // payoneer details
        $payoneer = array(
            'email' => $payoneer_email,
            'card' => $payoneer_card
        );

        if (!$payoneer_email && !$payoneer_card) {
            $payoneer = '';
        }

        // payoneer details
        $bitcoin = array(
            'network' => $bitcoin_network,
            'address' => $bitcoin_address
        );

        if (!$bitcoin_network && !$bitcoin_address) {
            $bitcoin = '';
        }
        
        // bank account details
        $bank = array(
            'fullname' => $bank_fullname,
            'user_address' => $bank_user_address,
            'name' => $bank_name,
            'address' => $bank_address,
            'swift_code' => $bank_swift_code,
            'account_number' => $bank_account_number
        );

        if (!$bank_fullname && !$bank_user_address && !$bank_name && !$bank_address && !$bank_swift_code && !$bank_account_number) {
            $bank = '';
        }

        $save_paypal = update_user_meta($user_id, 'financial_paypal', $paypal);
        $save_payoneer = update_user_meta($user_id, 'financial_payoneer', $payoneer);
        $save_bitcoin = update_user_meta($user_id, 'financial_bitcoin', $bitcoin);
        $save_bank = update_user_meta($user_id, 'financial_bank', $bank);

        if ($save_paypal || $save_payoneer || $save_bank || $save_bitcoin) {
            echo json_encode(array('status'=>true, 'message'=>esc_html__('Your Financial Information was saved successfully!', 'campoal-tapo')));
        } else {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Your financial information was saved with not changed!', 'campoal-tapo')));
        }
        exit();

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_financial_infomation', 'conikal_financial_infomation' );
add_action( 'wp_ajax_conikal_financial_infomation', 'conikal_financial_infomation' );


/**
 * Delete account
 *
 * @since Campoal Tapo 1.0.0
 */
if( !function_exists('conikal_delete_account') ): 
    function conikal_delete_account() {
        check_ajax_referer('user_profile_ajax_nonce', 'security');

        $user_id = isset($_POST['user_id']) ? sanitize_text_field($_POST['user_id']) : '';
        $confirm_password = isset($_POST['confirm_password']) ? sanitize_text_field($_POST['confirm_password']) : '';
        $reassign = isset($_POST['reassign']) ? sanitize_text_field($_POST['reassign']) : '';
        $user_data = get_userdata($user_id);

        if ($confirm_password == '' || !wp_check_password($confirm_password, $user_data->user_pass, $user_id)) {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('The password do not match!', 'campoal-tapo')));
            exit();
        }

        if($reassign && is_email($reassign)) {
            $user_data = get_user_by('email', $reassign);
            if(empty($user_data)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Invalid email address!', 'campoal-tapo')));
                exit();
            }
        } elseif ($reassign) {
            $user_data = get_user_by('login', $reassign);
            if(empty($user_data)) {
                echo json_encode(array('status'=>false, 'message'=>esc_html__('Invalid username!', 'campoal-tapo')));
                exit();
            }
        }

        if ($reassign) {
            $delete_user = wp_delete_user($user_id, $user_data->ID);
        } else {
            $delete_user = wp_delete_user($user_id);
        }

        if($delete_user) {
            echo json_encode(array('status'=>true, 'message'=>esc_html__('Your account has been deteled successfully!', 'campoal-tapo')));
        } else {
            echo json_encode(array('status'=>false, 'message'=>esc_html__('Your account delete failed!', 'campoal-tapo')));
        }
        exit();

        die();
    }
endif;
add_action( 'wp_ajax_nopriv_conikal_delete_account', 'conikal_delete_account' );
add_action( 'wp_ajax_conikal_delete_account', 'conikal_delete_account' );

?>