<?php
/**
 * @package WordPress
 * @subpackage Campoal Tapo
 */


/**
 * Contact widget
 *
 * @since Campoal Tapo 1.0.0
 */
class Contact_Widget extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'contact_sidebar', 'description' => 'Your contact information.');
        $control_ops = array('id_base' => 'contact_widget');
        parent::__construct('contact_widget', 'Campoal Contact', $widget_ops, $control_ops);
    }

    function form($instance) {
        $defaults = array(
            'title' => '',
            'organization' => '',
            'phone' => '',
            'mail' => '',
            'address' => '',
            'city' => '',
            'state' => '',
            'zip' => '',
            'country' => ''
        );
        $instance = wp_parse_args((array) $instance, $defaults); ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')) ?>"><?php esc_html_e('Title', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')) ?>" name="<?php echo esc_attr($this->get_field_name('title')) ?>" value="<?php echo esc_attr($instance['title']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('organization'))  ?>"><?php esc_html_e('Organization', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('organization')) ?>" name="<?php echo esc_attr($this->get_field_name('organization')) ?>" value="<?php echo esc_attr($instance['organization']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone')) ?>"><?php esc_html_e('Phone', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('phone')) ?>" name="<?php echo esc_attr($this->get_field_name('phone')) ?>" value="<?php echo esc_attr($instance['phone']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('mail')) ?>"><?php esc_html_e('Email', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('mail')) ?>" name="<?php echo esc_attr($this->get_field_name('mail')) ?>" value="<?php echo esc_attr($instance['mail']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('address')) ?>"><?php esc_html_e('Address', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('address')) ?>" name="<?php echo esc_attr($this->get_field_name('address')) ?>" value="<?php echo esc_attr($instance['address']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('city')) ?>"><?php esc_html_e('City', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('city')) ?>" name="<?php echo esc_attr($this->get_field_name('city')) ?>" value="<?php echo esc_attr($instance['city']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('state')) ?>"><?php esc_html_e('State/County', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('state')) ?>" name="<?php echo esc_attr($this->get_field_name('state')) ?>" value="<?php echo esc_attr($instance['state']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('zip')) ?>"><?php esc_html_e('Zip code', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('zip')) ?>" name="<?php echo esc_attr($this->get_field_name('zip')) ?>" value="<?php echo esc_attr($instance['zip']) ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('country')) ?>"><?php esc_html_e('Country', 'campoal-tapo') ?>:</label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('country')) ?>" name="<?php echo esc_attr($this->get_field_name('country')) ?>" value="<?php echo esc_attr($instance['country']) ?>" />
        </p>
    <?php }


    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = sanitize_text_field($new_instance['title']);
        $instance['organization'] = sanitize_text_field($new_instance['organization']);
        $instance['phone'] = sanitize_text_field($new_instance['phone']);
        $instance['mail'] = sanitize_text_field($new_instance['mail']);
        $instance['address'] = sanitize_text_field($new_instance['address']);
        $instance['city'] = sanitize_text_field($new_instance['city']);
        $instance['state'] = sanitize_text_field($new_instance['state']);
        $instance['zip'] = sanitize_text_field($new_instance['zip']);
        $instance['country'] = sanitize_text_field($new_instance['country']);

        if (function_exists('icl_register_string')) {
            icl_register_string('conikal_contact_widget', 'contact_widget_title', sanitize_text_field($new_instance['title']));
            icl_register_string('conikal_contact_widget', 'contact_widget_organization', sanitize_text_field($new_instance['organization']));
            icl_register_string('conikal_contact_widget', 'contact_widget_phone', sanitize_text_field($new_instance['phone']));
            icl_register_string('conikal_contact_widget', 'contact_widget_mail', sanitize_text_field($new_instance['mail']));
            icl_register_string('conikal_contact_widget', 'contact_widget_address', sanitize_text_field($new_instance['address']));
            icl_register_string('conikal_contact_widget', 'contact_widget_city', sanitize_text_field($new_instance['city']));
            icl_register_string('conikal_contact_widget', 'contact_widget_state', sanitize_text_field($new_instance['state']));
            icl_register_string('conikal_contact_widget', 'contact_widget_zip', sanitize_text_field($new_instance['zip']));
            icl_register_string('conikal_contact_widget', 'contact_widget_country', sanitize_text_field($new_instance['country']));
        }

        return $instance;
    }

    function widget($args, $instance) {
        extract($args);
        $title = apply_filters('widget_title', $instance['title']);

        echo wp_kses_post($before_widget);
        if ($title) {
            echo wp_kses_post($before_title) . esc_html($title) . wp_kses_post($after_title);
        }

        if ($instance['organization']) {
            if (function_exists('icl_t')) {
                $info_organization = icl_t('conikal_contact_widget', 'contact_widget_organization', $instance['organization']);
            } else {
                $info_organization = $instance['organization'];
            } ?>
            <h3><?php echo esc_html($info_organization) ?></h3>
        <?php } ?>

        <div>
        <?php 
        if ($instance['phone']) {
            if (function_exists('icl_t')) {
                $info_phone = icl_t('conikal_contact_widget', 'contact_widget_phone', $instance['phone']);
            } else {
                $info_phone = $instance['phone'];
            } ?>
            <div class="font large"><i class="phone icon"></i> <?php echo esc_html($info_phone) ?></div>
        <?php } 
        if ($instance['mail']) {
            if (function_exists('icl_t')) {
                $info_mail = icl_t('conikal_contact_widget', 'contact_widget_phone', $instance['mail']);
            } else {
                $info_mail = $instance['mail'];
            } ?>
            <div><i class="mail icon"></i> <?php echo esc_html($info_mail) ?></div>
        <?php } 
        if ($instance['address']) {
            if (function_exists('icl_t')) {
                $info_address = icl_t('conikal_contact_widget', 'contact_widget_address', $instance['address']);
            } else {
                $info_address = $instance['address'];
            } ?>
            <i class="map marker icon"></i><?php echo esc_html($info_address) ?><br/>
        <?php } 
        if ($instance['city']) {
            if (function_exists('icl_t')) {
                $info_city = icl_t('conikal_contact_widget', 'contact_widget_city', $instance['city']);
            } else {
                $info_city = $instance['city'];
            }
            echo esc_html($info_city) . ', ';
        } 
        if ($instance['state']) {
            if (function_exists('icl_t')) {
                $info_state = icl_t('conikal_contact_widget', 'contact_widget_state', $instance['state']);
            } else {
                $info_state = $instance['state'];
            }
            echo esc_html($info_state) . ', ';
        } 
        if ($instance['zip']) {
            if (function_exists('icl_t')) {
                $info_zip = icl_t('conikal_contact_widget', 'contact_widget_zip', $instance['zip']);
            } else {
                $info_zip = $instance['zip'];
            }
            echo esc_html($info_zip) . ', ';
        } 
        if ($instance['country']) {
            if (function_exists('icl_t')) {
                $info_country = icl_t('conikal_contact_widget', 'contact_widget_country', $instance['country']);
            } else {
                $info_country = $instance['country'];
            }
            echo esc_html($info_country);
        } ?>
        </div>

        <?php 
        echo wp_kses_post($after_widget);
    }

}

?>