<?php

/**
 * Petitions by ID shortcode
 */
if( !function_exists('conikal_petition_by_id_shortcode') ): 
    function conikal_petition_by_id_shortcode($attrs, $content = null) {
        extract(shortcode_atts(array(
            'title'     => 'Petition by ID',
            'show'      => '4',
            'petition_ids' => '',
            'style'     => 'grid',
            'carousel'  => 'no',
            'column'    => 'four',
            'hover'     => false,
            'order'     => 'DESC',
            'orderby'   => 'date',
        ), $attrs));

        global $campoal_options;
        $minimum_signature = isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;

        if ($petition_ids != '') {
            $petition_ids = array_map('intval', explode(',', $petition_ids));
        }

        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

        $args = array(
            'posts_per_page'   => $show,
            'paged'            => $paged,
            'post_type'        => 'petition',
            'order'            => $order,
            'orderby'          => conikal_meta_key_ordering_filter($orderby),
            'post__in'         => $petition_ids,
            'post_status'      => 'publish' );

        // add meta key or supporters ordering
        if ($orderby == 'supporters') {
            $args['meta_key'] = 'petition_sign';
        }
        if ($orderby == 'views') {
            $args['meta_key'] = 'post_views_count';
        }

        $posts = new WP_Query($args);

        $return_string = conikal_shortcode_loop_petition($posts, $attrs, $content);

        wp_reset_postdata();
        wp_reset_query();
        return $return_string;
    }
endif;


// interact with visual composer

add_action( 'vc_before_init', 'conikal_vc_petition_by_id_shortcode' );
function conikal_vc_petition_by_id_shortcode() {
   vc_map( array(
      "name" => esc_html__('Petition by ID', 'campoal-tapo'),
      "base" => 'petition_by_id',
      "class" => '',
      "category" => esc_html__('Campoal', 'campoal-tapo'),
      'admin_enqueue_js' => plugin_dir_url( __FILE__ ) . 'vc_extend/bartag.js',
      'admin_enqueue_css' => plugin_dir_url( __FILE__ ) . 'vc_extend/bartag.css',
      "icon" => plugin_dir_url( __FILE__ ) . 'images/campoal-icon.svg',
      "params" => array(
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Title', 'campoal-tapo'),
            "param_name" => 'title',
            "value" => 'Petition by ID',
            "description" => esc_html__('Title of Segment', 'campoal-tapo')
        ),
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Show Number', 'campoal-tapo'),
            "param_name" => 'show',
            "value" => 4,
            "description" => esc_html__('Number of Petitions', 'campoal-tapo')
        ),
        array(
            "type" => 'textfield',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Petitions IDs (separated by comma)', 'campoal-tapo'),
            "param_name" => 'petition_ids',
            "value" => '',
            "description" => esc_html__('Petition IDs comma-separated list of IDs', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Style', 'campoal-tapo'),
            "param_name" => 'style',
            "value" => array(
                'Grid' => 'grid',
                'List' => 'list'
                ),
            "std" => 'grid',
            "description" => esc_html__('Style Display of Petition', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Carousel Mode', 'campoal-tapo'),
            "param_name" => 'carousel',
            "value" => array(
                'No' => 'no',
                'Yes' => 'yes',
                ),
            "std" => 'no',
            "description" => esc_html__('Display Petitions follow Carousel style', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Column', 'campoal-tapo'),
            "param_name" => 'column',
            "value" => conikal_shortcode_column_options(),
            "std" => 'four',
            "description" => esc_html__('Column of Petitions', 'campoal-tapo')
        ),
        array(
            "type" => 'checkbox',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Active hover', 'campoal-tapo'),
            "param_name" => 'hover',
            "description" => esc_html__('Active hover card', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Order', 'campoal-tapo'),
            "param_name" => 'order',
            "value" => array_flip(conikal_sort_petition_options('order')),
            "std" => 'DESC',
            "description" => esc_html__('Ordering petitions', 'campoal-tapo')
        ),
        array(
            "type" => 'dropdown',
            "holder" => 'div',
            "class" => '',
            "heading" => esc_html__('Sort by', 'campoal-tapo'),
            "param_name" => 'orderby',
            "value" => array_flip(conikal_sort_petition_options('orderby')),
            "std" => 'date',
            "description" => esc_html__('Sort petittion by conditional', 'campoal-tapo')
        ),
      )
   ) );
}

?>