<?php

/**
 * Petition list content in shortcode
 */
if (!function_exists('conikal_shortcode_post_card')) :
    function conikal_shortcode_post_card($post, $attrs, $content = null) {
        global $campoal_options;
        $external_link = isset($campoal_options['conikal_external_link_field']) ? $campoal_options['conikal_external_link_field'] : 0;
        $view_counter = isset($campoal_options['conikal_view_counter_field']) ? $campoal_options['conikal_view_counter_field'] : 0;

        // convert shortcode attributes to variables
        extract(shortcode_atts(array(
            'title' => 'Featured Posts',
            'show' => '4',
            'carousel' => 'no',
            'column' => 'four',
            'hover' => false,
        ), $attrs));

        $id = get_the_ID();
        $post_link = get_permalink($id);
        $post_title = get_the_title($id);
        $post_date = get_the_date(get_option( 'date_format' ), $id);
        $post_comments = wp_count_comments($id);
        $post_excerpt = conikal_get_excerpt_by_id($id, 12);
        $post_excerpt_medium = conikal_get_excerpt_by_id($id, 20);
        $post_excerpt_long = conikal_get_excerpt_by_id($id, 30);
        $post_view = conikal_format_number('%!,0i', (int) conikal_get_post_views($id), true);
        $post_author = get_the_author_meta( 'ID' );

        $avatar             = conikal_get_avatar_url( $post_author, array('size' => 64) );
        $avatar_retina      = conikal_get_avatar_url( $post_author, array('size' => 128) );

        // get post thumbnail
        $thumbnail          = conikal_get_petition_thumbnail($id, 'conikal-petition-thumbnail', false);
        $thumbnail_retina   = conikal_get_petition_thumbnail($id, 'conikal-petition-thumbnail-retina', false);

        $lazy_placeholder           = conikal_lazy_load_placeholder('thumbnail-small');
        $lazy_placeholder_avatar    = conikal_lazy_load_placeholder('avatar');

        $return_string = '';
        if ( conikal_carousel_mode($carousel) == 0 ) {
            $return_string .= '<div class="card blogs post petition-card' . esc_attr($hover == true ? ' active-hover' : '') . '">';
        } else {
            $return_string .= '<div>';
            $return_string .= '<div class="ui fluid card blogs post petition-card post-card' . esc_attr($hover == true ? ' active-hover' : '') . '" style="margin-bottom: 2px;">';
        }
        
        // post thumbnail
        if ( has_post_thumbnail($id) ) {
            $return_string .= '<a href="' . esc_url($post_link) . '" class="ui fluid image" target="' . ($external_link != 0 ? esc_attr('_blank') : esc_attr('_self')) . '" ' . ($external_link != 0 ? '' : esc_attr('data-bjax')) . '>';
            $return_string .= '<div class="ui dimmer"><div class="content">';
            $return_string .= '<div class="center"><div class="ui icon inverted circular ' . ($column == 'three' ? 'big ' : '') . 'button"><i class="external alternate icon"></i></div></div>';
            $return_string .= '<div class="view-counter"><i class="comments icon"></i>' . $post_comments->approved;
            if ($view_counter == 1) {
                $return_string .= '<i class="eye icon"></i>' . esc_html($post_view);
            }
            $return_string .= '</div></div></div>';
            if ( is_sticky($id) ) {
                $return_string .= '<span class="ui primary right large corner label"><i class="star icon"></i></span>';
            }
            $return_string .= '<img class="lazy" src="' . esc_url($lazy_placeholder) . '" data-src="' . esc_url($thumbnail) . '" data-retina="' . esc_url($thumbnail_retina) . '" alt="' . esc_attr($post_title) . '">';
            $return_string .= '</a>';
        } else {
            if ( is_sticky($id) ) {
                $return_string .= '<span class="ui primary right large corner label"><i class="star icon"></i></span>';
            }
        }

        // post card content
        $return_string .= '<div class="content petition-content' . (has_post_thumbnail($id) ? '' : ' title-only') . '">';
        if ( !has_post_thumbnail($id) ) {
            $return_string .= '<div class="view-counter"><i class="comments icon"></i>' . esc_html($post_comments->approved);
                if ($view_counter == 1) {
                    $return_string .= '<i class="eye icon"></i>' . esc_html($post_view);
                }
            $return_string .= '</div>';
        }

        if ( has_post_thumbnail($id) ) {
            // category tags
            $categories = get_the_category($id);
            $separator = ' ';
            $output = '';
            if($categories) {
                foreach($categories as $category) {
                    $output .= '<a class="ui tiny label" href="' . esc_url(get_category_link($category->term_id)) . '" title="' . esc_attr(sprintf(esc_html__("View all posts in %s", 'campoal-tapo'), $category->name)) . '" data-bjax>' . esc_html($category->cat_name) . '</a>' . esc_html($separator);
                }
                $return_string .= trim($output, $separator);
            }

            // post title
            $return_string .= '<div class="header card-post-title"><a href="' . esc_url($post_link) . '" data-bjax>' . esc_html($post_title) . '</a></div>';
        } else {
            $return_string .= '<p class="text grey text center">' . esc_html($post_date) . '</p>' .
                                '<div class="header card-post-title text center">' .
                                    '<h2 class="ui center aligned header">' .
                                        '<a href="' . esc_url($post_link) . '" data-bjax>' . esc_html($post_title) . '</a>' .
                                    '</h2>';
            $return_string .= $column == 'three' ? '<div class="post-title-divider"></div>' : '';
            $return_string .= '</div>';
        }

        if ($column == 'three') {
        $return_string .= '<div class="description">';
        $return_string .= '<p class="text grey' . (has_post_thumbnail($id) ? '' : ' text center') . '">' . (has_post_thumbnail($id) ? esc_html($post_excerpt) : esc_html($post_excerpt_medium)) . '</p>';
        $return_string .= '</div>';
            if (!has_post_thumbnail($id)) {
            $return_string .= '<div class="ui hidden divider"></div>' .
                                '<p class="text center">' .
                                    '<img class="ui avatar image lazy" data-src="' . esc_url($avatar) . '" data-retina="' . esc_url($avatar_retina) . '" src="' . esc_url($lazy_placeholder_avatar) . '">' .
                                    '<a href="' . get_author_posts_url($post_author) . '" data-bjax>' . get_the_author_meta('display_name' , $post_author) . '</a>' .
                                '</p>';
            }
        }
        $return_string .= '</div>';
        if (has_post_thumbnail($id)) {
            $return_string .= '<div class="extra content">';
            $return_string .= '<span class="right floated">';
            $return_string .= '<a href="' . get_author_posts_url($post_author) . '">' . get_the_author_meta('display_name' , $post_author) . '</a>';
            $return_string .= '</span>';
            
            $return_string .= '<span><i class="calendar outline icon"></i>' . esc_html($post_date) .'</span>';
            $return_string .= '</div>';
        }
        $return_string .= '</div>';

        if ( conikal_carousel_mode($carousel) == 0 ) {
            
        } else {
            $return_string .= '</div>';
        }

        return $return_string;
    }
endif;
?>