<?php

/**
 * Petition list content in shortcode
 */
if (!function_exists('conikal_shortcode_loop_petition')) :
    function conikal_shortcode_loop_petition($posts, $attrs, $content = null) {
    	if (!$posts) {
    		return;
    	}

    	global $campoal_options;
        $minimum_signature      = isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;
        $external_link          = isset($campoal_options['conikal_external_link_field']) ? $campoal_options['conikal_external_link_field'] : 0;
        $view_counter           = isset($campoal_options['conikal_view_counter_field']) ? $campoal_options['conikal_view_counter_field'] : 0;
        $decisionmakers_display = isset($campoal_options['conikal_decisionmakers_display_field']) ? $campoal_options['conikal_decisionmakers_display_field'] : 1;
        $excerpt_words_grid 	= isset($campoal_options['conikal_excerpt_words_grid_field']) ? $campoal_options['conikal_excerpt_words_grid_field'] : 1;
        $excerpt_words_list 	= isset($campoal_options['conikal_excerpt_words_list_field']) ? $campoal_options['conikal_excerpt_words_list_field'] : 1;

        // convert shortcode attributes to variables
        extract(shortcode_atts(array(
            'title'     	    => '',
            'title_alignment'   => 'center',
            'type'			    => 'recent',
            'show'      	    => '4',
            'categories' 	    => '',
            'topics' 		    => '',
            'style'     	    => 'grid',
            'carousel'  	    => 'no',
            'column'    	    => 'four',
            'hover'     	    => false,
            'order'     	    => 'DESC',
            'orderby'   	    => 'date',
            'petition_ids' 	    => '',
        ), $attrs));

    	$return_string = '';
        if ($title != '') {
            $return_string .= '<div class="ui ' . esc_attr( $title_alignment ) . ' aligned vertical basic segment"><div class="ui huge header">' . esc_html($title) . '</div><div class="title-divider"></div></div>';
        }

        if ($style == 'grid') {
            if ( conikal_carousel_mode($carousel) == 0 ) {
                $return_string .= '<div class="ui ' . $column . ' stackable cards petition-cards">';
            } else {
                $return_string .= '<div class="recent-petition-carousel carousel-v1"><div class="post-carousel" data-column="' . esc_attr($column) . '">';
            }
        }

        if ( $posts->have_posts() ) {
            while ( $posts->have_posts() ) {
                $posts->the_post();

                $id         = get_the_ID();
                $author_id  = get_the_author_meta( 'ID' );

                if ($style == 'grid') {
                    $supporter_number  = conikal_get_supporter_donors_number($id, 'supporter', true);
                } else {
                    $supporter_number  = conikal_get_supporter_donors_number($id);
                }

                $petition = array(
                    'id'                => $id,
                    'author_id'         => $author_id,
                    'link'              => get_permalink($id),
                    'petition_title'    => get_the_title($id),
                    'category'          => wp_get_post_terms($id, 'petition_category', true),
                    'comments'          => wp_count_comments($id),
                    'excerpt'           => conikal_get_excerpt_by_id($id, $excerpt_words_grid),
                    'excerpt_long'      => conikal_get_excerpt_by_id($id, $excerpt_words_list),
                    'view'              => conikal_format_number('%!,0i', (int) conikal_get_post_views($id), true),
                    'address'           => get_post_meta($id, 'petition_address', true),
                    'city'              => get_post_meta($id, 'petition_city', true),
                    'state'             => get_post_meta($id, 'petition_state', true),
                    'neighborhood'      => get_post_meta($id, 'petition_neighborhood', true),
                    'zip'               => get_post_meta($id, 'petition_zip', true),
                    'country'           => get_post_meta($id, 'petition_country', true),
                    'lat'               => get_post_meta($id, 'petition_lat', true),
                    'lng'               => get_post_meta($id, 'petition_lng', true),
                    'receiver'          => conikal_get_decistion_makers($id, true, $decisionmakers_display),
                    'supporter_number'  => $supporter_number,
                    'supporter_label'   => $supporter_number->label,
                    'goal'              => $supporter_number->goal,
                    'sign'              => $supporter_number->sign,
                    'updates'           => get_post_meta($id, 'petition_update', true),
                    'status'            => get_post_meta($id, 'petition_status', true),
                    'author_name' 	    => conikal_get_author_name(get_the_author_meta('ID')),
                    'author_url'        => get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' )),
                    'avatar'            => conikal_get_avatar_url( $author_id, array('size' => 64) ),
                    'avatar_retina'     => conikal_get_avatar_url( $author_id, array('size' => 128) ),
                    'user_address'      => get_user_meta($author_id, 'user_address', true),
                    'user_neigborhood'  => get_user_meta($author_id, 'user_neigborhood', true),
                    'user_city'         => get_user_meta($author_id, 'user_city', true),
                    'user_state'        => get_user_meta($author_id, 'user_state', true),
                    'user_country'      => get_user_meta($author_id, 'user_country', true),
                    'thumbnail'         => conikal_get_petition_thumbnail($id, 'conikal-petition-thumbnail', false),
                    'thumbnail_retina'  => conikal_get_petition_thumbnail($id, 'conikal-petition-thumbnail-retina', false),
                    'lazy_placeholder' 	=> conikal_lazy_load_placeholder('thumbnail-small'),
                    'lazy_placeholder_avatar' => conikal_lazy_load_placeholder('avatar'),
                    'minimum_signature' => $minimum_signature,
                    'external_link'     => $external_link,
                    'view_counter'      => $view_counter,
                    'decisionmakers_display' => $decisionmakers_display,
                );

                if ($style == 'grid') {
                    $return_string .= conikal_shortcode_petition_card($petition, $attrs, $content);
                } else {
                    $return_string .= conikal_shortcode_petition_list($petition, $attrs, $content);
                }

            }
        }

        if ($style == 'grid') {
            if ( conikal_carousel_mode($carousel) == 0 ) {
                $return_string .= '</div>';
            } else {
                $return_string .= '</div></div>';
            }
        }

        return $return_string;
    }
endif;

?>