<?php

/*
/ Render topic cards block in html
*/

if (!function_exists('conikal_topic_cards_render')) :
    function conikal_topic_cards_render($attrs, $content = null) {
        extract(shortcode_atts(array(
            'type' => 'petition_topics',
            'show' => 5,
            'order' => 'DESC',
            'orderby' => 'id',
            'categories' => '',
            'topics' => '',
            'slugs' => '',
            'show_empty' => 0,
        ), $attrs));

        global $campoal_options;
        
        $minimum_signature = isset($campoal_options['conikal_minimum_signature_field']) ? $campoal_options['conikal_minimum_signature_field'] : 0;

        // get follow topics
        $current_user = wp_get_current_user();
        $follow_topics = get_user_meta($current_user->ID, 'follow_topics', true);

        if ($slugs != '') {
            $slugs = str_replace(' ', '', $slugs);
            $slugs = explode(',', $slugs);
        } else if ( $type == 'petition_category' && !empty($categories) ) {
            $slugs = $categories;
        } else if ( $type == 'petition_topics' && !empty($topics) ) {
            $slugs = $topics;
        } else {
            $slugs = array();
            $terms = get_terms( 
                array(
                    'taxonomy' => $type,
                    'orderby' => $orderby,
                    'order' => $order,
                    'hide_empty' => ($show_empty == 1 ? false : true),
                    'number' => $show,
                ) 
            );

            if (!is_wp_error($terms)) {
                foreach ($terms as $term ) {
                    array_push($slugs, $term->slug);
                }
            }
        }

        $taxonomy_name = $type;
        $term_meta_image = $type . '_image';
        ?>

        <?php if ($slugs) : ?>
            <div class="topic-cards">
                <?php for ($i=0; $i < count($slugs); $i++) {
                    // get term
                    if (array_key_exists($i, $slugs)) {
                        $id_slug = intval($slugs[$i]);
                        $term = get_term_by('id', $id_slug, $taxonomy_name);
                        if (!$term) {
                            $id_slug = strval($slugs[$i]);
                            $term = get_term_by('slug', $id_slug, $taxonomy_name);
                        }
                    }
                    
                    if ($term) {
                        // get post
                        $args = array( 
                            'posts_per_page' => 1,
                            'paged' => 1,
                            'post_type' => 'petition',
                            'post_status' => 'publish'
                        );

                        $args['tax_query'] = array(
                            'relation' => 'OR',
                            array(
                                'taxonomy' => 'petition_topics',
                                'terms'    => $term->term_id,
                            )
                        );
                        $args['tag_id'] = $term->term_id;
                        $args['meta_query'] = array('relation' => 'AND');

                        if ($minimum_signature != 0) {
                            array_push(
                                $args['meta_query'], array(
                                    'key'     => 'petition_sign',
                                    'value'   => $minimum_signature,
                                    'type'    => 'NUMERIC',
                                    'compare' => '>='
                                )
                            );
                        }
                        $postslist = new WP_Query($args);
                        
                        if ($postslist->have_posts() ) {
                            $post = $postslist->posts[0];
                        }

                        $term_image = get_term_meta($term->term_id, $term_meta_image, true);
                        if ( empty($term_image) && $postslist->have_posts() ) {
                            $term_image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'conikal-petition-medium');
                            if ($term_image) {
                                $term_image = $term_image[0];
                            } else {
                                $term_image = get_template_directory_uri() . '/images/cover-card.svg';
                            }
                        } else if (empty($term_image)) {
                            $term_image = get_template_directory_uri() . '/images/cover-card.svg';
                        }

                        $term_link  = get_term_link($term->term_id, $taxonomy_name); ?>
                        <div class="topic-card snip">
                        <img src="<?php echo esc_url($term_image ? esc_url($term_image) : '') ?>" alt="<?php echo esc_attr($term->name) ?>"/>
                        <a href="<?php echo esc_url($term_link) ?>" class="caption" data-bjax><h3><?php echo esc_html($term->name) ?></h3></a>

                        <?php if ($type == 'petition_topics') :
                        if (is_user_logged_in()) {
                            if ($follow_topics != '') {
                                if (in_array($term->term_id, $follow_topics) === false) { ?>
                                    <button id="follow-topic-<?php echo esc_attr($term->term_id) ?>" class="follow-topic follow" data-id="<?php echo esc_attr($term->term_id) ?>"><?php esc_html_e('Follow', 'campoal-tapo') ?></button>
                                <?php } else { ?>
                                    <button id="follow-topic-<?php echo esc_attr($term->term_id) ?>" class="follow-topic following" data-id="<?php echo esc_attr($term->term_id) ?>"><?php esc_html_e('Following', 'campoal-tapo') ?></button>
                                <?php } ?>
                            <?php } else { ?>
                                    <button id="follow-topic-<?php echo esc_attr($term->term_id) ?>" class="follow-topic follow" data-id="<?php echo esc_attr($term->term_id) ?>"><?php esc_html_e('Follow', 'campoal-tapo') ?></button>
                            <?php } ?>
                        <?php } else { ?>
                                <button class="signin-btn follow-topic follow"><?php esc_html_e('Follow', 'campoal-tapo') ?></button>
                        <?php }
                        elseif ($type == 'petition_category') : ?>
                            <a href="<?php echo esc_url($term_link) ?>" class="follow-topic" data-id="<?php echo esc_attr($term->term_id) ?>" data-bjax><?php esc_html_e('Browse', 'campoal-tapo') ?></a>
                        <?php endif; ?>
                        </div>
                    <?php }
                    }
                wp_nonce_field('follow_ajax_nonce', 'securityFollow', true); ?>
            </div>
        <?php endif; ?>

        <?php 
        wp_reset_postdata();
        wp_reset_query();
    }
endif;
?>