<?php

    /**
     * ReduxFramework Barebones Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "campoal_options";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    // -> START Activate License
    $customizer_support = true;
    if (is_admin() && substr($_SERVER['REMOTE_ADDR'], 0, 4) != '127.' && $_SERVER['REMOTE_ADDR'] != '::1') {
        $license    = ConikalLicense();
        $vaidate_object = get_option('campoal-is-valid');
        $valid_status   = $license->validate_status();

        if (!array_key_exists('is_valid', $valid_status) || $valid_status['is_valid'] != 1 || empty($valid_status['github_token'])) {
            $license_notice['critical'] = array(
                'id' => 'info_critical',
                'type' => 'info',
                'style' => 'critical',
                'title' => esc_html__('Campoal unlicensed!', 'campoal-tapo'),
                'desc'  => sprintf(__('Please enter a licenses for Campoal to unlock features and receive automatic updates. Have you a license key or purchase code? %s', 'campoal-tapo'), '<a href="' . admin_url('options-general.php?page=conikal-license') . '">' . __('Enter a license', 'campoal-tapo') . '</a>')
            );
            
            $customizer_support = false;
        } else {
            $license_notice['success'] = array(
                'id'    => 'info_success',
                'type'  => 'info',
                'style' => 'success',
                'title' => esc_html__('Campoal licensed!', 'campoal-tapo'),
                'desc'  => sprintf(__('Your license has been activated successfully! All features have been unlocked, the theme and plugin will be updated automatically. Do you appreciate it? %s', 'campoal-tapo'), '<a href="//themeforest.net/item/campoal-social-movement-wordpress-theme/reviews/36150364" target="_blank">' . __('Write a review', 'campoal-tapo') . '</a>')
            );

            $customizer_support = true;
        }
    }

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_html__('Theme Options', 'campoal-tapo'),
        'page_title'           => esc_html__('Theme Options' , 'campoal-tapo'),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => 'AIzaSyAQ21lP_4H4O41OOe4LbV0Y0mK6UwOD48Q',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-admin-generic',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => $customizer_support,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => 2,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => 'dashicons-admin-generic',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => 'campoal_options',
        // Page slug used to denote the panel
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        //'compiler'             => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
    $args['admin_bar_links'][] = array(
        'id'    => 'campoal-docs',
        'href'  => '//www.conikal.com/docs/campoal',
        'title' => esc_html__('Documentation', 'campoal-tapo'),
    );

    $args['admin_bar_links'][] = array(
        'id'    => 'campoal-community',
        'href'  => '//www.conikal.com/community',
        'title' => esc_html__('Community', 'campoal-tapo'),
    );

    $args['admin_bar_links'][] = array(
        'id'    => 'campoal-help',
        'href'  => '//www.conikal.com/support',
        'title' => esc_html__('Support Desk', 'campoal-tapo'),
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => '//github.com/conikal',
        'title' => 'Visit us on GitHub',
        'icon'  => 'el el-github'
        //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
    );
    $args['share_icons'][] = array(
        'url'   => '//www.facebook.com/conikal',
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => '//twitter.com/conikal',
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    $args['share_icons'][] = array(
        'url'   => '//www.youtube.com/channel/UCAhaa9RF0mbgxufFnPrD3dg',
        'title' => 'Find us on Youtube',
        'icon'  => 'el el-youtube'
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        /*$args['intro_text'] = sprintf( esc_html__('Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: $%1$s', 'campoal-tapo'), $v ); */
    } else {
        /*$$args['intro_text'] = esc_html__('This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.', 'campoal-tapo');*/
    }

    // Add content after the form.
    /*$args['footer_text'] = '';*/

    Redux::set_args( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'campoal-help-tab-1',
            'title'   => esc_html__('Theme Information 1', 'campoal-tapo'),
            'content' => esc_html__('This is the tab content, HTML is allowed.', 'campoal-tapo')
        ),
        array(
            'id'      => 'campoal-help-tab-2',
            'title'   => esc_html__('Theme Information 2', 'campoal-tapo'),
            'content' => esc_html__('This is the tab content, HTML is allowed.', 'campoal-tapo')
        )
    );
    Redux::set_help_tab( $opt_name, $tabs );

    // Set the help sidebar
    $sidebar_content = esc_html__('This is the sidebar content, HTML is allowed.', 'campoal-tapo');
    Redux::set_help_sidebar( $opt_name, $sidebar_content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*
        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for
     */

    if (is_admin() && substr($_SERVER['REMOTE_ADDR'], 0, 4) != '127.' && $_SERVER['REMOTE_ADDR'] != '::1') {
        // -> START License key
        Redux::set_section( $opt_name, array(
            'title'  => esc_html__('License', 'campoal-tapo'),
            'id'     => 'license',
            'desc'   => esc_html__('Activate the license key to receive automatic updates and unlock the settings panel.', 'campoal-tapo'),
            'icon'   => 'el el-lock',
            'fields' => $license_notice,
        ) );
    }
    
    // -> START General Options
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('General', 'campoal-tapo'),
        'id'     => 'general',
        'desc'   => esc_html__('General options.', 'campoal-tapo'),
        'icon'   => 'el el-adjust-alt',
        'fields' => array(
            array(
                'id'       => 'conikal_fundraising_mode_field',
                'type'     => 'switch',
                'title'    => esc_html__('Fundraising Mode', 'campoal-tapo'),
                'subtitle' => esc_html__('Fundraising mode will switch petition site to crawdfunding site, it only display the donation feature and show fundraising information.', 'campoal-tapo'),
                'desc'     => esc_html__('If set it on let go to Give Donation > Settings and select Sign Successful for Success Page.', 'campoal-tapo'),
                'on'       => esc_html__('On', 'campoal-tapo'),
                'off'      => esc_html__('Off', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_fundraising_mode_apply_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Fundraising mode apply', 'campoal-tapo'),
                'subtitle' => esc_html__('Apply fundraising mode setting for single petition or all the petitions.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between Global or Single', 'campoal-tapo'),
                'options'  => array(
                    'global'        => esc_html__('Global', 'campoal-tapo'),
                    'single'       => esc_html__('Single', 'campoal-tapo'),
                ),
                'default'  => 'single',
            ),
            /*
            array(
                'id'       => 'conikal_auto_load_next_post_field',
                'type'     => 'switch',
                'title'    => esc_html__('Auto load next post', 'campoal-tapo'),
                'subtitle' => esc_html__('Automatically loads the next post and petition once the viewer has reached the bottom of the initial post they are reading and repeats the process as they read your content until there are no more posts to load.', 'campoal-tapo'),
                'desc'     => esc_html__('This feature integrated from Auto Load Next Post plugin developed by Sébastien Dumont with small change. If set it on you can refresh page then go to Settings > Auto Load Next Post > Misc to customize as you like.', 'campoal-tapo'),
                'on'       => esc_html__('On', 'campoal-tapo'),
                'off'      => esc_html__('Off', 'campoal-tapo'),
                'default'  => false,
            ),
            */
            array(
                'id'       => 'conikal_country_field',
                'type'     => 'select',
                'title'    => esc_html__('Country', 'campoal-tapo'),
                'desc'     => esc_html__('Select your country.', 'campoal-tapo'),
                'subtitle' => esc_html__('Set your website default country', 'campoal-tapo'),
                'options'  => array("AF"=>"Afghanistan","AL"=>"Albania","DZ"=>"Algeria","AS"=>"American Samoa","AD"=>"Andorra","AO"=>"Angola","AI"=>"Anguilla","AQ"=>"Antarctica","AG"=>"Antigua and Barbuda","AR"=>"Argentina","AM"=>"Armenia","AW"=>"Aruba","AU"=>"Australia","AT"=>"Austria","AZ"=>"Azerbaijan","BS"=>"Bahamas","BH"=>"Bahrain","BD"=>"Bangladesh","BB"=>"Barbados","BY"=>"Belarus","BE"=>"Belgium","BZ"=>"Belize","BJ"=>"Benin","BM"=>"Bermuda","BT"=>"Bhutan","BO"=>"Bolivia","BA"=>"Bosnia and Herzegovina","BW"=>"Botswana","BV"=>"Bouvet Island","BR"=>"Brazil","BQ"=>"British Antarctic Territory","IO"=>"British Indian Ocean Territory","VG"=>"British Virgin Islands","BN"=>"Brunei","BG"=>"Bulgaria","BF"=>"Burkina Faso","BI"=>"Burundi","KH"=>"Cambodia","CM"=>"Cameroon","CA"=>"Canada","CT"=>"Canton and Enderbury Islands","CV"=>"Cape Verde","KY"=>"Cayman Islands","CF"=>"Central African Republic","TD"=>"Chad","CL"=>"Chile","CN"=>"China","CX"=>"Christmas Island","CC"=>"Cocos [Keeling] Islands","CO"=>"Colombia","KM"=>"Comoros","CG"=>"Congo - Brazzaville","CD"=>"Congo - Kinshasa","CK"=>"Cook Islands","CR"=>"Costa Rica","HR"=>"Croatia","CU"=>"Cuba","CY"=>"Cyprus","CZ"=>"Czech Republic","CI"=>"Côte d’Ivoire","DK"=>"Denmark","DJ"=>"Djibouti","DM"=>"Dominica","DO"=>"Dominican Republic","NQ"=>"Dronning Maud Land","DD"=>"East Germany","EC"=>"Ecuador","EG"=>"Egypt","SV"=>"El Salvador","GQ"=>"Equatorial Guinea","ER"=>"Eritrea","EE"=>"Estonia","ET"=>"Ethiopia","FK"=>"Falkland Islands","FO"=>"Faroe Islands","FJ"=>"Fiji","FI"=>"Finland","FR"=>"France","GF"=>"French Guiana","PF"=>"French Polynesia","TF"=>"French Southern Territories","FQ"=>"French Southern and Antarctic Territories","GA"=>"Gabon","GM"=>"Gambia","GE"=>"Georgia","DE"=>"Germany","GH"=>"Ghana","GI"=>"Gibraltar","GR"=>"Greece","GL"=>"Greenland","GD"=>"Grenada","GP"=>"Guadeloupe","GU"=>"Guam","GT"=>"Guatemala","GG"=>"Guernsey","GN"=>"Guinea","GW"=>"Guinea-Bissau","GY"=>"Guyana","HT"=>"Haiti","HM"=>"Heard Island and McDonald Islands","HN"=>"Honduras","HK"=>"Hong Kong SAR China","HU"=>"Hungary","IS"=>"Iceland","IN"=>"India","ID"=>"Indonesia","IR"=>"Iran","IQ"=>"Iraq","IE"=>"Ireland","IM"=>"Isle of Man","IL"=>"Israel","IT"=>"Italy","JM"=>"Jamaica","JP"=>"Japan","JE"=>"Jersey","JT"=>"Johnston Island","JO"=>"Jordan","KZ"=>"Kazakhstan","KE"=>"Kenya","KI"=>"Kiribati","KW"=>"Kuwait","KG"=>"Kyrgyzstan","LA"=>"Laos","LV"=>"Latvia","LB"=>"Lebanon","LS"=>"Lesotho","LR"=>"Liberia","LY"=>"Libya","LI"=>"Liechtenstein","LT"=>"Lithuania","LU"=>"Luxembourg","MO"=>"Macau SAR China","MK"=>"Macedonia","MG"=>"Madagascar","MW"=>"Malawi","MY"=>"Malaysia","MV"=>"Maldives","ML"=>"Mali","MT"=>"Malta","MH"=>"Marshall Islands","MQ"=>"Martinique","MR"=>"Mauritania","MU"=>"Mauritius","YT"=>"Mayotte","FX"=>"Metropolitan France","MX"=>"Mexico","FM"=>"Micronesia","MI"=>"Midway Islands","MD"=>"Moldova","MC"=>"Monaco","MN"=>"Mongolia","ME"=>"Montenegro","MS"=>"Montserrat","MA"=>"Morocco","MZ"=>"Mozambique","MM"=>"Myanmar [Burma]","NA"=>"Namibia","NR"=>"Nauru","NP"=>"Nepal","NL"=>"Netherlands","AN"=>"Netherlands Antilles","NT"=>"Neutral Zone","NC"=>"New Caledonia","NZ"=>"New Zealand","NI"=>"Nicaragua","NE"=>"Niger","NG"=>"Nigeria","NU"=>"Niue","NF"=>"Norfolk Island","KP"=>"North Korea","VD"=>"North Vietnam","MP"=>"Northern Mariana Islands","NO"=>"Norway","OM"=>"Oman","PC"=>"Pacific Islands Trust Territory","PK"=>"Pakistan","PW"=>"Palau","PS"=>"Palestinian Territories","PA"=>"Panama","PZ"=>"Panama Canal Zone","PG"=>"Papua New Guinea","PY"=>"Paraguay","YD"=>"People's Democratic Republic of Yemen","PE"=>"Peru","PH"=>"Philippines","PN"=>"Pitcairn Islands","PL"=>"Poland","PT"=>"Portugal","PR"=>"Puerto Rico","QA"=>"Qatar","RO"=>"Romania","RU"=>"Russia","RW"=>"Rwanda","RE"=>"Réunion","BL"=>"Saint Barthélemy","SH"=>"Saint Helena","KN"=>"Saint Kitts and Nevis","LC"=>"Saint Lucia","MF"=>"Saint Martin","PM"=>"Saint Pierre and Miquelon","VC"=>"Saint Vincent and the Grenadines","WS"=>"Samoa","SM"=>"San Marino","SA"=>"Saudi Arabia","SN"=>"Senegal","RS"=>"Serbia","CS"=>"Serbia and Montenegro","SC"=>"Seychelles","SL"=>"Sierra Leone","SG"=>"Singapore","SK"=>"Slovakia","SI"=>"Slovenia","SB"=>"Solomon Islands","SO"=>"Somalia","ZA"=>"South Africa","GS"=>"South Georgia and the South Sandwich Islands","KR"=>"South Korea","ES"=>"Spain","LK"=>"Sri Lanka","SD"=>"Sudan","SR"=>"Suriname","SJ"=>"Svalbard and Jan Mayen","SZ"=>"Swaziland","SE"=>"Sweden","CH"=>"Switzerland","SY"=>"Syria","ST"=>"São Tomé and Príncipe","TW"=>"Taiwan","TJ"=>"Tajikistan","TZ"=>"Tanzania","TH"=>"Thailand","TL"=>"Timor-Leste","TG"=>"Togo","TK"=>"Tokelau","TO"=>"Tonga","TT"=>"Trinidad and Tobago","TN"=>"Tunisia","TR"=>"Turkey","TM"=>"Turkmenistan","TC"=>"Turks and Caicos Islands","TV"=>"Tuvalu","UM"=>"U.S. Minor Outlying Islands","PU"=>"U.S. Miscellaneous Pacific Islands","VI"=>"U.S. Virgin Islands","UG"=>"Uganda","UA"=>"Ukraine","SU"=>"Union of Soviet Socialist Republics","AE"=>"United Arab Emirates","GB"=>"United Kingdom","US"=>"United States","ZZ"=>"Unknown or Invalid Region","UY"=>"Uruguay","UZ"=>"Uzbekistan","VU"=>"Vanuatu","VA"=>"Vatican City","VE"=>"Venezuela","VN"=>"Vietnam","WK"=>"Wake Island","WF"=>"Wallis and Futuna","EH"=>"Western Sahara","YE"=>"Yemen","ZM"=>"Zambia","ZW"=>"Zimbabwe","AX"=>"Åland Islands"),
                'default'  => 'US',
            ),
            array(
                'id'       => 'conikal_office_address_field',
                'type'     => 'text',
                'title'    => esc_html__('Office address', 'campoal-tapo'),
                'subtitle' => esc_html__('Office address display on site and email footer.', 'campoal-tapo'),
                'desc'     => esc_html__('Use text only.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => esc_html__('2671  Collins Avenue, Columbus, Ohio (OH) 43215, United States', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_minimum_signature_field',
                'type'     => 'text',
                'title'    => esc_html__('Minimum of supporters', 'campoal-tapo'),
                'subtitle' => esc_html__('Campagin need reached this number to visible on website', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 5,
            ),
            array(
                'id'       => 'conikal_number_sign_change_field',
                'type'     => 'text',
                'title'    => esc_html__('Minimum supporters to change goal', 'campoal-tapo'),
                'subtitle' => esc_html__('Campaign need reached this number to have permission to change goal', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 1000,
            ),
            array(
                'id'       => 'conikal_p_goal_default_field',
                'type'     => 'text',
                'title'    => esc_html__('Goal default number', 'campoal-tapo'),
                'subtitle' => esc_html__('Set default goal for petition if goal field is no enabled or user not set', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 5000,
            ),
            array(
                'id'       => 'conikal_auto_increase_goal_field',
                'type'     => 'switch',
                'title'    => esc_html__('Auto increase goal', 'campoal-tapo'),
                'subtitle' => esc_html__('The goal of campaign will be auto increase when supporters reached goal', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_auto_increase_goal_d_field',
                'type'     => 'select',
                'title'    => esc_html__('Percent increase goal', 'campoal-tapo'),
                'subtitle' => esc_html__('Default percent when increase goal if user is not set percent', 'campoal-tapo'),
                'desc'     => esc_html__('Select percent. Zero percent is disable auto increase.', 'campoal-tapo'),
                'options'  => array(
                    0   => esc_html__('No increase', 'campoal-tapo'),
                    10  => esc_html__('10%', 'campoal-tapo'),
                    20  => esc_html__('20%', 'campoal-tapo'),
                    30  => esc_html__('30%', 'campoal-tapo'),
                    40  => esc_html__('40%', 'campoal-tapo'),
                    50  => esc_html__('50%', 'campoal-tapo'),
                    60  => esc_html__('60%', 'campoal-tapo'),
                    70  => esc_html__('70%', 'campoal-tapo'),
                    80  => esc_html__('80%', 'campoal-tapo'),
                    90  => esc_html__('90%', 'campoal-tapo'),
                    100 => esc_html__('100%', 'campoal-tapo'),
                    150 => esc_html__('150%', 'campoal-tapo'),
                    200 => esc_html__('200%', 'campoal-tapo'),
                    300 => esc_html__('300%', 'campoal-tapo'),
                    500 => esc_html__('500%', 'campoal-tapo'),
                ),
                'default'  => 0,
            ),
            array(
                'id'       => 'conikal_signature_update_time_field',
                'type'     => 'text',
                'title'    => esc_html__('Real-time supporters number', 'campoal-tapo'),
                'subtitle' => esc_html__('Supporters number on single campaign will be auto update by time(min)', 'campoal-tapo'),
                'desc'     => esc_html__('Set the number of minutes. Zero is disable update. (Set minimum 5 minutes. This feature maybe uses many of your server resources, we do not recommend use it.)', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 0,
            ),
            array(
                'id'       => 'conikal_number_days_trending_field',
                'type'     => 'text',
                'title'    => esc_html__('Days of trending', 'campoal-tapo'),
                'subtitle' => esc_html__('The trend algorithm calculates based on this number of days', 'campoal-tapo'),
                'desc'     => esc_html__('Set the number of days.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 14,
            ),
            array(
                'id'       => 'conikal_social_hastag_field',
                'type'     => 'text',
                'title'    => esc_html__('Hastag', 'campoal-tapo'),
                'subtitle' => esc_html__('Default hastag on Facebook share box if topics of petition is empty.', 'campoal-tapo'),
                'desc'     => esc_html__('Start by "#" symbol, separated by comma.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => '#share',
            ),
            array(
                'id'       => 'conikal_remember_login_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Remember login', 'campoal-tapo'),
                'subtitle' => esc_html__('The form to remember login when user sign petition or login.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose the specific form or remeber all and not rememer', 'campoal-tapo'),
                'options'  => array(
                    'all'        => esc_html__('All', 'campoal-tapo'),
                    'none'       => esc_html__('No', 'campoal-tapo'),
                    'petition'   => esc_html__('Sign only', 'campoal-tapo'),
                    'login'      => esc_html__('Login only', 'campoal-tapo'),
                ),
                'default'  => 'all',
            ),
            array(
                'id'       => 'conikal_modal_transition_field',
                'type'     => 'select',
                'title'    => esc_html__('Modal Transition', 'campoal-tapo'),
                'subtitle' => esc_html__('The type of transition action when open or close modal', 'campoal-tapo'),
                'desc'     => esc_html__('Select a type of transition.', 'campoal-tapo'),
                'options'  => array(
                    'scale'   => esc_html__('Scale', 'campoal-tapo'),
                    'zoom'   => esc_html__('Zoom', 'campoal-tapo'),
                    'fade'   => esc_html__('Fade', 'campoal-tapo'),
                    'fade down'   => esc_html__('Fade Down', 'campoal-tapo'),
                    'fade up'   => esc_html__('Fade Up', 'campoal-tapo'),
                    'fade right'   => esc_html__('Fade right', 'campoal-tapo'),
                    'fade left'   => esc_html__('Fade left', 'campoal-tapo'),
                    'slide down'   => esc_html__('Slide Down', 'campoal-tapo'),
                    'slide up'   => esc_html__('Slide Up', 'campoal-tapo'),
                    'slide right'   => esc_html__('Slide right', 'campoal-tapo'),
                    'slide left'   => esc_html__('Slide left', 'campoal-tapo'),
                    'horizontal flip'   => esc_html__('Horizontal flip', 'campoal-tapo'),
                    'vertical flip'   => esc_html__('Vertical flip', 'campoal-tapo'),
                ),
                'default'  => 'scale',
            ),
            /*
            array(
                'id'       => 'conikal_flagged_content_field',
                'type'     => 'switch',
                'title'    => esc_html__('Flagged content', 'campoal-tapo'),
                'subtitle' => esc_html__('Allows visitors to flag content', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ), */
            array(
                'id'       => 'conikal_smooth_scroll_field',
                'type'     => 'switch',
                'title'    => esc_html__('Smooth scroll', 'campoal-tapo'),
                'subtitle' => esc_html__('Scroll effectly when scroll instead for default scroll on browser', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_external_link_field',
                'type'     => 'switch',
                'title'    => esc_html__('External link', 'campoal-tapo'),
                'subtitle' => esc_html__('Open new tab when click on social link or external icon', 'campoal-tapo'),
                'desc'     => esc_html__('Enabled or Disabled for external link.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START Logo
    Redux::set_section( $opt_name, array(
        'title'      => esc_html__('Logo', 'campoal-tapo'),
        'desc'       => esc_html__('Set logo on header', 'campoal-tapo'),
        'id'         => 'logo',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'conikal_use_inverted_logo_field',
                'type'     => 'switch',
                'title'    => esc_html__('Use inverted logo', 'campoal-tapo'),
                'subtitle' => esc_html__('Enable inverted logo if the header background is dark color.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_header_logo_height_field',
                'type'     => 'text',
                'title'    => esc_html__('Logo height', 'campoal-tapo'),
                'subtitle' => esc_html__('Height of logo on header.', 'campoal-tapo'),
                'desc'     => esc_html__('Set height of logo.', 'campoal-tapo'),
                'validate' => 'not_empty',
                'default'  => '40px',
            ),
            array(
                'id'       => 'conikal_logo_field',
                'type'     => 'media',
                'title'    => esc_html__('Logo', 'campoal-tapo'),
                'subtitle' => esc_html__('Orginal logo', 'campoal-tapo'),
                'desc'     => esc_html__('Upload image. Recommended use SVG format.', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
            array(
                'id'       => 'conikal_inverted_logo_field',
                'type'     => 'media',
                'title'    => esc_html__('Inverted Logo', 'campoal-tapo'),
                'subtitle' => esc_html__('White logo display on hero section.', 'campoal-tapo'),
                'desc'     => esc_html__('Upload image. Recommended use SVG format.', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
            array(
                'id'       => 'conikal_logo_mobile_field',
                'type'     => 'media',
                'title'    => esc_html__('Logo Mobile', 'campoal-tapo'),
                'subtitle' => esc_html__('Orginal logo display by mobile devices.', 'campoal-tapo'),
                'desc'     => esc_html__('Upload image. Recommended use SVG format.', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
            array(
                'id'       => 'conikal_inverted_logo_mobile_field',
                'type'     => 'media',
                'title'    => esc_html__('Inverted Logo Mobile', 'campoal-tapo'),
                'subtitle' => esc_html__('White logo display on hero section by mobile devices.', 'campoal-tapo'),
                'desc'     => esc_html__('Upload image. Recommended use SVG format.', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
            array(
                'id'       => 'conikal_default_avatar_field',
                'type'     => 'media',
                'title'    => esc_html__('Default Avatar', 'campoal-tapo'),
                'subtitle' => esc_html__('Display when user not upload avatar yet.', 'campoal-tapo'),
                'desc'     => esc_html__('Upload square image.', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
            array(
                'id'       => 'conikal_decision_maker_verified_badge_field',
                'type'     => 'media',
                'title'    => esc_html__('Decision maker verify badge', 'campoal-tapo'),
                'subtitle' => esc_html__('The badge icon display on avatar when decision maker account were verified.', 'campoal-tapo'),
                'desc'     => esc_html__('Upload square image.', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
        )
    ) );

    // -> START Icon
    Redux::set_section( $opt_name, array(
        'title'      => esc_html__('Icon', 'campoal-tapo'),
        'desc'       => esc_html__('Set icon on pages and button', 'campoal-tapo'),
        'id'         => 'icon',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'conikal_submit_button_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Submit Button icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on start a petition button', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'edit outline icon',
            ),
            array(
                'id'       => 'conikal_donation_button_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Donation Button Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on donation button', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'gift icon',
            ),
            array(
                'id'       => 'conikal_victory_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Victory Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on victory campaign', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'flag icon',
            ),
            array(
                'id'       => 'conikal_victory_inverse_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Victory Icon Inverted', 'campoal-tapo'),
                'subtitle' => esc_html__('White icon display on victory campaign', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'flag icon',
            ),
            array(
                'id'       => 'conikal_sign_button_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Sign Button Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on sign button', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'lock icon',
            ),
            array(
                'id'       => 'conikal_supporter_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Supporter Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display before supporter counter on cards', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'user icon',
            ),
            array(
                'id'       => 'conikal_send_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Send Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display before petition to subtitle on cards', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'paper plane outline icon',
            ),
            array(
                'id'       => 'conikal_citation_button_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Citation Button Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on add citation button', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'quote left icon',
            ),
            array(
                'id'       => 'conikal_citation_agree_field',
                'type'     => 'text',
                'title'    => esc_html__('Citation Agree Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on add citation button', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'thumbs up icon',
            ),
            array(
                'id'       => 'conikal_citation_disagree_field',
                'type'     => 'text',
                'title'    => esc_html__('Citation Disagree Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on add citation button', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'thumbs down icon',
            ),
            array(
                'id'       => 'conikal_share_button_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Share Button Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on share button', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'share icon',
            ),
            array(
                'id'       => 'conikal_profile_activist_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Profile Supporter Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on supporter profile', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'hand rock icon',
            ),
            array(
                'id'       => 'conikal_profile_legislator_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Profile Legislator Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on legislator profile', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'balance scale icon',
            ),
            array(
                'id'       => 'conikal_profile_organization_icon_field',
                'type'     => 'text',
                'title'    => esc_html__('Profile Organization Icon', 'campoal-tapo'),
                'subtitle' => esc_html__('Icon display on organization profile', 'campoal-tapo'),
                'desc'     => esc_html__('Set a URL or icon name selected from: ', 'campoal-tapo') . '<a href="//semantic-ui.com/elements/icon.html">Semantic UI - Icon</a>',
                'default'  => 'users icon',
            ),
        )
    ) );

    // -> START Moderation
    Redux::set_section( $opt_name, array(
        'title'      => esc_html__('Moderation', 'campoal-tapo'),
        'desc'       => esc_html__('Set the activity need moderation or not', 'campoal-tapo'),
        'id'         => 'moderation',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'conikal_admin_submit_petition_only_field',
                'type'     => 'switch',
                'title'    => esc_html__('Admin submit only', 'campoal-tapo'),
                'subtitle' => esc_html__('Only admin have permission submit campaign on front-end', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_review_field',
                'type'     => 'switch',
                'title'    => esc_html__('Petition approval', 'campoal-tapo'),
                'subtitle' => esc_html__('Petition need review by admin before publish on website', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_review_update_field',
                'type'     => 'switch',
                'title'    => esc_html__('Update approval', 'campoal-tapo'),
                'subtitle' => esc_html__('Update post for petition need review by admin before publish on website', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_review_decision_field',
                'type'     => 'switch',
                'title'    => esc_html__('Decision Maker approval', 'campoal-tapo'),
                'subtitle' => esc_html__('Decision Maker need review by admin before publish on website', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_review_contribute_field',
                'type'     => 'switch',
                'title'    => esc_html__('Contribute & donation approval', 'campoal-tapo'),
                'subtitle' => esc_html__('Contribute form need review by admin before publish on website', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_review_citation_field',
                'type'     => 'switch',
                'title'    => esc_html__('Citation approval', 'campoal-tapo'),
                'subtitle' => esc_html__('Citation need review by admin before publish on website', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
        )
    ) );

    // -> START Ajax pages
    Redux::set_section( $opt_name, array(
        'title'      => esc_html__('Ajax pages', 'campoal-tapo'),
        'desc'       => esc_html__('Set the activity need moderation or not', 'campoal-tapo'),
        'id'         => 'ajax_page',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'conikal_ajax_pages_field',
                'type'     => 'switch',
                'title'    => esc_html__('Ajax pages', 'campoal-tapo'),
                'subtitle' => esc_html__('Click on new link without refresh page', 'campoal-tapo'),
                'desc'     => esc_html__('Ajax page loader only working when user is logged in.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_type_ajax_preloader_field',
                'type'     => 'select',
                'title'    => esc_html__('Ajax preloader', 'campoal-tapo'),
                'subtitle' => esc_html__('Loader animation icon when lick on ajax link', 'campoal-tapo'),
                'desc'     => esc_html__('Select a icon. Default is not display loader.', 'campoal-tapo'),
                'options'  => array(
                    'none'              => esc_html__('None', 'campoal-tapo'),
                    'chasing-dots'      => esc_html__('Chasing Dots', 'campoal-tapo'),
                    'cube-grid'         => esc_html__('Cube Grid', 'campoal-tapo'),
                    'double-bounce'     => esc_html__('Double Bounce', 'campoal-tapo'),
                    'fading-circle'     => esc_html__('Fading Circle', 'campoal-tapo'),
                    'folding-cube'      => esc_html__('Folding Cube', 'campoal-tapo'),
                    'pulse'             => esc_html__('Pulse', 'campoal-tapo'),
                    'rotating-plane'    => esc_html__('Rotating Plance', 'campoal-tapo'),
                    'three-bounce'      => esc_html__('Three Bounce', 'campoal-tapo'),
                    'wandering-cubes'   => esc_html__('Wandering Cubes', 'campoal-tapo'),
                    'wave'              => esc_html__('Wave', 'campoal-tapo'),
                ),
                'default'  => 'none',
            ),
        )
    ) );

    // -> START homepage
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Homepage', 'campoal-tapo'),
        'id'     => 'homepage',
        'desc'   => esc_html__('Set option display on homepage. ', 'campoal-tapo'),
        'icon'   => 'el el-home',
        'fields' => array(
            array(
                'id'       => 'conikal_petition_redirection_field',
                'type'     => 'text',
                'title'    => esc_html__('Petition redirection', 'campoal-tapo'),
                'subtitle' => esc_html__('Redirect to single petition when visit homepage.', 'campoal-tapo'),
                'desc'     => esc_html__('Enter an Petition ID or URL', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => '',
            ),
            array(
                'id'       => 'conikal_home_header_field',
                'type'     => 'select',
                'title'    => esc_html__('Homepage hero page type', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of background on homepage hero section', 'campoal-tapo'),
                'desc'     => esc_html__('Select a type of background. We recommended Smart Slider plugin for custom slider option.', 'campoal-tapo'),
                'options'  => array(
                    'none' => esc_html__('None', 'campoal-tapo'),
                    'slideshow' => esc_html__('Slideshow', 'campoal-tapo'), 
                    'video' => esc_html__('Video', 'campoal-tapo'),
                    'slider' => esc_html__('Custom Slider', 'campoal-tapo')
                ),
                'default'  => 'slideshow',
            ),
            array(
                'id'       => 'conikal_home_slideshow_images',
                'type'     => 'gallery',
                'title'    => esc_html__('Homepage slideshow Images', 'campoal-tapo'),
                'subtitle' => esc_html__('Background images for homepage slideshow', 'campoal-tapo'),
                'desc'     => esc_html__('Upload photos.', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_home_header_video_field',
                'type'     => 'media',
                'title'    => esc_html__('Video background', 'campoal-tapo'),
                'subtitle' => esc_html__('Video for background on hero section.', 'campoal-tapo'),
                'desc'     => esc_html__('Just upload video if you has selected video type of background.', 'campoal-tapo'),
                'library_filter' => array('mp4', 'm4v', 'asf', 'asx', 'wmv', 'wmx', 'wm', 'avi', 'divx', 'flv', 'mov', 'qt', 'mpeg', 'mpg', 'mpe', 'ogv', 'webm', 'mkv'),
                'url'      => true,
                'mode'     => false,
                'preview'  => true,
            ),
            array(
                'id'       => 'conikal_home_header_video_sound_field',
                'type'     => 'switch',
                'title'    => esc_html__('Video sound', 'campoal-tapo'),
                'subtitle' => esc_html__('Sound of video background on hero section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_home_header_hide_logined_field',
                'type'     => 'switch',
                'title'    => esc_html__('Homepage slideshow logged in', 'campoal-tapo'),
                'subtitle' => esc_html__('Hidde or show homepage slideshow for user logged in', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_home_victory_field',
                'type'     => 'switch',
                'title'    => esc_html__('Victory Slider', 'campoal-tapo'),
                'subtitle' => esc_html__('Hidden or show victory slider', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_home_victory_hide_logined_field',
                'type'     => 'switch',
                'title'    => esc_html__('Victory slider logged in', 'campoal-tapo'),
                'subtitle' => esc_html__('Hidden or show victory slider user logged in', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_home_spotlight_field',
                'type'     => 'switch',
                'title'    => esc_html__('Spotlight', 'campoal-tapo'),
                'subtitle' => esc_html__('Spotlight section display below hero section on homepage', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_home_spotlight_hide_logined_field',
                'type'     => 'switch',
                'title'    => esc_html__('Spotlight logged in', 'campoal-tapo'),
                'subtitle' => esc_html__('Hidden or show spotlight section user logged in', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_home_sticky_sidebar_field',
                'type'     => 'switch',
                'title'    => esc_html__('Sticky Sidebar', 'campoal-tapo'),
                'subtitle' => esc_html__('Hidden or show sticky category menu on right sidebar', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_shadow_opacity_field',
                'type'     => 'slider',
                'title'    => esc_html__('Hero section opacity percent', 'campoal-tapo'),
                'subtitle' => esc_html__('Percent of shadown background on hero section', 'campoal-tapo'),
                'desc'     => esc_html__('Range the percent (%).', 'campoal-tapo'),
                'min'      => 0,
                'max'      => 100,
                'display_value' => 'label',
                'default'  => 0,
            ),
            array(
                'id'       => 'conikal_hieght_slideshow_field',
                'type'     => 'text',
                'title'    => esc_html__('Hero section height', 'campoal-tapo'),
                'subtitle' => esc_html__('Height of hero section (px)', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only, unit in pixel (px)', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 980,
            ),
            array(
                'id'       => 'conikal_home_caption_top_field',
                'type'     => 'text',
                'title'    => esc_html__('Caption top', 'campoal-tapo'),
                'subtitle' => esc_html__('Padding from top to caption on hero section (px)', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only, unit in pixel (px)', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 300,
            ),
        )
    ) );

    // -> START Caption
    Redux::set_section( $opt_name, array(
        'title'      => esc_html__('Caption', 'campoal-tapo'),
        'desc'       => esc_html__('Set options for caption on homepage', 'campoal-tapo'),
        'id'         => 'caption',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'conikal_home_caption_field',
                'type'     => 'switch',
                'title'    => esc_html__('Home caption', 'campoal-tapo'),
                'subtitle' => esc_html__('Title and caption display on homepage', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_home_caption_alignment_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Caption Alignment', 'campoal-tapo'),
                'subtitle' => esc_html__('Alignment of caption on homepage', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between left, right or center.', 'campoal-tapo'),
                'options'  => array(
                    'left'      => esc_html__('Left', 'campoal-tapo'),
                    'center'    => esc_html__('Center', 'campoal-tapo'),
                    'right'     => esc_html__('Right', 'campoal-tapo')
                ),
                'default'  => 'left',
            ),
            array(
                'id'       => 'conikal_home_caption_title_field',
                'type'     => 'text',
                'title'    => esc_html__('Caption title', 'campoal-tapo'),
                'subtitle' => esc_html__('Title of caption display on homepage', 'campoal-tapo'),
                'desc'     => esc_html__('Type any text on the box, allowed html tags.', 'campoal-tapo'),
                'default'  => 'Build a Better World Together',
                'validate' => 'html',
            ),
            array(
                'id'       => 'conikal_home_caption_subtitle_field',
                'type'     => 'text',
                'title'    => esc_html__('Caption subtitle', 'campoal-tapo'),
                'subtitle' => esc_html__('Subtitle of caption display on homepage', 'campoal-tapo'),
                'desc'     => esc_html__('Type any text on the box, allowed html tags.', 'campoal-tapo'),
                'default'  => 'When we are together, nothing is impossible',
                'validate' => 'html',
            ),
        )
    ) );

    // -> START Call to action button
    Redux::set_section( $opt_name, array(
        'title'      => esc_html__('CTA Button', 'campoal-tapo'),
        'desc'       => esc_html__('Set the link and label for call to action button', 'campoal-tapo'),
        'id'         => 'cta_button',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'conikal_home_caption_cta_field',
                'type'     => 'switch',
                'title'    => esc_html__('CTA Button', 'campoal-tapo'),
                'subtitle' => esc_html__('Call to action button below homepage caption', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_home_caption_cta_size_field',
                'type'     => 'select',
                'title'    => esc_html__('CTA button size', 'campoal-tapo'),
                'subtitle' => esc_html__('Size of call to action button', 'campoal-tapo'),
                'desc'     => esc_html__('Choose the size of button.', 'campoal-tapo'),
                'options'  => array(
                    'mini'      => esc_html__('Mini', 'campoal-tapo'),
                    'tiny'      => esc_html__('Tiny', 'campoal-tapo'),
                    'small'     => esc_html__('Small', 'campoal-tapo'),
                    'medium'    => esc_html__('Medium', 'campoal-tapo'),
                    'large'     => esc_html__('Large', 'campoal-tapo'),
                    'big'       => esc_html__('Big', 'campoal-tapo'),
                    'huge'      => esc_html__('Huge', 'campoal-tapo'),
                    'massive'   => esc_html__('Massive', 'campoal-tapo')),
                'default'  => 'medium',
            ),
            array(
                'id'       => 'conikal_home_caption_cta_type_field',
                'type'     => 'select',
                'title'    => esc_html__('CTA button type', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of call to action button', 'campoal-tapo'),
                'desc'     => esc_html__('Choose the type of button.', 'campoal-tapo'),
                'options'  => array(
                    'square'        => esc_html__('Square', 'campoal-tapo'),
                    'circular'      => esc_html__('Circular', 'campoal-tapo')),
                'default'  => 'circular',
            ),
            array(
                'id'       => 'conikal_home_caption_cta_text_field',
                'type'     => 'text',
                'title'    => esc_html__('Button label 1', 'campoal-tapo'),
                'subtitle' => esc_html__('The text of call to action button 1', 'campoal-tapo'),
                'desc'     => esc_html__('Type text only, not allowed html tag.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'Start a petition',
            ),
            array(
                'id'            => 'conikal_home_caption_cta_link_field',
                'type'          => 'text',
                'title'         => esc_html__('Button link 1', 'campoal-tapo'),
                'subtitle'      => esc_html__('The link of call to action button 1', 'campoal-tapo'),
                'desc'          => esc_html__('URL of button, allow URI format only.', 'campoal-tapo'),
                'validate'      => 'no_html',
                'placeholder'   => esc_html__('Enter the link of button', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_home_caption_cta_text_2_field',
                'type'     => 'text',
                'title'    => esc_html__('Button label 2', 'campoal-tapo'),
                'subtitle' => esc_html__('The text of call to action button 2', 'campoal-tapo'),
                'desc'     => esc_html__('Type text only, not allowed html tag.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'Learn more',
            ),
            array(
                'id'            => 'conikal_home_caption_cta_link_2_field',
                'type'          => 'text',
                'title'         => esc_html__('Button link 2', 'campoal-tapo'),
                'subtitle'      => esc_html__('The link of call to action button 2', 'campoal-tapo'),
                'desc'          => esc_html__('URL of button, allow URI format only.', 'campoal-tapo'),
                'validate'      => 'no_html',
                'placeholder'   => esc_html__('Enter the link of button', 'campoal-tapo'),
            ),
        )
    ) );

    // -> START spotlight
    Redux::set_section( $opt_name, array(
        'title'      => esc_html__('Spotlight', 'campoal-tapo'),
        'desc'       => esc_html__('Set text and options spotlight on homepage', 'campoal-tapo'),
        'id'         => 'spolight',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'conikal_home_spotlight_title_field',
                'type'     => 'text',
                'title'    => esc_html__('Spotlight title', 'campoal-tapo'),
                'subtitle' => esc_html__('The title of spotlight section', 'campoal-tapo'),
                'desc'     => esc_html__('Type text only, not allowed html tag.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'Welcom to Campoal',
            ),
            array(
                'id'       => 'conikal_home_spotlight_text_field',
                'type'     => 'text',
                'title'    => esc_html__('Spotlight subtitle', 'campoal-tapo'),
                'subtitle' => esc_html__('Subtitle of spotlight section', 'campoal-tapo'),
                'desc'     => esc_html__('Type text only, not allowed html tag.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'Explore the most of trending petition right now',
            ),
            array(
                'id'       => 'conikal_home_topics_number_field',
                'type'     => 'text',
                'title'    => esc_html__('Topics number', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of topics display on spotlight section', 'campoal-tapo'),
                'desc'     => esc_html__('Enter number only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 8,
            ),
            array(
                'id'        =>'conikal_trending_topics_field',
                'type'      => 'textarea',
                'title'     => esc_html__('Trending topics', 'campoal-tapo'), 
                'subtitle'  => esc_html__('Topics display below title on spotlight section', 'campoal-tapo'),
                'desc'      => esc_html__('Use slug of topics and separate by comma. eg. women, humam-right. Leave empty to use popular topics', 'campoal-tapo'),
                'validate'  => 'no_html',
            ),
        )
    ) );

    // -> START Home tab
    Redux::set_section( $opt_name, array(
        'title'      => esc_html__('Home Tabs', 'campoal-tapo'),
        'desc'       => esc_html__('Order the tabs on homepage.', 'campoal-tapo'),
        'id'         => 'home_tab',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'conikal_home_tabs_sortable_field',
                'type'     => 'sortable',
                'title'    => __('Home tabs sortable', 'campoal-tapo'),
                'subtitle' => __('Re-order tabs on homepage in the order you want.', 'campoal-tapo'),
                'desc'     => __('Checked to display or not, drag and drop to sorting.', 'campoal-tapo'),
                'mode'     => 'checkbox',
                'options'  => array(
                    'newsfeed'     => esc_html__('Newsfeed', 'campoal-tapo'),
                    'trending'     => esc_html__('Trending', 'campoal-tapo'),
                    'recent'       => esc_html__('Recent', 'campoal-tapo'),
                ),
                // For checkbox mode
                'default' => array(
                    'newsfeed'     => true,
                    'trending'     => true,
                    'recent'       => true,
                ),
            ),
        )
    ) );

    // -> START Appearance
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Appearance', 'campoal-tapo'),
        'id'     => 'appearance',
        'desc'   => esc_html__('Set options on header menu ', 'campoal-tapo'),
        'icon'   => 'el el-screen',
        'fields' => array(
            array(
                'id'       => 'conikal_page_hero_bg_image_field',
                'type'     => 'media',
                'title'    => esc_html__('Page hero background image', 'campoal-tapo'),
                'subtitle' => esc_html__('Default background image if thumbnail of page is not set', 'campoal-tapo'),
                'desc'     => esc_html__('Upload image.', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
            array(
                'id'       => 'conikal_breadcrumbs_field',
                'type'     => 'switch',
                'title'    => esc_html__('Breadcrumbs', 'campoal-tapo'),
                'subtitle' => esc_html__('Breadcrumbs section on pages', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_show_petition_closed_field',
                'type'     => 'switch',
                'title'    => esc_html__('Petition closed', 'campoal-tapo'),
                'subtitle' => esc_html__('Show petition closed or hide it from website.', 'campoal-tapo'),
                'desc'     => esc_html__('Hidden or show date on petition.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_action_after_sign_field',
                'type'     => 'select',
                'title'    => esc_html__('Action after sign', 'campoal-tapo'),
                'subtitle' => esc_html__('The action after user sign petition success', 'campoal-tapo'),
                'desc'     => esc_html__('Choose the action will be doing.', 'campoal-tapo'),
                'options'  => array(
                    'none' => esc_html__('None action', 'campoal-tapo'),
                    'refresh' => esc_html__('Refresh current page', 'campoal-tapo'),
                    'redirect' => esc_html__('Redirect to success page', 'campoal-tapo'),
                    'modal' => esc_html__('Show modal', 'campoal-tapo'),
                ),
                'default'  => 'modal',
            ),
            array(
                'id'       => 'conikal_passing_button_link_field',
                'type'     => 'select',
                'title'    => esc_html__('Passing button', 'campoal-tapo'),
                'subtitle' => esc_html__('The link of passing button on success sign modal.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page or leave empty to close modal when click it.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
            ),
            array(
                'id'       => 'conikal_condition_text_position_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Condition text position', 'campoal-tapo'),
                'subtitle' => esc_html__('Position where condition text display.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose all to display any where or no to hidden it or some specific position.', 'campoal-tapo'),
                'options'  => array(
                    'all'       => esc_html__('All', 'campoal-tapo'),
                    'none'      => esc_html__('No', 'campoal-tapo'),
                    'desktop'   => esc_html__('Desktop only', 'campoal-tapo'),
                    'mobile'    => esc_html__('Mobile only', 'campoal-tapo'),
                ),
                'default'  => 'desktop',
            ),
            array(
                'id'       => 'conikal_condition_text_field',
                'type'     => 'editor',
                'title'    => esc_html__('Condition text', 'campoal-tapo'),
                'subtitle' => esc_html__('The text show below on register and sign petition form', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html tags.', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5,
                ),
                'default'  => __('By signing, you accept Campoal’s <u><a href="//www.conikal.com/campoal/">Terms of Service</a></u> and <u><a href="//www.conikal.com/campoal/">Privacy Policy</a></u>, and agree to receive occasional emails about campaigns on Campoal. You can unsubscribe at any time.', 'campoal-tapo'),
            ),
        )
    ) );

    // -> START Layout
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Layout', 'campoal-tapo'),
        'id'     => 'layout',
        'desc'   => esc_html__('Set options for layout', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_container_width_field',
                'type'     => 'text',
                'title'    => esc_html__('Site container', 'campoal-tapo'),
                'subtitle' => esc_html__('Width of container on website', 'campoal-tapo'),
                'desc'     => esc_html__('Number of width container, number format only. Unit by pixel (px)', 'campoal-tapo'),
                'validate' => 'numeric',
            ),
            array(
                'id'       => 'conikal_signed_author_page_field',
                'type'     => 'switch',
                'title'    => esc_html__('Signed petitions tab', 'campoal-tapo'),
                'subtitle' => esc_html__('Signed petitions tab on author page for public.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_sidebar_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Sidebar position', 'campoal-tapo'),
                'subtitle' => esc_html__('Position of side bar on blogs and pages', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between left or right.', 'campoal-tapo'),
                'options'  => array(
                    'left'  => esc_html__('Left', 'campoal-tapo'),
                    'right' => esc_html__('Right', 'campoal-tapo'),
                ),
                'default'  => 'right',
            ),
            array(
                'id'       => 'conikal_page_title_aligment_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Page title aligment', 'campoal-tapo'),
                'subtitle' => esc_html__('Aligment of title on hero section page', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between left, right or center.', 'campoal-tapo'),
                'options'  => array(
                    'left'      => esc_html__('Left', 'campoal-tapo'),
                    'center'    => esc_html__('Center', 'campoal-tapo'),
                    'right'     => esc_html__('Right', 'campoal-tapo'),
                ),
                'default'  => 'center',
            ),
            array(
                'id'       => 'conikal_page_hero_height_field',
                'type'     => 'text',
                'title'    => esc_html__('Page Hero height', 'campoal-tapo'),
                'subtitle' => esc_html__('Height of page hero section', 'campoal-tapo'),
                'desc'     => esc_html__('Set height of page hero section', 'campoal-tapo'),
                'validate' => 'not_empty',
                'default'  => '365px',
            ),
            array(
                'id'       => 'conikal_page_header_opacity_field',
                'type'     => 'slider',
                'title'    => esc_html__('Page hero opacity', 'campoal-tapo'),
                'subtitle' => esc_html__('Percent of shadown background on page hero section', 'campoal-tapo'),
                'desc'     => esc_html__('Range the percent (%).', 'campoal-tapo'),
                'min'      => 0,
                'max'      => 100,
                'display_value' => 'label',
                'default'  => 90,
            ),
            array(
                'id'       => 'conikal_post_title_aligment_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Post title aligment', 'campoal-tapo'),
                'subtitle' => esc_html__('Aligment of title on hero section post', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between left, right or center.', 'campoal-tapo'),
                'options'  => array(
                    'left'      => esc_html__('Left', 'campoal-tapo'),
                    'center'    => esc_html__('Center', 'campoal-tapo'),
                    'right'     => esc_html__('Right', 'campoal-tapo'),
                ),
                'default'  => 'left',
            ),
            array(
                'id'       => 'conikal_post_hero_height_field',
                'type'     => 'text',
                'title'    => esc_html__('Post Hero height', 'campoal-tapo'),
                'subtitle' => esc_html__('Height of post hero section', 'campoal-tapo'),
                'desc'     => esc_html__('Set height of post hero section', 'campoal-tapo'),
                'validate' => 'not_empty',
                'default'  => '500px',
            ),
            array(
                'id'       => 'conikal_post_header_opacity_field',
                'type'     => 'slider',
                'title'    => esc_html__('Post hero opacity', 'campoal-tapo'),
                'subtitle' => esc_html__('Percent of shadown background on post hero section', 'campoal-tapo'),
                'desc'     => esc_html__('Range the percent (%).', 'campoal-tapo'),
                'min'      => 0,
                'max'      => 100,
                'display_value' => 'label',
                'default'  => 90,
            ),
            array(
                'id'       => 'conikal_excerpt_words_grid_field',
                'type'     => 'text',
                'title'    => esc_html__('Card excerpt words', 'campoal-tapo'),
                'subtitle' => esc_html__('The number of words showing on the card', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 12,
            ),
            array(
                'id'       => 'conikal_excerpt_words_list_field',
                'type'     => 'text',
                'title'    => esc_html__('List excerpt words', 'campoal-tapo'),
                'subtitle' => esc_html__('The number of words showing on the list', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 22,
            ),
        )
    ) );

    // -> START Single petition
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Single petition', 'campoal-tapo'),
        'id'     => 'single_petition',
        'desc'   => esc_html__('Set appearance for single petition', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_petition_to_text_field',
                'type'     => 'switch',
                'title'    => esc_html__('Petition to', 'campoal-tapo'),
                'subtitle' => esc_html__('Show petition to text on petition card and single page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_petition_date_field',
                'type'     => 'switch',
                'title'    => esc_html__('Petition date', 'campoal-tapo'),
                'subtitle' => esc_html__('Display publish date on single petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('Hidden or show date on petition.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_decisionmakers_display_field',
                'type'     => 'select',
                'title'    => esc_html__('Decision makers display', 'campoal-tapo'),
                'subtitle' => esc_html__('Set how many decision makers display on petition list or card', 'campoal-tapo'),
                'desc'     => esc_html__('Select a number. Default is show one name.', 'campoal-tapo'),
                'options'  => array(
                    0   => esc_html__('All', 'campoal-tapo'),
                    1  => esc_html__('1', 'campoal-tapo'),
                    2  => esc_html__('2', 'campoal-tapo'),
                    3  => esc_html__('3', 'campoal-tapo'),
                    4  => esc_html__('4', 'campoal-tapo'),
                    5  => esc_html__('5', 'campoal-tapo'),
                    6  => esc_html__('6', 'campoal-tapo'),
                    7  => esc_html__('7', 'campoal-tapo'),
                    8  => esc_html__('8', 'campoal-tapo'),
                    9  => esc_html__('9', 'campoal-tapo'),
                    10 => esc_html__('10', 'campoal-tapo'),
                ),
                'default'  => 1,
            ),
            array(
                'id'       => 'conikal_show_letter_section_field',
                'type'     => 'switch',
                'title'    => esc_html__('Letter section', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden letter on single petiton page.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_show_navigation_section_field',
                'type'     => 'switch',
                'title'    => esc_html__('Navigation section', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden navigation on single petiton page.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden. If you are using Infinite Scroll, this option required enabled.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_video_embed_placeholder_field',
                'type'     => 'switch',
                'title'    => esc_html__('Video embed placeholder', 'campoal-tapo'),
                'subtitle' => esc_html__('Embed video as normally or put placeholder over video.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_show_supporters_section_field',
                'type'     => 'switch',
                'title'    => esc_html__('Supporters section', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden latest supporters on single petiton page.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_show_donors_section_field',
                'type'     => 'switch',
                'title'    => esc_html__('Donors section', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden latest donors on single petiton page.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_supporters_donors_style_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Supporters & Donors style', 'campoal-tapo'),
                'subtitle' => esc_html__('Style to display latest supporters and donors on single petitions', 'campoal-tapo'),
                'desc'     => esc_html__('List style are display avatar and name, grid are display avatar only.', 'campoal-tapo'),
                'options'  => array(
                    'avatar'    => esc_html__('Avatar', 'campoal-tapo'),
                    'list'      => esc_html__('List', 'campoal-tapo'),
                ),
                'default'  => 'list',
            ),
            array(
                'id'       => 'conikal_supporter_counter_animation_field',
                'type'     => 'text',
                'title'    => esc_html__('Supporter counter animation', 'campoal-tapo'),
                'subtitle' => esc_html__('Enable counter animation on supporter number on single petition', 'campoal-tapo'),
                'desc'     => esc_html__('Set in millisecond eg 3000 meaning 3 secound. Set 0 to disable animation', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 2000,
            ),
        )
    ) );

    // -> START Pagination
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Pagination', 'campoal-tapo'),
        'id'     => 'pagination',
        'desc'   => esc_html__('Set options for pagination', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_recent_supporters_donors_field',
                'type'     => 'text',
                'title'    => esc_html__('Recent supporters & donors', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of user display on recent supporters and donors section', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 10,
            ),
            array(
                'id'       => 'conikal_similar_petition_per_page_field',
                'type'     => 'text',
                'title'    => esc_html__('Related and similar', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of petitions display on section', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 3,
            ),
            array(
                'id'       => 'conikal_related_posts_per_page_field',
                'type'     => 'text',
                'title'    => esc_html__('Related post per page', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of posts display on section', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 3,
            ),
            array(
                'id'       => 'conikal_petitions_per_page_field',
                'type'     => 'text',
                'title'    => esc_html__('Petitions per page', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of petitions on per page', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 12,
            ),
            array(
                'id'       => 'conikal_updates_per_page_field',
                'type'     => 'text',
                'title'    => esc_html__('Updates per page', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of updates on per page', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 5,
            ),
            array(
                'id'       => 'conikal_citations_per_page_field',
                'type'     => 'text',
                'title'    => esc_html__('Citation per page', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of citation on per page', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 5,
            ),
            array(
                'id'       => 'conikal_supporter_per_page_field',
                'type'     => 'text',
                'title'    => esc_html__('Supporters per page', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of supporters on per page', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 48,
            ),
            array(
                'id'       => 'conikal_item_per_page_field',
                'type'     => 'text',
                'title'    => esc_html__('Items per page', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of items on per page in dashboard', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 20,
            ),
            array(
                'id'       => 'conikal_item_per_page_field',
                'type'     => 'text',
                'title'    => esc_html__('Items per page', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of items on per page in dashboard', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 20,
            ),
        )
    ) );

    // -> START Similar petition
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Similar petition', 'campoal-tapo'),
        'id'     => 'similar_petition',
        'desc'   => esc_html__('Set options for similar petition', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_similar_field',
                'type'     => 'switch',
                'title'    => esc_html__('Similar petition', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden similar petitions on single petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_similar_display_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Similar display', 'campoal-tapo'),
                'subtitle' => esc_html__('Set style of similar petition card.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between normal or slider.', 'campoal-tapo'),
                'options'  => array(
                    'normal'      => esc_html__('Normal', 'campoal-tapo'),
                    'slider'    => esc_html__('Slider', 'campoal-tapo'),
                ),
                'default'  => 'normal',
            ),
            array(
                'id'       => 'conikal_similar_base_field',
                'type'     => 'select',
                'title'    => esc_html__('Condition of Similar', 'campoal-tapo'),
                'subtitle' => esc_html__('Similar of petition will be base on this condition.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'options'  => array(
                    'both'      => esc_html__('Both Category & Topics', 'campoal-tapo'),
                    'category'  => esc_html__('Base on Category', 'campoal-tapo'),
                    'topics' => esc_html__('Base on Topics', 'campoal-tapo')
                ),
                'default'  => 'category',
            ),
        )
    ) );


    // -> START Sign section
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Sign section', 'campoal-tapo'),
        'id'     => 'sign_section',
        'desc'   => esc_html__('Sign, Share and donation section settings', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_sign_button_text_field',
                'type'     => 'text',
                'title'    => esc_html__('Sign button text', 'campoal-tapo'),
                'subtitle' => esc_html__('The text of button display on sign section.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => 'Sign',
            ),
            array(
                'id'       => 'conikal_sign_petition_without_login_field',
                'type'     => 'switch',
                'title'    => esc_html__('Sign petition without login', 'campoal-tapo'),
                'subtitle' => esc_html__('Using email of user to sign a petition but not login', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_sign_show_all_field',
                'type'     => 'switch',
                'title'    => esc_html__('Sign show all', 'campoal-tapo'),
                'subtitle' => esc_html__('Display all sign box, share box and contribute box at same time', 'campoal-tapo'),
                'desc'     => esc_html__('If you enable this option, so you also need switch sign style on mobile to sidebar.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_mobile_sign_style_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Sign style', 'campoal-tapo'),
                'subtitle' => esc_html__('Display button or show sidebar on mobile', 'campoal-tapo'),
                'desc'     => esc_html__('Show button only or display sidebar for sign and share on mobile', 'campoal-tapo'),
                'options'  => array(
                    'button'    => esc_html__('Button', 'campoal-tapo'),
                    'sidebar'      => esc_html__('Sidebar', 'campoal-tapo'),
                ),
                'default'  => 'button',
            ),
            array(
                'id'       => 'conikal_sign_victory_field',
                'type'     => 'switch',
                'title'    => esc_html__('Sign victory', 'campoal-tapo'),
                'subtitle' => esc_html__('Allowed visitors continue sign petition whether petition victory.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_default_accordion_sign_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Default accordion', 'campoal-tapo'),
                'subtitle' => esc_html__('Default of accordion section after user sign petition success', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between share or contribute section.', 'campoal-tapo'),
                'options'  => array(
                    'share'         => esc_html__('Share on Facebook', 'campoal-tapo'),
                    'contribute'    => esc_html__('Contribute & Donation', 'campoal-tapo'),
                ),
                'default'  => 'contribute',
            ),
            array(
                'id'       => 'conikal_disable_unsign_field',
                'type'     => 'switch',
                'title'    => esc_html__('Unsign Petition', 'campoal-tapo'),
                'subtitle' => esc_html__('Supporter can unsign petition they just sign, just in single petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_reason_sign_box_field',
                'type'     => 'switch',
                'title'    => esc_html__('Reason sign box', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden reason sign box sign petiton section.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_share_comment_box_field',
                'type'     => 'switch',
                'title'    => esc_html__('Share comment box', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden share comment box share petiton section.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_receive_update_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Receive update', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden receive update checkbox below sign petition section.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'options'  => array(
                    'none'       => esc_html__('Hidden', 'campoal-tapo'),
                    'checked'    => esc_html__('Checked', 'campoal-tapo'),
                    'not'    => esc_html__('Not Checked', 'campoal-tapo'),
                ),
                'default'  => 'checked',
            ),
            array(
                'id'       => 'conikal_sign_anonymous_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Anonymous signing', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden display name of supporter checkbox below sign petition section.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'options'  => array(
                    'none'       => esc_html__('Hidden', 'campoal-tapo'),
                    'checked'    => esc_html__('Checked', 'campoal-tapo'),
                    'not'    => esc_html__('Not Checked', 'campoal-tapo'),
                ),
                'default'  => 'checked',
            ),
            array(
                'id'       => 'conikal_default_heading_template_field',
                'type'     => 'text',
                'title'    => esc_html__('Share custom heading template', 'campoal-tapo'),
                'subtitle' => esc_html__('Heading template for social sharing meta.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed alphabet only and variables: {title}, {supporter_name}, {supporter_number}, {decision_maker}, {author_name}', 'campoal-tapo'),
                'default'  => 'Petition to {decision_maker}: {title}',
            ),
            array(
                'id'       => 'conikal_sign_cta_field',
                'type'     => 'editor',
                'title'    => esc_html__('Sign call to action', 'campoal-tapo'),
                'subtitle' => esc_html__('The call to action text show below on spread button', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html tags.', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5,
                ),
                'default'  => __('The small action you take today can make a huge difffernt', 'campoal-tapo'),
            ),
        )
    ) );

    // -> START Number formated
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Number format', 'campoal-tapo'),
        'id'     => 'number_format',
        'desc'   => esc_html__('Set options for number format', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_compact_number_field',
                'type'     => 'switch',
                'title'    => esc_html__('Compact supporters number', 'campoal-tapo'),
                'subtitle' => esc_html__('Show full or compact number of supporters counter.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_thousands_separator_field',
                'type'     => 'text',
                'title'    => esc_html__('Thousands Separator', 'campoal-tapo'),
                'subtitle' => esc_html__('Symbol of Thousands Separator supporters number.', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'not_empty',
                'default'  => ',',
            ),
            array(
                'id'       => 'conikal_demical_separator_field',
                'type'     => 'text',
                'title'    => esc_html__('Demical Separator', 'campoal-tapo'),
                'subtitle' => esc_html__('Symbol of Demical Separator supporters number.', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'not_empty',
                'default'  => '.',
            ),
        )
    ) );


    // -> START Comments
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Comments', 'campoal-tapo'),
        'id'     => 'comment',
        'desc'   => esc_html__('Set options for comment', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_petition_comment_field',
                'type'     => 'switch',
                'title'    => esc_html__('Petition comment', 'campoal-tapo'),
                'subtitle' => esc_html__('Comments display on single petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('Hidden or show comments on petition.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_post_comment_field',
                'type'     => 'switch',
                'title'    => esc_html__('Post comment', 'campoal-tapo'),
                'subtitle' => esc_html__('Comments display on single article page.', 'campoal-tapo'),
                'desc'     => esc_html__('Hidden or show comments on article.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_comments_style_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Comments style', 'campoal-tapo'),
                'subtitle' => esc_html__('Set style of comments', 'campoal-tapo'),
                'desc'     => esc_html__('Choose the style of comments list with thread, minimal and normal.', 'campoal-tapo'),
                'options'  => array(
                    'normal' 	=> esc_html__('Normal', 'campoal-tapo'),
					'minimal' 	=> esc_html__('Minimal', 'campoal-tapo'),
					'threaded' 	=> esc_html__('Threaded', 'campoal-tapo'),
                ),
                'default'  => 'normal',
            ),
            array(
                'id'       => 'conikal_ajax_comment_field',
                'type'     => 'switch',
                'title'    => esc_html__('Ajax comment', 'campoal-tapo'),
                'subtitle' => esc_html__('Replace default comment by ajax', 'campoal-tapo'),
                'desc'     => esc_html__('Disable to show default comment or Enable to use ajax comment.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_comments_sort_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Comments sort', 'campoal-tapo'),
                'subtitle' => esc_html__('Set position of newest comments', 'campoal-tapo'),
                'desc'     => esc_html__('Newest will display newest comment on top or oldest comments on top.', 'campoal-tapo'),
                'options'  => array(
                    'newest'         => esc_html__('Newest', 'campoal-tapo'),
                    'oldest'    => esc_html__('Oldest', 'campoal-tapo'),
                ),
                'default'  => 'oldest',
            ),
            array(
                'id'       => 'conikal_replies_sort_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Replies sort', 'campoal-tapo'),
                'subtitle' => esc_html__('Set position of newest replies', 'campoal-tapo'),
                'desc'     => esc_html__('Newest will display newest replies on top or oldest replies on top.', 'campoal-tapo'),
                'options'  => array(
                    'newest'         => esc_html__('Newest', 'campoal-tapo'),
                    'oldest'    => esc_html__('Oldest', 'campoal-tapo'),
                ),
                'default'  => 'oldest',
            ),
            array(
                'id'       => 'conikal_comments_per_page_field',
                'type'     => 'text',
                'title'    => esc_html__('Comments per page', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of comments on per page', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 10,
            ),
            array(
                'id'       => 'conikal_reply_per_comment_field',
                'type'     => 'text',
                'title'    => esc_html__('Replies per page', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of replies on per page', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 2,
            ),
        )
    ) );


    // -> START Editor style
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Editor style', 'campoal-tapo'),
        'id'     => 'editor_style',
        'desc'   => esc_html__('Select editor style and markdown option', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_editor_style_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Editor Style', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of editor on user interface', 'campoal-tapo'),
                'desc'     => esc_html__('If you use Classic editor, let disabled Optimize JavaScript on Autoptimize plugin please.', 'campoal-tapo'),
                'options'  => array(
                    'markdown'    => esc_html__('Markdown', 'campoal-tapo'),
                    'classic'      => esc_html__('Classic', 'campoal-tapo'),
                ),
                'default'  => 'markdown',
            ),
            array(
                'id'       => 'conikal_markdown_spell_checker_field',
                'type'     => 'switch',
                'title'    => esc_html__('Spell checker', 'campoal-tapo'),
                'subtitle' => esc_html__('Spell check when type content on markdown editor', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );


    // -> START Prompt action
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Prompt action', 'campoal-tapo'),
        'id'     => 'prompt_action',
        'desc'   => esc_html__('Remind users to take action on the petition page', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_prompt_action_field',
                'type'     => 'switch',
                'title'    => esc_html__('Prompt action modal', 'campoal-tapo'),
                'subtitle' => esc_html__('Show modal to prompt action if user stay long time on petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_prompt_action_time_field',
                'type'     => 'text',
                'title'    => esc_html__('Waiting time', 'campoal-tapo'),
                'subtitle' => esc_html__('Set the time how long it takes to show modal.', 'campoal-tapo'),
                'desc'     => esc_html__('Set in minutes eg. 3.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 3,
            ),
            array(
                'id'       => 'conikal_prompt_action_remind_field',
                'type'     => 'text',
                'title'    => esc_html__('Remind time', 'campoal-tapo'),
                'subtitle' => esc_html__('Set the times will show prompt action modal again after click sign button.', 'campoal-tapo'),
                'desc'     => esc_html__('Set in minutes eg. 1440. Leave empty to remind again when browser session end.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 1440,
            ),
        )
    ) );

    // -> START Profile type
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Profile type', 'campoal-tapo'),
        'id'     => 'profile_type',
        'desc'   => esc_html__('Control that profile type appear on site', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_profile_petitioner_field',
                'type'     => 'switch',
                'title'    => esc_html__('Activist', 'campoal-tapo'),
                'subtitle' => esc_html__('Show modal to prompt action if user stay long time on petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_profile_decision_maker_field',
                'type'     => 'switch',
                'title'    => esc_html__('Legislator', 'campoal-tapo'),
                'subtitle' => esc_html__('Show modal to prompt action if user stay long time on petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_profile_researcher_field',
                'type'     => 'switch',
                'title'    => esc_html__('Organization', 'campoal-tapo'),
                'subtitle' => esc_html__('Show organization profile type.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START Mobile
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Mobile', 'campoal-tapo'),
        'id'     => 'mobile_interface',
        'desc'   => esc_html__('Control mobile web version interface', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_mobile_sign_scroll_field',
                'type'     => 'switch',
                'title'    => esc_html__('Scroll sign', 'campoal-tapo'),
                'subtitle' => esc_html__('Hidden sign button when scroll up page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_mobile_progress_bar_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Mobile progress bar', 'campoal-tapo'),
                'subtitle' => esc_html__('Show progress on sidebar or below thumbnail on petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between sidebar, thumbnail or both down.', 'campoal-tapo'),
                'options'  => array(
                    'sidebar'   => esc_html__('Sidebar', 'campoal-tapo'),
                    'thumbnail' => esc_html__('Thumbnail', 'campoal-tapo'),
                    'both'      => esc_html__('Both', 'campoal-tapo'),
                ),
                'default'  => 'sidebar',
            ),
            array(
                'id'       => 'conikal_mobile_menu_animation_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Mobile menu animation', 'campoal-tapo'),
                'subtitle' => esc_html__('Animation of mobile menu sidebar when click hamburger button', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between overlay, push or scale down.', 'campoal-tapo'),
                'options'  => array(
                    'overlay'   => esc_html__('Overlay', 'campoal-tapo'),
                    'push'      => esc_html__('Push', 'campoal-tapo'),
                    'scale'     => esc_html__('Scale Down', 'campoal-tapo'),
                ),
                'default'  => 'overlay',
            ),
            array(
                'id'       => 'conikal_mobile_login_button_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Mobile login button', 'campoal-tapo'),
                'subtitle' => esc_html__('Display login button on header bar by mobile devices', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between button or icon.', 'campoal-tapo'),
                'options'  => array(
                    'button'   => esc_html__('Button', 'campoal-tapo'),
                    'icon'      => esc_html__('Icon', 'campoal-tapo'),
                ),
                'default'  => 'button',
            ),
        )
    ) );

    // -> START Views counter
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Views Counter', 'campoal-tapo'),
        'id'     => 'views_counter',
        'desc'   => esc_html__('Control view and visitor counter', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_view_counter_field',
                'type'     => 'switch',
                'title'    => esc_html__('View counter', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden view counter of posts and petitons.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_view_counter_type_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Counter type', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of counter to show on all pages', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between views, visitors or players down.', 'campoal-tapo'),
                'options'  => array(
                    'views'   => esc_html__('Views', 'campoal-tapo'),
                    'visitors'      => esc_html__('Vistors', 'campoal-tapo'),
                    'players'     => esc_html__('Players', 'campoal-tapo'),
                ),
                'default'  => 'views',
            ),
            array(
                'id'       => 'conikal_video_watching_time_field',
                'type'     => 'text',
                'title'    => esc_html__('Video watching time', 'campoal-tapo'),
                'subtitle' => esc_html__('Set the time how long since click on play video button is a view.', 'campoal-tapo'),
                'desc'     => esc_html__('Set in secound eg. 30.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 30,
            ),
            array(
                'id'       => 'conikal_visitors_statictis_field',
                'type'     => 'switch',
                'title'    => esc_html__('Visitors statictis', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden visitors statictis for all users.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START Submit step
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Submit step', 'campoal-tapo'),
        'id'     => 'submit_step',
        'desc'   => esc_html__('Control steps visible on submit page', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_receiver_step_field',
                'type'     => 'switch',
                'title'    => esc_html__('Receiver step', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden receiver step on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_fundraising_step_field',
                'type'     => 'switch',
                'title'    => esc_html__('Fundraising step', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden fundraising step on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
        )
    ) );

    // -> START Cookie notice
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Cookie Notice', 'campoal-tapo'),
        'id'     => 'cookie_notice',
        'desc'   => esc_html__('This can be used for providing notices like the site use of cookies, an important change to a site like a security breach.', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_cookie_notice_field',
                'type'     => 'switch',
                'title'    => esc_html__('Cookie notice', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden cookie notice on website', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_cookie_notice_style_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Cookie notice style', 'campoal-tapo'),
                'subtitle' => esc_html__('Cookie notice display style', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between toast or sidebar.', 'campoal-tapo'),
                'options'  => array(
                    'sidebar' => esc_html__('Sidebar', 'campoal-tapo'),
                    'toast' => esc_html__('Toast', 'campoal-tapo'),
                ),
                'default'  => 'toast',
            ),
            array(
                'id'       => 'conikal_cookie_notice_position_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Cookie notice position', 'campoal-tapo'),
                'subtitle' => esc_html__('Position where cookie notice is displayed.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between header, footer or notification.', 'campoal-tapo'),
                'options'  => array(
                    'header' => esc_html__('Header', 'campoal-tapo'),
                    'footer' => esc_html__('Footer', 'campoal-tapo'),
                ),
                'default'  => 'footer',
            ),
            array(
                'id'       => 'conikal_cookie_notice_display_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Cookie notice display', 'campoal-tapo'),
                'subtitle' => esc_html__('Set the cookie notification display type.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between sidebar, thumbnail or both down.', 'campoal-tapo'),
                'options'  => array(
                    'block' => esc_html__('Block', 'campoal-tapo'),
                    'fixed' => esc_html__('Fixed', 'campoal-tapo'),
                ),
                'default'  => 'fixed',
            ),
            array(
                'id'       => 'conikal_cookie_hidden_type_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Hidden type', 'campoal-tapo'),
                'subtitle' => esc_html__('Hide cookie notice from website', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between scoll down to hidden or button click.', 'campoal-tapo'),
                'options'  => array(
                    'scroll' => esc_html__('Scroll down', 'campoal-tapo'),
                    'click' => esc_html__('Button click', 'campoal-tapo'),
                ),
                'default'  => 'scroll',
            ),
            array(
                'id'       => 'conikal_cookie_toast_position_field',
                'type'     => 'select',
                'title'    => esc_html__('Cookie Toast position', 'campoal-tapo'),
                'subtitle' => esc_html__('Sets where the toast can be displayed.', 'campoal-tapo'),
                'desc'     => esc_html__('Can be top right, top center, top left, bottom right, bottom center and bottom left.', 'campoal-tapo'),
                'options'  => array(
                    'top right' => esc_html__('Top right', 'campoal-tapo'),
                    'top center' => esc_html__('Top center', 'campoal-tapo'),
                    'top left' => esc_html__('Top left', 'campoal-tapo'),
                    'bottom right' => esc_html__('Bottom right', 'campoal-tapo'),
                    'bottom center' => esc_html__('Bottom center', 'campoal-tapo'),
                    'bottom left' => esc_html__('Bottom left', 'campoal-tapo'),
                ),
                'default'  => 'bottom left',
            ),
            array(
                'id'       => 'conikal_cookie_toast_transiation_show_field',
                'type'     => 'select',
                'title'    => esc_html__('Cookie Toast transiation show', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of transiation when show a toast.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a transiation.', 'campoal-tapo'),
                'options'  => array(
                    'scale' => esc_html__('scale', 'campoal-tapo'),
                    'zoom' => esc_html__('zoom', 'campoal-tapo'),
                    'fade' => esc_html__('fade', 'campoal-tapo'),
                    'fade up' => esc_html__('fade up', 'campoal-tapo'),
                    'fade down' => esc_html__('fade down', 'campoal-tapo'),
                    'fade left' => esc_html__('fade left', 'campoal-tapo'),
                    'fade right' => esc_html__('fade right', 'campoal-tapo'),
                    'horizontal flip' => esc_html__('horizontal flip', 'campoal-tapo'),
                    'vertical flip' => esc_html__('vertical flip', 'campoal-tapo'),
                    'fly left' => esc_html__('fly left', 'campoal-tapo'),
                    'fly right' => esc_html__('fly right', 'campoal-tapo'),
                    'fly up' => esc_html__('fly up', 'campoal-tapo'),
                    'fly down' => esc_html__('fly down', 'campoal-tapo'),
                    'swing left' => esc_html__('swing left', 'campoal-tapo'),
                    'swing right' => esc_html__('swing right', 'campoal-tapo'),
                    'swing up' => esc_html__('swing up', 'campoal-tapo'),
                    'swing down' => esc_html__('swing down', 'campoal-tapo'),
                    'browse' => esc_html__('browse', 'campoal-tapo'),
                    'browse right' => esc_html__('browse right', 'campoal-tapo'),
                    'slide down' => esc_html__('slide down', 'campoal-tapo'),
                    'slide up' => esc_html__('slide up', 'campoal-tapo'),
                    'slide left' => esc_html__('slide left', 'campoal-tapo'),
                    'slide left' => esc_html__('slide left', 'campoal-tapo'),
                ),
                'default'  => 'fly up',
            ),
            array(
                'id'       => 'conikal_cookie_toast_transiation_hide_field',
                'type'     => 'select',
                'title'    => esc_html__('Cookie Toast transiation hidden', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of transiation when hidden a toast.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a transiation.', 'campoal-tapo'),
                'options'  => array(
                    'scale' => esc_html__('scale', 'campoal-tapo'),
                    'zoom' => esc_html__('zoom', 'campoal-tapo'),
                    'fade' => esc_html__('fade', 'campoal-tapo'),
                    'fade up' => esc_html__('fade up', 'campoal-tapo'),
                    'fade down' => esc_html__('fade down', 'campoal-tapo'),
                    'fade left' => esc_html__('fade left', 'campoal-tapo'),
                    'fade right' => esc_html__('fade right', 'campoal-tapo'),
                    'horizontal flip' => esc_html__('horizontal flip', 'campoal-tapo'),
                    'vertical flip' => esc_html__('vertical flip', 'campoal-tapo'),
                    'fly left' => esc_html__('fly left', 'campoal-tapo'),
                    'fly right' => esc_html__('fly right', 'campoal-tapo'),
                    'fly up' => esc_html__('fly up', 'campoal-tapo'),
                    'fly down' => esc_html__('fly down', 'campoal-tapo'),
                    'swing left' => esc_html__('swing left', 'campoal-tapo'),
                    'swing right' => esc_html__('swing right', 'campoal-tapo'),
                    'swing up' => esc_html__('swing up', 'campoal-tapo'),
                    'swing down' => esc_html__('swing down', 'campoal-tapo'),
                    'browse' => esc_html__('browse', 'campoal-tapo'),
                    'browse right' => esc_html__('browse right', 'campoal-tapo'),
                    'slide down' => esc_html__('slide down', 'campoal-tapo'),
                    'slide up' => esc_html__('slide up', 'campoal-tapo'),
                    'slide left' => esc_html__('slide left', 'campoal-tapo'),
                    'slide left' => esc_html__('slide left', 'campoal-tapo'),
                ),
                'default'  => 'fly up',
            ),
            array(
                'id'       => 'conikal_cookie_notice_time_field',
                'type'     => 'text',
                'title'    => esc_html__('Cookie time', 'campoal-tapo'),
                'subtitle' => esc_html__('How long time that a particular computer does not receive the nag again.', 'campoal-tapo'),
                'desc'     => esc_html__('Set in days. eg 30.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 30,
            ),
            array(
                'id'       => 'conikal_cookie_notice_content_field',
                'type'     => 'editor',
                'title'    => esc_html__('Cookie notice content', 'campoal-tapo'),
                'subtitle' => esc_html__('The content showing on cookie notice', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html tags.', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5,
                ),
                'default'  => __('We use cookies on our website to give you the most relevant experience by remembering your preferences and repeat visits. By clicking “Accept”, you consent to the use of ALL the cookies.', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_cookie_policy_page_field',
                'type'     => 'select',
                'title'    => esc_html__('Cookie policy page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page about cookie policy show on notice message.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page descript about cookie policy.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('privacy-policy.php') : '',
            ),
        )
    ) );

    // -> START Social button
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Share buttons', 'campoal-tapo'),
        'id'     => 'social_buttons',
        'desc'   => esc_html__('Sortable social buttons and choose big button visible on sharing section.', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_share_url_copiable_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Share URL copiable', 'campoal-tapo'),
                'subtitle' => esc_html__('Copyible URL of petition to share.', 'campoal-tapo'),
                'desc'     => esc_html__('Select long URL or short URL to display.', 'campoal-tapo'),
                'options'  => array(
                    'long' => esc_html__('Long', 'campoal-tapo'),
                    'short' => esc_html__('Short', 'campoal-tapo'),
                ),
                'default'  => 'short',
            ),
            array(
                'id'       => 'conikal_primary_share_button_field',
                'type'     => 'select',
                'title'    => esc_html__('Primary share button', 'campoal-tapo'),
                'subtitle' => esc_html__('Big button visible on sharing section.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose the type of sharing button.', 'campoal-tapo'),
                'options'  => array(
                    'mail'          => esc_html__('Mail', 'campoal-tapo'),
                    'gmail'         => esc_html__('Gmail', 'campoal-tapo'),
                    'facebook'      => esc_html__('Facebook', 'campoal-tapo'),
                    'twitter'       => esc_html__('Twitter', 'campoal-tapo'),
                    'telegram'      => esc_html__('Telegram', 'campoal-tapo'),
                    'embed-widget'  => esc_html__('Embed', 'campoal-tapo'),
                    'messenger'     => esc_html__('Messenger', 'campoal-tapo'),
                    'whatsapp'      => esc_html__('Whatsapp', 'campoal-tapo'),
                    'line'          => esc_html__('Line', 'campoal-tapo'),
                    'linkedin'      => esc_html__('LinkedIn', 'campoal-tapo'),
                    'tumblr'        => esc_html__('Tumblr', 'campoal-tapo'),
                    'pinterest'     => esc_html__('Pinterest', 'campoal-tapo'),
                    'reddit'        => esc_html__('Reddit', 'campoal-tapo'),
                    'vk'            => esc_html__('VK', 'campoal-tapo'),
                    'sms'           => esc_html__('SMS', 'campoal-tapo'),
                ),
                'default'  => 'facebook',
            ),
            array(
                'id'       => 'conikal_social_buttons_sortable_field',
                'type'     => 'sortable',
                'title'    => __('Social buttons sortable', 'campoal-tapo'),
                'subtitle' => __('Re-order social share buttons in the order you want.', 'campoal-tapo'),
                'desc'     => __('Checked on eye icon to display or not, drag and drop to sorting.', 'campoal-tapo'),
                'mode'     => 'checkbox',
                'options'  => array(
                    'mail'          => esc_html__('Mail', 'campoal-tapo'),
                    'gmail'         => esc_html__('Gmail', 'campoal-tapo'),
                    'facebook'      => esc_html__('Facebook', 'campoal-tapo'),
                    'twitter'       => esc_html__('Twitter', 'campoal-tapo'),
                    'telegram'      => esc_html__('Telegram', 'campoal-tapo'),
                    'embed-widget'  => esc_html__('Embed', 'campoal-tapo'),
                    'messenger'     => esc_html__('Messenger', 'campoal-tapo'),
                    'whatsapp'      => esc_html__('Whatsapp', 'campoal-tapo'),
                    'line'          => esc_html__('Line', 'campoal-tapo'),
                    'linkedin'      => esc_html__('LinkedIn', 'campoal-tapo'),
                    'tumblr'        => esc_html__('Tumblr', 'campoal-tapo'),
                    'pinterest'     => esc_html__('Pinterest', 'campoal-tapo'),
                    'reddit'        => esc_html__('Reddit', 'campoal-tapo'),
                    'vk'            => esc_html__('VK', 'campoal-tapo'),
                    'sms'           => esc_html__('SMS', 'campoal-tapo'),
                ),
                // For checkbox mode
                'default' => array(
                    'mail'          => true,
                    'gmail'         => true,
                    'facebook'      => true,
                    'twitter'       => true,
                    'telegram'      => true,
                    'embed-widget'  => true,
                    'messenger'     => true,
                    'whatsapp'      => true,
                    'line'          => true,
                    'linkedin'      => true,
                    'tumblr'        => true,
                    'pinterest'     => true,
                    'reddit'        => true,
                    'vk'            => true,
                    'sms'           => true,
                ),
            ),
            array(
                'id'       => 'conikal_mail_sharing_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Mail sharing subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Custom email subject when user sharing campaign via email.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed alphabet only and variables: {title}, {link}, {supporter_name}, {supporter_number}, {decision_maker}, {author_name}', 'campoal-tapo'),
                'validate' => 'text',
                'default'  => 'Invitation to Sign the Petition - {title}',
            ),
            array(
                'id'       => 'conikal_mail_sharing_content_field',
                'type'     => 'editor',
                'title'    => esc_html__('Mail sharing content', 'campoal-tapo'),
                'subtitle' => esc_html__('Custom email content when user sharing campaign via email.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed alphabet only and variables: {title}, {link}, {supporter_name}, {supporter_number}, {decision_maker}, {author_name}', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5,
                ),
                'default'  => conikal_default_mail_sharing_content_template(),
            ),
            array(
                'id'       => 'conikal_mail_sharing_custom_field',
                'type'     => 'editor',
                'title'    => esc_html__('Client mail content', 'campoal-tapo'),
                'subtitle' => esc_html__('Custom email content when user enter their custom message before send email.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed alphabet only and variables: {title}, {link}, {supporter_name}, {supporters_number}, {decision_maker}, {author_name}, {message}', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5,
                ),
                'default'  => conikal_default_mail_sharing_custom_template(),
            ),
            array(
                'id'       => 'conikal_post_sharing_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Post sharing subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Custom email subject when user sharing post via email.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed alphabet only and variables: {title}, {link}, {author_name}, {supporter_name}', 'campoal-tapo'),
                'validate' => 'text',
                'default'  => 'Invitation to Read Article - {title}',
            ),
            array(
                'id'       => 'conikal_post_sharing_custom_field',
                'type'     => 'editor',
                'title'    => esc_html__('Post mail content', 'campoal-tapo'),
                'subtitle' => esc_html__('Custom email content when user sharing post via email.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed alphabet only and variables: {title}, {link}, {author_name}, {supporter_name}', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5,
                ),
                'default'  => conikal_default_email_sharing_post_template(),
            ),
        )
    ) );

    // -> START Pages
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Pages', 'campoal-tapo'),
        'id'     => 'pages',
        'desc'   => esc_html__('Set required page for site. ', 'campoal-tapo'),
        'icon'   => 'el el-website',
        'fields' => array(
            array(
                'id'       => 'conikal_page_redirect_logged_in_field',
                'type'     => 'select',
                'title'    => esc_html__('Homepage redirect logged in', 'campoal-tapo'),
                'subtitle' => esc_html__('The page display for user logged in.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a redirect page.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('homepage.php') : '',
            ),
            array(
                'id'       => 'conikal_page_api_field',
                'type'     => 'select',
                'title'    => esc_html__('API Search', 'campoal-tapo'),
                'subtitle' => esc_html__('The page response json data for search petition, organization, topics, decision makers.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by API template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('api-search.php') : '',
            ),
            array(
                'id'       => 'conikal_page_submit_petition_field',
                'type'     => 'select',
                'title'    => esc_html__('Submit petition page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page allow user submit a petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Submit Petition template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('submit-petition.php') : '',
            ),
            array(
                'id'       => 'conikal_page_submit_give_form_field',
                'type'     => 'select',
                'title'    => esc_html__('Submit Give form page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page allow user create a fundraising campaign.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Submit Give form template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('submit-give-form.php') : '',
            ),
            array(
                'id'       => 'conikal_page_login_field',
                'type'     => 'select',
                'title'    => esc_html__('Login page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page display login and register form for user.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Login template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('login.php') : '',
            ),
            array(
                'id'       => 'conikal_page_dashboard_petition_field',
                'type'     => 'select',
                'title'    => esc_html__('Dashboard petition page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page display dashboard petition to control campaign.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Dashboard Petition template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('dashboard-petition.php') : '',
            ),
            array(
                'id'       => 'conikal_page_user_account_field',
                'type'     => 'select',
                'title'    => esc_html__('User account page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page allow user edit their profile and settings.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by User Account template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('user-account.php') : '',
            ),
            array(
                'id'       => 'conikal_page_dashboard_user_field',
                'type'     => 'select',
                'title'    => esc_html__('Dashboard user page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page allow user view their petition, transaction, topics and withdraw.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by User Account template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('dashboard-user.php') : '',
            ),
            array(
                'id'       => 'conikal_page_petitions_search_results_field',
                'type'     => 'select',
                'title'    => esc_html__('Petition search results page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page display petition search results.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Petition search results template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('petitions-search-results.php') : '',
            ),
            array(
                'id'       => 'conikal_page_sign_successful_field',
                'type'     => 'select',
                'title'    => esc_html__('Sign successful page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page display successful alert when completed sign petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Sign Successful template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('sign-successful.php') : '',
            ),
            array(
                'id'       => 'conikal_page_sign_successful_field',
                'type'     => 'select',
                'title'    => esc_html__('Sign successful page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page display successful alert when completed sign petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Sign Successful template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('sign-successful.php') : '',
            ),
            array(
                'id'       => 'conikal_page_supporters_list_field',
                'type'     => 'select',
                'title'    => esc_html__('Supporters list page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page display supporters and donors.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Supporters List template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('supporters-list.php') : '',
            ),
            array(
                'id'       => 'conikal_page_embed_field',
                'type'     => 'select',
                'title'    => esc_html__('Embed page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page show code for embed card.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Embed template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('embed-widget.php') : '',
            ),
            array(
                'id'       => 'conikal_page_verificattion_success_field',
                'type'     => 'select',
                'title'    => esc_html__('Verification success page', 'campoal-tapo'),
                'subtitle' => esc_html__('The page shows a successful email verification message.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was designed for email verify notice or any you want redirect to.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? '' : '',
            ),
            array(
                'id'       => 'conikal_page_oauth_redirect_field',
                'type'     => 'select',
                'title'    => esc_html__('OAuth Redirect ', 'campoal-tapo'),
                'subtitle' => esc_html__('The page rediect after login via social.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by OAuth Redirect template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('oauth-redirect.php') : '',
            ),
        )
    ) );

    // -> START Header
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Header', 'campoal-tapo'),
        'id'     => 'header',
        'desc'   => esc_html__('Set options on header menu', 'campoal-tapo'),
        'icon'   => 'el el-lines',
        'fields' => array(
            array(
                'id'       => 'conikal_header_visibility_field',
                'type'     => 'switch',
                'title'    => esc_html__('Header visibility', 'campoal-tapo'),
                'subtitle' => esc_html__('Control the visibility of the header', 'campoal-tapo'),
                'desc'     => esc_html__('Disable that if you want to use static header.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_wide_header_menu_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Header wide', 'campoal-tapo'),
                'subtitle' => esc_html__('Wide of header bar', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between boxed or wide.', 'campoal-tapo'),
                'options'  => array(
                    'boxed'   => esc_html__('Boxed', 'campoal-tapo'),
                    'wide'    => esc_html__('Wide', 'campoal-tapo'),
                ),
                'default'  => 'wide',
            ),
            array(
                'id'       => 'conikal_style_header_menu_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Header style', 'campoal-tapo'),
                'subtitle' => esc_html__('Style of header bar', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between shadow or flat.', 'campoal-tapo'),
                'options'  => array(
                    'flat'     => esc_html__('Flat', 'campoal-tapo'),
                    'shadow'      => esc_html__('Shadow', 'campoal-tapo'),
                    'soft'     => esc_html__('Soft', 'campoal-tapo'),
                    'strong'     => esc_html__('Strong', 'campoal-tapo'),
                ),
                'default'  => 'shadow',
            ),
            array(
                'id'       => 'conikal_type_header_menu_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Header type', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of header bar', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between scoll, fixed or none.', 'campoal-tapo'),
                'options'  => array(
                    'none'      => esc_html__('None', 'campoal-tapo'),
                    'fixed'     => esc_html__('Fixed', 'campoal-tapo'),
                    'scroll'    => esc_html__('Scroll', 'campoal-tapo'),
                ),
                'default'  => 'none',
            ),
            array(
                'id'       => 'conikal_height_header_menu_field',
                'type'     => 'text',
                'title'    => esc_html__('Header height', 'campoal-tapo'),
                'subtitle' => esc_html__('Height of header bar.', 'campoal-tapo'),
                'desc'     => esc_html__('Set height of header.', 'campoal-tapo'),
                'validate' => 'not_empty',
                'default'  => '65px',
            ),
            array(
                'id'       => 'conikal_user_menu_field',
                'type'     => 'switch',
                'title'    => esc_html__('User menu', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden user menu on header', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_user_menu_name_field',
                'type'     => 'select',
                'title'    => esc_html__('User name on menu', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of name display on user menu', 'campoal-tapo'),
                'desc'     => esc_html__('Choose type of display name.', 'campoal-tapo'),
                'options'  => array(
                    'none'      => esc_html__('None', 'campoal-tapo'),
                    'firstname' => esc_html__('First name', 'campoal-tapo'),
                    'lastname'  => esc_html__('Last name', 'campoal-tapo'),
                    'fullname'  => esc_html__('Full name', 'campoal-tapo'),
                    'nickname'  => esc_html__('Nick name', 'campoal-tapo')),
                'default'  => 'firstname',
            ),
            array(
                'id'       => 'conikal_submit_button_field',
                'type'     => 'switch',
                'title'    => esc_html__('Submit button', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden submit petiton button on header', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_submit_button_link_field',
                'type'     => 'select',
                'title'    => esc_html__('Submit button link', 'campoal-tapo'),
                'subtitle' => esc_html__('The page link for submit button on header.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a page was set by Submit Petition or Submit Give Form template.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('submit-petition.php') : '',
            ),
            array(
                'id'       => 'conikal_login_link_desktop_field',
                'type'     => 'switch',
                'title'    => esc_html__('Login link on Desktop', 'campoal-tapo'),
                'subtitle' => esc_html__('Use link instead modal when user click on sign in or sign up on desktop', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_login_link_mobile_field',
                'type'     => 'switch',
                'title'    => esc_html__('Login link on mobile', 'campoal-tapo'),
                'subtitle' => esc_html__('Use link instead modal when user click on sign in or sign up on mobile', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );


    // -> START top menu
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Top menu', 'campoal-tapo'),
        'id'     => 'top_menu',
        'desc'   => esc_html__('Control visiable on top menu above on header bar.', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_top_menu_field',
                'type'     => 'switch',
                'title'    => esc_html__('Top menu', 'campoal-tapo'),
                'subtitle' => esc_html__('Show top menu above on header bar', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_search_bar_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Search button', 'campoal-tapo'),
                'subtitle' => esc_html__('Position of search button on top menu', 'campoal-tapo'),
                'desc'     => esc_html__('Header is show on header bar, top menu is on above header.', 'campoal-tapo'),
                'options'  => array(
                    'header'      => esc_html__('Header', 'campoal-tapo'),
                    'top'         => esc_html__('Top menu', 'campoal-tapo'),
                    'hidden'      => esc_html__('Hidden', 'campoal-tapo'),
                ),
                'default'  => 'header',
            ),
            array(
                'id'       => 'conikal_shopping_cart_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Shopping cart', 'campoal-tapo'),
                'subtitle' => esc_html__('Position of shopping cart on top menu or header bar', 'campoal-tapo'),
                'desc'     => esc_html__('Header is show on header bar, top menu is on above header.', 'campoal-tapo'),
                'options'  => array(
                    'header'     => esc_html__('Header', 'campoal-tapo'),
                    'top'           => esc_html__('Top menu', 'campoal-tapo'),
                    'hidden'     => esc_html__('Hidden', 'campoal-tapo'),
                ),
                'default'  => 'header',
            ),
            array(
                'id'       => 'conikal_country_selection_position_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Country selection position', 'campoal-tapo'),
                'subtitle' => esc_html__('Position of country selection on top menu or header bar', 'campoal-tapo'),
                'desc'     => esc_html__('Header is show on header bar, top menu is on above header.', 'campoal-tapo'),
                'options'  => array(
                    'header'     => esc_html__('Header', 'campoal-tapo'),
                    'top'    => esc_html__('Top menu', 'campoal-tapo'),
                    'hidden'      => esc_html__('Hidden', 'campoal-tapo'),
                ),
                'default'  => 'header',
            ),
            array(
                'id'       => 'conikal_language_switcher_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Languages switcher', 'campoal-tapo'),
                'subtitle' => esc_html__('Position of languages switcher dropdown on top menu or header bar', 'campoal-tapo'),
                'desc'     => esc_html__('To enable languages you need install Polylang or GTranslate plugin, use only one of the two. Visibility inside country selection only support for Polylang.', 'campoal-tapo'),
                'options'  => array(
                    'header'        => esc_html__('Header', 'campoal-tapo'),
                    'top'           => esc_html__('Top menu', 'campoal-tapo'),
                    'country'       => esc_html__('Country selection', 'campoal-tapo'),
                    'hidden'        => esc_html__('Hidden', 'campoal-tapo'),
                ),
                'default'  => 'country',
            ),
        )
    ) );

    // -> START promo header
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Header promo', 'campoal-tapo'),
        'id'     => 'header_promo',
        'desc'   => esc_html__('Set promo section on header with video or text.', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_header_promo_field',
                'type'     => 'switch',
                'title'    => esc_html__('Header promo', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden promo section on header', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_header_promo_video_field',
                'type'     => 'text',
                'title'    => esc_html__('Header promo video', 'campoal-tapo'),
                'subtitle' => esc_html__('The video display on header promo section.', 'campoal-tapo'),
                'desc'     => esc_html__('URL embed of Youtube or Vimeo.', 'campoal-tapo'),
                'validate' => 'url',
            ),
            array(
                'id'       => 'conikal_header_promo_container_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Header promo container', 'campoal-tapo'),
                'subtitle' => esc_html__('Container of title and content on header promo section', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between boxed or wide.', 'campoal-tapo'),
                'options'  => array(
                    'boxed'      => esc_html__('Boxed', 'campoal-tapo'),
                    'wide'    => esc_html__('Wide', 'campoal-tapo'),
                ),
                'default'  => 'boxed',
            ),
            array(
                'id'       => 'conikal_header_promo_aligment_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Header promo aligment', 'campoal-tapo'),
                'subtitle' => esc_html__('Aligment of title and content on header promo section', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between left, right or center.', 'campoal-tapo'),
                'options'  => array(
                    'left'      => esc_html__('Left', 'campoal-tapo'),
                    'center'    => esc_html__('Center', 'campoal-tapo'),
                    'right'     => esc_html__('Right', 'campoal-tapo'),
                ),
                'default'  => 'left',
            ),
            array(
                'id'       => 'conikal_header_promo_title_field',
                'type'     => 'text',
                'title'    => esc_html__('Header promo title', 'campoal-tapo'),
                'subtitle' => esc_html__('The title display on header promo section.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_header_promo_content_field',
                'type'     => 'editor',
                'title'    => esc_html__('Header promo content', 'campoal-tapo'),
                'subtitle' => esc_html__('The content showing on header promo section ', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html tags.', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5,
                ),
                'default'  => __('Be the change that you wish to see in the world.', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_close_promo_time_field',
                'type'     => 'text',
                'title'    => esc_html__('Close time', 'campoal-tapo'),
                'subtitle' => esc_html__('Set the times will show promo again after close promo section.', 'campoal-tapo'),
                'desc'     => esc_html__('Set in days eg. 7. Leave empty to remind again when browser session end.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => '',
            ),
        )
    ) );

    // -> START country selection
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Country selection', 'campoal-tapo'),
        'id'     => 'country_selection',
        'desc'   => esc_html__('Set promo section on header with video or text.', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_country_selection_mode_field',
                'type'     => 'switch',
                'title'    => esc_html__('Country selection', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hide country selection on header', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_country_selection_field',
                'type'     => 'select',
                'multi'    => true,
                'title'    => __('Country list', 'campoal-tapo'), 
                'subtitle' => __('The countries allow selection on header', 'campoal-tapo'),
                'desc'     => __('Choose multi countries to display on dropdown.', 'campoal-tapo'),
                'options'  => function_exists('conikal_country_list') ? conikal_country_list() : array(),
                'default'  => array('us', 'uk', 'de', 'fr', 'it', 'be', 'nl', 'br', 'au', 'ca', 'in', 'id', 'jp', 'kr', 'vn'),
                'select2'  => array('select2' => array( 'allowClear' => False ) )
            ),
            array(
                'id'       => 'conikal_filter_by_country_field',
                'type'     => 'switch',
                'title'    => esc_html__('Filter petitions by country', 'campoal-tapo'),
                'subtitle' => esc_html__('Only show petitions located in country selected.', 'campoal-tapo'),
                'desc'     => esc_html__('Enabled to filter by country or disabled to show all petition.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_country_auto_detection_field',
                'type'     => 'switch',
                'title'    => esc_html__('Auto detect country', 'campoal-tapo'),
                'subtitle' => esc_html__('Set country automatically by Geolocation IP Detection .', 'campoal-tapo'),
                'desc'     => esc_html__('Recommendations are enabled only when there are already available petitions in the list of countries.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
        )
    ) );

    // -> START custom js
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Custom JS', 'campoal-tapo'),
        'id'     => 'header_custom_js',
        'desc'   => esc_html__('Add custom js to header tag.', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_header_custom_js_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Custom javascript', 'campoal-tapo'),
                'subtitle' => esc_html__('JavaScript code add on header', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed javascript code only.', 'campoal-tapo'),
                'mode'     => 'javascript',
            ),
            array(
                'id'       => 'conikal_header_js_ready_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('On document ready', 'campoal-tapo'),
                'subtitle' => esc_html__('Will be executed on $(document).ready() on header', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed javascript code only.', 'campoal-tapo'),
                'mode'     => 'javascript',
            ),
        ),
    ) );

    // -> START Footer
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Footer', 'campoal-tapo'),
        'id'     => 'footer',
        'desc'   => esc_html__('Set options for footer', 'campoal-tapo'),
        'icon'   => 'el el-pause',
        'fields' => array(
            array(
                'id'       => 'conikal_footer_visibility_field',
                'type'     => 'switch',
                'title'    => esc_html__('Footer visibility', 'campoal-tapo'),
                'subtitle' => esc_html__('Control the visibility of the footer', 'campoal-tapo'),
                'desc'     => esc_html__('Disable that if you want to use static footer.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_footer_column_field',
                'type'     => 'image_select',
                'title'    => __('Footer column', 'campoal-tapo'),
                'subtitle' => __('Select main content and sidebar alignment. Choose between 1, 2 or 3 column layout.', 'campoal-tapo'),
                'options'  => array(
                    '1'      => array(
                        'alt'   => '4 Column Default',
                        'img'   => ReduxFramework::$_url.'assets/img/1col.png'
                    ),
                    '2'      => array(
                        'alt'   => '2 Column Left',
                        'img'   => ReduxFramework::$_url.'assets/img/2cl.png'
                    ),
                    '3'      => array(
                        'alt'   => '2 Column Right',
                        'img'  => ReduxFramework::$_url.'assets/img/2cr.png'
                    ),
                    '4'      => array(
                        'alt'   => '3 Column Middle',
                        'img'   => ReduxFramework::$_url.'assets/img/3cm.png'
                    ),
                    '5'      => array(
                        'alt'   => '3 Column Left',
                        'img'   => ReduxFramework::$_url.'assets/img/3cl.png'
                    ),
                    '6'      => array(
                        'alt'  => '3 Column Right',
                        'img'  => ReduxFramework::$_url.'assets/img/3cr.png'
                    ),
                ),
                'default' => '1'
            ),
            array(
                'id'       => 'conikal_back_to_top_field',
                'type'     => 'switch',
                'title'    => esc_html__('Back to top', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden back to top button on footer', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_custom_js_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Custom javascript', 'campoal-tapo'),
                'subtitle' => esc_html__('JavaScript code add on footer', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed javascript code only.', 'campoal-tapo'),
                'mode'     => 'javascript',
            ),
            array(
                'id'       => 'conikal_js_ready_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('On document ready', 'campoal-tapo'),
                'subtitle' => esc_html__('Will be executed on $(document).ready()', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed javascript code only.', 'campoal-tapo'),
                'mode'     => 'javascript',
            ),
            array(
                'id'       => 'conikal_copyright_field',
                'type'     => 'editor',
                'title'    => esc_html__('Copyright text', 'campoal-tapo'),
                'subtitle' => esc_html__('The text show below on register and sign petition form', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html tags and variables: %1$s is current year, %2$s is site name.', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => true,
                    'textarea_rows'    => 3,
                ),
                'default'  => '© 2019 Campoal by Conikal.',
            ),
        )
    ) );


    // -> START Blog
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Blog', 'campoal-tapo'),
        'id'     => 'blog',
        'desc'   => esc_html__('Set options for blog', 'campoal-tapo'),
        'icon'   => 'el el-bold',
        'fields' => array(
            array(
                'id'       => 'conikal_blog_layout_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Blog layout', 'campoal-tapo'),
                'subtitle' => esc_html__('Layout of blogs page', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between classic, grid or list.', 'campoal-tapo'),
                'options'  => array(
                    'classic' => esc_html__('Classic', 'campoal-tapo'),
                    'grid' => esc_html__('Grid', 'campoal-tapo'),
                    'list' => esc_html__('List', 'campoal-tapo'),
                ),
                'default'  => 'list',
            ),
            array(
                'id'       => 'conikal_single_post_style_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Single post style', 'campoal-tapo'),
                'subtitle' => esc_html__('Style of single post', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between classic, center or simple.', 'campoal-tapo'),
                'options'  => array(
                    'classic' => esc_html__('Classic', 'campoal-tapo'),
                    'center' => esc_html__('Center', 'campoal-tapo'),
                    'simple' => esc_html__('Simple', 'campoal-tapo'),
                ),
                'default'  => 'classic',
            ),
            array(
                'id'       => 'conikal_dropcap_post_field',
                'type'     => 'switch',
                'title'    => esc_html__('Post Dropcap', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden big size on first letter in posts.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_related_field',
                'type'     => 'switch',
                'title'    => esc_html__('Related articles', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden related articles on single post.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_related_style_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Related articles style', 'campoal-tapo'),
                'subtitle' => esc_html__('Style of related articles on single post.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between classic, grid or list.', 'campoal-tapo'),
                'options'  => array(
                    'classic' => esc_html__('Classic', 'campoal-tapo'),
                    'card' => esc_html__('Card', 'campoal-tapo'),
                    'list' => esc_html__('List', 'campoal-tapo'),
                ),
                'default'  => 'list',
            ),
            array(
                'id'       => 'conikal_post_share_button_position_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Share button position', 'campoal-tapo'),
                'subtitle' => esc_html__('The position of social share buttons.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between Header, Bottom or Hidden.', 'campoal-tapo'),
                'options'  => array(
                    'all' => esc_html__('All', 'campoal-tapo'),
                    'header' => esc_html__('Header', 'campoal-tapo'),
                    'bottom' => esc_html__('Bottom', 'campoal-tapo'),
                    'hidden' => esc_html__('Hidden', 'campoal-tapo'),
                ),
                'default'  => 'bottom',
            ),
        )
    ) );

    // -> START Styling
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Styling', 'campoal-tapo'),
        'id'     => 'color',
        'desc'   => esc_html__('Set colors and border for website', 'campoal-tapo'),
        'icon'   => 'el el-tint',
        'fields' => array(
            array(
                'id'       => 'conikal_main_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Main color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#6059C9',
            ),
            array(
                'id'       => 'conikal_background_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#FFFCF7',
            ),
            array(
                'id'       => 'conikal_body_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Body text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
            array(
                'id'       => 'conikal_text_link_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Link color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
            array(
                'id'       => 'conikal_preloader_progress_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Preloader color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#6059C9',
            ),
            array(
                'id'       => 'conikal_victory_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Text and Progress Victory color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#6059C9',
            ),
            array(
                'id'       => 'conikal_victory_label_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Victory label color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#6059C9',
            ),
            array(
                'id'       => 'conikal_message_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Message background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#F9F9FF',
            ),
            array(
                'id'       => 'conikal_segment_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Segment background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#fbf7ed',
            ),
            array(
                'id'       => 'conikal_post_overlay_primary_color_field',
                'type'     => 'color_gradient',
                'title'    => esc_html__('Posts overlay primary color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => array(
                    'from' => '#FBC2EB',
                    'to'   => '#6059C9',
                ),
            ),
        )
    ) );

    // -> START Border radius
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Border radius', 'campoal-tapo'),
        'id'     => 'border_radius',
        'desc'   => esc_html__('Set border style for button, card and segment', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_label_border_radius_field',
                'type'     => 'text',
                'title'    => esc_html__('Label border radius', 'campoal-tapo'),
                'subtitle' => esc_html__('Set border radius for label', 'campoal-tapo'),
                'desc'     => esc_html__('Set numbers with units like px, rem or percentage', 'campoal-tapo'),
                'default'  => '6px',
            ),
            array(
                'id'       => 'conikal_button_border_radius_field',
                'type'     => 'text',
                'title'    => esc_html__('Button border radius', 'campoal-tapo'),
                'subtitle' => esc_html__('Set border radius for button', 'campoal-tapo'),
                'desc'     => esc_html__('Set numbers with units like px, rem or percentage', 'campoal-tapo'),
                'default'  => '10px',
            ),
            array(
                'id'       => 'conikal_card_border_radius_field',
                'type'     => 'text',
                'title'    => esc_html__('Card border radius', 'campoal-tapo'),
                'subtitle' => esc_html__('Set border radius for card', 'campoal-tapo'),
                'desc'     => esc_html__('Set numbers with units like px, rem or percentage', 'campoal-tapo'),
                'default'  => '12px',
            ),
            array(
                'id'       => 'conikal_segment_border_radius_field',
                'type'     => 'text',
                'title'    => esc_html__('Segment border radius', 'campoal-tapo'),
                'subtitle' => esc_html__('Set border radius for segment', 'campoal-tapo'),
                'desc'     => esc_html__('Set numbers with units like px, rem or percentage', 'campoal-tapo'),
                'default'  => '12px',
            ),
        )
    ) );

    // -> START Heading colors
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Heading Color', 'campoal-tapo'),
        'id'     => 'heading_color',
        'desc'   => esc_html__('Set color for website', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_page_title_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Page title color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
            array(
                'id'       => 'conikal_heading_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Heading color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
            array(
                'id'       => 'conikal_subheading_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Sub-Heading color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#5F5F75',
            ),
        )
    ) );


    // -> START Homepage Color
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Homepage Color', 'campoal-tapo'),
        'id'     => 'homepage_color',
        'desc'   => esc_html__('Set color for website', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_home_caption_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Home caption color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
            array(
                'id'       => 'conikal_home_sub_caption_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Home sub-caption color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#5F5F75',
            ),
            array(
                'id'       => 'conikal_home_menu_background_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Home menu background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => 'transparent',
            ),
            array(
                'id'       => 'conikal_home_menu_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Home menu text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
            array(
                'id'       => 'conikal_home_submenu_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Home submenu background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#ffffff',
            ),
            array(
                'id'       => 'conikal_home_submenu_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Home submenu text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
        )
    ) );

    // -> START Button Color
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Buttons Color', 'campoal-tapo'),
        'id'     => 'button_color',
        'desc'   => esc_html__('Set color for website', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_soft_button_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Soft button background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#EBECF0',
            ),
            array(
                'id'       => 'conikal_soft_button_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Soft button text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#8993A4',
            ),
            array(
                'id'       => 'conikal_submit_petition_button_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Submit petition button color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#6059C9',
            ),
            array(
                'id'       => 'conikal_sign_petition_button_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Sign petition button color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#6059C9',
            ),
            array(
                'id'       => 'conikal_citation_opinion_agree_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Citation opinion agree color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#36B37E',
            ),
            array(
                'id'       => 'conikal_citation_opinion_disagree_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Citation opinion disagree color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#FF5630',
            ),
            array(
                'id'       => 'conikal_signup_button_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Sign up button color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#FFAB00',
            ),
            array(
                'id'       => 'conikal_share_button_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Share button color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#6059C9',
            ),
            array(
                'id'       => 'conikal_donate_button_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Donate button color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#6059C9',
            ),
        )
    ) );

    // -> START Heading colors
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Top menu color', 'campoal-tapo'),
        'id'     => 'top_menu_color',
        'desc'   => esc_html__('Set color for website', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_top_menu_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Top menu background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#ffffff',
            ),
            array(
                'id'       => 'conikal_top_menu_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Top menu text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#5F5F75',
            ),
            array(
                'id'       => 'conikal_top_menu_link_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Top menu text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
        )
    ) );


    // -> START Header Color
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Header Color', 'campoal-tapo'),
        'id'     => 'header_color',
        'desc'   => esc_html__('Set color for header and promo section', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_header_menu_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Header menu color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#ffffff',
            ),
            array(
                'id'       => 'conikal_header_menu_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Header menu text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
            array(
                'id'       => 'conikal_header_submenu_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Header submenu background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#ffffff',
            ),
            array(
                'id'       => 'conikal_header_submenu_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Header submenu text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
            array(
                'id'       => 'conikal_header_promo_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Header promo background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#F5EFE0',
            ),
            array(
                'id'       => 'conikal_header_promo_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Header promo text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#0056ff',
            ),
            array(
                'id'       => 'conikal_opacity_hero_page_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Opacity hero color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#ffffff',
            ),
        )
    ) );

    // -> START Cookie Color
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Cookie Color', 'campoal-tapo'),
        'id'     => 'cookie_color',
        'desc'   => esc_html__('Set color for cookie notice bar', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_cookie_background_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Cookie Background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#091E42',
            ),
            array(
                'id'       => 'conikal_cookie_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Cookie text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#FFFCF7',
            ),
        )
    ) );

    // -> START Mobile Color
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Mobile Color', 'campoal-tapo'),
        'id'     => 'mobile_color',
        'desc'   => esc_html__('Set color for website', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_mobile_menu_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Mobile menu background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#ffffff',
            ),
            array(
                'id'       => 'conikal_mobile_menu_text_link_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Mobile menu text link color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#2B2B39',
            ),
        )
    ) );

    // -> START Chart Color
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Chart Color', 'campoal-tapo'),
        'id'     => 'chart_color',
        'desc'   => esc_html__('Set color for website', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_chart_color_1_field',
                'type'     => 'color',
                'title'    => esc_html__('Chart color 1', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#6554C0',
            ),
             array(
                'id'       => 'conikal_chart_color_2_field',
                'type'     => 'color',
                'title'    => esc_html__('Chart color 1', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#FF991F',
            ),
        )
    ) );

     // -> START Label Color
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Label Color', 'campoal-tapo'),
        'id'     => 'label_color',
        'desc'   => esc_html__('Set color for website', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_label_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Soft Label background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#F5EFE0',
            ),
             array(
                'id'       => 'conikal_label_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Soft Label text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#5F5F75',
            ),
        )
    ) );


    // -> START Footer Color
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Footer Color', 'campoal-tapo'),
        'id'     => 'footer_color',
        'desc'   => esc_html__('Set color for website', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_footer_bg_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Footer background color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#22130C',
            ),
            array(
                'id'       => 'conikal_footer_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Footer text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#FFFCF7',
            ),
             array(
                'id'       => 'conikal_sidebar_menu_text_color_field',
                'type'     => 'color',
                'title'    => esc_html__('Sidebar menu text color', 'campoal-tapo'),
                'desc'     => esc_html__('Pick the color.', 'campoal-tapo'),
                'validate' => 'color',
                'default'  => '#5F5F75',
            ),
        )
    ) );


    // -> START Typography
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Typography', 'campoal-tapo'),
        'id'     => 'typography',
        'desc'   => esc_html__('Set typography font size and weight', 'campoal-tapo'),
        'icon'   => 'el el-fontsize',
        'fields' => array(
            array(
                'id'       => 'conikal_default_font_field',
                'type'     => 'switch',
                'title'    => esc_html__('Custom font', 'campoal-tapo'),
                'subtitle' => esc_html__('Set all fonts by default font or including your font via children theme', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_theme_font_family_field',
                'type'     => 'select',
                'title'    => esc_html__('Theme font', 'campoal-tapo'),
                'subtitle' => esc_html__('Default font available in theme', 'campoal-tapo'),
                'desc'     => esc_html__('Select a font family', 'campoal-tapo'),
                'options'  => array(
                    'system'        => esc_html__('System font', 'campoal-tapo'),
                    'Sen'           => esc_html__('Sen', 'campoal-tapo'),
                    'CircularStd'   => esc_html__('CircularStd', 'campoal-tapo'),
                    'ProductSans'   => esc_html__('ProductSans', 'campoal-tapo'),
                    'custom'        => esc_html__('Custom font', 'campoal-tapo'),
                ),
                'default'  => 'Sen',
            ),
            array(
                'id'       => 'conikal_default_font_family_field',
                'type'     => 'text',
                'title'    => esc_html__('Custom font family', 'campoal-tapo'),
                'subtitle' => esc_html__('Your custom font name included via children theme.', 'campoal-tapo'),
                'desc'     => esc_html__('Leave blank to use default font.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => '',
            ),
            array(
                'id'                => 'conikal_body_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Body font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Main font display on all front-end', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font on all over the site.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '400',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '16px',
                    'line-height'       => '24px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '-0.2px',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_home_heading_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Home Heading Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Heading font style display on homepage caption', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for heading in hero section on homepage.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '700',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '56px',
                    'line-height'       => '64px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '-2.6px',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_home_subheading_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Home Sub-Heading Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Sub-Heading font style display on homepage caption', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for subheading in hero section on homepage.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '400',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '24px',
                    'line-height'       => '28px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '-1px',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_heading_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Heading Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Heading font display on all font-end', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for heading on all over the site.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '600',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '24px',
                    'line-height'       => '28px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '-1px',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_subheading_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Sub-Heading Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Sub-Heading font display on all font-end', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for sub heading on all over the site.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '400',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '16px',
                    'line-height'       => '18px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '-0.2px',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_page_heading_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Pages Heading Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Heading font display on pages, petition and single post', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for sing page heading.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '700',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '42px',
                    'line-height'       => '48px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '-2px',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_widget_title_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Widget Title Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Heading font of widget title.', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for widget title.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '700',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '24px',
                    'line-height'       => '38px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '-0.8px',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_title_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Post Title Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Heading font of post title display on blogs, post cards.', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for single post title.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '800',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '20px',
                    'line-height'       => '26px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '-0.6px',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_content_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Content Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Font of content on single post and petition page', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for main content on the pages.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '400',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '18px',
                    'line-height'       => '32px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '0',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_letter_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Letter Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Font of letter below content section on single petition page', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for letter section on single petition page.', 'campoal-tapo'),
                'color'             => false,
                'text-align'        => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '400',
                    'font-family'       => 'Sen',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '14px',
                    'line-height'       => '24px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => 'inherit',
                    'text-transform'    => 'inherit',
                ),
            ),
            array(
                'id'                => 'conikal_button_font_field',
                'type'              => 'typography',
                'title'             => esc_html__('Button Font', 'campoal-tapo'),
                'subtitle'          => esc_html__('Font of button display on all font-end', 'campoal-tapo'),
                'desc'              => esc_html__('Styling font for all over buttons.', 'campoal-tapo'),
                'color'             => false,
                'word-spacing'      => true,
                'letter-spacing'    => true,
                'text-align'        => false,
                'text-transform'    => true,
                'default'           => array(
                    'font-weight'       => '700',
                    'font-family'       => 'Open Sans',
                    'google'            => true,
                    'subsets'           => 'latin',
                    'font-size'         => '16px',
                    'line-height'       => '18px',
                    'word-spacing'      => 'inherit',
                    'letter-spacing'    => '-0.4px',
                    'text-transform'    => 'inherit',
                ),
            ),
        )
    ) );

    // -> START Fields & Requirement
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Fields', 'campoal-tapo'),
        'id'     => 'petition_fields',
        'desc'   => esc_html__('Manage visiable and requirement for user fields, petition fields and custom fields.', 'campoal-tapo'),
        'icon'   => 'el el-edit',
        'fields' => array(
            array(
                'id'       => 'conikal_p_category_field',
                'type'     => 'switch',
                'title'    => esc_html__('Category', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden category field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_topics_field',
                'type'     => 'switch',
                'title'    => esc_html__('Topics', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden topics field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_address_field',
                'type'     => 'switch',
                'title'    => esc_html__('Address', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden address field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_city_field',
                'type'     => 'switch',
                'title'    => esc_html__('City', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden city field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_coordinates_field',
                'type'     => 'switch',
                'title'    => esc_html__('Coordinates', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden coordinates field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_neighborhood_field',
                'type'     => 'switch',
                'title'    => esc_html__('Neighborhood', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden neighborhood field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_zip_field',
                'type'     => 'switch',
                'title'    => esc_html__('Zip Code', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden zip code field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_state_field',
                'type'     => 'switch',
                'title'    => esc_html__('State', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden state field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_country_field',
                'type'     => 'switch',
                'title'    => esc_html__('Country', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden country field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_receiver_field',
                'type'     => 'switch',
                'title'    => esc_html__('Receiver', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden receiver field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_position_field',
                'type'     => 'switch',
                'title'    => esc_html__('Position', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden position field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_goal_field',
                'type'     => 'switch',
                'title'    => esc_html__('Goal', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden goal field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_media_upload_field',
                'type'     => 'switch',
                'title'    => esc_html__('Media upload button', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden media upload button on editor', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START Fields Requirement
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Submit Requirement', 'campoal-tapo'),
        'id'     => 'fields_requirement',
        'desc'   => esc_html__('Set requirement for petition fields', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_p_category_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Category', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of category field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_topics_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Topics', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of topics field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_address_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Address', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of address field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_p_city_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('City', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of city field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_p_coordinates_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Coordinates', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of coordinates field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_p_neighborhood_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Neighborhood', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of neighborhood field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_p_zip_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Zip Code', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of zip code field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_p_state_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('State', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of state field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_p_country_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Country', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of country field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_p_receiver_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Receiver', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of receiver field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_p_position_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Position', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of position field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_p_goal_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Goal', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of goal field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_p_photo_video_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Photo & Video', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of photo & video field on submit petition page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );


    // -> START Category and topics
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Category & Topics', 'campoal-tapo'),
        'id'     => 'category_tags',
        'desc'   => esc_html__('Set maxinum of categories and topics on one petition.', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_maximum_category_field',
                'type'     => 'text',
                'title'    => esc_html__('Maximum Category', 'campoal-tapo'),
                'subtitle' => esc_html__('Maxinum of categories allowed on one petition', 'campoal-tapo'),
                'desc'     => esc_html__('Allow number only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 1,
            ),
            array(
                'id'       => 'conikal_maximum_topics_field',
                'type'     => 'text',
                'title'    => esc_html__('Maximum Topics', 'campoal-tapo'),
                'subtitle' => esc_html__('Maxinum of topics allowed on one petition', 'campoal-tapo'),
                'desc'     => esc_html__('Allow number only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 5,
            ),
        )
    ) );

    // -> START Guest fields
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Guest fields', 'campoal-tapo'),
        'id'     => 'guest_fields',
        'desc'   => esc_html__('Set requirement for fields on guest sign', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_guest_location_field',
                'type'     => 'switch',
                'title'    => esc_html__('Guest location', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden location field on guest sign section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch hidden or show.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_guest_country_field',
                'type'     => 'switch',
                'title'    => esc_html__('Guest country', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden country selection on guest sign section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch hidden or show.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_guest_zip_field',
                'type'     => 'switch',
                'title'    => esc_html__('Guest zip code', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden zip code on guest sign section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch hidden or show.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_guest_phone_field',
                'type'     => 'switch',
                'title'    => esc_html__('Guest phone number', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden phone number field on guest sign section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch hidden or show.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_guest_location_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Guest location requirement', 'campoal-tapo'),
                'subtitle' => esc_html__('Required location field on guest sign section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch Required or Not Required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_guest_country_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Guest country requirement', 'campoal-tapo'),
                'subtitle' => esc_html__('Required country field on guest sign section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch Required or Not Required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_guest_zip_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Guest zip code requirement', 'campoal-tapo'),
                'subtitle' => esc_html__('Required zip code field on guest sign section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch Required or Not Required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_guest_phone_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('Guest phone number requirement', 'campoal-tapo'),
                'subtitle' => esc_html__('Required phone number field on guest sign section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch Required or Not Required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
        )
    ) );


    // -> START User fields
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('User fields', 'campoal-tapo'),
        'id'     => 'user_fields',
        'desc'   => esc_html__('Set requirement for user fields', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_user_country_field',
                'type'     => 'switch',
                'title'    => esc_html__('User country', 'campoal-tapo'),
                'subtitle' => esc_html__('Enable the user country field on user settings', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_user_zip_field',
                'type'     => 'switch',
                'title'    => esc_html__('User zip code', 'campoal-tapo'),
                'subtitle' => esc_html__('Enable the user zip code field on user settings', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_user_gender_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('User gender', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of user gender field on user settings', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_user_birthday_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('User birthday', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of user birthday field on user settings', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_user_location_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('User location', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of user location field on user settings', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_user_zip_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('User zip code', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of user zip code field on user settings', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_user_country_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('User country', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of user country field on user settings', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_user_phone_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('User phone number', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of user birthday field on user settings', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_user_avatar_r_field',
                'type'     => 'switch',
                'title'    => esc_html__('User avatar', 'campoal-tapo'),
                'subtitle' => esc_html__('Requirement of user avatar field on user settings', 'campoal-tapo'),
                'desc'     => esc_html__('Switch required or not required.', 'campoal-tapo'),
                'on'       => esc_html__('Required', 'campoal-tapo'),
                'off'      => esc_html__('Not Required', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_user_gender_types_field',
                'type'     => 'checkbox',
                'title'    => esc_html__('Gender identity', 'campoal-tapo'),
                'subtitle' => esc_html__('The gender identity display on gender selection.', 'campoal-tapo'),
                'desc'     => esc_html__('Check the box to show the gender identity on selection.', 'campoal-tapo'),
                'options'  => array(
                    'male'          => esc_html__('Male', 'campoal-tapo'),
                    'female'        => esc_html__('Female', 'campoal-tapo'),
                    'transgender'   => esc_html__('Transgender', 'campoal-tapo'),
                    'gender_neutra' => esc_html__('Gender neutra', 'campoal-tapo'),
                    'non_binary'    => esc_html__('Non binary', 'campoal-tapo'),
                    'agender'       => esc_html__('Agender', 'campoal-tapo'),
                    'pangender'     => esc_html__('Pangender', 'campoal-tapo'),
                    'genderqueer'   => esc_html__('Genderqueer', 'campoal-tapo'),
                    'two_spirit'    => esc_html__('Two-spirit', 'campoal-tapo'),
                    'third_gender'  => esc_html__('Third gender', 'campoal-tapo'),
                    'two_spirit'    => esc_html__('Two-spirit', 'campoal-tapo'),
                ),
                'default' => array(
                    'male'          => '1',
                    'female'        => '1',
                    'transgender'   => '1',
                    'gender_neutra' => '0',
                    'non_binary'    => '0',
                    'agender'       => '0',
                    'pangender'     => '0',
                    'genderqueer'   => '0',
                    'two_spirit'    => '0',
                    'third_gender'  => '0',
                    'two_spirit'    => '0',
                )
            ),
        )
    ) );

    // -> START Registration fields
    Redux::set_section( $opt_name, array(
        'title'      => esc_html__('Registration fields', 'campoal-tapo'),
        'desc'       => esc_html__('Options for registration form', 'campoal-tapo'),
        'id'         => 'registration_form',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'conikal_format_separate_fullname_field',
                'type'     => 'select',
                'title'    => esc_html__('Separate fullname', 'campoal-tapo'),
                'subtitle' => esc_html__('Separate fullname to firstname and lastname after user registered', 'campoal-tapo'),
                'desc'     => esc_html__('Select an formarted of separate fullname.', 'campoal-tapo'),
                'options'  => array(
                    'first_s_middle_last' => esc_html__('First name | Middle Last name', 'campoal-tapo'),
                    'first_middle_s_last' => esc_html__('First name Middle | Last name', 'campoal-tapo'),
                    'last_s_middle_first' => esc_html__('Last name | Middle First name', 'campoal-tapo'),
                    'last_middle_s_first' => esc_html__('Last name Middle | First name', 'campoal-tapo')
                ),
                'default'  => 'first_s_middle_last',
            ),
            array(
                'id'       => 'conikal_short_display_name_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Short display name', 'campoal-tapo'),
                'subtitle' => esc_html__('Shorten the display name when creating a new account.', 'campoal-tapo'),
                'desc'     => esc_html__('Only display first character of first name or last name.', 'campoal-tapo'),
                'options'  => array(
                    'fullname'          => esc_html__('Full name', 'campoal-tapo'),
                    'firstname'         => esc_html__('First name', 'campoal-tapo'),
                    'lastname'           => esc_html__('Last name', 'campoal-tapo'),
                ),
                'default'  => 'fullname',
            ),
            array(
                'id'       => 'conikal_signup_newsletters_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Newsletters', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden signup for newsletter checkbox below registration form.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between hidden or checked and not checked.', 'campoal-tapo'),
                'options'  => array(
                    'none'       => esc_html__('Hidden', 'campoal-tapo'),
                    'checked'    => esc_html__('Checked', 'campoal-tapo'),
                    'not'    => esc_html__('Not Checked', 'campoal-tapo'),
                ),
                'default'  => 'checked',
            ),
            array(
                'id'       => 'conikal_choose_username_field',
                'type'     => 'switch',
                'title'    => esc_html__('Choose username', 'campoal-tapo'),
                'subtitle' => esc_html__('Enable enter their username field on sign up form', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_two_input_name_field',
                'type'     => 'switch',
                'title'    => esc_html__('Two field name', 'campoal-tapo'),
                'subtitle' => esc_html__('Split two boxes with first name and last name', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_repeat_password_field',
                'type'     => 'switch',
                'title'    => esc_html__('Repeat Password', 'campoal-tapo'),
                'subtitle' => esc_html__('Force the user to enter the password again when sign up', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_registration_gender_field',
                'type'     => 'switch',
                'title'    => esc_html__('Gender', 'campoal-tapo'),
                'subtitle' => esc_html__('Display gender field on registration form', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_registration_location_field',
                'type'     => 'switch',
                'title'    => esc_html__('Location', 'campoal-tapo'),
                'subtitle' => esc_html__('Display location field on registration form', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_registration_zip_field',
                'type'     => 'switch',
                'title'    => esc_html__('Zip code', 'campoal-tapo'),
                'subtitle' => esc_html__('Display zip code field on registration form', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_registration_country_field',
                'type'     => 'switch',
                'title'    => esc_html__('Country', 'campoal-tapo'),
                'subtitle' => esc_html__('Display country field on registration form', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_registration_phone_field',
                'type'     => 'switch',
                'title'    => esc_html__('Phone number', 'campoal-tapo'),
                'subtitle' => esc_html__('Display country field on registration form', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_registration_birthday_field',
                'type'     => 'switch',
                'title'    => esc_html__('Birthday', 'campoal-tapo'),
                'subtitle' => esc_html__('Display country field on registration form', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
        )
    ) );

    // -> START Export fields
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Export fields', 'campoal-tapo'),
        'id'     => 'export_fields',
        'desc'   => esc_html__('Allow or not allow fields in signature export file', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_export_user_id_field',
                'type'     => 'switch',
                'title'    => esc_html__('User ID', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export user ID data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_email_field',
                'type'     => 'switch',
                'title'    => esc_html__('Email address', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter email data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_export_phone_number_field',
                'type'     => 'switch',
                'title'    => esc_html__('Phone Number', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter phone number data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_export_date_field',
                'type'     => 'switch',
                'title'    => esc_html__('Signature date', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export signature date data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_ip_address_field',
                'type'     => 'switch',
                'title'    => esc_html__('IP Address', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export IP address data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_first_name_field',
                'type'     => 'switch',
                'title'    => esc_html__('First name', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter first name data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_last_name_field',
                'type'     => 'switch',
                'title'    => esc_html__('Last name', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter last name data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_gender_field',
                'type'     => 'switch',
                'title'    => esc_html__('Gender', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter gender data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_birthday_field',
                'type'     => 'switch',
                'title'    => esc_html__('Birthday', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter birthday data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_neigborhood_field',
                'type'     => 'switch',
                'title'    => esc_html__('Neigborhood', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter neigborhood data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_city_field',
                'type'     => 'switch',
                'title'    => esc_html__('City', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter City data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_state_field',
                'type'     => 'switch',
                'title'    => esc_html__('State', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter State data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_country_field',
                'type'     => 'switch',
                'title'    => esc_html__('Country', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter Country data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_zip_field',
                'type'     => 'switch',
                'title'    => esc_html__('Zip Code', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter zip code data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_export_reason_field',
                'type'     => 'switch',
                'title'    => esc_html__('Reason', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow or not allow export supporter Reason data in export file', 'campoal-tapo'),
                'desc'     => esc_html__('Switch allow or not allow.', 'campoal-tapo'),
                'on'       => esc_html__('Allow', 'campoal-tapo'),
                'off'      => esc_html__('Not Allow', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );
    // -> START Custom fields
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Custom fields', 'campoal-tapo'),
        'id'     => 'custom_fields',
        'desc'   => esc_html__('Manage custom fields for petitions', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_custom_fields_mode_field',
                'type'     => 'switch',
                'title'    => esc_html__('Custom fields', 'campoal-tapo'),
                'subtitle' => esc_html__('To enabled custom fields the Advanced Custom Fields plugin also needs to be installed and actived.', 'campoal-tapo'),
                'desc'     => esc_html__('Disabled will hidden custom fields on front-end, if you want disable at all let uninstall Advenced Custom Fields plugin.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_custom_fields_front_end_field',
                'type'     => 'switch',
                'title'    => esc_html__('Display custom fields', 'campoal-tapo'),
                'subtitle' => esc_html__('Display custom fields on single petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('If the custom fields is hidden it will still display allowed user enter custom fields on submit petition page.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
        )
    ) );

    // -> START Custom fields
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Password strength', 'campoal-tapo'),
        'id'     => 'password_strength_fields',
        'desc'   => esc_html__('Control password strength checker and set acceptable strength level.', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_password_strength_field',
                'type'     => 'switch',
                'title'    => esc_html__('Password strength', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hide password strength checker on all password fields.', 'campoal-tapo'),
                'desc'     => esc_html__('Password strength checker will visible below password fields.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_acceptable_strength_field',
                'type'     => 'select',
                'title'    => esc_html__('Acceptable strength', 'campoal-tapo'),
                'subtitle' => esc_html__('Minimum password strength for account registration.', 'campoal-tapo'),
                'desc'     => esc_html__('Acceptable password strength for account registration processing.', 'campoal-tapo'),
                'options'  => array(
                    1 => esc_html__('Very weak', 'campoal-tapo'),
                    2 => esc_html__('Weak', 'campoal-tapo'),
                    3 => esc_html__('Medium', 'campoal-tapo'),
                    4 => esc_html__('Strong', 'campoal-tapo')
                ),
                'default'  => 1,
            ),
        )
    ) );


    // -> START Search
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Search', 'campoal-tapo'),
        'id'     => 'search',
        'desc'   => esc_html__('Set options for search suggestion', 'campoal-tapo'),
        'icon'   => 'el el-search',
        'fields' => array(
            array(
                'id'       => 'conikal_s_min_characters_field',
                'type'     => 'text',
                'title'    => esc_html__('Minimum Characters', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of characters type in search input to show suggestion', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 3,
            ),
            array(
                'id'       => 'conikal_s_max_results_field',
                'type'     => 'text',
                'title'    => esc_html__('Maxinum Results', 'campoal-tapo'),
                'subtitle' => esc_html__('Number of results show on search suggestion', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 8,
            ),
            array(
                'id'       => 'conikal_s_type_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Type suggestion', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of dropdown when show search suggestion results', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between category or standard.', 'campoal-tapo'),
                'options'  => array(
                    'category'      => esc_html__('Category', 'campoal-tapo'),
                    'standard'      => esc_html__('Dtandard', 'campoal-tapo'),
                ),
                'default'  => 'category',
            ),
            array(
                'id'       => 'conikal_s_link_field',
                'type'     => 'switch',
                'title'    => esc_html__('Link', 'campoal-tapo'),
                'subtitle' => esc_html__('Link of items show on search suggestion dropdown', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_s_description_field',
                'type'     => 'switch',
                'title'    => esc_html__('Description', 'campoal-tapo'),
                'subtitle' => esc_html__('Description of items show on search suggestion dropdown', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_s_image_field',
                'type'     => 'switch',
                'title'    => esc_html__('Images', 'campoal-tapo'),
                'subtitle' => esc_html__('Images of items show on search suggestion dropdown', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_s_supporters_field',
                'type'     => 'switch',
                'title'    => esc_html__('Supporter', 'campoal-tapo'),
                'subtitle' => esc_html__('Supporter counter of items show on search suggestion dropdown', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START Filter
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Filter & Sort', 'campoal-tapo'),
        'id'     => 'filter',
        'desc'   => esc_html__('Set options for search filter and default sorting', 'campoal-tapo'),
        'icon'   => 'el el-filter',
        'fields' => array(
            array(
                'id'       => 'conikal_sortby_default_field',
                'type'     => 'select',
                'title'    => esc_html__('Default of Sort by', 'campoal-tapo'),
                'subtitle' => esc_html__('Default value of sort by option', 'campoal-tapo'),
                'desc'     => esc_html__('Choose type of sort.', 'campoal-tapo'),
                'options'  => array(
                    'name'          => esc_html__('Name', 'campoal-tapo'), 
                    'author'        => esc_html__('Author', 'campoal-tapo'),
                    'title'         => esc_html__('Title', 'campoal-tapo'),
                    'date'          => esc_html__('Date', 'campoal-tapo'),
                    'comment_count' => esc_html__('Comments', 'campoal-tapo'),
                    'supporters'    => esc_html__('Supporters', 'campoal-tapo'),
                    'views'         => esc_html__('Views', 'campoal-tapo')
                ),
                'default'  => 'date',
            ),
            array(
                'id'       => 'conikal_order_default_field',
                'type'     => 'select',
                'title'    => esc_html__('Default of Order', 'campoal-tapo'),
                'subtitle' => esc_html__('Default value of order option', 'campoal-tapo'),
                'desc'     => esc_html__('Choose type of order.', 'campoal-tapo'),
                'options'  => array(
                    'ASC'   => esc_html__('Ascending', 'campoal-tapo'),
                    'DESC'  => esc_html__('Descending', 'campoal-tapo'),
                ),
                'default'  => 'DESC',
            ),
            array(
                'id'       => 'conikal_f_category_field',
                'type'     => 'switch',
                'title'    => esc_html__('Category', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden category option on search filter section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_f_topic_field',
                'type'     => 'switch',
                'title'    => esc_html__('Topics', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden topics option on search filter section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_f_address_field',
                'type'     => 'switch',
                'title'    => esc_html__('Address', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden address option on search filter section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_f_country_field',
                'type'     => 'switch',
                'title'    => esc_html__('Country', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden country option on search filter section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_f_state_field',
                'type'     => 'switch',
                'title'    => esc_html__('State', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden state option on search filter section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_f_city_field',
                'type'     => 'switch',
                'title'    => esc_html__('City', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden city option on search filter section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_f_neighborhood_field',
                'type'     => 'switch',
                'title'    => esc_html__('Neighborhood', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden neighborhood option on search filter section', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );


    // -> START Shop
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Shop', 'campoal-tapo'),
        'id'     => 'shop',
        'desc'   => esc_html__('Set options for shop', 'campoal-tapo'),
        'icon'   => 'el el-shopping-cart',
        'fields' => array(
            /*
             array(
                'id'       => 'conikal_shop_header_style_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Shop Header', 'campoal-tapo'),
                'subtitle' => esc_html__('Shop header style', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between Standard or Simple.', 'campoal-tapo'),
                'options'  => array(
                    'standard'    => esc_html__('Standard', 'campoal-tapo'),
                    'simple'      => esc_html__('Simple', 'campoal-tapo'),
                ),
                'default'  => 'simple',
            ), */
            array(
                'id'       => 'conikal_shop_layout_field',
                'type'     => 'select',
                'title'    => esc_html__('Shop layout', 'campoal-tapo'),
                'subtitle' => esc_html__('Layout of shop display product', 'campoal-tapo'),
                'desc'     => esc_html__('Select a layout.', 'campoal-tapo'),
                'options'  => array(
                    'column-2' => esc_html__('2 Column', 'campoal-tapo'),
                    'column-3' => esc_html__('3 Column', 'campoal-tapo'),
                    'column-4' => esc_html__('4 Column', 'campoal-tapo')
                ),
                'default'  => 'column-3',
            ),
            array(
                'id'       => 'conikal_add_cart_style_field',
                'type'     => 'select',
                'title'    => esc_html__('Add to cart button', 'campoal-tapo'),
                'subtitle' => esc_html__('Set the style of add to cart button', 'campoal-tapo'),
                'desc'     => esc_html__('Select a style.', 'campoal-tapo'),
                'options'  => array(
                    'text' => esc_html__('Text and Icon', 'campoal-tapo'),
                    'icon' => esc_html__('Icon', 'campoal-tapo'),
                    'fluid' => esc_html__('Full', 'campoal-tapo'),
                    'not' => esc_html__('No display', 'campoal-tapo')
                ),
                'default'  => 'text',
            ),
            array(
                'id'       => 'conikal_cart_link_menu_field',
                'type'     => 'switch',
                'title'    => esc_html__('Cart link menu', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden cart link on header menu', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_cart_subtotal_field',
                'type'     => 'switch',
                'title'    => esc_html__('Cart subtotal', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden subtotal on cart link menu', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_cart_item_count_field',
                'type'     => 'switch',
                'title'    => esc_html__('Cart items count', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden items count on cart link menu', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_product_rating_field',
                'type'     => 'switch',
                'title'    => esc_html__('Product rating', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden product rating on card', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_product_excerpt_field',
                'type'     => 'switch',
                'title'    => esc_html__('Product exerpt', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden product excerpt on card', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START Citation Opinion
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Citation opinion', 'campoal-tapo'),
        'id'     => 'opinion',
        'desc'   => esc_html__('Set options for citation opinion', 'campoal-tapo'),
        'icon'   => 'el el-quote-alt',
        'fields' => array(
            array(
                'id'       => 'conikal_citation_field',
                'type'     => 'switch',
                'title'    => esc_html__('Citation', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow people add citaion on petition', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled show or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_citation_apply_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Citation apply', 'campoal-tapo'),
                'subtitle' => esc_html__('Enabled or disabled on all petition or single petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between global or single section.', 'campoal-tapo'),
                'options'  => array(
                    'global'         => esc_html__('Global', 'campoal-tapo'),
                    'single'    => esc_html__('Single', 'campoal-tapo'),
                ),
                'default'  => 'single',
            ),
            array(
                'id'       => 'conikal_citation_button_text_field',
                'type'     => 'text',
                'title'    => esc_html__('Citation button text', 'campoal-tapo'),
                'subtitle' => esc_html__('The text of button display on citation section.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => 'Send Citation',
            ),
            array(
                'id'       => 'conikal_citation_comment_field',
                'type'     => 'switch',
                'title'    => esc_html__('Citation comment', 'campoal-tapo'),
                'subtitle' => esc_html__('Comments display on single citation page.', 'campoal-tapo'),
                'desc'     => esc_html__('Hidden or show comments on citation.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_citation_fact_score_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Fact score position', 'campoal-tapo'),
                'subtitle' => esc_html__('Set where fact score and progress bar display.', 'campoal-tapo'),
                'desc'     => esc_html__('Desktop, Mobile, Citation list, Show all or Hidden position.', 'campoal-tapo'),
                'options'  => array(
                    'all'       => esc_html__('All', 'campoal-tapo'),
                    'desktop'   => esc_html__('Desktop', 'campoal-tapo'),
                    'mobile'    => esc_html__('Mobile', 'campoal-tapo'),
                    'list'      => esc_html__('Citation List', 'campoal-tapo'),
                    'hidden'    => esc_html__('Hidden', 'campoal-tapo'),
                ),
                'default'  => 'all',
            ),
            array(
                'id'       => 'conikal_citation_instant_add_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Citation instant add', 'campoal-tapo'),
                'subtitle' => esc_html__('Instant open add citation modal when sign petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Hidden or show citation instant add option.', 'campoal-tapo'),
                'options'  => array(
                    'none'       => esc_html__('Hidden', 'campoal-tapo'),
                    'checked'    => esc_html__('Checked', 'campoal-tapo'),
                    'not'    => esc_html__('Not Checked', 'campoal-tapo'),
                ),
                'default'  => 'checked',
            ),
            array(
                'id'       => 'conikal_citation_button_style_field',
                'type'     => 'select',
                'title'    => esc_html__('Button style', 'campoal-tapo'),
                'subtitle' => esc_html__('Style of agree and disagree opinion button', 'campoal-tapo'),
                'desc'     => esc_html__('Select a style.', 'campoal-tapo'),
                'options'  => array(
                    'one' => esc_html__('One style', 'campoal-tapo'),
                    'two' => esc_html__('Two style', 'campoal-tapo'),
                ),
                'default'  => 'two',
            ),
        )
    ) );

    // -> START Contribute
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Fundraising', 'campoal-tapo'),
        'id'     => 'fundraising',
        'desc'   => esc_html__('Set options for fundraising', 'campoal-tapo'),
        'icon'   => 'el el-usd',
        'fields' => array(
            /*
            array(
                'id'       => 'conikal_fundraising_stats_display_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Stats display', 'campoal-tapo'),
                'subtitle' => esc_html__('Choose the type of statistics display on fundraising', 'campoal-tapo'),
                'desc'     => esc_html__('Choose between donors or money.', 'campoal-tapo'),
                'options'  => array(
                    'donors'       => esc_html__('Donors', 'campoal-tapo'),
                    'income'    => esc_html__('Income', 'campoal-tapo'),
                ),
                'default'  => 'income',
            ),
            */
            array(
                'id'       => 'conikal_common_donation_form_field',
                'type'     => 'switch',
                'title'    => esc_html__('Common donation form', 'campoal-tapo'),
                'subtitle' => esc_html__('Display one donation form on all over petitions.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled show or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_common_form_id_field',
                'type'     => 'text',
                'title'    => esc_html__('Common donation form ID', 'campoal-tapo'),
                'subtitle' => esc_html__('Display one donation form on all over petitions.', 'campoal-tapo'),
                'desc'     => esc_html__('Set a Form ID or leave empty disable it.', 'campoal-tapo'),
                'validate' => 'numeric',
                ),
            array(
                'id'       => 'conikal_amount_contribute_field',
                'type'     => 'switch',
                'title'    => esc_html__('Amount of contribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden amount of contribute on donors page', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_fundraising_only_field',
                'type'     => 'switch',
                'title'    => esc_html__('Show fundraising only', 'campoal-tapo'),
                'subtitle' => esc_html__('Show only the fundraising campaign or show the entire fundraising petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Fundraising only', 'campoal-tapo'),
                'off'      => esc_html__('Petition & Fundraising', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START Contribution level badge
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Level badge', 'campoal-tapo'),
        'id'            => 'level_badge',
        'desc'          => esc_html__('Set level badge show on avatar', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_contribute_level_badge_field',
                'type'     => 'switch',
                'title'    => esc_html__('Contribution level badge', 'campoal-tapo'),
                'subtitle' => esc_html__('Show or hidden contribution level badge on avatar', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between show or hidden.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_give_form_id_field',
                'type'     => 'text',
                'title'    => esc_html__('Give Form ID', 'campoal-tapo'),
                'subtitle' => esc_html__('Form ID of Crowdfunding to calculating contribution level', 'campoal-tapo'),
                'desc'     => esc_html__('Set Form IDs (separator with comma, ex: 2321, 2122, 2113) or leave empty or "all" to get total donations amount of user.', 'campoal-tapo'),
                'validate' => 'no_html',
                ),
            array(
                'id'       => 'conikal_minimum_donation_amount_field',
                'type'     => 'text',
                'title'    => esc_html__('Minimum donation amount', 'campoal-tapo'),
                'subtitle' => esc_html__('Minimum of donation amount to display level badge', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 10,
            ),
            array(
                'id'       => 'conikal_level_badge_image_field',
                'type'     => 'media',
                'title'    => esc_html__('Badge Image', 'campoal-tapo'),
                'subtitle' => esc_html__('Image for level badge', 'campoal-tapo'),
                'desc'     => esc_html__('Upload squared or circular image with small size (16px).', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
        )
    ) );


    // -> START Contribution level badge
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Button labels', 'campoal-tapo'),
        'id'            => 'button_label',
        'desc'          => esc_html__('Set button label option for donation form', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_button_labels_field',
                'type'     => 'multi_text',
                'title'    => esc_html__('Button labels', 'campoal-tapo'),
                'subtitle' => esc_html__('Label of button show on contribute submit page select by user', 'campoal-tapo'),
                'desc'     => esc_html__('Add multi label text. Not allowed html tag.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => array(
                    0   => esc_html__('Contribute', 'campoal-tapo'),
                    1   => esc_html__('Donate', 'campoal-tapo'),
                    2   => esc_html__('Support', 'campoal-tapo'),
                ),
            ),
        )
    ) );

    // -> START Service fees
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Service fees', 'campoal-tapo'),
        'id'            => 'service_fees',
        'desc'          => esc_html__('Set service fees and Transaction fees for donations', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_service_charge_field',
                'type'     => 'text',
                'title'    => esc_html__('Service charge (%)', 'campoal-tapo'),
                'subtitle' => esc_html__('The percentage that admin receives per donation', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 5,
            ),
            array(
                'id'       => 'conikal_transaction_fee_field',
                'type'     => 'text',
                'title'    => esc_html__('Transaction fee (%)', 'campoal-tapo'),
                'subtitle' => esc_html__('The percentage that donor pay for the payment method', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 3,
            ),
        )
    ) );

    // -> START Payout
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Payout methods', 'campoal-tapo'),
        'id'            => 'payout_methods',
        'desc'          => esc_html__('Control withdraw methods and set minimum payout fee.', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_withdrawal_paypal_field',
                'type'     => 'switch',
                'title'    => esc_html__('Withdraw PayPal', 'campoal-tapo'),
                'subtitle' => esc_html__('Payout to fundraiser via Paypal', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_minimum_withdrawal_paypal_field',
                'type'     => 'text',
                'title'    => esc_html__('Minimum Withdraw PayPal', 'campoal-tapo'),
                'subtitle' => esc_html__('Minimum of money when user submit a request withdraw via Paypal', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 50,
            ),
            array(
                'id'       => 'conikal_withdrawal_payoneer_field',
                'type'     => 'switch',
                'title'    => esc_html__('Withdraw Payoneer', 'campoal-tapo'),
                'subtitle' => esc_html__('Payout to fundraiser via Payoneer', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_minimum_withdrawal_payoneer_field',
                'type'     => 'text',
                'title'    => esc_html__('Minimum Withdraw Payoneer', 'campoal-tapo'),
                'subtitle' => esc_html__('Minimum of money when user submit a request withdraw via Payoneer', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 100,
            ),
            array(
                'id'       => 'conikal_withdrawal_bank_field',
                'type'     => 'switch',
                'title'    => esc_html__('Withdraw Bank Transfer', 'campoal-tapo'),
                'subtitle' => esc_html__('Payout to fundraiser via Bank Transfer', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_minimum_withdrawal_bank_field',
                'type'     => 'text',
                'title'    => esc_html__('Minimum Withdraw Bank Transfer', 'campoal-tapo'),
                'subtitle' => esc_html__('Minimum of money when user submit a request withdraw via Bank transfer', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 200,
            ),
            array(
                'id'       => 'conikal_withdrawal_bitcoin_field',
                'type'     => 'switch',
                'title'    => esc_html__('Withdraw Bitcoin', 'campoal-tapo'),
                'subtitle' => esc_html__('Payout to fundraiser via Bitcoin', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_minimum_withdrawal_bitcoin_field',
                'type'     => 'text',
                'title'    => esc_html__('Minimum Withdraw Bitcoin', 'campoal-tapo'),
                'subtitle' => esc_html__('Minimum of money when user submit a request withdraw via Bitcoin', 'campoal-tapo'),
                'desc'     => esc_html__('Set number format only.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 100,
            ),
            array(
                'id'       => 'conikal_bitcoin_networks_field',
                'type'     => 'multi_text',
                'title'    => esc_html__('Bitcoin networks', 'campoal-tapo'),
                'subtitle' => esc_html__('Add a bitcoin network that you support withdrawals', 'campoal-tapo'),
                'desc'     => esc_html__('Add multi label text. Not allowed html tag.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => array(
                    0     => esc_html__('SegWit', 'campoal-tapo'),
                    1     => esc_html__('Lightning', 'campoal-tapo'),
                ),
            ),
        )
    ) );

    // -> START Notication
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Notification', 'campoal-tapo'),
        'id'            => 'notification',
        'icon'          => 'el el-globe',
        'desc'          => esc_html__('Show and custom notification toast for user.', 'campoal-tapo'),
        'subsection'    => false,
        'fields' => array(
            array(
                'id'       => 'conikal_toast_position_field',
                'type'     => 'select',
                'title'    => esc_html__('Toast position', 'campoal-tapo'),
                'subtitle' => esc_html__('Sets where the toast can be displayed.', 'campoal-tapo'),
                'desc'     => esc_html__('Can be top right, top center, top left, bottom right, bottom center and bottom left.', 'campoal-tapo'),
                'options'  => array(
                    'top right' => esc_html__('Top right', 'campoal-tapo'),
                    'top center' => esc_html__('Top center', 'campoal-tapo'),
                    'top left' => esc_html__('Top left', 'campoal-tapo'),
                    'bottom right' => esc_html__('Bottom right', 'campoal-tapo'),
                    'bottom center' => esc_html__('Bottom center', 'campoal-tapo'),
                    'bottom left' => esc_html__('Bottom left', 'campoal-tapo'),
                ),
                'default'  => 'bottom right',
            ),
            array(
                'id'       => 'conikal_toast_transiation_show_field',
                'type'     => 'select',
                'title'    => esc_html__('Toast transiation show', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of transiation when show a toast.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a transiation.', 'campoal-tapo'),
                'options'  => array(
                    'scale' => esc_html__('scale', 'campoal-tapo'),
                    'zoom' => esc_html__('zoom', 'campoal-tapo'),
                    'fade' => esc_html__('fade', 'campoal-tapo'),
                    'fade up' => esc_html__('fade up', 'campoal-tapo'),
                    'fade down' => esc_html__('fade down', 'campoal-tapo'),
                    'fade left' => esc_html__('fade left', 'campoal-tapo'),
                    'fade right' => esc_html__('fade right', 'campoal-tapo'),
                    'horizontal flip' => esc_html__('horizontal flip', 'campoal-tapo'),
                    'vertical flip' => esc_html__('vertical flip', 'campoal-tapo'),
                    'fly left' => esc_html__('fly left', 'campoal-tapo'),
                    'fly right' => esc_html__('fly right', 'campoal-tapo'),
                    'fly up' => esc_html__('fly up', 'campoal-tapo'),
                    'fly down' => esc_html__('fly down', 'campoal-tapo'),
                    'swing left' => esc_html__('swing left', 'campoal-tapo'),
                    'swing right' => esc_html__('swing right', 'campoal-tapo'),
                    'swing up' => esc_html__('swing up', 'campoal-tapo'),
                    'swing down' => esc_html__('swing down', 'campoal-tapo'),
                    'browse' => esc_html__('browse', 'campoal-tapo'),
                    'browse right' => esc_html__('browse right', 'campoal-tapo'),
                    'slide down' => esc_html__('slide down', 'campoal-tapo'),
                    'slide up' => esc_html__('slide up', 'campoal-tapo'),
                    'slide left' => esc_html__('slide left', 'campoal-tapo'),
                    'slide left' => esc_html__('slide left', 'campoal-tapo'),
                ),
                'default'  => 'fly left',
            ),
            array(
                'id'       => 'conikal_toast_transiation_hide_field',
                'type'     => 'select',
                'title'    => esc_html__('Toast transiation hidden', 'campoal-tapo'),
                'subtitle' => esc_html__('Type of transiation when hidden a toast.', 'campoal-tapo'),
                'desc'     => esc_html__('Select a transiation.', 'campoal-tapo'),
                'options'  => array(
                    'scale' => esc_html__('scale', 'campoal-tapo'),
                    'zoom' => esc_html__('zoom', 'campoal-tapo'),
                    'fade' => esc_html__('fade', 'campoal-tapo'),
                    'fade up' => esc_html__('fade up', 'campoal-tapo'),
                    'fade down' => esc_html__('fade down', 'campoal-tapo'),
                    'fade left' => esc_html__('fade left', 'campoal-tapo'),
                    'fade right' => esc_html__('fade right', 'campoal-tapo'),
                    'horizontal flip' => esc_html__('horizontal flip', 'campoal-tapo'),
                    'vertical flip' => esc_html__('vertical flip', 'campoal-tapo'),
                    'fly left' => esc_html__('fly left', 'campoal-tapo'),
                    'fly right' => esc_html__('fly right', 'campoal-tapo'),
                    'fly up' => esc_html__('fly up', 'campoal-tapo'),
                    'fly down' => esc_html__('fly down', 'campoal-tapo'),
                    'swing left' => esc_html__('swing left', 'campoal-tapo'),
                    'swing right' => esc_html__('swing right', 'campoal-tapo'),
                    'swing up' => esc_html__('swing up', 'campoal-tapo'),
                    'swing down' => esc_html__('swing down', 'campoal-tapo'),
                    'browse' => esc_html__('browse', 'campoal-tapo'),
                    'browse right' => esc_html__('browse right', 'campoal-tapo'),
                    'slide down' => esc_html__('slide down', 'campoal-tapo'),
                    'slide up' => esc_html__('slide up', 'campoal-tapo'),
                    'slide left' => esc_html__('slide left', 'campoal-tapo'),
                    'slide left' => esc_html__('slide left', 'campoal-tapo'),
                ),
                'default'  => 'fly left',
            ),
            array(
                'id'       => 'conikal_toast_show_duration_field',
                'type'     => 'text',
                'title'    => esc_html__('Show duration', 'campoal-tapo'),
                'subtitle' => esc_html__('The time of transiation toast show.', 'campoal-tapo'),
                'desc'     => esc_html__('Set in minisecound eg. 800.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 800,
            ),
            array(
                'id'       => 'conikal_toast_hide_duration_field',
                'type'     => 'text',
                'title'    => esc_html__('Hide duration', 'campoal-tapo'),
                'subtitle' => esc_html__('The time of transiation toast show.', 'campoal-tapo'),
                'desc'     => esc_html__(' Set in minisecound eg. 500.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 500,
            ),
            array(
                'id'       => 'conikal_toast_display_time_field',
                'type'     => 'text',
                'title'    => esc_html__('Display time', 'campoal-tapo'),
                'subtitle' => esc_html__('Set the time (in ms) of the toast appearance. ', 'campoal-tapo'),
                'desc'     => esc_html__('Set 0 to disable the automatic dismissal. Set auto to calculate the time by the given amount of words within the toast', 'campoal-tapo'),
                'default'  => 'auto',
            ),
            array(
                'id'       => 'conikal_toast_remind_time_field',
                'type'     => 'text',
                'title'    => esc_html__('Remind time', 'campoal-tapo'),
                'subtitle' => esc_html__('Set the times will show toast again after click later button.', 'campoal-tapo'),
                'desc'     => esc_html__(' Set in minutes eg. 60.', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 60,
            ),
            array(
                'id'       => 'conikal_toast_newest_on_top_field',
                'type'     => 'switch',
                'title'    => esc_html__('Newest on top', 'campoal-tapo'),
                'subtitle' => esc_html__('Define if new toasts should be displayed above the others.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_toast_compact_field',
                'type'     => 'switch',
                'title'    => esc_html__('Compact', 'campoal-tapo'),
                'subtitle' => esc_html__('Enabled will display the toast in a fixed width, disabled displays the toast responsively with dynamic width', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START Custom notification
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Custom notification', 'campoal-tapo'),
        'id'     => 'custom_notification',
        'desc'   => esc_html__('Enable notification toast and change the text of notification', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_toast_update_profile_field',
                'type'     => 'switch',
                'title'    => esc_html__('Update profile', 'campoal-tapo'),
                'subtitle' => esc_html__('Remind user update their profile if is not complete.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_toast_set_password_field',
                'type'     => 'switch',
                'title'    => esc_html__('Set new password.', 'campoal-tapo'),
                'subtitle' => esc_html__('Remind new user set new passowrd if sign up via social or sign petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_toast_welcome_field',
                'type'     => 'switch',
                'title'    => esc_html__('Welcome', 'campoal-tapo'),
                'subtitle' => esc_html__('Show welcome notification for new user if they are complete profile and verified.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_toast_welcome_title_field',
                'type'     => 'text',
                'title'    => esc_html__('Welcome title', 'campoal-tapo'),
                'subtitle' => esc_html__('Set title for welcome notification toast.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed text only and variables: %1$s is user display name, %2$s is site name.', 'campoal-tapo'),
                'default'  => 'Welcome to %2$s!',
            ),
            array(
                'id'       => 'conikal_toast_welcome_message_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Welcome title', 'campoal-tapo'),
                'subtitle' => esc_html__('Set title for welcome notification toast.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %1$s is user display name, %2$s is site name.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => 'Hi %1$s! Congratulations on being a %2$s member, start exploring the campaigns and support the petitions you are interested.',
            ),
            array(
                'id'       => 'conikal_toast_welcome_button_url_field',
                'type'     => 'text',
                'title'    => esc_html__('Welcome button url', 'campoal-tapo'),
                'subtitle' => esc_html__('The page blow welcome message when user click.', 'campoal-tapo'),
                'desc'     => esc_html__('Set URI of page.', 'campoal-tapo'),
                'default'  => '/all-campaigns/',
            ),
            array(
                'id'       => 'conikal_toast_welcome_button_text_field',
                'type'     => 'text',
                'title'    => esc_html__('Welcome button text', 'campoal-tapo'),
                'subtitle' => esc_html__('Set text of action button blow message.', 'campoal-tapo'),
                'desc'     => esc_html__('Set by text string only', 'campoal-tapo'),
                'default'  => 'Explore',
            ),
        )
    ) );

    // -> START Verify notification
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Verify notification', 'campoal-tapo'),
        'id'     => 'verify_notification',
        'desc'   => esc_html__('Select transition type and position of verify notification sidebar', 'campoal-tapo'),
        'subsection' => true,
        'fields' => array(
            array(
                'id'       => 'conikal_verify_notification_style_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Notification style', 'campoal-tapo'),
                'subtitle' => esc_html__('Notification style of verify notification sidebar', 'campoal-tapo'),
                'desc'     => esc_html__('Choose sidebar style or toast style for verify notification.', 'campoal-tapo'),
                'options'  => array(
                    'toast'    => esc_html__('Toast', 'campoal-tapo'),
                    'sidebar'      => esc_html__('Sidebar', 'campoal-tapo'),
                ),
                'default'  => 'toast',
            ),
            array(
                'id'       => 'conikal_verify_notification_transition_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Transition type', 'campoal-tapo'),
                'subtitle' => esc_html__('Transition type of verify notification sidebar', 'campoal-tapo'),
                'desc'     => esc_html__('Choose overlay display over web page or push to display as segment on web page.', 'campoal-tapo'),
                'options'  => array(
                    'overlay'    => esc_html__('Overlay', 'campoal-tapo'),
                    'push'      => esc_html__('Push', 'campoal-tapo'),
                ),
                'default'  => 'overlay',
            ),
            array(
                'id'       => 'conikal_verify_notification_position_field',
                'type'     => 'button_set',
                'title'    => esc_html__('Position', 'campoal-tapo'),
                'subtitle' => esc_html__('Position of verify notification sidebar', 'campoal-tapo'),
                'desc'     => esc_html__('Set verify notification sidebar at top or bottom.', 'campoal-tapo'),
                'options'  => array(
                    'top'    => esc_html__('Top', 'campoal-tapo'),
                    'bottom'      => esc_html__('Bottom', 'campoal-tapo'),
                ),
                'default'  => 'bottom',
            ),
            array(
                'id'       => 'conikal_verify_notification_dimmer_field',
                'type'     => 'switch',
                'title'    => esc_html__('Dim page', 'campoal-tapo'),
                'subtitle' => esc_html__('Overlay all page with a opacity black color', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_verify_notification_closable_field',
                'type'     => 'switch',
                'title'    => esc_html__('Closable & Later', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow user close verify notification sidebar or clickable later button.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START Email notification
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Email', 'campoal-tapo'),
        'id'     => 'email',
        'desc'   => esc_html__('Set options for email notification', 'campoal-tapo'),
        'icon'   => 'el el-envelope',
        'fields' => array(
            array(
                'id'       => 'conikal_email_logo_field',
                'type'     => 'media',
                'title'    => esc_html__('Email Logo', 'campoal-tapo'),
                'subtitle' => esc_html__('Logo display on email template', 'campoal-tapo'),
                'desc'     => esc_html__('Upload image. Recommended use PNG format.', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
            array(
                'id'       => 'conikal_sender_name_field',
                'type'     => 'text',
                'title'    => esc_html__('Sender Name', 'campoal-tapo'),
                'subtitle' => esc_html__('This name will display on email sent for user', 'campoal-tapo'),
                'desc'     => esc_html__('Choose the name you want display it for user on mail.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => get_option('blogname'),
            ),
            array(
                'id'       => 'conikal_sender_email_field',
                'type'     => 'text',
                'title'    => esc_html__('Sender Email', 'campoal-tapo'),
                'subtitle' => esc_html__('This email will display on email sent for user', 'campoal-tapo'),
                'desc'     => esc_html__('Choose any email you want, can use not exist email like noreply@example.com', 'campoal-tapo'),
                'validate' => 'email',
                'default'  => get_option('admin_email'),
            ),
            array(
                'id'       => 'conikal_email_header_field',
                'type'     => 'switch',
                'title'    => esc_html__('Email header', 'campoal-tapo'),
                'subtitle' => esc_html__('Use custom header for email', 'campoal-tapo'),
                'desc'     => esc_html__('Some email service provider not support custom header so you can disable header if it\'s not support.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_verification_email_field',
                'type'     => 'switch',
                'title'    => esc_html__('User verification email', 'campoal-tapo'),
                'subtitle' => esc_html__('Send verification email for user when registered', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_force_verify_field',
                'type'     => 'switch',
                'title'    => esc_html__('Force verify email', 'campoal-tapo'),
                'subtitle' => esc_html__('Disabled button for sign and submit petition if email is not verified.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_new_petition_confirm_field',
                'type'     => 'switch',
                'title'    => esc_html__('New Petition confirm', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for petition owner when new petition submited successfully', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_new_crowdfunding_confirm_field',
                'type'     => 'switch',
                'title'    => esc_html__('New Crowdfunding confirm', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for campaign owner when new crowdfunding submited successfully', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_new_petition_field',
                'type'     => 'switch',
                'title'    => esc_html__('New Petition', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new petition submited', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_edit_petition_field',
                'type'     => 'switch',
                'title'    => esc_html__('Edit Petition', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new edit petition', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_new_crowdfunding_field',
                'type'     => 'switch',
                'title'    => esc_html__('New Crowdfunding', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new crowdfunding project submited', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_edit_crowdfunding_field',
                'type'     => 'switch',
                'title'    => esc_html__('Edit Crowdfunding', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new update crowdfunding project', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_new_contribute_field',
                'type'     => 'switch',
                'title'    => esc_html__('New Contribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new contribute submited', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_edit_contribute_field',
                'type'     => 'switch',
                'title'    => esc_html__('Edit Contribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new edit contribute', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_new_citation_field',
                'type'     => 'switch',
                'title'    => esc_html__('New Citation', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new citation', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_edit_citation_field',
                'type'     => 'switch',
                'title'    => esc_html__('Edit Citation', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have edit citation', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_new_update_field',
                'type'     => 'switch',
                'title'    => esc_html__('New Update', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new update of petition', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_edit_update_field',
                'type'     => 'switch',
                'title'    => esc_html__('Edit Update', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new edit update of petition', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_update_supporter_field',
                'type'     => 'switch',
                'title'    => esc_html__('Update notification', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for supporters when have new update of petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled. Please active and integrate SendinBlue to use this feature.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_new_signature_field',
                'type'     => 'switch',
                'title'    => esc_html__('New signature', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new supporter', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_signature_supporter_field',
                'type'     => 'switch',
                'title'    => esc_html__('Signature confirm', 'campoal-tapo'),
                'subtitle' => esc_html__('Send confirm email for user when they signed petition', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_new_user_signup_field',
                'type'     => 'switch',
                'title'    => esc_html__('Admin new user registered', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for admin when have new user registered', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_new_account_confirm_field',
                'type'     => 'switch',
                'title'    => esc_html__('New account confirm', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for new user with account infomation', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_co_author_invite_email_field',
                'type'     => 'switch',
                'title'    => esc_html__('Co-author invite notification', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email for co-author when main author invite them join team.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_decision_maker_new_petition_field',
                'type'     => 'switch',
                'title'    => esc_html__('Decision maker new petition', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email to decision maker when have new petition to them.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_decision_maker_new_update_field',
                'type'     => 'switch',
                'title'    => esc_html__('Decision maker new update', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email to decision maker when have new update on petition to them.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_decision_maker_petition_victory_field',
                'type'     => 'switch',
                'title'    => esc_html__('Decision maker petition victory', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email to decision maker when petition to the declare victory.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_decision_maker_new_signature_field',
                'type'     => 'switch',
                'title'    => esc_html__('Decision maker new signature', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email to decision maker when petition have new signature.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_decision_maker_new_milestone_field',
                'type'     => 'switch',
                'title'    => esc_html__('Decision maker new milestone', 'campoal-tapo'),
                'subtitle' => esc_html__('Send notification email to decision maker when have new milestone on petition to them.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    // -> START General templates
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('General templates', 'campoal-tapo'),
        'id'            => 'email_templates',
        'desc'          => esc_html__('Edit email template apply for all email', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_enable_general_email_template_field',
                'type'     => 'switch',
                'title'    => esc_html__('Use general email template', 'campoal-tapo'),
                'subtitle' => esc_html__('Apply general template for email sending for user and admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_general_email_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('General email template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template apply for all email sending for user and admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url%, %blog_name%, %main_color%, %segment_color%, %email_subject%, %email_content%. Use Codepen to edit email template', 'campoal-tapo') . ' <a href="https://codepen.io/pen/" target="_blank">' . esc_html__('codepen.io', 'campoal-tapo') . '</a>',
                'mode'     => 'html',
                'default'  => function_exists('conikal_general_email_template') ? conikal_general_email_template() : '',
            ),
        )
    ) );


    // -> START User templates
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('User templates', 'campoal-tapo'),
        'id'            => 'user_email_templates',
        'desc'          => esc_html__('Edit email notification template send for users', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_enable_custom_template_petition_update_field',
                'type'     => 'switch',
                'title'    => esc_html__('Supporter update custom template', 'campoal-tapo'),
                'subtitle' => esc_html__('Use custom petition update template instead use general template.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_supporter_petition_update_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Supporter petition update subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of petition update send for supporters.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only. Use with variables %petition_title%, %update_title%', 'campoal-tapo'),
                'default'  => esc_html__('New update %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_supporter_petition_update_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Supporter petition update template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for user to when have new petition update.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %post_edit_link%, %petition_title%, %petition_link%, %update_title%, %update_link%, %update_content%, %main_color%,%heading_color%,%subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_supporter_petition_update_email_template') ? conikal_supporter_petition_update_email_template() : '',
            ),
            array(
                'id'       => 'conikal_verification_email_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Verification email subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of verification email.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('Activate your new account %user_login%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_verification_email_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Verification email template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for user to verify email after registered.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %user_login%, %%user_email%, %user_first_name%, %user_last_name%, %active_account_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_verification_email_template') ? conikal_verification_email_template() : '',
            ),
            array(
                'id'       => 'conikal_change_email_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Verification new email subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of change email.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('Confirm your new email %user_login%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_change_email_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Change email template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for user to verify email changed.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %user_login%, %%user_email%, %user_first_name%, %user_last_name%, %active_account_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_change_email_template') ? conikal_change_email_template() : '',
            ),
            array(
                'id'       => 'conikal_email_signature_confirm_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New signature confirm subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of confirm new signature email send for supporter.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('You signed successfully %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_email_signature_confirm_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Signature confirm template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for supporter after signing petition success.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %supporter_name%, %supporter_email%, %petition_title%, %petition_link%, %petition_thumbnail%, %join_date%, %main_color%,%heading_color%,%subheading_color%, %template_uri%, %reason%, %remove_signature%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_email_signature_confirm_template') ? conikal_email_signature_confirm_template() : '',
            ),
            array(
                'id'       => 'conikal_email_new_petition_confirm_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New petition confirm subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of confirm new petition submited email send for petition owner.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only. Use with variables %petition_title%', 'campoal-tapo'),
                'default'  => esc_html__('Your petition submited successfully %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_email_new_petition_confirm_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Petition submitted confirm template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for petition owner after submit petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables:  %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %petition_title%, %petition_link%, %petition_thumbnail%, %petition_dashboard_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_email_new_petition_confirm_template') ? conikal_email_new_petition_confirm_template() : '',
            ),
            array(
                'id'       => 'conikal_email_new_crowdfunding_confirm_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New crowdfunding confirm subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of confirm new crowdfunding submited email send for petition owner.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only. Use with variables %crowdfunding_title%', 'campoal-tapo'),
                'default'  => esc_html__('Your crowdfunding submited successfully %crowdfunding_title%', 'campoal-tapo'),
            ),
             array(
                'id'       => 'conikal_email_new_crowdfunding_confirm_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Crowdfunding submitted confirm template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for petition owner after submit crowdfunding.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables:  %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %crowdfunding_title%, %crowdfunding_link%, %crowdfunding_thumbnail%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_email_new_crowdfunding_confirm_template') ? conikal_email_new_crowdfunding_confirm_template() : '',
            ),
            array(
                'id'       => 'conikal_signup_confirm_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New account confirm subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of email template send for user when they register successful.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('Your username and password %blog_name%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_signup_confirm_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New account confirm template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for user when they register successful.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %user_login%, %user_email%, %user_first_name%, %user_last_name%, %user_pass%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_signup_confirm_template') ? conikal_signup_confirm_template() : '',
            ),
            array(
                'id'       => 'conikal_forgot_pass_email_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Reset password subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of email template send for user when user ask reset password.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('Request Password Reset for %user_login%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_forgot_pass_email_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Reset password template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for user when user ask reset password.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %user_login%, %%user_email%, %security_code%, %reset_pass_link%, %comment_edit_link%, %petition_title%, %petition_link%, %petition_thumbnail%, %main_color%,%heading_color%,%subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_forgot_pass_email_template') ? conikal_forgot_pass_email_template() : '',
            ),
            array(
                'id'       => 'conikal_invite_decision_email_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Invite decision template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for decision makers invite them response petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %invite_name%, %invite_decision_name%, %invite_title%, %%invite_subject%, %invite_message% %invite_link%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_invite_decision_email_template') ? conikal_invite_decision_email_template() : '',
            ),
            array(
                'id'       => 'conikal_invite_co_author_email_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Invite co author subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of email template send for co-author who invited by author join the team.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('You are invited to be a co-author %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_invite_co_author_email_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Invite co author template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for co-author who invited by author join the team.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %co_author_name%, %author_name%, %petition_title%, %petition_link%, %petition_dashboard_link%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_invite_co_author_email_template') ? conikal_invite_co_author_email_template() : '',
            ),
        )
    ) );

    // -> START Admin templates
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Admin templates', 'campoal-tapo'),
        'id'            => 'admin_email_templates',
        'desc'          => esc_html__('Edit email notification template send for admin', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_admin_new_petition_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New petition subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new petition email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('An Petition Submitted %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_new_petition_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New petition template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %post_edit_link%, %petition_title%, %petition_link%, %main_color%,%heading_color%,%subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_new_petition_template') ? conikal_admin_new_petition_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_update_petition_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Update petition subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of update petition email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('An Petition Updated %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_update_petition_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Update petition template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new update petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %post_edit_link%, %petition_title%, %petition_link%, %main_color%,%heading_color%,%subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_update_petition_template') ? conikal_admin_update_petition_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_new_citation_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New citation subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new citation email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('A New Citation Submited %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_new_citation_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New citation template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new citation.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %citation_title%, %citation_link%, %post_edit_link%, %petition_title%, %petition_link%, %main_color%,%heading_color%,%subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_new_citation_notification_template') ? conikal_admin_new_citation_notification_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_update_citation_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Update citation subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of update citation email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('An Citation Changed %citation_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_update_citation_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Edit citation template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new update citation.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %citation_title%, %citation_link%, %post_edit_link%, %petition_title%, %petition_link%, %main_color%,%heading_color%,%subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_edit_citation_notification_template') ? conikal_admin_edit_citation_notification_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_new_update_campaign_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New update campaign subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new update campaign email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('New Update on Petition %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_new_update_campaign_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New update campaign template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new update campaign.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %update_title%, %update_link%, %post_edit_link%, %petition_title%, %petition_link%, %main_color%,%heading_color%,%subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_new_update_campaign_template') ? conikal_admin_new_update_campaign_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_edit_update_campaign_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New edit update campaign subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new edit update citation email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('Petition Update Changed %update_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_edit_update_campaign_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New edit update campaign template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new edit update campaign.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %update_title%, %update_link%, %post_edit_link%, %petition_title%, %petition_link%, %main_color%,%heading_color%,%subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_edit_update_campaign_template') ? conikal_admin_edit_update_campaign_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_crowdfunding_submit_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New crowdfunding subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new crowdfunding subject email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('A Crowdfunding Submitted %crowdfunding_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_crowdfunding_submit_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New crowdfunding template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new crowdfunding.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %post_edit_link%, %crowdfunding_title%, %crowdfunding_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_crowdfunding_submit_template') ? conikal_admin_crowdfunding_submit_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_crowdfunding_update_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New crowdfunding subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new crowdfunding subject email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('A Crowdfunding Changed %crowdfunding_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_crowdfunding_update_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New update crowdfunding template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new update crowdfunding.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %post_edit_link%, %crowdfunding_title%, %crowdfunding_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_crowdfunding_update_template') ? conikal_admin_crowdfunding_update_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_contribute_submit_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New contribute subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new contribute subject email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('A Contribute Submitted %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_contribute_submit_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New contribute template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new contribute.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%,  %post_edit_link%, %petition_title%, %petition_link%, %contribute_title%, %contribute_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_contribute_submit_template') ? conikal_admin_contribute_submit_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_contribute_update_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Update contribute subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of update contribute email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('An Contribute Changed %contribute_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_contribute_update_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New update contribute template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new update_contribute.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %author_name%, %author_email%, %author_link%, %post_edit_link%, %petition_title%, %petition_link%, %contribute_title%, %contribute_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_contribute_update_template') ? conikal_admin_contribute_update_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_new_comment_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New comment subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new commment email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('A New Commment submitted %comment_author%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_new_comment_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New comment template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new comment on petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %post_title%, %comment_author%, %comment_author_email%, %comment_author_IP%, %comment_agent%, %comment_author_url%, %comment_content%, %comment_link%, %home_url%, %logo_url%, %blog_name%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_new_comment_template') ? conikal_admin_new_comment_template() : '',
            ),
            array(
                'id'       => 'conikal_admin_new_signature_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New signature subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new signature email send for admin.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('New Signature on %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_admin_new_signature_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New signature template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when someone was sign a petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %supporter_name%, %supporter_email%, %petition_title%, %petition_link%, %petition_thumbnail%, %join_date%, %main_color%,%heading_color%,%subheading_color%, %template_uri%, %reason%, %remove_signature%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_admin_new_signature_template') ? conikal_admin_new_signature_template() : '',
            ),
            array(
                'id'       => 'conikal_signup_notifications_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New user register subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of email template send for admin when have new user sign up.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('New User Sign Up %user_login%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_signup_notifications_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New user register template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for admin when have new user sign up.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %user_login%, %%user_email%, %user_first_name%, %user_last_name%, %user_pass%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_signup_notifications_template') ? conikal_signup_notifications_template() : '',
            ),
        )
    ) );

    // -> START Decision maker templates
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Decision maker templates', 'campoal-tapo'),
        'id'            => 'decision_maker_email_templates',
        'desc'          => esc_html__('Edit email notification template send for decision maker', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_decision_maker_new_petition_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New petition to decision maker subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new petition email send to decision maker.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('A new petition to you %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_decision_maker_new_petition_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New petition to decision maker template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for decision makers when have new petition.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %decision_name%, %%decision_position%, %decision_email%, %petition_title%, %petition_link%, %supporters_number%, %supporters_label%, %author_name%, %author_url%, %response_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_decision_maker_new_petition_template') ? conikal_decision_maker_new_petition_template() : '',
            ),
            array(
                'id'       => 'conikal_decision_maker_new_update_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New update to decision maker subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new update email send to decision maker.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('Petition to you has a new update %update_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_decision_maker_new_update_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New update to decision maker template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for decision maker when have new petition update.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %decision_name%, %%decision_position%, %decision_email%, %petition_title%, %petition_link%, %update_title%, %update_link%, %supporters_number%, %supporters_label%, %author_name%, %author_url%, %response_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_decision_maker_new_update_template') ? conikal_decision_maker_new_update_template() : '',
            ),
            array(
                'id'       => 'conikal_decision_maker_victory_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Petition victory subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of victory petition email send for decision maker.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('A petition to you declared victory %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_decision_maker_victory_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Petition victory template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for decision maker when petition declare victory.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %decision_name%, %%decision_position%, %decision_email%, %petition_title%, %petition_link%, %update_title%, %update_link%, %supporters_number%, %supporters_label%, %author_name%, %author_url%, %response_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_decision_maker_victory_template') ? conikal_decision_maker_victory_template() : '',
            ),
            array(
                'id'       => 'conikal_decision_maker_new_signature_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('New signature subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new signature email send for decision maker.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('New signature on %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_decision_maker_new_signature_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('New signature template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for decision maker when petition have new signature.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %decision_name%, %%decision_position%, %decision_email%, %petition_title%, %petition_link%, %update_title%, %update_link%, %supporters_number%, %supporters_label%, %author_name%, %author_url%, %response_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_decision_maker_new_signature_template') ? conikal_decision_maker_new_signature_template() : '',
            ),
            array(
                'id'       => 'conikal_decision_maker_signature_reached_subject_field',
                'type'     => 'text',
                'title'    => esc_html__('Signature milestone subject', 'campoal-tapo'),
                'subtitle' => esc_html__('Subject of new signature reached email send for decision maker.', 'campoal-tapo'),
                'desc'     => esc_html__('Text format only.', 'campoal-tapo'),
                'default'  => esc_html__('A petition to you just hit the new signature milestone %petition_title%', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_decision_maker_signature_reached_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Signature milestone template', 'campoal-tapo'),
                'subtitle' => esc_html__('Email template send for decision maker when petition reached new milestone signature.', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html code only and variables: %home_url%, %logo_url% ,%blog_name%, %decision_name%, %%decision_position%, %decision_email%, %petition_title%, %petition_link%, %supporters_number%, %supporters_label%, %author_name%, %author_url%, %response_link%, %main_color%, %heading_color%, %subheading_color%, %template_uri%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_decision_maker_signature_reached_template') ? conikal_decision_maker_signature_reached_template() : '',
            ),
            array(
                'id'       => 'conikal_decision_maker_percent_reached_field',
                'type'     => 'checkbox',
                'title'    => __('Signature milestones', 'campoal-tapo'), 
                'subtitle' => __('Send email to decision maker when signature reached a percent was selected.', 'campoal-tapo'),
                'desc'     => __('Check a percent option to sending email. Uncheck all to disabled feature.', 'campoal-tapo'),
        
                //Must provide key => value pairs for multi checkbox options
                'options'  => array(
                    10 => esc_html__('10%', 'campoal-tapo'),
                    20 => esc_html__('20%', 'campoal-tapo'),
                    40 => esc_html__('40%', 'campoal-tapo'),
                    50 => esc_html__('50%', 'campoal-tapo'),
                    60 => esc_html__('60%', 'campoal-tapo'),
                    70 => esc_html__('70%', 'campoal-tapo'),
                    80 => esc_html__('80%', 'campoal-tapo'),
                    90 => esc_html__('90%', 'campoal-tapo'),
                    100 => esc_html__('100%', 'campoal-tapo'),
                ),
        
                //See how default has changed? you also don't need to specify opts that are 0.
                'default' => array(
                    10 => 1, 
                    20 => 0, 
                    30 => 0,
                    40 => 0, 
                    50 => 1, 
                    60 => 0, 
                    70 => 0, 
                    80 => 0, 
                    90 => 1, 
                    100 => 0, 
                )
            )
        )
    ) );

    // -> START Embed Widget
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Embed widget', 'campoal-tapo'),
        'id'     => 'embed_code',
        'desc'   => esc_html__('Embed function provide for journalist or blogger embed a card into their articles via a iframe tag.', 'campoal-tapo'),
        'icon'   => 'el el-puzzle',
        'fields' => array(
            array(
                'id'       => 'conikal_embed_code_field',
                'type'     => 'switch',
                'title'    => esc_html__('Embed widget', 'campoal-tapo'),
                'subtitle' => esc_html__('Embed widget is a iframe tag allow journalist or blogger embed a card into their articles', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_embed_css_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Petition Embed CSS', 'campoal-tapo'),
                'subtitle' => esc_html__('This CSS define way the style of embed card look like. Use Codepen to edit the template', 'campoal-tapo') . ' <a href="https://codepen.io/pen/" target="_blank">' . esc_html__('codepen.io', 'campoal-tapo') . '</a>',
                'desc'     => esc_html__('Edit the style of embed card by CSS. Variable use in tempplate: %main_color%, %heading_color%, %caption_color%, %link_color%, %border_radius%, %label_radius%', 'campoal-tapo'),
                'mode'     => 'css',
                'default'  => function_exists('conikal_embed_css_template') ? conikal_embed_css_template() : '',
            ),
            array(
                'id'       => 'conikal_share_embed_css_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Share Embed CSS', 'campoal-tapo'),
                'subtitle' => esc_html__('This CSS define way the style of embed share section look like. Use Codepen to edit the template', 'campoal-tapo') . ' <a href="https://codepen.io/pen/" target="_blank">' . esc_html__('codepen.io', 'campoal-tapo') . '</a>',
                'desc'     => esc_html__('Edit the style of embed card by CSS. Variable use in tempplate: %main_color%, %heading_color%, %caption_color%, %link_color%, %border_radius%, %label_radius%', 'campoal-tapo'),
                'mode'     => 'css',
                'default'  => function_exists('conikal_share_embed_css_template') ? conikal_share_embed_css_template() : '',
            ),
        )
    ) );

    // -> START Petition embed templates
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Petition Embed', 'campoal-tapo'),
        'id'            => 'petition_embed_template',
        'desc'          => esc_html__('Edit style and html template for petition embed card.', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_embed_width_field',
                'type'     => 'text',
                'title'    => esc_html__('Embed width', 'campoal-tapo'),
                'subtitle' => esc_html__('Width of campaign embed card.', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only. Unit by pixel (px).', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 380
            ),
            array(
                'id'       => 'conikal_embed_height_field',
                'type'     => 'text',
                'title'    => esc_html__('Embed height', 'campoal-tapo'),
                'subtitle' => esc_html__('Height of campaign embed card.', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only. Unit by pixel (px).', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 560
            ),
            array(
                'id'       => 'conikal_embed_html_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Petition Embed HTML', 'campoal-tapo'),
                'subtitle' => esc_html__('This HTML define way the layout of embed card look like. Use Codepen to edit the template', 'campoal-tapo') . ' <a href="https://codepen.io/pen/" target="_blank">' . esc_html__('codepen.io', 'campoal-tapo') . '</a>',
                'desc'     => esc_html__('Edit the HTML if you want to change the embed card layout. Variable use in tempplate: %petition_title%, %petition_thumbnail%, %petition_link%, %petition_location%, %counter_view%, %petition_receiver%, %petition_description%, %author_link%, %author_name%, %author_avatar%, %counter_supporter%, %counter_comment%, %sign_text%, %sign_percent%, %petition_status%, %supporter_label%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_embed_html_template') ? conikal_embed_html_template() : '',
            ),
        )
    ) );

    // -> START Fundraising embed templates
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Fundraising Embed', 'campoal-tapo'),
        'id'            => 'fundraising_embed_template',
        'desc'          => esc_html__('Edit style and html template for petition embed card.', 'campoal-tapo') . ' <a href="https://codepen.io/pen/" target="_blank">' . esc_html__('codepen.io', 'campoal-tapo') . '</a>',
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_give_embed_width_field',
                'type'     => 'text',
                'title'    => esc_html__('Embed width', 'campoal-tapo'),
                'subtitle' => esc_html__('Width of campaign embed card.', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only. Unit by pixel (px).', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 380
            ),
            array(
                'id'       => 'conikal_give_embed_height_field',
                'type'     => 'text',
                'title'    => esc_html__('Embed height', 'campoal-tapo'),
                'subtitle' => esc_html__('Height of campaign embed card.', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only. Unit by pixel (px).', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 620
            ),
            array(
                'id'       => 'conikal_give_embed_html_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Fundraising Embed HTML', 'campoal-tapo'),
                'subtitle' => esc_html__('This HTML define way the layout of embed card look like. Use Codepen to edit the template', 'campoal-tapo') . ' <a href="https://codepen.io/pen/" target="_blank">' . esc_html__('codepen.io', 'campoal-tapo') . '</a>',
                'desc'     => esc_html__('Edit the HTML if you want to change the embed card layout. Variable use in tempplate: %campaign_title%, %campaign_thumbnail%, %campaign_link%, %campaign_location%, %campaign_description%, %author_link%, %author_name%, %author_avatar%, %counter_view%, %counter_backer%, %counter_comment%, %button_label%, %fund_goal%, %fund_raised%, %fund_needed%, %fund_goal_label%, %fund_goal_label%, %fund_raised_label%, %fund_needed_label%,', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_embed_html_template') ? conikal_give_embed_html_template() : '',
            ),
        )
    ) );

    // -> START Share embed templates
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Share Embed', 'campoal-tapo'),
        'id'            => 'share_embed_template',
        'desc'          => esc_html__('Edit style and html template for sharing petition section.', 'campoal-tapo') . ' <a href="https://codepen.io/pen/" target="_blank">' . esc_html__('codepen.io', 'campoal-tapo') . '</a>',
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_share_embed_width_field',
                'type'     => 'text',
                'title'    => esc_html__('Embed width', 'campoal-tapo'),
                'subtitle' => esc_html__('Width of share embed.', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only. Unit by pixel (px).', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 500
            ),
            array(
                'id'       => 'conikal_share_embed_height_field',
                'type'     => 'text',
                'title'    => esc_html__('Embed height', 'campoal-tapo'),
                'subtitle' => esc_html__('Height of share embed.', 'campoal-tapo'),
                'desc'     => esc_html__('Number format only. Unit by pixel (px).', 'campoal-tapo'),
                'validate' => 'numeric',
                'default'  => 320
            ),
            array(
                'id'       => 'conikal_share_embed_button_icon_field',
                'type'     => 'media',
                'title'    => esc_html__('Primary button icon', 'campoal-tapo'),
                'subtitle' => esc_html__('The icon display on primary share button of sharing embed widget.', 'campoal-tapo'),
                'desc'     => esc_html__('Upload square image icon by PNGo or JPG format only.', 'campoal-tapo'),
                'url'      => true,
                'preview'  => true,
            ),
            array(
                'id'       => 'conikal_share_embed_html_template_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Share Embed HTML', 'campoal-tapo'),
                'subtitle' => esc_html__('This HTML define way the layout of share section look like. Use Codepen to edit the template', 'campoal-tapo') . ' <a href="https://codepen.io/pen/" target="_blank">' . esc_html__('codepen.io', 'campoal-tapo') . '</a>',
                'desc'     => esc_html__('Edit the HTML if you want to change the embed share layout. Variable use in tempplate: %petition_title%, %petition_thumbnail%, %petition_link%, %petition_location%, %counter_view%, %petition_receiver%, %petition_description%, %author_link%, %author_name%, %author_avatar%, %counter_supporter%, %counter_comment%, %sign_text%, %sign_percent%, %petition_status%, %supporter_label%, %shorten_link%, %primary_share_url%, %primary_share_label%, %primary_button_icon%', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => function_exists('conikal_share_embed_html_template') ? conikal_share_embed_html_template() : '',
            ),
        )
    ) );

    // -> START Ads Banner
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Ads Banner', 'campoal-tapo'),
        'id'     => 'ads_banner',
        'desc'   => esc_html__('Add ads banner to your website with code.', 'campoal-tapo'),
        'icon'   => 'el el-bullhorn',
        'fields' => array(
            array(
                'id'       => 'conikal_ads_banner_field',
                'type'     => 'switch',
                'title'    => esc_html__('Ads banner', 'campoal-tapo'),
                'subtitle' => esc_html__('Enabble show banners on website', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_adsense_publish_id_field',
                'type'     => 'text',
                'title'    => esc_html__('Google Adsense Publish ID', 'campoal-tapo'),
                'subtitle' => esc_html__('Google Adsense Publish ID use to embed html tag on site.', 'campoal-tapo'),
                'desc'     => esc_html__('Example: pub-123123123123123', 'campoal-tapo'),
                'default'  => '',
            ),
        ),
    ) );

    // -> START single petition
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Single petition', 'campoal-tapo'),
        'id'            => 'banner_single_petition',
        'desc'          => esc_html__('Show ads banner on single petition ', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_single_petition_banner_1_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Banner 1', 'campoal-tapo'),
                'subtitle' => esc_html__('Banner display on head of single petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('Banner size recommended: 728 x 90.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => '',
            ),
            array(
                'id'       => 'conikal_single_petition_banner_2_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Banner 2', 'campoal-tapo'),
                'subtitle' => esc_html__('Banner display on below petition content.', 'campoal-tapo'),
                'desc'     => esc_html__('Banner size recommended: 468 x 60.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => '',
            ),
            array(
                'id'       => 'conikal_single_petition_banner_3_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Banner 3', 'campoal-tapo'),
                'subtitle' => esc_html__('Banner display on foot of single petition page.', 'campoal-tapo'),
                'desc'     => esc_html__('Banner size recommended: 970 x 90.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => '',
            ),
        )
    ) );

    // -> START single post
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Single post', 'campoal-tapo'),
        'id'            => 'banner_single_post',
        'desc'          => esc_html__('Show ads banner on single post ', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_single_post_banner_1_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Banner 1', 'campoal-tapo'),
                'subtitle' => esc_html__('Banner display on head of post content.', 'campoal-tapo'),
                'desc'     => esc_html__('Banner size recommended: 468 x 60.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => '',
            ),
            array(
                'id'       => 'conikal_single_post_banner_2_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Banner 2', 'campoal-tapo'),
                'subtitle' => esc_html__('Banner display on below post content.', 'campoal-tapo'),
                'desc'     => esc_html__('Banner size recommended: 468 x 60.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => '',
            ),
            array(
                'id'       => 'conikal_single_post_banner_3_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Banner 3', 'campoal-tapo'),
                'subtitle' => esc_html__('Banner display on right sticky sidebar.', 'campoal-tapo'),
                'desc'     => esc_html__('Banner size recommended: 160 x 600.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => '',
            ),
            array(
                'id'       => 'conikal_single_post_banner_4_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Banner 4', 'campoal-tapo'),
                'subtitle' => esc_html__('Banner display on foot of single post.', 'campoal-tapo'),
                'desc'     => esc_html__('Banner size recommended: 970 x 90.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => '',
            ),
        )
    ) );

    // -> START success page
    Redux::set_section( $opt_name, array(
        'title'         => esc_html__('Success page', 'campoal-tapo'),
        'id'            => 'banner_success_page',
        'desc'          => esc_html__('Show ads banner on sucess page ', 'campoal-tapo'),
        'subsection'    => true,
        'fields' => array(
            array(
                'id'       => 'conikal_success_page_banner_1_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Banner 1', 'campoal-tapo'),
                'subtitle' => esc_html__('Banner display on head of sucess page.', 'campoal-tapo'),
                'desc'     => esc_html__('Banner size recommended: 970 x 90.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => '',
            ),
            array(
                'id'       => 'conikal_success_page_banner_2_field',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Banner 2', 'campoal-tapo'),
                'subtitle' => esc_html__('Banner display on foot of sucess page.', 'campoal-tapo'),
                'desc'     => esc_html__('Banner size recommended: 970 x 90.', 'campoal-tapo'),
                'mode'     => 'html',
                'default'  => '',
            ),
        )
    ) );

    // -> START Authentication
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Authentication', 'campoal-tapo'),
        'id'     => 'authentication',
        'desc'   => esc_html__('Set key to third party service intergrated', 'campoal-tapo'),
        'icon'   => 'el el-key',
        'fields' => array(
            array(
                'id'       => 'conikal_google_api_key_field',
                'type'     => 'text',
                'title'    => esc_html__('Google API key', 'campoal-tapo'),
                'subtitle' => esc_html__('Google API key using for Google Place Autocomplete and Google Fonts', 'campoal-tapo'),
                'desc'     => esc_html__('We strongly encourage you to load the Google Maps using an APIs Console key. You can get it from ', 'campoal-tapo') . '<a href="//developers.google.com/maps/documentation/javascript/tutorial#api_key">' . esc_html__('here', 'campoal-tapo') . '</a>',
                'validate' => 'no_html',
            ),
            array(
                'id'       => 'conikal_google_place_types_field',
                'type'     => 'radio',
                'title'    => esc_html__('Place Autocomplete Types', 'campoal-tapo'), 
                'subtitle' => esc_html__('Choose types of predictions that the autocomplete returns.', 'campoal-tapo'),
                'data'  => array(
                    'address'       => esc_html__('Address', 'campoal-tapo'), 
                    'geocode'       => esc_html__('Geocode', 'campoal-tapo'), 
                    '(cities)'      => esc_html__('Cities', 'campoal-tapo'), 
                    '(regions)'     => esc_html__('Regions', 'campoal-tapo'), 
                    'establishment' => esc_html__('Establishment', 'campoal-tapo'), 
                ),
                'default' => 'address'
            )
        )
    ) );

    // -> START Facebook login
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Facebook Login', 'campoal-tapo'),
        'id'     => 'facebook_login',
        'desc'   => esc_html__('Set the App ID, secret and version for Facebook App', 'campoal-tapo'),
        'subsection'   => true,
        'fields' => array(
            array(
                'id'       => 'conikal_fb_login_field',
                'type'     => 'switch',
                'title'    => esc_html__('Facebook Login', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow new user login via Facebook account', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_fb_version_field',
                'type'     => 'text',
                'title'    => esc_html__('Facebook App version', 'campoal-tapo'),
                'subtitle' => esc_html__('Version of Facebook App correct with App version on developer dashboard', 'campoal-tapo'),
                'desc'     => esc_html__('Version eg. v3.1', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'v3.1',
            ),
            array(
                'id'       => 'conikal_fb_id_field',
                'type'     => 'text',
                'title'    => esc_html__('Facebook App ID', 'campoal-tapo'),
                'subtitle' => esc_html__('ID of Facebook App from developer dasbboard', 'campoal-tapo'),
                'desc'     => esc_html__('How to create a Facebook App. Please read the tutorial: ', 'campoal-tapo') . '<a href="//developers.facebook.com/docs/apps/">' . esc_html__('App Development', 'campoal-tapo') . '</a>',
                'validate' => 'no_html',
            ),
            array(
                'id'       => 'conikal_fb_secret_field',
                'type'     => 'text',
                'title'    => esc_html__('Facebook App Secret', 'campoal-tapo'),
                'subtitle' => esc_html__('Secret of Facebook App from developer dasbboard', 'campoal-tapo'),
                'desc'     => esc_html__('How to get Facebook App secret. Please read the tutorial: ', 'campoal-tapo') . '<a href="//developers.facebook.com/docs/apps/">' . esc_html__('App Development', 'campoal-tapo') . '</a>',
                'validate' => 'no_html',
            ),
        )
    ) );


    // -> START Google signin
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Google Signin', 'campoal-tapo'),
        'id'     => 'google_signin',
        'desc'   => esc_html__('Set the Client ID and Secret for Google API ', 'campoal-tapo'),
        'subsection'   => true,
        'fields' => array(
            array(
                'id'       => 'conikal_google_login_field',
                'type'     => 'switch',
                'title'    => esc_html__('Google Signin', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow new user login via Google+ account', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_google_id_field',
                'type'     => 'text',
                'title'    => esc_html__('Google Client ID', 'campoal-tapo'),
                'subtitle' => esc_html__('Client ID of Google API on developer console', 'campoal-tapo'),
                'desc'     => esc_html__('Known more Google API and OAuth 2.0. Please read referent: ', 'campoal-tapo') . '<a href="//developers.google.com/identity/protocols/OAuth2" target="_blank">' . esc_html__('Google OAuth 2.0', 'campoal-tapo') . '</a>',
                'validate' => 'no_html',
            ),
            array(
                'id'       => 'conikal_google_secret_field',
                'type'     => 'text',
                'title'    => esc_html__('Google Client Secret', 'campoal-tapo'),
                'subtitle' => esc_html__('Client Secret of Google API on developer console', 'campoal-tapo'),
                'desc'     => esc_html__('Known more Google API and OAuth 2.0. Please read referent: ', 'campoal-tapo') . '<a href="//developers.google.com/identity/protocols/OAuth2" target="_blank">' . esc_html__('Google OAuth 2.0', 'campoal-tapo') . '</a>',
                'validate' => 'no_html',
            ),
        )
    ) );

    // -> START Twitter
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Twitter API', 'campoal-tapo'),
        'id'     => 'twitter_api',
        'desc'   => esc_html__('Set twitter API and username for login and get analytics.', 'campoal-tapo'),
        'subsection'   => true,
        'fields' => array(
            array(
                'id'       => 'conikal_twitter_username_field',
                'type'     => 'text',
                'title'    => esc_html__('Twitter username', 'campoal-tapo'),
                'subtitle' => esc_html__('Set username to use more tools from Twitter', 'campoal-tapo'),
                'desc'     => esc_html__('Twitter recommends using that contains the Twitter username that you want associated with the shared Web page', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => '@conikal',
            ),
        )
    ) );

    // -> START SendinBlue
    $sendinblue_affiliate_key = '?tap_a=30591-fb13f0&tap_s=327307-2c92bf';
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Brevo Mail', 'campoal-tapo'),
        'id'     => 'sendinblue',
        'desc'   => esc_html__('Set API key, folder ID and fields name for Brevo mail', 'campoal-tapo'),
        'subsection'   => true,
        'fields' => array(
            array(
                'id'       => 'conikal_sendinblue_list_field',
                'type'     => 'switch',
                'title'    => esc_html__('Brevo Save List', 'campoal-tapo'),
                'subtitle' => esc_html__('Allow auto create new Brevo list and save supporters email to list', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_sendinblue_key_field',
                'type'     => 'text',
                'title'    => esc_html__('Brevo API key v3', 'campoal-tapo'),
                'subtitle' => esc_html__('API key version 3 from Brevo Dashboad', 'campoal-tapo'),
                'desc'     => esc_html__('Please ', 'campoal-tapo') . '<a href="//get.brevo.com/register" target="_blank">' . esc_html__('Register Brevo account', 'campoal-tapo') . '</a>' . esc_html__(' then access to ', 'campoal-tapo') . '<a href="//get.brevo.com/smtp-api" target="_blank">' . esc_html__('SMTP & API', 'campoal-tapo') . '</a>' . esc_html__(' page while login to get API Key.', 'campoal-tapo'),
                'validate' => 'no_html',
            ),
            // array(
            //     'id'       => 'conikal_sendinblue_folder_id_field',
            //     'type'     => 'select',
            //     'title'    => esc_html__('Brevo Folder ID', 'campoal-tapo'),
            //     'desc'     => esc_html__('To get Folder ID, please access to ', 'campoal-tapo') . '<a href="//my.sendinblue.com/list/' . esc_attr($sendinblue_affiliate_key) . '" target="_blank">' . esc_html__('Lists Page', 'campoal-tapo') . '</a>' . esc_html__(' while login then select your folder and see on address bar /lists/index/id/<Folder ID>.', 'campoal-tapo'),
            //     'subtitle' => esc_html__('ID of folder Brevo where contains email lists', 'campoal-tapo'),
            //     'options'  => get_option('campoal_sendinblue_folder_options'),
            //     'default'  => 1,
            // ),
            array(
                'id'       => 'conikal_sendinblue_folder_id_field',
                'type'     => 'text',
                'title'    => esc_html__('Brevo Folder ID', 'campoal-tapo'),
                'subtitle' => esc_html__('ID of folder Brevo where contains email lists', 'campoal-tapo'),
                'desc'     => esc_html__('To get Folder ID, please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/folder-api" target="_blank">' . esc_html__('Folder API Document', 'campoal-tapo') . '</a>' . esc_html__(' and paste API key to Authorization field then click on Try it button.', 'campoal-tapo'),
                'validate' => 'numeric',
            ),
            array(
                'id'       => 'conikal_sendinblue_newsletter_list_id_field',
                'type'     => 'text',
                'title'    => esc_html__('Newsletter list ID', 'campoal-tapo'),
                'subtitle' => esc_html__('List ID where contains emails for newsletters', 'campoal-tapo'),
                'desc'     => esc_html__('To get List ID, please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/list" target="_blank">' . esc_html__('Lists Page', 'campoal-tapo') . '</a>' . esc_html__(' while login then copy list ID on ID column.', 'campoal-tapo'),
                'validate' => 'numeric',
            ),
            array(
                'id'       => 'conikal_sendinblue_sender_name_field',
                'type'     => 'text',
                'title'    => esc_html__('Brevo Sender Name', 'campoal-tapo'),
                'subtitle' => esc_html__('The name display when sending email from Brevo to supporters', 'campoal-tapo'),
                'desc'     => esc_html__('Enter your name display on email send to supporters', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => get_bloginfo(),
            ),
            array(
                'id'       => 'conikal_sendinblue_sender_email_field',
                'type'     => 'text',
                'title'    => esc_html__('Brevo Sender Email', 'campoal-tapo'),
                'subtitle' => esc_html__('Email send from Brevo to supporters', 'campoal-tapo'),
                'desc'     => esc_html__('To get and create sender, please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/sender" target="_blank">' . esc_html__('Senders Page', 'campoal-tapo') . '</a>' . esc_html__(' while login then copy email and paste to this box.', 'campoal-tapo'),
                'validate' => 'email',
            ),
            array(
                'id'       => 'conikal_sendinblue_name_field',
                'type'     => 'text',
                'title'    => esc_html__('Contact Name attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact9234" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'NAME',
            ),
            array(
                'id'       => 'conikal_sendinblue_firstname_field',
                'type'     => 'text',
                'title'    => esc_html__('First Name attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact9234" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'FIRSTNAME',
            ),
            array(
                'id'       => 'conikal_sendinblue_sms_field',
                'type'     => 'text',
                'title'    => esc_html__('SMS attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'SMS',
            ),
            array(
                'id'       => 'conikal_sendinblue_id_field',
                'type'     => 'text',
                'title'    => esc_html__('User ID attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'USER_ID',
            ),
            array(
                'id'       => 'conikal_sendinblue_gender_field',
                'type'     => 'text',
                'title'    => esc_html__('Gender attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'GENDER',
            ),
            array(
                'id'       => 'conikal_sendinblue_birthday_field',
                'type'     => 'text',
                'title'    => esc_html__('Birthday attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'BIRTHDAY',
            ),
            array(
                'id'       => 'conikal_sendinblue_location_field',
                'type'     => 'text',
                'title'    => esc_html__('Location attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'LOCATION',
            ),
            array(
                'id'       => 'conikal_sendinblue_neigborhood_field',
                'type'     => 'text',
                'title'    => esc_html__('Neigborhood attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'NEIGBORHOOD',
            ),
            array(
                'id'       => 'conikal_sendinblue_city_field',
                'type'     => 'text',
                'title'    => esc_html__('City attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'CITY',
            ),
            array(
                'id'       => 'conikal_sendinblue_state_field',
                'type'     => 'text',
                'title'    => esc_html__('State attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'STATE',
            ),
            array(
                'id'       => 'conikal_sendinblue_country_field',
                'type'     => 'text',
                'title'    => esc_html__('Country attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'COUNTRY',
            ),
            array(
                'id'       => 'conikal_sendinblue_zip_field',
                'type'     => 'text',
                'title'    => esc_html__('Zip code attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'ZIP',
            ),
            array(
                'id'       => 'conikal_sendinblue_lat_field',
                'type'     => 'text',
                'title'    => esc_html__('Latitude attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'LATITUDE',
            ),
            array(
                'id'       => 'conikal_sendinblue_lng_field',
                'type'     => 'text',
                'title'    => esc_html__('Longitude attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'LONGITUDE',
            ),
            array(
                'id'       => 'conikal_sendinblue_ip_field',
                'type'     => 'text',
                'title'    => esc_html__('IP address attribute', 'campoal-tapo'),
                'subtitle' => esc_html__('Enter your custom attribute for contact you created in setting.', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'IP',
            ),
            array(
                'id'       => 'conikal_sendinblue_opt_in_field',
                'type'     => 'switch',
                'title'    => esc_html__('Brevo OPT-IN', 'campoal-tapo'),
                'subtitle' => esc_html__("Verify user's email before add contact to Brevo.", 'campoal-tapo'),
                'desc'     => esc_html__('Disable if you want to add contacts to SendinBlue without confirmation.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_sendinblue_opt_in_name_field',
                'type'     => 'text',
                'title'    => esc_html__('Brevo OPT-IN name field', 'campoal-tapo'),
                'subtitle' => esc_html__('In the different language Brevo has different OPT-IN field, so you need correct it', 'campoal-tapo'),
                'desc'     => esc_html__('Please access to ', 'campoal-tapo') . '<a href="//get.brevo.com/contact923" target="_blank">' . esc_html__('Contact Page', 'campoal-tapo') . '</a>' . esc_html__(' while login to see the field name, it is label of column.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'DOUBLE_OPT-IN',
            ),
            array(
                'id'       => 'conikal_sendinblue_doi_template_field',
                'type'     => 'text',
                'title'    => esc_html__('Double opt-in template ID', 'campoal-tapo'),
                'subtitle' => esc_html__('Template used to send Double opt-in emails to users.', 'campoal-tapo'),
                'desc'     => esc_html__('Click here to learn how to ', 'campoal-tapo') . '<a href="https://get.brevo.com/opt-in" target="_blank">' . esc_html__('create a new opt-in template', 'campoal-tapo') . '</a>' . esc_html__(' and paste the template id into this field.', 'campoal-tapo'),
                'validate' => 'numeric',
            ),
            array(
                'id'       => 'conikal_sendinblue_doi_redirect_url_field',
                'type'     => 'select',
                'title'    => esc_html__('Double opt-in redirect URL', 'campoal-tapo'),
                'subtitle' => esc_html__('URL of the web page that user will be redirected to after clicking on the double opt in URL.', 'campoal-tapo'),
                'desc'     => esc_html__('When editing your DOI template you can reference this URL by using the tag {{ params.DOIurl }}.', 'campoal-tapo'),
                'options'  => conikal_get_all_pages(),
                'default'  => function_exists('conikal_get_page_id_by_template') ? conikal_get_page_id_by_template('email-confirmation.php') : '',
            ),
            array(
                'id'       => 'conikal_sendinblue_force_add_field',
                'type'     => 'switch',
                'title'    => esc_html__('Brevo force add', 'campoal-tapo'),
                'subtitle' => esc_html__("Force add supporter's email to email list on Brevo.", 'campoal-tapo'),
                'desc'     => esc_html__('Always add users to the email list on Sendinblue whatever uncheck box of receiving updates', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_sendinblue_update_supporters_field',
                'type'     => 'switch',
                'title'    => esc_html__('Subscribers to supporters', 'campoal-tapo'),
                'subtitle' => esc_html__("Get subscribers of list and update to supporters number", 'campoal-tapo'),
                'desc'     => esc_html__('Enable to update contact number of email list to supporters number to avoid duplicate contact number.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_sendinblue_header_email_field',
                'type'     => 'editor',
                'title'    => esc_html__('Email header', 'campoal-tapo'),
                'subtitle' => esc_html__('The text show below on register and sign petition form', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html tags.', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5,
                ),
                'default'  => __('If you are not able to see this mail, click {here}', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_sendinblue_footer_email_field',
                'type'     => 'editor',
                'title'    => esc_html__('Email footer', 'campoal-tapo'),
                'subtitle' => esc_html__('The text show below on register and sign petition form', 'campoal-tapo'),
                'desc'     => esc_html__('Allowed html tags.', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5,
                ),
                'default'  => __('If you are not able to see this mail, click {here}', 'campoal-tapo'),
            ),
        )
    ) );

    // -> START Bitly shorten
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Bitly Short URL', 'campoal-tapo'),
        'id'     => 'bitly',
        'desc'   => esc_html__('Set API key for Bit.ly short URL service', 'campoal-tapo'),
        'subsection'   => true,
        'fields' => array(
            array(
                'id'       => 'conikal_bitly_field',
                'type'     => 'switch',
                'title'    => esc_html__('Bitly Short URL', 'campoal-tapo'),
                'subtitle' => esc_html__('Bitly allows you to easily shorten, share, manage, and analyze your favorite links.', 'campoal-tapo'),
                'desc'     => esc_html__('Switch between enabled or disabled.', 'campoal-tapo'),
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_bitly_access_token_field',
                'type'     => 'text',
                'title'    => esc_html__('Bitly Access Token', 'campoal-tapo'),
                'subtitle' => esc_html__('Access token of your Bitly account to use short url', 'campoal-tapo'),
                'desc'     => esc_html__('Get Access token by way login your Bitly account then access to Generic Access Token.', 'campoal-tapo'),
                'validate' => 'no_html',
            ),
            array(
                'id'       => 'conikal_bitly_domain_field',
                'type'     => 'text',
                'title'    => esc_html__('Bitly Domain', 'campoal-tapo'),
                'subtitle' => esc_html__('Premium domain replace free domain bit.ly', 'campoal-tapo'),
                'desc'     => esc_html__('Upgrade your Bitly account to take premium domain you want use.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'bit.ly',
            ),
            array(
                'id'       => 'conikal_bitly_group_guid_field',
                'type'     => 'text',
                'title'    => esc_html__('Bitly Group GUID', 'campoal-tapo'),
                'subtitle' => esc_html__('Groups to organize your links and users', 'campoal-tapo'),
                'desc'     => esc_html__('Upgrade your Bitly account and create a group from Settings > Group.', 'campoal-tapo'),
                'validate' => 'no_html',
                'default'  => 'bit.ly',
            ),
        )
    ) );

    // -> START Google reCapcha
    Redux::set_section( $opt_name, array(
        'title'  => esc_html__('Google reCAPTCHA', 'campoal-tapo'),
        'id'     => 'google_recaptcha',
        'desc'   => esc_html__('Enable and set API key for Google reCAPTCHA', 'campoal-tapo'),
        'subsection'   => true,
        'fields' => array(
            array(
                'id'       => 'conikal_google_recaptcha_field',
                'type'     => 'switch',
                'title'    => esc_html__('Google reCAPTCHA v3', 'campoal-tapo'),
                'subtitle' => esc_html__('Google reCAPTCHA protects you against spam and other types of automated abuse.', 'campoal-tapo'),
                'desc'     => esc_html__('If you do not know what is Google reCAPTCHA. Please learn more about it in here', 'campoal-tapo') . ' <a href="//www.google.com/recaptcha/">' . esc_html__('here', 'campoal-tapo') . '</a>',
                'on'       => esc_html__('Enabled', 'campoal-tapo'),
                'off'      => esc_html__('Disabled', 'campoal-tapo'),
                'default'  => false,
            ),
            array(
                'id'       => 'conikal_google_recaptcha_key_field',
                'type'     => 'text',
                'title'    => esc_html__('Site Key', 'campoal-tapo'),
                'subtitle' => esc_html__('Site key use to serves to users on your site', 'campoal-tapo'),
                'desc'     => esc_html__('Enter site key. If you do not have a key yet, to create them please visit', 'campoal-tapo') . ' <a href="//www.google.com/recaptcha/admin/">' . esc_html__('here', 'campoal-tapo') . '</a>',
                'validate' => 'no_html',
            ),
            array(
                'id'       => 'conikal_google_recaptcha_secret_field',
                'type'     => 'text',
                'title'    => esc_html__('Secret key', 'campoal-tapo'),
                'subtitle' => esc_html__('Secret key use to communication with reCAPTCHA', 'campoal-tapo'),
                'desc'     => esc_html__('Enter site key. If you do not have a key yet, to create them please visit', 'campoal-tapo') . ' <a href="//www.google.com/recaptcha/admin/">' . esc_html__('here', 'campoal-tapo') . '</a>',
                'validate' => 'no_html',
            ),
            array(
                'id'       => 'conikal_google_recaptcha_position_field',
                'type'     => 'select',
                'title'    => esc_html__('Position badge', 'campoal-tapo'),
                'subtitle' => esc_html__('Reposition the reCAPTCHA badge', 'campoal-tapo'),
                'desc'     => esc_html__('"inline" lets you position it with CSS.', 'campoal-tapo'),
                'options'  => array(
                    'hidden' => esc_html__('Hidde and show text', 'campoal-tapo'),
                    'bottomright ' => esc_html__('Bottom Right', 'campoal-tapo'),
                    'bottomleft' => esc_html__('Bottom Left', 'campoal-tapo'),
                    'inline' => esc_html__('Inline', 'campoal-tapo'),
                ),
                'default'  => 'hidden',
            ),
            array(
                'id'       => 'conikal_google_recaptcha_text_field',
                'type'     => 'editor',
                'title'    => esc_html__('reCaptcha text', 'campoal-tapo'),
                'subtitle' => esc_html__('Show text instead badge.', 'campoal-tapo'),
                'desc'     => esc_html__('Include the reCAPTCHA branding visibly in the user flow in case the badge is hidden.', 'campoal-tapo'),
                'wpautop'  => false,
                'media_buttons' => false,
                'dfw'      => true,
                'args'     => array(
                    'teeny'            => true,
                    'textarea_rows'    => 3,
                ),
                'default'  => __('This site is protected by reCAPTCHA and the Google <a href="https://policies.google.com/privacy">Privacy Policy</a> and <a href="https://policies.google.com/terms">Terms of Service</a> apply.', 'campoal-tapo'),
            ),
            array(
                'id'       => 'conikal_google_recaptcha_login_field',
                'type'     => 'switch',
                'title'    => esc_html__('Login & Register', 'campoal-tapo'),
                'subtitle' => esc_html__('Display Google reCAPTCHA on Login and Register form', 'campoal-tapo'),
                'desc'     => esc_html__('Google reCAPTCHA will be display on Login and Register form.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_google_recaptcha_forgot_password_field',
                'type'     => 'switch',
                'title'    => esc_html__('Forgot Password', 'campoal-tapo'),
                'subtitle' => esc_html__('Display Google reCAPTCHA on Forgot Password and Reset Pssword.', 'campoal-tapo'),
                'desc'     => esc_html__('Google reCAPTCHA will be display on forgot password and reset password form.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_google_recaptcha_contact_field',
                'type'     => 'switch',
                'title'    => esc_html__('Contact form', 'campoal-tapo'),
                'subtitle' => esc_html__('Display Google reCAPTCHA on Contact form.', 'campoal-tapo'),
                'desc'     => esc_html__('Google reCAPTCHA will be display on contact form, people need passed reCAPTCHA when sent an email.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_google_recaptcha_submit_petition_field',
                'type'     => 'switch',
                'title'    => esc_html__('Submit Petition', 'campoal-tapo'),
                'subtitle' => esc_html__('Display Google reCAPTCHA on Submit Petition and Project page.', 'campoal-tapo'),
                'desc'     => esc_html__('Google reCAPTCHA will be display on submit petition page, people need passed reCAPTCHA when submit petition and project.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_google_recaptcha_sign_field',
                'type'     => 'switch',
                'title'    => esc_html__('Sign Petition', 'campoal-tapo'),
                'subtitle' => esc_html__('Display Google reCAPTCHA on Sign Petition section.', 'campoal-tapo'),
                'desc'     => esc_html__('Google reCAPTCHA will be display on sign petition section, people need passed reCAPTCHA when sign a petition.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
            array(
                'id'       => 'conikal_google_recaptcha_comment_field',
                'type'     => 'switch',
                'title'    => esc_html__('Commment', 'campoal-tapo'),
                'subtitle' => esc_html__('Display Google reCAPTCHA on Commment box.', 'campoal-tapo'),
                'desc'     => esc_html__('Google reCAPTCHA will be display on Commment box, people need passed reCAPTCHA when send a Commment.', 'campoal-tapo'),
                'on'       => esc_html__('Show', 'campoal-tapo'),
                'off'      => esc_html__('Hidden', 'campoal-tapo'),
                'default'  => true,
            ),
        )
    ) );

    /*
     * <--- END SECTIONS
     */
